@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: autocompletion.php 7938 2009-02-02 21:10:12Z moyo $
+ * @version $Id: autocompletion.php 8147 2009-04-10 14:29:52Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -36,7 +36,7 @@
 
 define('GLPI_ROOT','..');
 // Include plugin if it is a plugin table
-if (!ereg("plugin",$_POST['table'])){
+if (!strstr($_POST['table'],"plugin")){
 	$AJAX_INCLUDE=1;
 }
 include (GLPI_ROOT."/inc/includes.php");
@@ -55,13 +55,37 @@ if (isset($_POST['entity_restrict'])&&$_POST['entity_restrict']>=0&&in_array($_P
 	$entity=" AND FK_entities='".$_POST['entity_restrict']."' ";
 }
 
-$query="SELECT DISTINCT `".$_POST['field']."` AS VAL FROM `".$_POST['table']."` WHERE `".$_POST['field']."` LIKE '".$_POST[$_POST['myname']]."%' AND `".$_POST['field']."` <> '".$_POST[$_POST['myname']]."' $entity ORDER BY `".$_POST['field']."` LIMIT 0,20";
+if (isset($_POST['user_restrict'])&&$_POST['user_restrict']>0){
+	$entity=" AND FK_users='".$_POST['user_restrict']."' ";
+}
+
+$query="SELECT COUNT(`".$_POST['field']."`) 
+	FROM `".$_POST['table']."` 
+	WHERE `".$_POST['field']."` LIKE '".$_POST['query']."%' 
+		AND `".$_POST['field']."` <> '".$_POST['query']."' $entity ";
+$result=$DB->query($query);
+$totnum=$DB->result($result,0,0);
+
+
+$query="SELECT DISTINCT `".$_POST['field']."` AS VAL 
+	FROM `".$_POST['table']."` 
+	WHERE `".$_POST['field']."` LIKE '".$_POST['query']."%' AND `".$_POST['field']."` <> '".$_POST['query']."' $entity 
+	ORDER BY `".$_POST['field']."` LIMIT ".intval($_POST['start']).",".intval($_POST['limit']);
+
+
 if ($result=$DB->query($query))
+	echo '{"totalCount":"'.$totnum.'","items":[';
 	if ($DB->numrows($result)>0){
-		echo "<ul class='autocomp'>";
-		while ($data=$DB->fetch_array($result))
-			echo "<li class='autocomp'>".cleanInputText($data["VAL"])."</li>";
-		echo "</ul>";
+		$first=true;
+		while ($data=$DB->fetch_array($result))	{
+			if ($first){
+				$first=false;
+			} else {
+				echo ',';
+			}
+			echo '{"value":"'.$data['VAL'].'"}';
+		}
 	}
+	echo ']}';
 
 ?>
