@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: comments.php 7938 2009-02-02 21:10:12Z moyo $
+ * @version $Id: comments.php 8708 2009-08-14 09:34:02Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -43,12 +43,13 @@ header_nocache();
 
 checkLoginUser();
 
-// Security
-if (! TableExists($_POST['table']) ){
-	exit();
-}
+if (isset($_POST["table"]) && isset($_POST["value"])) {	
 
-if (isset($_POST["table"])&&isset($_POST["value"])){	
+   // Security
+   if (! TableExists($_POST['table']) ){
+      exit();
+   }
+   
 	switch ($_POST["table"]){
 		case "glpi_users":
 			if ($_POST['value']==0){
@@ -61,7 +62,7 @@ if (isset($_POST["table"])&&isset($_POST["value"])){
 
 			if (isset($_POST['withlink'])){
 				echo "<script type='text/javascript' >\n";
-				echo "\$('".$_POST['withlink']."').href='".$tmpname['link']."';";
+				echo "	Ext.get('".$_POST['withlink']."').dom.href='".$tmpname['link']."';";
 				echo "</script>\n";
 			} 
 			break;
