@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownDevice.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: dropdownDevice.php 7762 2009-01-06 18:30:32Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -59,7 +59,7 @@ if (isset($_POST["idtable"])){
 
 
 
-        $params=array('searchText'=>'__VALUE__',
+        $paramsdev=array('searchText'=>'__VALUE__',
                         'table'=>$table,
                         'value'=>0,
                         'myname'=>$_POST["myname"],
@@ -67,6 +67,6 @@ if (isset($_POST["idtable"])){
                         );
 
 	$default="<select name='".$_POST["myname"]."'><option value='0'>------</option></select>";
-	ajaxDropdown($use_ajax,"/ajax/dropdownValue.php",$params,$default,$rand);
+	ajaxDropdown($use_ajax,"/ajax/dropdownValue.php",$paramsdev,$default,$rand);
 }		
-?>
+?>
\ No newline at end of file
