@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownDocument.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: dropdownDocument.php 8875 2009-09-03 05:13:53Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -34,7 +34,7 @@
 // ----------------------------------------------------------------------
 
 // Direct access to file
-if(ereg("dropdownDocument.php",$_SERVER['PHP_SELF'])){
+if(strpos($_SERVER['PHP_SELF'],"dropdownDocument.php")){
 	define('GLPI_ROOT','..');
 	$AJAX_INCLUDE=1;
 	include (GLPI_ROOT."/inc/includes.php");
@@ -51,21 +51,23 @@ $where=" WHERE  (glpi_docs.rubrique = '".$_POST['rubdoc']."' AND glpi_docs.delet
 
 
 if (isset($_POST["entity_restrict"])){
+   if (!is_numeric($_POST["entity_restrict"]) && !is_array($_POST["entity_restrict"])) {
+      $_POST["entity_restrict"] = unserialize(stripslashes($_POST["entity_restrict"]));
+   }
 	$where.=getEntitiesRestrictRequest("AND","glpi_docs",'',$_POST["entity_restrict"],true);
 } else {
 	$where.=getEntitiesRestrictRequest("AND","glpi_docs",'','',true);
 }
 
 if (isset($_POST['used'])) {
-	$where .=" AND ID NOT IN (0";
 	if (is_array($_POST['used'])) {
 			$used=$_POST['used'];
 		} else {
 			$used=unserialize(stripslashes($_POST['used']));
 		}
-	foreach($used as $val)
-		$where .= ",$val";
-	$where .= ") ";
+	if (count($used)) {
+		$where .=" AND ID NOT IN ('".implode("','",$used)."') ";
+	}
 }
 
 if ($_POST['searchText']!=$CFG_GLPI["ajax_wildcard"])
@@ -76,7 +78,10 @@ $LIMIT="LIMIT 0,$NBMAX";
 if ($_POST['searchText']==$CFG_GLPI["ajax_wildcard"]) $LIMIT="";
 
 
-$query = "SELECT * FROM glpi_docs $where ORDER BY FK_entities, name $LIMIT";
+$query = "SELECT *
+	FROM glpi_docs
+	$where
+	ORDER BY FK_entities, name $LIMIT";
 //error_log($query);
 $result = $DB->query($query);
 
@@ -95,7 +100,10 @@ if ($DB->numrows($result)) {
 			echo "<optgroup label=\"". getDropdownName("glpi_entities", $prev) ."\">";
 		}
 		$output = $data["name"];
-		echo "<option value=\"".$data["ID"]."\" title=\"".cleanInputText($output)."\">".substr($output,0,$CFG_GLPI["dropdown_limit"])."</option>";
+		if($_SESSION["glpiview_ID"]||empty($output)){
+			$output.=" (".$data["ID"].")";
+		}
+		echo "<option value=\"".$data["ID"]."\" title=\"".cleanInputText($output)."\">".substr($output,0,$_SESSION["glpidropdown_limit"])."</option>";
 	}
 	if ($prev>=0) {
 		echo "</optgroup>";
@@ -103,4 +111,4 @@ if ($DB->numrows($result)) {
 }
 echo "</select>";
 
-?>
+?>
\ No newline at end of file
