@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownRubDocument.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: dropdownRubDocument.php 7762 2009-01-06 18:30:32Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -34,7 +34,7 @@
 // ----------------------------------------------------------------------
 
 
-if(ereg("dropdownRubDocument.php",$_SERVER['PHP_SELF'])){
+if(strpos($_SERVER['PHP_SELF'],"dropdownRubDocument.php")){
 	define('GLPI_ROOT','..');
 	$AJAX_INCLUDE=1;
 	include (GLPI_ROOT."/inc/includes.php");
@@ -58,7 +58,7 @@ if (isset($_POST["rubdoc"])){
 	}
 
 
-	$params=array('searchText'=>'__VALUE__',
+	$paramsrubdoc=array('searchText'=>'__VALUE__',
 			'rubdoc'=>$_POST["rubdoc"],
 			'entity_restrict'=>$_POST["entity_restrict"],
 			'rand'=>$_POST['rand'],
@@ -67,7 +67,7 @@ if (isset($_POST["rubdoc"])){
 			);
 	
 	$default="<select name='".$_POST["myname"]."'><option value='0'>------</option></select>";
-	ajaxDropdown($use_ajax,"/ajax/dropdownDocument.php",$params,$default,$rand);
+	ajaxDropdown($use_ajax,"/ajax/dropdownDocument.php",$paramsrubdoc,$default,$rand);
 
 }		
-?>
+?>
\ No newline at end of file
