@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownSelectSoftware.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: dropdownSelectSoftware.php 7888 2009-01-24 22:08:55Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -34,7 +34,7 @@
 // ----------------------------------------------------------------------
 
 
-if(ereg("dropdownSelectSoftware.php",$_SERVER['PHP_SELF'])){
+if(strpos($_SERVER['PHP_SELF'],"dropdownSelectSoftware.php")){
 	define('GLPI_ROOT','..');
 	$AJAX_INCLUDE=1;
 	include (GLPI_ROOT."/inc/includes.php");
@@ -50,20 +50,20 @@ checkRight("software","w");
 $rand=mt_rand();
 
 $where="";
-$leftjoin=""; 
-
-// only global and free  
-if ($_POST['only_globalfree']){ 
-        $leftjoin="LEFT JOIN glpi_licenses ON (glpi_licenses.sID = glpi_software.ID )"; 
-        $where="AND (glpi_licenses.serial='global' OR glpi_licenses.serial='free') "; 
-} 
 	 	
 if (strlen($_POST['searchText'])>0&&$_POST['searchText']!=$CFG_GLPI["ajax_wildcard"])
 	$where.=" AND name ".makeTextSearch($_POST['searchText'])." ";
 
-$where.=" AND FK_entities='".$_POST["entity_restrict"]."' ";
+//$where.=" AND FK_entities='".$_POST["entity_restrict"]."' ";
+$where .= getEntitiesRestrictRequest(' AND', 'glpi_software','FK_entities',$_POST["entity_restrict"],true);
 
-$query = "SELECT DISTINCT glpi_software.ID, glpi_software.name FROM glpi_software $leftjoin WHERE glpi_software.deleted=0 AND glpi_software.is_template=0 $where ORDER BY glpi_software.name";
+
+$query = "SELECT DISTINCT glpi_software.ID, glpi_software.name 
+		FROM glpi_software 
+		WHERE glpi_software.deleted=0 
+			AND glpi_software.is_template=0 
+			$where 
+		ORDER BY glpi_software.name";
 $result = $DB->query($query);
 
 echo "<select name='sID' id='item_type$rand'>\n";
@@ -72,20 +72,17 @@ if ($DB->numrows($result)) {
 	while ($data=$DB->fetch_array($result)) {
 		$sID = $data["ID"];
 		$output=$data["name"];
-		echo  "<option value='$sID' title=\"".cleanInputText($output)."\">".substr($output,0,$CFG_GLPI["dropdown_limit"])."</option>";
+		echo  "<option value='$sID' title=\"".cleanInputText($output)."\">".substr($output,0,$_SESSION["glpidropdown_limit"])."</option>";
 	}	
 }
 echo "</select>\n";
 
 
-$params=array('sID'=>'__VALUE__',
+$paramsselsoft=array('sID'=>'__VALUE__',
 		'myname'=>$_POST["myname"],
-		'only_globalfree'=>$_POST["only_globalfree"]
 		);
-ajaxUpdateItemOnSelectEvent("item_type$rand","show_".$_POST["myname"].$rand,$CFG_GLPI["root_doc"]."/ajax/dropdownInstallLicense.php",$params,false);
+ajaxUpdateItemOnSelectEvent("item_type$rand","show_".$_POST["myname"].$rand,$CFG_GLPI["root_doc"]."/ajax/dropdownInstallVersion.php",$paramsselsoft,false);
 
 echo "<span id='show_".$_POST["myname"]."$rand'>&nbsp;</span>\n";	
 
-?>
-
-	
+?>
\ No newline at end of file
