@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownTrackingDeviceType.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: dropdownTrackingDeviceType.php 8237 2009-04-27 12:02:19Z tsmr $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -33,24 +33,21 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-
 define('GLPI_ROOT','..');
-$AJAX_INCLUDE=1;
+//$AJAX_INCLUDE=1;
+$NEEDED_ITEMS=array("tracking");
 include (GLPI_ROOT."/inc/includes.php");
 header("Content-Type: text/html; charset=UTF-8");
 header_nocache();
 
-
 checkLoginUser();
 
-// Make a select box
-
-
-if (isset($LINK_ID_TABLE[$_POST["type"]])&&$_POST["type"]>0&&($_SESSION["glpiactiveprofile"]["helpdesk_hardware_type"]&pow(2,$_POST["type"]))){
+// Make a select box                                            
+if (isset($LINK_ID_TABLE[$_POST["type"]])&&$_POST["type"]>0&&(isPossibleToAssignType($_POST["type"]))){
 	$table=$LINK_ID_TABLE[$_POST["type"]];
 
 	if (!isset($_POST["admin"])||$_POST["admin"]==0){
-		echo "<div align='center'>".$LANG["help"][23].":&nbsp;";
+		echo "<div align='center'>".$LANG['help'][23].":&nbsp;";
 	}
 	$rand=mt_rand();
 
@@ -60,16 +57,16 @@ if (isset($LINK_ID_TABLE[$_POST["type"]])&&$_POST["type"]>0&&($_SESSION["glpiact
 		echo "<br>";
 	}
 
-	$params=array('searchText'=>'__VALUE__',
+	$paramstrackingdt=array('searchText'=>'__VALUE__',
 			'myname'=>$_POST["myname"],
 			'table'=>$table,
+			'type'=>$_POST["type"],
 			'entity_restrict'=>$_POST['entity_restrict'],
 	);
-	ajaxUpdateItemOnInputTextEvent("search_".$_POST['myname'].$rand,"results_ID$rand",$CFG_GLPI["root_doc"]."/ajax/dropdownFindNum.php",$params,false);
+	ajaxUpdateItemOnInputTextEvent("search_".$_POST['myname'].$rand,"results_ID$rand",$CFG_GLPI["root_doc"]."/ajax/dropdownFindNum.php",$paramstrackingdt,false);
 
 	echo "<span id='results_ID$rand'>";
 	echo "<select name='ID'><option value='0'>------</option></select>";
 	echo "</span>";	
 }		
-?>
-
+?>
\ No newline at end of file
