@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownUsers.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: dropdownUsers.php 8024 2009-02-28 16:03:22Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -34,7 +34,7 @@
 // ----------------------------------------------------------------------
 
 // Direct access to file
-if(ereg("dropdownUsers.php",$_SERVER['PHP_SELF'])){
+if(strpos($_SERVER['PHP_SELF'],"dropdownUsers.php")){
 	define('GLPI_ROOT','..');
 	$AJAX_INCLUDE=1;
 	include (GLPI_ROOT."/inc/includes.php");
@@ -48,6 +48,11 @@ if (!defined('GLPI_ROOT')){
 checkCentralAccess();
 // Make a select box with all glpi users
 
+if (isset($_POST["helpdesk_ajax"])&& $_POST["helpdesk_ajax"])
+	$is_helpdesk_multientity = true;
+else
+	$is_helpdesk_multientity = false;
+		
 if (!isset($_POST['right'])) {
 	$_POST['right']="all";
 }
@@ -65,30 +70,35 @@ if (isset($_POST['used'])) {
 		$used=unserialize(stripslashes($_POST['used']));
 	}
 }
+if (isset($_POST["entity_restrict"])&&!is_numeric($_POST["entity_restrict"])&&!is_array($_POST["entity_restrict"])){
+	$_POST["entity_restrict"]=unserialize(stripslashes($_POST["entity_restrict"]));
+}
 
 $result=dropdownUsersSelect(false, $_POST['right'], $_POST["entity_restrict"], $_POST['value'], $used, $_POST['searchText']);
 
+$users=array();
+if ($DB->numrows($result)) {
+	while ($data=$DB->fetch_array($result)) {
+		$users[$data["ID"]]=formatUserName($data["ID"],$data["name"],$data["realname"],$data["firstname"]);
+		$logins[$data["ID"]]=$data["name"];
+	}
+}	
 
-$users=array(); 
-if ($DB->numrows($result)) { 
-	while ($data=$DB->fetch_array($result)) { 
-		$users[$data["ID"]]=formatUserName($data["ID"],$data["name"],$data["realname"],$data["firstname"]); 
-		$logins[$data["ID"]]=$data["name"]; 
-	} 
-}        
-	 
-asort($users); 
+asort($users);
 
-echo "<select id='dropdown_".$_POST["myname"].$_POST["rand"]."' name=\"".$_POST['myname']."\">";
+echo "<select id='dropdown_".$_POST["myname"].$_POST["rand"]."' name=\"".$_POST['myname']."\"";
+if ($is_helpdesk_multientity)
+	echo " onChange='submit()'";
+echo ">";
 
 if ($_POST['searchText']!=$CFG_GLPI["ajax_wildcard"] && $DB->numrows($result)==$CFG_GLPI["dropdown_max"])
-echo "<option value=\"0\">--".$LANG["common"][11]."--</option>";
+echo "<option value=\"0\">--".$LANG['common'][11]."--</option>";
 
 
 if ($_POST['all']==0){
 echo "<option value=\"0\">[ Nobody ]</option>";
 } else if($_POST['all']==1) {
-	echo "<option value=\"0\">[ ".$LANG["common"][66]." ]</option>";
+	echo "<option value=\"0\">[ ".$LANG['common'][66]." ]</option>";
 }
 
 if (isset($_POST['value'])){
@@ -98,35 +108,37 @@ if (isset($_POST['value'])){
 }		
 
 if (count($users)) {
-	foreach ($users as $ID => $output){ 
+	foreach ($users as $ID => $output){
 			
-		echo "<option value=\"".$ID."\" title=\"".cleanInputText($output." - ".$logins[$ID])."\">".substr($output,0,$CFG_GLPI["dropdown_limit"])."</option>";
+		echo "<option value=\"".$ID."\" title=\"".cleanInputText($output." - ".$logins[$ID])."\">".substr($output,0,$_SESSION["glpidropdown_limit"])."</option>";
 	}
 }
 echo "</select>";
 
-if (isset($_POST["comments"])&&$_POST["comments"]){
-	$params=array('value'=>'__VALUE__','table'=>"glpi_users");
-	if (isset($_POST['update_link'])){
-		$params['withlink']="comments_link_".$_POST["myname"].$_POST["rand"];
+if (!$is_helpdesk_multientity)
+{
+	if (isset($_POST["comments"])&&$_POST["comments"]){
+		$paramscomments=array('value'=>'__VALUE__','table'=>"glpi_users");
+		if (isset($_POST['update_link'])){
+			$paramscomments['withlink']="comments_link_".$_POST["myname"].$_POST["rand"];
+		}
+		ajaxUpdateItemOnSelectEvent("dropdown_".$_POST["myname"].$_POST["rand"],"comments_".$_POST["myname"].$_POST["rand"],$CFG_GLPI["root_doc"]."/ajax/comments.php",$paramscomments,false);
 	}
-	ajaxUpdateItemOnSelectEvent("dropdown_".$_POST["myname"].$_POST["rand"],"comments_".$_POST["myname"].$_POST["rand"],$CFG_GLPI["root_doc"]."/ajax/comments.php",$params,false);
 }
 
 // Manage updates others dropdown for helpdesk
-if (isset($_POST["helpdesk_ajax"])&&$_POST["helpdesk_ajax"]){
-
-	$params=array('userID'=>'__VALUE__',
-			'entity_restrict'=>$_POST["entity_restrict"],
-			'device_type'=>0
-	);
-	ajaxUpdateItemOnSelectEvent("dropdown_author".$_POST["rand"],"tracking_my_devices",$CFG_GLPI["root_doc"]."/ajax/updateTrackingDeviceType.php",$params,false);
-
-	$params=array('value'=>'__VALUE__'
-	);
-	ajaxUpdateItemOnSelectEvent("dropdown_author".$_POST["rand"],"uemail_result",$CFG_GLPI["root_doc"]."/ajax/uemailUpdate.php",$params,false);
+if ($is_helpdesk_multientity){
+	if (!isMultiEntitiesMode())
+	{
+		$paramscomments=array('userID'=>'__VALUE__',
+				'entity_restrict'=>$_POST["entity_restrict"],
+				'device_type'=>0,
+				'author_field'=>"dropdown_author".$_POST["rand"]
+		);
 
+		ajaxUpdateItemOnSelectEvent("dropdown_author".$_POST["rand"],"tracking_my_devices",$CFG_GLPI["root_doc"]."/ajax/updateTrackingDeviceType.php",$paramscomments,false);
+		$paramscomments=array('value'=>'__VALUE__');
+		ajaxUpdateItemOnSelectEvent("dropdown_author".$_POST["rand"],"uemail_result",$CFG_GLPI["root_doc"]."/ajax/uemailUpdate.php",$paramscomments,false);
+	}
 }
-
-
-?>
+?>
\ No newline at end of file
