@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownValue.php 7938 2009-02-02 21:10:12Z moyo $
+ * @version $Id: dropdownValue.php 8454 2009-07-15 13:40:28Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -34,10 +34,10 @@
 // ----------------------------------------------------------------------
 
 // Direct access to file
-if(ereg("dropdownValue.php",$_SERVER['PHP_SELF'])){
+if(strpos($_SERVER['PHP_SELF'],"dropdownValue.php")){
 	define('GLPI_ROOT','..');
 	// Include plugin if it is a plugin table
-	if (!ereg("plugin",$_POST['table'])){
+	if (!strstr($_POST['table'],"plugin")){
 		$AJAX_INCLUDE=1;
 	}
 	include (GLPI_ROOT."/inc/includes.php");
@@ -60,7 +60,7 @@ if (isset($_POST["entity_restrict"])&&!is_numeric($_POST["entity_restrict"])&&!i
 	$_POST["entity_restrict"]=unserialize(stripslashes($_POST["entity_restrict"]));
 }
 // Make a select box with preselected values
-if (!isset($_POST["limit"])) $_POST["limit"]=$CFG_GLPI["dropdown_limit"];
+if (!isset($_POST["limit"])) $_POST["limit"]=$_SESSION["glpidropdown_limit"];
 
 	$where="WHERE 1 ";
 	
@@ -84,7 +84,6 @@ if (!isset($_POST["limit"])) $_POST["limit"]=$CFG_GLPI["dropdown_limit"];
 			$where.=" AND completename ".makeTextSearch($_POST['searchText']);
 		}
 
-
 		$multi=false;
 
 		// Manage multiple Entities dropdowns
@@ -117,26 +116,33 @@ if (!isset($_POST["limit"])) $_POST["limit"]=$CFG_GLPI["dropdown_limit"];
 			}
 		}
 
-		$query = "SELECT * FROM `".$_POST['table']."` $where ORDER BY $add_order completename $LIMIT";
+		$query = "SELECT * 
+			FROM `".$_POST['table']."` 
+			$where 
+			ORDER BY $add_order completename 
+			$LIMIT";
 		//error_log("SQL1:".$query);
 		$result = $DB->query($query);
 
-		echo "<select id='dropdown_".$_POST["myname"].$_POST["rand"]."' name=\"".$_POST['myname']."\" size='1'>";
+		echo "<select id='dropdown_".$_POST["myname"].$_POST["rand"]."' name=\"".$_POST['myname']."\" size='1'"; 
+		if ($_POST['table'] == "glpi_entities" &&$_POST["auto_submit"]==1)
+			echo " onChange='submit()'";
+		echo ">";
 
 		if ($_POST['searchText']!=$CFG_GLPI["ajax_wildcard"]&&$DB->numrows($result)==$NBMAX)
-			echo "<option class='tree' value=\"0\">--".$LANG["common"][11]."--</option>";
+			echo "<option class='tree' value=\"0\">--".$LANG['common'][11]."--</option>";
 		$display_selected=true;
 		switch ($_POST["table"]){
 			case "glpi_dropdown_kbcategories" :
-				echo "<option class='tree' value=\"0\">--".$LANG["knowbase"][12]."--</option>";
+				echo "<option class='tree' value=\"0\">--".$LANG['knowbase'][12]."--</option>";
 				break;
 			case "glpi_entities" :
 				// If entity=0 allowed
 				if (isset($_POST["entity_restrict"])&& 
-					(($_POST["entity_restrict"]<0 && in_array(0,$_SESSION['glpiactiveentities']))
+					(($_POST["entity_restrict"]<=0 && in_array(0,$_SESSION['glpiactiveentities']))
 					|| (is_array($_POST["entity_restrict"]) && in_array(0,$_POST["entity_restrict"]))))
 				{	
-					echo "<option class='tree' value=\"0\">--".$LANG["entity"][2]."--</option>";
+					echo "<option class='tree' value=\"0\">--".$LANG['entity'][2]."--</option>";
 				}
 				// Entity=0 already add above
 				if ($_POST['value']==0){
@@ -150,8 +156,17 @@ if (!isset($_POST["limit"])) $_POST["limit"]=$CFG_GLPI["dropdown_limit"];
 
 		if ($display_selected){
 			$outputval=getDropdownName($_POST['table'],$_POST['value']);
-			if (!empty($outputval)&&$outputval!="&nbsp;")
+			if (!empty($outputval)&&$outputval!="&nbsp;") {
+				if (strlen($outputval)>$_POST["limit"]) {
+					// Completename for tree dropdown : keep right
+					$outputval = "&hellip;".utf8_substr($outputval,-$_POST["limit"]);
+				}
+				if ($_SESSION["glpiview_ID"]||empty($outputval)){
+					 $outputval.=" (".$_POST['value'].")";
+				}
+
 				echo "<option class='tree' selected value='".$_POST['value']."'>".$outputval."</option>";
+			}
 		}
 
 		if ($DB->numrows($result)) {
@@ -178,7 +193,7 @@ if (!isset($_POST["limit"])) $_POST["limit"]=$CFG_GLPI["dropdown_limit"];
 					$raquo="";
 				}
 
-				if ($CFG_GLPI['flat_dropdowntree']){
+				if ($_SESSION['glpiflat_dropdowntree']){
 					$output=$data['completename'];
 					if ($level>1){
 						$class="";
@@ -187,30 +202,39 @@ if (!isset($_POST["limit"])) $_POST["limit"]=$CFG_GLPI["dropdown_limit"];
 					}
 				}
 				
-				if (empty($output)) {
-					$output="($ID)";
+				if (strlen($output)>$_POST["limit"]) {
+					if ($_SESSION['glpiflat_dropdowntree']){
+						$output="&hellip;".utf8_substr($output,-$_POST["limit"]);
+					} else {
+						$output=utf8_substr($output,0,$_POST["limit"])."&hellip;";
+					}
+				}
+				
+				if ($_SESSION["glpiview_ID"]||empty($output)){
+					 $output.=" ($ID)";
 				}
 
 				$style=$class;
 				$addcomment="";
 				if (isset($data["comments"])) $addcomment=" - ".$data["comments"];
 
-				echo "<option value=\"$ID\" $style title=\"".cleanInputText($data['completename'].$addcomment)."\">".str_repeat("&nbsp;&nbsp;&nbsp;", $level).$raquo.utf8_substr($output,0,$_POST["limit"])."</option>";
+				echo "<option value=\"$ID\" $style title=\"".cleanInputText($data['completename'].$addcomment)."\">".str_repeat("&nbsp;&nbsp;&nbsp;", $level).$raquo.$output."</option>";
 			}
 
 		}
 		echo "</select>";
 
 	} else { // Not dropdowntree_tables
-		$where .=" AND ID NOT IN (".$_POST['value'];
+		$where .=" AND `".$_POST['table']."`.ID NOT IN ('".$_POST['value']."'";
 		if (isset($_POST['used'])) {
 			if (is_array($_POST['used'])) {
 				$used=$_POST['used'];
 			} else {
 				$used=unserialize(stripslashes($_POST['used']));
 			}
-			foreach($used as $val)
-				$where .= ", $val";
+			if (count($used)) {
+				$where .= ",'".implode("','",$used)."'";
+			}
 		}
 		$where .= ") ";
 
@@ -232,17 +256,36 @@ if (!isset($_POST["limit"])) $_POST["limit"]=$CFG_GLPI["dropdown_limit"];
 		}
 
 		$field="name";
-		if (ereg("glpi_device",$_POST['table'])) $field="designation";
+		if (strstr($_POST['table'],"glpi_device")) {
+			$field="designation";
+		}
 
-		if ($_POST['searchText']!=$CFG_GLPI["ajax_wildcard"])
-			$where.=" AND $field ".makeTextSearch($_POST['searchText']);
+		if ($_POST['searchText']!=$CFG_GLPI["ajax_wildcard"]){
+         $search=makeTextSearch($_POST['searchText']);
+         $where.=" AND  (`".$_POST['table']."`.`$field` ".$search;
+         if ($_POST['table']=="glpi_softwarelicenses"){
+            $where.=" OR `glpi_software`.`name` ".$search;
+         }
+         $where.=')';
+      }
 
 		switch ($_POST['table']){
 			case "glpi_contacts":
-				$query = "SELECT FK_entities, CONCAT(name,' ',firstname) as $field, `".$_POST['table']."`.comments, ".$_POST['table'].".ID FROM `".$_POST['table']."` $where";
+				$query = "SELECT `".$_POST['table']."`.FK_entities, CONCAT(name,' ',firstname) as $field, 
+						`".$_POST['table']."`.comments, `".$_POST['table']."`.ID 
+					FROM `".$_POST['table']."` 
+					$where";
+			break;
+			case "glpi_softwarelicenses":
+				$query = "SELECT `".$_POST['table']."`.*, CONCAT(glpi_software.name,' - ',glpi_softwarelicenses.name) as $field
+					FROM `".$_POST['table']."` LEFT JOIN glpi_software ON (glpi_softwarelicenses.sID = glpi_software.ID)
+					$where";
+
 			break;
 			default :
-				$query = "SELECT * FROM `".$_POST['table']."` $where";
+				$query = "SELECT * 
+					FROM `".$_POST['table']."` 
+					$where";
 			break;
 		}
 		if ($multi) {
@@ -252,16 +295,21 @@ if (!isset($_POST["limit"])) $_POST["limit"]=$CFG_GLPI["dropdown_limit"];
 		}
 		//error_log("SQL2:".$query);
 		$result = $DB->query($query);
-
+		//echo $query;
 		echo "<select id='dropdown_".$_POST["myname"].$_POST["rand"]."' name=\"".$_POST['myname']."\" size='1'>";
 
 		if ($_POST['searchText']!=$CFG_GLPI["ajax_wildcard"]&&$DB->numrows($result)==$NBMAX)
-			echo "<option value=\"0\">--".$LANG["common"][11]."--</option>";
+			echo "<option value=\"0\">--".$LANG['common'][11]."--</option>";
 
 		echo "<option value=\"0\">-----</option>";
 
 		$output=getDropdownName($_POST['table'],$_POST['value']);
 		if (!empty($output)&&$output!="&nbsp;"){
+
+			if($_SESSION["glpiview_ID"]||empty($output)){
+				$output.=" (".$_POST['value'].")";
+			}
+
 			echo "<option selected value='".$_POST['value']."'>".$output."</option>";
 		}
 
@@ -269,13 +317,19 @@ if (!isset($_POST["limit"])) $_POST["limit"]=$CFG_GLPI["dropdown_limit"];
 			$prev=-1;
 			while ($data =$DB->fetch_array($result)) {
 				$output = $data[$field];
-				if (isset($_POST['withserial'])&&isset($data["serial"])) $output.=" - ".$data["serial"];
-				if (isset($_POST['withotherserial'])&&isset($data["otherserial"])) $output.=" - ".$data["otherserial"];
+				if (isset($_POST['withserial'])&&isset($data["serial"]) && !empty($data["serial"])){
+					 $output.=" - ".$data["serial"];
+				}
+				if (isset($_POST['withotherserial'])&&isset($data["otherserial"]) && !empty($data["otherserial"])) {
+					$output.=" - ".$data["otherserial"];
+				}
 				$ID = $data['ID'];
 				$addcomment="";
 				if (isset($data["comments"])) $addcomment=" - ".$data["comments"];
 
-				if (empty($output)) $output="($ID)";
+				if ($_SESSION["glpiview_ID"]||empty($output)){
+					 $output.=" ($ID)";
+				}
 				if ($multi && $data["FK_entities"]!=$prev) {
 					if ($prev>=0) {
 						echo "</optgroup>";
@@ -293,8 +347,8 @@ if (!isset($_POST["limit"])) $_POST["limit"]=$CFG_GLPI["dropdown_limit"];
 	}
 
 if (isset($_POST["comments"])&&$_POST["comments"]){
-	$params=array('value'=>'__VALUE__','table'=>$_POST["table"]);
-	ajaxUpdateItemOnSelectEvent("dropdown_".$_POST["myname"].$_POST["rand"],"comments_".$_POST["myname"].$_POST["rand"],$CFG_GLPI["root_doc"]."/ajax/comments.php",$params,false);
+	$paramscomments=array('value'=>'__VALUE__','table'=>$_POST["table"]);
+	ajaxUpdateItemOnSelectEvent("dropdown_".$_POST["myname"].$_POST["rand"],"comments_".$_POST["myname"].$_POST["rand"],$CFG_GLPI["root_doc"]."/ajax/comments.php",$paramscomments,false);
 }
 
 if (isset($_POST["update_item"])&&
@@ -304,18 +358,18 @@ if (isset($_POST["update_item"])&&
 	} else $data=$_POST["update_item"];
 	
 	if (is_array($data)&&count($data)){
-		$params=array();
+		$paramsupdate=array();
 		if (isset($data['value_fieldname'])){
-			$params=array($data['value_fieldname']=>'__VALUE__');
+			$paramsupdate=array($data['value_fieldname']=>'__VALUE__');
 		}
 		if (isset($data["moreparams"])&&is_array($data["moreparams"])&&count($data["moreparams"])){
 			foreach ($data["moreparams"] as $key => $val){
-				$params[$key]=$val;
+				$paramsupdate[$key]=$val;
 			}
 		}
-		ajaxUpdateItemOnSelectEvent("dropdown_".$_POST["myname"].$_POST["rand"],$data['to_update'],$data['url'],$params,false);
+		ajaxUpdateItemOnSelectEvent("dropdown_".$_POST["myname"].$_POST["rand"],$data['to_update'],$data['url'],$paramsupdate,false);
 	}
 }
 
 
-?>
+?>
\ No newline at end of file
