@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: private_public.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: private_public.php 8024 2009-02-28 16:03:22Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -34,7 +34,7 @@
 // ----------------------------------------------------------------------
 
 
-if(ereg("private_public.php",$_SERVER['PHP_SELF'])){
+if(strpos($_SERVER['PHP_SELF'],"private_public.php")){
 	define('GLPI_ROOT','..');
 	$AJAX_INCLUDE=1;
 	include (GLPI_ROOT."/inc/includes.php");
@@ -52,20 +52,20 @@ if (!defined('GLPI_ROOT')){
 				echo "<input type='hidden' name='private' value='1'>\n";
 				echo "<input type='hidden' name='FK_entities' value='-1'>\n";
 				echo "<input type='hidden' name='recursive' value='0'>\n";
-				echo $LANG["common"][77]. " - ";
+				echo $LANG['common'][77]. " - ";
 
-				echo "<a onClick='setPublic".$_POST['rand']."()'>".$LANG["common"][78]."</a>";
+				echo "<a onClick='setPublic".$_POST['rand']."()'>".$LANG['common'][78]."</a>";
 				break;
 			case false :
 				echo "<input type='hidden' name='private' value='0'>\n";
-				echo $LANG["common"][76].":&nbsp;";
+				echo $LANG['common'][76].":&nbsp;";
 				dropdownValue('glpi_entities',"FK_entities",$_POST["FK_entities"]);
-				echo "&nbsp;+&nbsp;".$LANG["entity"][9].":&nbsp;";
+				echo "&nbsp;+&nbsp;".$LANG['entity'][9].":&nbsp;";
 				dropdownYesNo('recursive',$_POST["recursive"]);
 
 				echo " - ";
 
-				echo "<a onClick='setPrivate".$_POST['rand']."()'>".$LANG["common"][79]."</a>";
+				echo "<a onClick='setPrivate".$_POST['rand']."()'>".$LANG['common'][79]."</a>";
 				
 				break;
 		}
