@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ruleaction.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: ruleaction.php 7793 2009-01-10 16:41:33Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -34,7 +34,7 @@
 // ----------------------------------------------------------------------
 
 // Direct access to file
-if(ereg("ruleaction.php",$_SERVER['PHP_SELF'])){
+if(strpos($_SERVER['PHP_SELF'],"ruleaction.php")){
 	define('GLPI_ROOT','..');
 	$AJAX_INCLUDE=1;
 	include (GLPI_ROOT."/inc/includes.php");
@@ -55,24 +55,24 @@ if (!defined('GLPI_ROOT')){
 
 
 	// Non define case
-	if (isset($_POST["rule_type"])&&isset($RULES_ACTIONS[$_POST["rule_type"]])){
+	if (isset($_POST["sub_type"])&&isset($RULES_ACTIONS[$_POST["sub_type"]])){
 		// First include -> first of the predefined array
 		if (!isset($_POST["field"])){
-			$_POST["field"]=key($RULES_ACTIONS[$_POST["rule_type"]]);
+			$_POST["field"]=key($RULES_ACTIONS[$_POST["sub_type"]]);
 		}
 
-		$rand=dropdownRulesActions($_POST["rule_type"],"action_type",$_POST["field"]);
+		$randaction=dropdownRulesActions($_POST["sub_type"],"action_type",$_POST["field"]);
 
 		echo "&nbsp;&nbsp;";
 		echo "<span id='action_type_span'>\n";
 		echo "</span>\n";
 
-		$params=array('action_type'=>'__VALUE__',
+		$paramsaction=array('action_type'=>'__VALUE__',
 				'field'=>$_POST["field"],
-				'rule_type'=>$_POST["rule_type"],
+				'sub_type'=>$_POST["sub_type"],
 		);
-		ajaxUpdateItemOnSelectEvent("dropdown_action_type$rand","action_type_span",$CFG_GLPI["root_doc"]."/ajax/ruleactionvalue.php",$params,false);
-		ajaxUpdateItem("action_type_span",$CFG_GLPI["root_doc"]."/ajax/ruleactionvalue.php",$params,false,"dropdown_action_type$rand");
+		ajaxUpdateItemOnSelectEvent("dropdown_action_type$randaction","action_type_span",$CFG_GLPI["root_doc"]."/ajax/ruleactionvalue.php",$paramsaction,false);
+		ajaxUpdateItem("action_type_span",$CFG_GLPI["root_doc"]."/ajax/ruleactionvalue.php",$paramsaction,false,"dropdown_action_type$randaction");
 	}
 
 	
