@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ruleactionvalue.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: ruleactionvalue.php 7793 2009-01-10 16:41:33Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -34,7 +34,7 @@
 // ----------------------------------------------------------------------
 
 // Direct access to file
-if(ereg("ruleactionvalue.php",$_SERVER['PHP_SELF'])){
+if(strpos($_SERVER['PHP_SELF'],"ruleactionvalue.php")){
 	define('GLPI_ROOT','..');
 	$AJAX_INCLUDE=1;
 	include (GLPI_ROOT."/inc/includes.php");
@@ -51,13 +51,19 @@ if (!defined('GLPI_ROOT')){
 	
 	checkLoginUser();
 	$display=false;
+	
 	switch ($_POST["action_type"])
 	{
+		//If a regex value is used, then always display an autocompletiontextfield
+		case "regex_result":
+		case "append_regex_result":
+			autocompletionTextField("value", "glpi_rules_actions", "value", "", 40);
+		break;	
 		default:
-		if (isset($RULES_ACTIONS[$_POST["rule_type"]][$_POST["field"]]['type'])){
-			switch($RULES_ACTIONS[$_POST["rule_type"]][$_POST["field"]]['type']){
+		if (isset($RULES_ACTIONS[$_POST["sub_type"]][$_POST["field"]]['type'])){
+			switch($RULES_ACTIONS[$_POST["sub_type"]][$_POST["field"]]['type']){
 				case "dropdown":
-					dropdownValue($RULES_ACTIONS[$_POST["rule_type"]][$_POST["field"]]['table'],"value");
+					dropdownValue($RULES_ACTIONS[$_POST["sub_type"]][$_POST["field"]]['table'],"value");
 					$display=true;
 					break;
 				case "dropdown_assign":
@@ -83,7 +89,7 @@ if (!defined('GLPI_ROOT')){
 			}
 		}
 		if (!$display){
-			autocompletionTextField("value", "glpi_rules_actions", "value", "", 30);
+			autocompletionTextField("value", "glpi_rules_actions", "value", "", 40);
 		}
 		break;
 	}
