@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rulecriteria.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: rulecriteria.php 7793 2009-01-10 16:41:33Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -34,7 +34,7 @@
 // ----------------------------------------------------------------------
 
 // Direct access to file
-if(ereg("rulecriteria.php",$_SERVER['PHP_SELF'])){
+if(strpos($_SERVER['PHP_SELF'],"rulecriteria.php")){
 	define('GLPI_ROOT','..');
 	$AJAX_INCLUDE=1;
 	include (GLPI_ROOT."/inc/includes.php");
@@ -49,8 +49,8 @@ if (!defined('GLPI_ROOT')){
 	include_once (GLPI_ROOT."/inc/rulesengine.function.php");
 	
 	checkLoginUser();
-	if (isset($_POST["rule_type"])){
-		$rule=getRuleClass($_POST["rule_type"]);
+	if (isset($_POST["sub_type"])){
+		$rule=getRuleClass($_POST["sub_type"]);
 		$criterias=$rule->getCriterias();
 		if (count($criterias)){
 
@@ -62,18 +62,18 @@ if (!defined('GLPI_ROOT')){
 			if (isset($criterias[$_POST["criteria"]]['type'])){
 				$type=$criterias[$_POST["criteria"]]['type'];
 			}
-			$rand = dropdownRulesConditions($type,"condition");
+			$randcrit = dropdownRulesConditions($type,"condition");
 			echo "&nbsp;&nbsp;";
 
 			echo "<span id='condition_span'>\n";
 			echo "</span>\n";
 
-			$params=array('condition'=>'__VALUE__',
+			$paramscriteria=array('condition'=>'__VALUE__',
 					'criteria'=>$_POST["criteria"],
-					'rule_type'=>$_POST["rule_type"],
+					'sub_type'=>$_POST["sub_type"],
 			);
-			ajaxUpdateItemOnSelectEvent("dropdown_condition$rand","condition_span",$CFG_GLPI["root_doc"]."/ajax/rulecriteriavalue.php",$params,false);
-			ajaxUpdateItem("condition_span",$CFG_GLPI["root_doc"]."/ajax/rulecriteriavalue.php",$params,false,"dropdown_condition$rand");
+			ajaxUpdateItemOnSelectEvent("dropdown_condition$randcrit","condition_span",$CFG_GLPI["root_doc"]."/ajax/rulecriteriavalue.php",$paramscriteria,false);
+			ajaxUpdateItem("condition_span",$CFG_GLPI["root_doc"]."/ajax/rulecriteriavalue.php",$paramscriteria,false,"dropdown_condition$randcrit");
 		}
 
 	}
