@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rulecriteriavalue.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: rulecriteriavalue.php 8201 2009-04-20 08:12:03Z walid $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -34,9 +34,10 @@
 // ----------------------------------------------------------------------
 
 // Direct access to file
-if(ereg("rulecriteriavalue.php",$_SERVER['PHP_SELF'])){
+if(strstr($_SERVER['PHP_SELF'],"rulecriteriavalue.php")){
 	define('GLPI_ROOT','..');
-	$AJAX_INCLUDE=1;
+	//$AJAX_INCLUDE=1;
+	$NEEDED_ITEMS = array("tracking");
 	include (GLPI_ROOT."/inc/includes.php");
 	header("Content-Type: text/html; charset=UTF-8");
 	header_nocache();
@@ -50,8 +51,8 @@ include_once (GLPI_ROOT."/inc/rulesengine.function.php");
 	
 checkLoginUser();
 // Non define case
-if (isset($_POST["rule_type"])){
-	$rule=getRuleClass($_POST["rule_type"]);
+if (isset($_POST["sub_type"])){
+	$rule=getRuleClass($_POST["sub_type"]);
 	$criterias=$rule->getCriterias();
 	$rule->displayCriteriaSelectPattern("pattern",$_POST["criteria"],$_POST['condition']);
 }
