@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: textarea.php 8321 2009-05-22 12:24:53Z remi $
+ * @version $Id: textarea.php 8244 2009-04-28 15:01:11Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -44,8 +44,7 @@
 	
 	checkLoginUser();
 	echo "<textarea ".(isset($_POST['rows'])?" rows='".$_POST['rows']."' ":"")." ".(isset($_POST['cols'])?" cols='".$_POST['cols']."' ":"")."  name='".$_POST['name']."'>";
-	$order   = array('\r\n', '\n', "\\'", '\"');
-	$replace = array("\n",   "\n", "'",   '"');
-	echo str_replace($order,$replace,rawurldecode($_POST["data"])); 
+	echo cleanPostForTextArea(rawurldecode($_POST["data"]));
 	echo "</textarea>";
+
 ?>
