@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: based_config.php 8352 2009-06-01 18:57:03Z moyo $
+ * @version $Id: based_config.php 8396 2009-06-24 14:01:26Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -36,18 +36,17 @@ if (!defined('GLPI_ROOT')){
 
 // Notice problem  for date function :
 if (function_exists('date_default_timezone_set')){
-        $tz=ini_get('date.timezone');
-        if (!empty($tz)){
-                date_default_timezone_set($tz);
-        } else {
-                date_default_timezone_set(@date_default_timezone_get());
-        }
+	$tz=ini_get('date.timezone');
+	if (!empty($tz)){
+		date_default_timezone_set($tz);
+	} else {
+		date_default_timezone_set(@date_default_timezone_get());
+	}
 }
 
-
 // If this file exists, it is load, allow to set configdir/dumpdir elsewhere
 if(file_exists(GLPI_ROOT ."/config/config_path.php")) {
-	include(GLPI_ROOT ."/config/config_path.php");
+	include_once(GLPI_ROOT ."/config/config_path.php");
 }
 
 // Default location for database configuration : config_db.php
@@ -107,4 +106,12 @@ if (!defined("GLPI_CACHE_LITE_DIR")){
 	# if PEAR + Cache_Lite installed, use (in config_path.php)
 	# define("GLPI_CACHE_LITE_DIR", "Cache");
 }
-?>
+
+// Default PHPMailer installation dir
+if (!defined("GLPI_PHPMAILER_DIR")){
+	define("GLPI_PHPMAILER_DIR", GLPI_ROOT."/lib/phpmailer");
+
+	# if PHPMailer installed, use (in config_path.php)
+	# define("GLPI_PHPMAILER_DIR", "/usr/share/php/phpmailer");
+}
+?>
\ No newline at end of file
