@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: config.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: config.php 8173 2009-04-13 18:22:21Z jmd $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -46,12 +46,14 @@
 	if(!file_exists(GLPI_CONFIG_DIR . "/config_db.php")) {
 		nullHeader("DB Error",$_SERVER['PHP_SELF']);
 		if (!isCommandLine()){
-			echo "<div align='center'>";
+			echo "<div class='center'>";
 			echo "<p>Error : GLPI seems to not be installed properly.</p><p> config_db.php file is missing.</p><p>Please restart the install process.</p>";
+			echo "<p><a class='red' href='".GLPI_ROOT."'>Click here to proceed</a></p>";			
 			echo "</div>";
 		} else {
 			echo "Error : GLPI seems to not be installed properly.</p><p> config_db.php file is missing.\n";
 			echo "Please restart the install process.\n";
+			
 		}
 		nullFooter("DB Error",$_SERVER['PHP_SELF']);
 	
@@ -71,9 +73,14 @@
 		// ********************options d'installation statiques*********************
 		// ***********************************************************************		
 
-		//Options gerees dynamiquement, ne pas toucher cette partie.
 		//Options from DB, do not touch this part.
-		$CFG_GLPI["debug"]=$CFG_GLPI["debug_sql"]=$CFG_GLPI["debug_vars"]=$CFG_GLPI["debug_profile"]=$CFG_GLPI["debug_lang"]=0;
+
+
+		// Default Use mode
+		if (!isset($_SESSION['glpi_use_mode'])){
+			$_SESSION['glpi_use_mode']=NORMAL_MODE;
+		}
+
 		$config_object=new Config();
 	
 		if($config_object->getFromDB(1)){
@@ -98,24 +105,14 @@
 			$CFG_GLPI["typedoc_icon_dir"] = GLPI_ROOT."/pics/icones";
 
 
-			// *************************** Mode NORMAL / TRALATION /DEBUG  **********************
-			// *********************************************************************************
-	
-			// Mode debug ou traduction
-			//$CFG_GLPI["debug"]=DEBUG_MODE;
-			$CFG_GLPI["debug_sql"]=($CFG_GLPI["debug"]==DEBUG_MODE?1:0); // affiche les requetes
-			$CFG_GLPI["debug_vars"]=($CFG_GLPI["debug"]==DEBUG_MODE?1:0); // affiche les variables
-			$CFG_GLPI["debug_profile"]=($CFG_GLPI["debug"]==DEBUG_MODE?1:0); // Profile les requetes
-			$CFG_GLPI["debug_lang"]=($CFG_GLPI["debug"]==TRANSLATION_MODE?1:0); // affiche les variables de trads
-	
 		} else {
 			echo "Error accessing config table";
 			exit();
 		}
 
-		if (!isset($CFG_GLPI["use_cache"])){
-			$CFG_GLPI["use_cache"]=0;
-		}
+		// DO NOT USE CACHE : you can activate it if needed
+		$CFG_GLPI["use_cache"]=0;
+
 		$cache_options = array(
 			'cacheDir' => GLPI_CACHE_DIR,
 			'lifeTime' => DEFAULT_CACHE_LIFETIME,
@@ -127,14 +124,17 @@
 			'readControl' => CACHE_READCONTROL,
 		);
 
+		// Output cache 
 		$GLPI_CACHE = new Cache_Lite_Output($cache_options);
 		$CFG_GLPI["cache"]=$GLPI_CACHE;
 
+		// Cache for other operation
+		$CFG_GLPI["opcache"] = new Cache_Lite($cache_options);
 	
-		// Mode debug activé on affiche un certains nombres d'informations
-		if ($CFG_GLPI["debug"]==DEBUG_MODE){
+		// If debug mode activated : display some informations
+		if ($_SESSION['glpi_use_mode']==DEBUG_MODE){
 			ini_set('display_errors','On'); 
-			error_reporting(E_ALL); 
+			error_reporting(E_ALL | E_STRICT); 
 			//ini_set('error_prepend_string','<div style="position:fload-left; background-color:red; z-index:10000">PHP ERROR : '); 
 			//ini_set('error_append_string','</div>'); 
 			set_error_handler("userErrorHandler"); 
@@ -150,20 +150,23 @@
 	
 	
 		// Override cfg_features by session value
-		if (!isset($_SESSION['glpilist_limit'])||$_SESSION['glpilist_limit']<5) $_SESSION["glpilist_limit"]=$CFG_GLPI['list_limit'];
+		foreach ($CFG_GLPI['user_pref_field'] as $field){
+			if (!isset($_SESSION["glpi$field"]) && isset($CFG_GLPI[$field])){
+				$_SESSION["glpi$field"]=$CFG_GLPI[$field];
+			}
+		}
 
 		if ((!isset($CFG_GLPI["version"])||trim($CFG_GLPI["version"])!=GLPI_VERSION)&&!isset($_GET["donotcheckversion"])){
 			loadLanguage();
 			
 			if (isCommandLine()){
-				echo $LANG["update"][88] . "\n";
+				echo $LANG['update'][88] . "\n";
 			} else {			
 				nullHeader("UPDATE NEEDED",$_SERVER['PHP_SELF']);
-				echo "<div align='center'>";
+				echo "<div class='center'>";
 		
 		
-				echo "<table class='tab_cadre' style='width:700px'>";
-				echo "<tr><th>".$LANG["install"][6]."</th><th >".$LANG["install"][7]."</th></tr>";
+				echo "<table class='tab_check'>";
 		
 				$error=commonCheckForUseGLPI();
 		
@@ -172,22 +175,20 @@
 				if (!$error){
 					if (!isset($CFG_GLPI["version"])||trim($CFG_GLPI["version"])<GLPI_VERSION){
 						echo "<form method='post' action='".$CFG_GLPI["root_doc"]."/install/update.php'>";
-						echo "<table class='tab_cadre' style='width:500px'><tr><th>";
-						echo $LANG["update"][88];
-						echo "</th></tr>";
-						echo "<tr class='tab_bg_1'><td align='center'>";
-						echo "<input type='submit' name='from_update' value='".$LANG["install"][4]."' class='submit'>";
-						echo "</td></tr>";
-						echo "</table></form>";
+						echo "<p class='red'>";
+						echo $LANG['update'][88];
+						echo "</p>";						
+						echo "<input type='submit' name='from_update' value='".$LANG['install'][4]."' class='submit'>";
+						echo "</form>";
 					} else if (trim($CFG_GLPI["version"])>GLPI_VERSION){
-						echo "<table class='tab_cadre' style='width:500px'><tr><th>";
-						echo $LANG["update"][89];
-						echo "</th></tr>";
-						echo "</table>";
+						echo "<p class='red'>";
+						echo $LANG['update'][89];
+						
+						echo "</p>";
 					}
 				} else {
 					echo "<form action=\"".$_SERVER['PHP_SELF']."\" method=\"post\">";
-					echo "<input type=\"submit\" name=\"submit\" class=\"submit\" value=\"".$LANG["install"][27]."\" />";
+					echo "<input type=\"submit\" name=\"submit\" class=\"submit\" value=\"".$LANG['install'][27]."\" />";
 					echo "</form>";
 				}
 				echo "</div>";
