@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: cartridge.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: cartridge.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -40,13 +40,13 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("cartridge","r");
 
-commonHeader($LANG["Menu"][21],$_SERVER['PHP_SELF'],"inventory","cartridge");
+commonHeader($LANG['Menu'][21],$_SERVER['PHP_SELF'],"inventory","cartridge");
 
 manageGetValuesInSearch(CARTRIDGE_TYPE);
 
-searchForm(CARTRIDGE_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+searchForm(CARTRIDGE_TYPE,$_GET);
 
-showList(CARTRIDGE_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+showList(CARTRIDGE_TYPE,$_GET);
 
 commonFooter();
 
