@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: central.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: central.php 8133 2009-04-02 12:56:47Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -34,11 +34,11 @@
 // ----------------------------------------------------------------------
 
 define('GLPI_ROOT', '..');
-$NEEDED_ITEMS=array("central","tracking","computer","printer","monitor","peripheral","networking","software","user","group","setup","planning","phone","reminder","enterprise","contract");
+$NEEDED_ITEMS=array("central","tracking","computer","printer","monitor","peripheral","networking","software","user","group","setup","planning","phone","reminder","enterprise","contract","profile");
 include (GLPI_ROOT."/inc/includes.php");
 
-
 	checkCentralAccess();
+
 	// Change profile system
 	if (isset ($_POST['newprofile'])) {
 		if (isset ($_SESSION["glpiprofiles"][$_POST['newprofile']])) {
@@ -63,75 +63,45 @@ include (GLPI_ROOT."/inc/includes.php");
 		}
 	}
 
-	commonHeader($LANG["title"][0],$_SERVER['PHP_SELF']);
+	commonHeader($LANG['title'][0],$_SERVER['PHP_SELF']);
 
 	// Redirect management
 	if (isset($_GET["redirect"])){
 		manageRedirect($_GET["redirect"]);
 	}
 
-	// show "my view" in first
-	if (!isset($_SESSION['glpi_viewcentral'])) $_SESSION['glpi_viewcentral']="my";
-	if (isset($_GET['onglet'])) $_SESSION['glpi_viewcentral']=$_GET['onglet'];
-	
-	if (!isset($_GET['start'])) $_GET['start']=0;
-	if(empty($_GET["start"])) $_GET["start"] = 0;
-
-	if (!isset($_GET["sort"])) $_GET["sort"]="";
-	if (!isset($_GET["order"])) $_GET["order"]="";
 
 	// Greet the user
 
-	echo "<br><span class='icon_consol'>".$LANG["central"][0]." ";
+	echo "<br><span class='icon_consol'>".$LANG['central'][0]." ";
 
 	echo formatUserName($_SESSION["glpiID"],$_SESSION["glpiname"],$_SESSION["glpirealname"],$_SESSION["glpifirstname"]);
-	echo ", ".$LANG["central"][1]."</span>";
+	echo ", ".$LANG['central'][1]."</span>";
 
 	echo "<br><br>";
-	showCentralOnglets($_SERVER['PHP_SELF'],$_SESSION['glpi_viewcentral']);
 
-	switch ($_SESSION['glpi_viewcentral']){
-		case "global" :
-			showCentralGlobalView();
-			break;
-		case "group" :
-			showCentralGroupView();
-			break;
-		case "plugins" :
-			
-			echo "<table class='tab_cadre_central' ><tr><td>";
-		
-			doHook("central_action");
-			echo "</td></tr>";
-		
-			echo "</table>";
-			
-			break;
-		case "all":
-			showCentralMyView();
-			echo "<br>";
-			showCentralGroupView();
-			echo "<br>";
-			showCentralGlobalView();
-			echo "<br>";
-			if (isset($PLUGIN_HOOKS['central_action'])&&count($PLUGIN_HOOKS['central_action'])){
-				
-				echo "<table class='tab_cadre_central' ><tr><td>";
-			
-				doHook("central_action");
-				echo "</td></tr>";
-			
-				echo "</table>";
-				
-			}
+	
+	$tabs['my']=array('title'=>$LANG['central'][12],
+		'url'=>$CFG_GLPI['root_doc']."/ajax/central.tabs.php",
+		'params'=>"target=".$_SERVER['PHP_SELF']."&type=central&glpi_tab=my");
+	$tabs['group']=array('title'=>$LANG['central'][14],
+		'url'=>$CFG_GLPI['root_doc']."/ajax/central.tabs.php",
+		'params'=>"target=".$_SERVER['PHP_SELF']."&type=central&glpi_tab=group");
+	$tabs['global']=array('title'=>$LANG['central'][13],
+		'url'=>$CFG_GLPI['root_doc']."/ajax/central.tabs.php",
+		'params'=>"target=".$_SERVER['PHP_SELF']."&type=central&glpi_tab=global");
 
-			break;
-		default :
-			showCentralMyView();
-			break;
-	}
+	$plug_tabs=getPluginTabs($_SERVER['PHP_SELF'],"central","","");
+	$tabs+=$plug_tabs;
 
+	$tabs[-1]=array('title'=>$LANG['common'][66],
+		'url'=>$CFG_GLPI['root_doc']."/ajax/central.tabs.php",
+		'params'=>"target=".$_SERVER['PHP_SELF']."&type=central&glpi_tab=-1");
 
+	echo "<div id='tabspanel' class='center-h'></div>";
+	createAjaxTabs('tabspanel','tabcontent',$tabs,$_SESSION['glpi_tab']);
+	echo "<div id='tabcontent'></div>";
+	echo "<script type='text/javascript'>loadDefaultTab();</script>";
 
 
 commonFooter();
