@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: computer.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: computer.form.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -47,19 +47,19 @@ if(!isset($_GET["withtemplate"])) $_GET["withtemplate"] = "";
 $computer=new Computer();
 //Add a new computer
 if (isset($_POST["add"])) {
-	checkRight("computer","w");
+	$computer->check(-1,'w',$_POST['FK_entities']);
 	$newID=$computer->add($_POST);
-	logEvent($newID, "computers", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][20]." ".$_POST["name"].".");
+	logEvent($newID, "computers", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$_POST["name"].".");
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 // delete a computer
 else if (isset($_POST["delete"])) {
-	checkRight("computer","w");
+	$computer->check($_POST['ID'],'w');
 
 	if (!empty($_POST["withtemplate"]))
 		$computer->delete($_POST,1);
 	else $computer->delete($_POST);
-	logEvent($_POST["ID"], "computers", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+	logEvent($_POST["ID"], "computers", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 	if(!empty($_POST["withtemplate"])) 
 		glpi_header($CFG_GLPI["root_doc"]."/front/setup.templates.php");
 	else 
@@ -67,51 +67,54 @@ else if (isset($_POST["delete"])) {
 }
 else if (isset($_POST["restore"]))
 {
-	checkRight("computer","w");
+	$computer->check($_POST['ID'],'w');
 	$computer->restore($_POST);
-	logEvent($_POST["ID"],"computers", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][23]);
+	logEvent($_POST["ID"],"computers", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][23]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/computer.php");
 }
 else if (isset($_POST["purge"]) || isset($_GET["purge"]))
 {
-	checkRight("computer","w");
-
 	if (isset($_POST["purge"]))
 		$input["ID"]=$_POST["ID"];
 	else
 		$input["ID"] = $_GET["ID"];	
 
+	$computer->check($input['ID'],'w');
+
 	$computer->delete($input,1);
-	logEvent($input["ID"], "computers", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][24]);
+	logEvent($input["ID"], "computers", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][24]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/computer.php");
 }
 //update a computer
 else if (isset($_POST["update"])) {
-	checkRight("computer","w");
+	$computer->check($_POST['ID'],'w');
 	$computer->update($_POST);
-	logEvent($_POST["ID"], "computers", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+	logEvent($_POST["ID"], "computers", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 //Disconnect a device 
 else if (isset($_GET["disconnect"])) {
-	checkRight("computer","w");
+
+	$computer->check($_GET['cID'],'w');
+
 	Disconnect($_GET["ID"]);
-	logEvent($_GET["cID"], "computers", 5, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][26]);
+	logEvent($_GET["cID"], "computers", 5, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][26]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (isset($_POST["connect"])&&isset($_POST["item"])&&$_POST["item"]>0){
-	checkRight("computer","w");
+	$computer->check($_POST['cID'],'w');
+
 	Connect($_POST["item"],$_POST["cID"],$_POST["device_type"],$_POST["dohistory"]);
-	logEvent($_POST["cID"], "computers", 5, "inventory", $_SESSION["glpiname"] ." ".$LANG["log"][27]);
+	logEvent($_POST["cID"], "computers", 5, "inventory", $_SESSION["glpiname"] ." ".$LANG['log'][27]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 //Update a device specification
 elseif(isset($_POST["update_device"])) {
-	checkRight("computer","w");
+	$computer->check($_POST['ID'],'w');
 
 	// Update quantity
 	foreach ($_POST as $key => $val){
-		$data=split("_",$key);
+		$data=explode("_",$key);
 		if (count($data)==2)
 			if ($data[0]=="quantity"){
 				update_device_quantity($val,$data[1]);
@@ -120,25 +123,27 @@ elseif(isset($_POST["update_device"])) {
 
 	// Update specificity
 	foreach ($_POST as $key => $val){
-		$data=split("_",$key);
+		$data=explode("_",$key);
 		if (count($data)==2)
 			if ($data[0]=="devicevalue"){
 				update_device_specif($val,$data[1]);
 			} 
 	}
 
-	logEvent($_POST["ID"],"computers",4,"inventory",$_SESSION["glpiname"] ." ".$LANG["log"][28]);
+	logEvent($_POST["ID"],"computers",4,"inventory",$_SESSION["glpiname"] ." ".$LANG['log'][28]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 //add a new device
 elseif (isset($_POST["connect_device"])) {
-	checkRight("computer","w");
+	$computer->check($_POST['cID'],'w');
+
 	if (isset($_POST["new_device_id"])&&$_POST["new_device_id"]>0)
 		compdevice_add($_POST["cID"],$_POST["new_device_type"],$_POST["new_device_id"]);
 	glpi_header($_SERVER['PHP_SELF']."?ID=".$_POST["cID"]."&withtemplate=".$_POST["withtemplate"]);
 }
 elseif(isset($_POST["unlock_monitor"])){
-	checkRight("computer","w");
+	$computer->check($_POST['ID'],'w');
+
 	if (isset($_POST["lockmonitor"])&&count($_POST["lockmonitor"])){
 		foreach ($_POST["lockmonitor"] as $key => $val)
 			deleteInOcsArray($_POST["ID"],$key,"import_monitor");
@@ -146,7 +151,8 @@ elseif(isset($_POST["unlock_monitor"])){
 	glpi_header($_SERVER['HTTP_REFERER']);	
 }
 elseif(isset($_POST["unlock_printer"])){
-	checkRight("computer","w");
+	$computer->check($_POST['ID'],'w');
+
 	if (isset($_POST["lockprinter"])&&count($_POST["lockprinter"])){
 		foreach ($_POST["lockprinter"] as $key => $val)
 			deleteInOcsArray($_POST["ID"],$key,"import_printers");
@@ -154,15 +160,26 @@ elseif(isset($_POST["unlock_printer"])){
 	glpi_header($_SERVER['HTTP_REFERER']);	
 }
 elseif(isset($_POST["unlock_soft"])){
-	checkRight("computer","w");
+	$computer->check($_POST['ID'],'w');
+
 	if (isset($_POST["locksoft"])&&count($_POST["locksoft"])){
 		foreach ($_POST["locksoft"] as $key => $val)
 			deleteInOcsArray($_POST["ID"],$key,"import_software");
 	}
 	glpi_header($_SERVER['HTTP_REFERER']);	
 }
+elseif(isset($_POST["unlock_disk"])){
+	$computer->check($_POST['ID'],'w');
+
+	if (isset($_POST["lockdisk"])&&count($_POST["lockdisk"])){
+		foreach ($_POST["lockdisk"] as $key => $val)
+			deleteInOcsArray($_POST["ID"],$key,"import_disk");
+	}
+	glpi_header($_SERVER['HTTP_REFERER']);	
+}
 elseif(isset($_POST["unlock_periph"])){
-	checkRight("computer","w");
+	$computer->check($_POST['ID'],'w');
+
 	if (isset($_POST["lockperiph"])&&count($_POST["lockperiph"])){
 		foreach ($_POST["lockperiph"] as $key => $val)
 			deleteInOcsArray($_POST["ID"],$key,"import_peripheral");
@@ -170,7 +187,8 @@ elseif(isset($_POST["unlock_periph"])){
 	glpi_header($_SERVER['HTTP_REFERER']);	
 }
 elseif(isset($_POST["unlock_ip"])){
-	checkRight("computer","w");
+	$computer->check($_POST['ID'],'w');
+
 	if (isset($_POST["lockip"])&&count($_POST["lockip"])){
 		foreach ($_POST["lockip"] as $key => $val)
 			deleteInOcsArray($_POST["ID"],$key,"import_ip");
@@ -178,15 +196,15 @@ elseif(isset($_POST["unlock_ip"])){
 	glpi_header($_SERVER['HTTP_REFERER']);	
 }
 elseif(isset($_POST["unlock_field"])){
-	checkRight("computer","w");
+	$computer->check($_POST['ID'],'w');
+
 	if (isset($_POST["lockfield"])&&count($_POST["lockfield"])){
 		foreach ($_POST["lockfield"] as $key => $val)
 			deleteInOcsArray($_POST["ID"],$key,"computer_update");
 	}
 	glpi_header($_SERVER['HTTP_REFERER']);
 } elseif (isset($_POST["force_ocs_resynch"])){
-	//checkRight("ocsng","w");
-	checkRight("sync_ocsng","w");
+	$computer->check($_POST['ID'],'w');
 	
 	//Get the ocs server id associated with the machine
 	$ocs_server_id = getOCSServerByMachineID($_POST["ID"]);
@@ -196,110 +214,9 @@ elseif(isset($_POST["unlock_field"])){
 	glpi_header($_SERVER['HTTP_REFERER']);
 } else {//print computer informations
 
-	checkRight("computer","r");
-
-
-	if (!isset($_SESSION['glpi_onglet'])) $_SESSION['glpi_onglet']=1;
-	if (isset($_GET['onglet'])) {
-		$_SESSION['glpi_onglet']=$_GET['onglet'];
-	}
-
-
-	commonHeader($LANG["Menu"][0],$_SERVER['PHP_SELF'],"inventory","computer");
-
+	commonHeader($LANG['Menu'][0],$_SERVER['PHP_SELF'],"inventory","computer");
 	//show computer form to add
-	if (!empty($_GET["withtemplate"])) {
-	
-		if ($computer->showForm($_SERVER['PHP_SELF'],$_GET["ID"], $_GET["withtemplate"])){
-			if ($_GET["ID"]>0){
-				switch($_SESSION['glpi_onglet']){
-					case 2 :			
-						showSoftwareInstalled($_GET["ID"],$_GET["withtemplate"]);
-						break;
-					case 3 :
-						showConnections($_SERVER['PHP_SELF'],$_GET["ID"],$_GET["withtemplate"]);
-						if ($_GET["withtemplate"]!=2)
-							showPortsAdd($_GET["ID"],COMPUTER_TYPE);
-						showPorts($_GET["ID"], COMPUTER_TYPE,$_GET["withtemplate"]);
-						break;					
-					case 4 :
-						showInfocomForm($CFG_GLPI["root_doc"]."/front/infocom.form.php",COMPUTER_TYPE,$_GET["ID"],1,$_GET["withtemplate"]);
-						showContractAssociated(COMPUTER_TYPE,$_GET["ID"],$_GET["withtemplate"]);
-						break;
-					case 5 :
-						showDocumentAssociated(COMPUTER_TYPE,$_GET["ID"],$_GET["withtemplate"]);
-						break;
-					default :
-						if (!displayPluginAction(COMPUTER_TYPE,$_GET["ID"],$_SESSION['glpi_onglet'], $_GET["withtemplate"]))
-							showDeviceComputerForm($_SERVER['PHP_SELF'],$_GET["ID"], $_GET["withtemplate"]);	
-						break;
-				}
-			}
-		}
-	} else {
-
-		if ($computer->showForm($_SERVER['PHP_SELF'],$_GET["ID"], $_GET["withtemplate"])) {
-			switch($_SESSION['glpi_onglet']){
-				case -1 :
-					showDeviceComputerForm($_SERVER['PHP_SELF'],$_GET["ID"], $_GET["withtemplate"]);			
-					showSoftwareInstalled($_GET["ID"]);
-					showConnections($_SERVER['PHP_SELF'],$_GET["ID"]);
-					showPortsAdd($_GET["ID"],COMPUTER_TYPE);
-					showPorts($_GET["ID"], COMPUTER_TYPE);
-					showInfocomForm($CFG_GLPI["root_doc"]."/front/infocom.form.php",COMPUTER_TYPE,$_GET["ID"]);
-					showContractAssociated(COMPUTER_TYPE,$_GET["ID"]);
-					showDocumentAssociated(COMPUTER_TYPE,$_GET["ID"]);
-					showJobListForItem($_SESSION["glpiname"],COMPUTER_TYPE,$_GET["ID"],$_GET["sort"],$_GET["order"]);
-					showOldJobListForItem($_SESSION["glpiname"],COMPUTER_TYPE,$_GET["ID"],$_GET["sort"],$_GET["order"]);
-					showLinkOnDevice(COMPUTER_TYPE,$_GET["ID"]);
-					showRegistry($_GET["ID"]);
-					displayPluginAction(COMPUTER_TYPE,$_GET["ID"],$_SESSION['glpi_onglet'],$_GET["withtemplate"]);
-					break;
-				case 2 :
-					showSoftwareInstalled($_GET["ID"]);
-					break;
-				case 3 :
-					showConnections($_SERVER['PHP_SELF'],$_GET["ID"]);
-					showPortsAdd($_GET["ID"],COMPUTER_TYPE);
-					showPorts($_GET["ID"], COMPUTER_TYPE);
-					break;
-				case 4 :
-					showInfocomForm($CFG_GLPI["root_doc"]."/front/infocom.form.php",COMPUTER_TYPE,$_GET["ID"]);
-					showContractAssociated(COMPUTER_TYPE,$_GET["ID"]);
-					break;
-				case 5 :
-					showDocumentAssociated(COMPUTER_TYPE,$_GET["ID"]);
-					break;
-				case 6 :
-					showJobListForItem($_SESSION["glpiname"],COMPUTER_TYPE,$_GET["ID"],$_GET["sort"],$_GET["order"]);
-					showOldJobListForItem($_SESSION["glpiname"],COMPUTER_TYPE,$_GET["ID"],$_GET["sort"],$_GET["order"]);
-					break;
-				case 7 :
-					showLinkOnDevice(COMPUTER_TYPE,$_GET["ID"]);
-					break;
-				case 10 :
-					showNotesForm($_SERVER['PHP_SELF'],COMPUTER_TYPE,$_GET["ID"]);
-					break;
-				case 11 :
-					showDeviceReservations($_SERVER['PHP_SELF'],COMPUTER_TYPE,$_GET["ID"]);
-					break;
-				case 12 :
-					showHistory(COMPUTER_TYPE,$_GET["ID"]);
-					break;
-				case 13 :
-					ocsEditLock($_SERVER['PHP_SELF'],$_GET["ID"]);
-					break;
-				case 14:					
-					showRegistry($_GET["ID"]);
-					break;
-				default :
-					if (!displayPluginAction(COMPUTER_TYPE,$_GET["ID"],$_SESSION['glpi_onglet'],$_GET["withtemplate"]))
-						showDeviceComputerForm($_SERVER['PHP_SELF'],$_GET["ID"], $_GET["withtemplate"]);			
-					break;
-			}
-
-		}
-	}
+	$computer->showForm($_SERVER['PHP_SELF'],$_GET["ID"], $_GET["withtemplate"]);
 	commonFooter();
 }
 ?>
