@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: computer.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: computer.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -41,20 +41,20 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 if (isset($_GET["add_search_count"])){
 	$_SESSION["glpisearchcount"][$_GET["type"]]++;
-	glpi_header(ereg_replace("reset_before=1","",$_SERVER['HTTP_REFERER']));
+	glpi_header(str_replace("reset_before=1","",$_SERVER['HTTP_REFERER']));
 }
 if (isset($_GET["delete_search_count"])){
 	$_SESSION["glpisearchcount"][$_GET["type"]]--;
-	glpi_header(ereg_replace("reset_before=1","",$_SERVER['HTTP_REFERER']));
+	glpi_header(str_replace("reset_before=1","",$_SERVER['HTTP_REFERER']));
 }
 
 if (isset($_GET["add_search_count2"])){
 	$_SESSION["glpisearchcount2"][$_GET["type"]]++;
-	glpi_header(ereg_replace("reset_before=1","",$_SERVER['HTTP_REFERER']));
+	glpi_header(str_replace("reset_before=1","",$_SERVER['HTTP_REFERER']));
 }
 if (isset($_GET["delete_search_count2"])){
 	$_SESSION["glpisearchcount2"][$_GET["type"]]--;
-	glpi_header(ereg_replace("reset_before=1","",$_SERVER['HTTP_REFERER']));
+	glpi_header(str_replace("reset_before=1","",$_SERVER['HTTP_REFERER']));
 }
 
 if (isset($_GET["reset_search"])){
@@ -69,13 +69,13 @@ if (isset($_GET["reset_search"])){
 
 checkRight("computer","r");
 
-commonHeader($LANG["Menu"][0],$_SERVER['PHP_SELF'],"inventory","computer");
+commonHeader($LANG['Menu'][0],$_SERVER['PHP_SELF'],"inventory","computer");
 
 manageGetValuesInSearch(COMPUTER_TYPE);
 
-searchForm(COMPUTER_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+searchForm(COMPUTER_TYPE,$_GET);
 
-showList(COMPUTER_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+showList(COMPUTER_TYPE,$_GET);
 
 commonFooter();
 ?>
