@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: consumable.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: consumable.form.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -45,94 +45,48 @@ $constype=new ConsumableType();
 
 if (isset($_POST["add"]))
 {
-	checkRight("consumable","w");
+	$constype->check(-1,'w',$_POST['FK_entities']);
 
 	$newID=$constype->add($_POST);
-	logEvent($newID, "consumables", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][20]." ".$_POST["name"].".");
+	logEvent($newID, "consumables", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$_POST["name"].".");
 	glpi_header($_SERVER['HTTP_REFERER']);
 } 
 else if (isset($_POST["delete"]))
 {
-	checkRight("consumable","w");
+	$constype->check($_POST["ID"],'w');
 
 	$constype->delete($_POST);
-	logEvent($_POST["ID"], "consumables", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+	logEvent($_POST["ID"], "consumables", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/consumable.php");
 }
 else if (isset($_POST["restore"]))
 {
-	checkRight("consumable","w");
+	$constype->check($_POST["ID"],'w');
 
 	$constype->restore($_POST);
-	logEvent($_POST["ID"], "consumables", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][23]);
+	logEvent($_POST["ID"], "consumables", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][23]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/consumable.php");
 }
 else if (isset($_POST["purge"]))
 {
-	checkRight("consumable","w");
+	$constype->check($_POST["ID"],'w');
 
 	$constype->delete($_POST,1);
-	logEvent($_POST["ID"], "consumables", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][24]);
+	logEvent($_POST["ID"], "consumables", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][24]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/consumable.php");
 }
 else if (isset($_POST["update"]))
 {
-	checkRight("consumable","w");
+	$constype->check($_POST["ID"],'w');
 
 	$constype->update($_POST);
-	logEvent($_POST["ID"], "consumables", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+	logEvent($_POST["ID"], "consumables", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 } 
 else
 {
-	checkRight("consumable","r");
-
-	if (!isset($_SESSION['glpi_onglet'])) $_SESSION['glpi_onglet']=1;
-	if (isset($_GET['onglet'])) {
-		$_SESSION['glpi_onglet']=$_GET['onglet'];
-		//	glpi_header($_SERVER['HTTP_REFERER']);
-	}
-
-	commonHeader($LANG["Menu"][32],$_SERVER['PHP_SELF'],"inventory","consumable");
-
-
-
-	if ($constype->showForm($_SERVER['PHP_SELF'],$_GET["ID"])) {
-		if (!empty($_GET['ID'])){
-			switch($_SESSION['glpi_onglet']){
-				case -1 :	
-					showConsumableAdd($_GET["ID"]);
-					showConsumables($_GET["ID"]);
-					showConsumables($_GET["ID"],1);
-					showInfocomForm($CFG_GLPI["root_doc"]."/front/infocom.form.php",CONSUMABLE_TYPE,$_GET["ID"],1);
-					showDocumentAssociated(CONSUMABLE_TYPE,$_GET["ID"]);
-					showLinkOnDevice(CONSUMABLE_TYPE,$_GET["ID"]);
-					displayPluginAction(CONSUMABLE_TYPE,$_GET["ID"],$_SESSION['glpi_onglet']);
-					break;
-				case 4 :
-					showInfocomForm($CFG_GLPI["root_doc"]."/front/infocom.form.php",CONSUMABLE_TYPE,$_GET["ID"],1);
-					break;
-				case 5 :
-					showDocumentAssociated(CONSUMABLE_TYPE,$_GET["ID"]);
-					break;
-
-				case 7 : 
-					showLinkOnDevice(CONSUMABLE_TYPE,$_GET["ID"]);
-					break;
-
-				case 10 :
-					showNotesForm($_SERVER['PHP_SELF'],CONSUMABLE_TYPE,$_GET["ID"]);
-					break;
-				default :
-					if (!displayPluginAction(CONSUMABLE_TYPE,$_GET["ID"],$_SESSION['glpi_onglet'])){
-						showConsumableAdd($_GET["ID"]);
-						showConsumables($_GET["ID"]);
-						showConsumables($_GET["ID"],1);
-					}
-					break;
-			}
-		}
-	}
+	commonHeader($LANG['Menu'][32],$_SERVER['PHP_SELF'],"inventory","consumable");
+	$constype->showForm($_SERVER['PHP_SELF'],$_GET["ID"]);
 	commonFooter();
 }
 
