@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: consumable.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: consumable.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -41,7 +41,7 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("consumable","r");
 
-commonHeader($LANG["Menu"][32],$_SERVER['PHP_SELF'],"inventory","consumable");
+commonHeader($LANG['Menu'][32],$_SERVER['PHP_SELF'],"inventory","consumable");
 
 if (isset($_GET["synthese"])){
 	showConsumableSummary();
@@ -50,9 +50,9 @@ if (isset($_GET["synthese"])){
 
 	manageGetValuesInSearch(CONSUMABLE_TYPE);
 
-	searchForm(CONSUMABLE_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+	searchForm(CONSUMABLE_TYPE,$_GET);
 
-	showList(CONSUMABLE_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+	showList(CONSUMABLE_TYPE,$_GET);
 
 }
 commonFooter();
