@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: contact.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: contact.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -41,14 +41,14 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("contact_enterprise","r");
 
-commonHeader($LANG["Menu"][22],$_SERVER['PHP_SELF'],"financial","contact");
+commonHeader($LANG['Menu'][22],$_SERVER['PHP_SELF'],"financial","contact");
 
 
 manageGetValuesInSearch(CONTACT_TYPE);
 
-searchForm(CONTACT_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+searchForm(CONTACT_TYPE,$_GET);
 
-showList(CONTACT_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+showList(CONTACT_TYPE,$_GET);
 
 commonFooter();
 ?>
