@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: contract.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: contract.form.php 8643 2009-08-06 16:40:34Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -47,7 +47,7 @@ if (isset($_POST["add"]))
 	$contract->check(-1,'w',$_POST['FK_entities']);
 	
 	$newID=$contract->add($_POST);
-	logEvent($newID, "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG["log"][20]." ".$_POST["num"].".");
+	logEvent($newID, "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$_POST["num"].".");
 	glpi_header($_SERVER['HTTP_REFERER']);
 } 
 else if (isset($_POST["delete"]))
@@ -55,7 +55,7 @@ else if (isset($_POST["delete"]))
 	$contract->check($_POST['ID'],'w');
 
 	$contract->delete($_POST);
-	logEvent($_POST["ID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+	logEvent($_POST["ID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/contract.php");
 }
 else if (isset($_POST["restore"]))
@@ -63,7 +63,7 @@ else if (isset($_POST["restore"]))
 	$contract->check($_POST['ID'],'w');
 
 	$contract->restore($_POST);
-	logEvent($_POST["ID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG["log"][23]);
+	logEvent($_POST["ID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][23]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/contract.php");
 }
 else if (isset($_POST["purge"]))
@@ -71,7 +71,7 @@ else if (isset($_POST["purge"]))
 	$contract->check($_POST['ID'],'w');
 
 	$contract->delete($_POST,1);
-	logEvent($_POST["ID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG["log"][24]);
+	logEvent($_POST["ID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][24]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/contract.php");
 }
 else if (isset($_POST["update"]))
@@ -79,59 +79,53 @@ else if (isset($_POST["update"]))
 	$contract->check($_POST['ID'],'w');
 
 	$contract->update($_POST);
-	logEvent($_POST["ID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+	logEvent($_POST["ID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 } 
 else if (isset($_POST["additem"]))
 {
-	if (strstr($_SERVER['HTTP_REFERER'], $_SERVER['SCRIPT_NAME'])) {
-		// error_log("update from contract form");
-		$contract->check($_POST['conID'],'w');
-	} else {
-		// error_log("update from infocom form of an equipement");
-		checkRight("contract_infocom","w");
-	}
+   if (strstr($_SERVER['HTTP_REFERER'], $_SERVER['SCRIPT_NAME'])) {
+      // error_log("update from contract form");
+      $contract->check($_POST['conID'],'w');
+   } else {
+      // error_log("update from infocom form of an equipement");
+      // TODO check write on object
+      checkRight("contract","r");
+   }
 
 	if ($_POST['type']>0&&$_POST['item']>0){
 		addDeviceContract($_POST["conID"],$_POST['type'],$_POST['item']);
-		logEvent($_POST["conID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG["log"][32]);
+		logEvent($_POST["conID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][32]);
 	}
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (isset($_POST["deleteitem"]))
 {
-	// delete item from massive action menu
-	
-	if (strstr($_SERVER['HTTP_REFERER'], $_SERVER['SCRIPT_NAME'])) {
-		// error_log("update from contract form");
-		$contract->check($_POST['conID'],'w');
-	} else {
-		// error_log("update from infocom form of an equipement");
-		checkRight("contract_infocom","w");
-	}
+   // delete item from massive action menu
+   $contract->check($_POST['conID'],'w');
 
 	if (count($_POST["item"]))
 		foreach ($_POST["item"] as $key => $val)
 			deleteDeviceContract($key);
 
-	logEvent($_POST["conID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG["log"][33]);
+	logEvent($_POST["conID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][33]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (isset($_GET["deleteitem"]))
 {
 	// delete single item from url on list
+   if (strstr($_SERVER['HTTP_REFERER'], $_SERVER['SCRIPT_NAME'])) {
+      //error_log("delete from contract form");
+      $contract->check($_GET['conID'],'w');
+   } else {
+      // error_log("delete from infocom form of an equipement");
+      // TODO check write on object
+      checkRight("contract","r");
+   }
 	
-	if (strstr($_SERVER['HTTP_REFERER'], $_SERVER['SCRIPT_NAME'])) {
-		// error_log("update from contract form");
-		$contract->check($_GET['conID'],'w');
-	} else {
-		// error_log("update from infocom form of an equipement");
-		checkRight("contract_infocom","w");
-	}
-
 	deleteDeviceContract($_GET["ID"]);
 
-	logEvent($_GET["conID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG["log"][33]);
+	logEvent($_GET["conID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][33]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (isset($_POST["addenterprise"]))
@@ -139,7 +133,7 @@ else if (isset($_POST["addenterprise"]))
 	$contract->check($_POST['conID'],'w');
 
 	addEnterpriseContract($_POST["conID"],$_POST["entID"]);
-	logEvent($_POST["conID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG["log"][34]);
+	logEvent($_POST["conID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][34]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (isset($_GET["deleteenterprise"]))
@@ -147,48 +141,15 @@ else if (isset($_GET["deleteenterprise"]))
 	$contract->check($_GET['conID'],'w');
 
 	deleteEnterpriseContract($_GET["ID"]);
-	logEvent($_GET["ID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG["log"][35]);
+	logEvent($_GET["ID"], "contracts", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][35]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else
 {
-	$contract->check($_GET["ID"],'r');
+	commonHeader($LANG['Menu'][25],$_SERVER['PHP_SELF'],"financial","contract");
 
-	if (!isset($_SESSION['glpi_onglet'])) $_SESSION['glpi_onglet']=1;
-	if (isset($_GET['onglet'])) {
-		$_SESSION['glpi_onglet']=$_GET['onglet'];
-	}
-
-	commonHeader($LANG["Menu"][25],$_SERVER['PHP_SELF'],"financial","contract");
-
-	if ($contract->showForm($_SERVER['PHP_SELF'],$_GET["ID"])) {
-		if ($_GET['ID']>0){
-			switch($_SESSION['glpi_onglet']){
-				case -1 :	
-					showEnterpriseContract($_GET["ID"]);
-					showDeviceContract($_GET["ID"]);
-					showDocumentAssociated(CONTRACT_TYPE,$_GET["ID"]);
-					showLinkOnDevice(CONTACT_TYPE,$_GET["ID"]);
-					displayPluginAction(CONTRACT_TYPE,$_GET["ID"],$_SESSION['glpi_onglet']);
-					break;
-				case 5 : 
-					showDocumentAssociated(CONTRACT_TYPE,$_GET["ID"]);
-					break;
-				case 7 : 
-					showLinkOnDevice(CONTRACT_TYPE,$_GET["ID"]);
-					break;
-				case 10 :
-					showNotesForm($_SERVER['PHP_SELF'],CONTRACT_TYPE,$_GET["ID"]);
-					break;
-				default :
-					if (!displayPluginAction(CONTRACT_TYPE,$_GET["ID"],$_SESSION['glpi_onglet'])){
-						showEnterpriseContract($_GET["ID"]);
-						showDeviceContract($_GET["ID"]);
-					}
-					break;
-			}
-		}
-	}	
+	$contract->showForm($_SERVER['PHP_SELF'],$_GET["ID"]);
+		
 	commonFooter();
 }
 
