@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: contract.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: contract.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -38,15 +38,15 @@ $NEEDED_ITEMS=array("contract","infocom","search");
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("contract_infocom","r");
+checkRight("contract","r");
 
-commonHeader($LANG["Menu"][25],$_SERVER['PHP_SELF'],"financial","contract");
+commonHeader($LANG['Menu'][25],$_SERVER['PHP_SELF'],"financial","contract");
 
 manageGetValuesInSearch(CONTRACT_TYPE);
 
-searchForm(CONTRACT_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+searchForm(CONTRACT_TYPE,$_GET);
 
-showList(CONTRACT_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+showList(CONTRACT_TYPE,$_GET);
 
 commonFooter();
 
