@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: device.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: device.form.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -51,36 +51,37 @@ else if (isset($_POST["referer"])) {
 
 $REFERER=preg_replace("/&/","&amp;",$REFERER);
 
-if (!isset($_SESSION['glpi_onglet'])) $_SESSION['glpi_onglet']=1;
+if (!isset($_SESSION['glpi_tab'])) $_SESSION['glpi_tab']=1;
 if (isset($_GET['onglet'])) {
-	$_SESSION['glpi_onglet']=$_GET['onglet'];
+	$_SESSION['glpi_tab']=$_GET['onglet'];
 }
 
 
-checkRight("device","w");
+$device = new Device(-1);
+$device->check(-1,"w");
 
 if (isset($_POST["add"])) {
 	$device=new Device($_POST["device_type"]);	
 	$newID=$device->add($_POST);
 
-	logEvent(0, "devices", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][20]." ".$_POST["designation"].".");
+	logEvent(0, "devices", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$_POST["designation"].".");
 	glpi_header($CFG_GLPI["root_doc"]."/front/device.php?device_type=".$_POST["device_type"]);
 }
 else if (isset($_POST["delete"])) {
 	$device=new Device($_POST["device_type"]);	
 	$device->delete($_POST);
-	logEvent($_POST["ID"], "devices", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+	logEvent($_POST["ID"], "devices", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/device.php?device_type=".$_POST["device_type"]);
 }
 else if (isset($_POST["update"])) {
 	$device=new Device($_POST["device_type"]);	
 	$device->update($_POST);
-	logEvent($_POST["ID"], "devices", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+	logEvent($_POST["ID"], "devices", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 	glpi_header($_SERVER['HTTP_REFERER']."&referer=$REFERER");
 }
 else {
 
-	commonHeader($LANG["title"][30],$_SERVER['PHP_SELF'],"config","device");
+	commonHeader($LANG['title'][30],$_SERVER['PHP_SELF'],"config","device");
 	showDevicesForm($_SERVER['PHP_SELF'],$_GET["ID"],$_GET["device_type"]);
 	commonFooter();
 }
