@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: document.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: document.form.php 8950 2009-09-12 14:58:37Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -34,7 +34,8 @@
 // ----------------------------------------------------------------------
 
 
-$NEEDED_ITEMS=array("document","computer","printer","monitor","peripheral","networking","software","contract","knowbase","cartridge","consumable","phone","enterprise","contact","tracking");
+$NEEDED_ITEMS=array("document","computer","printer","monitor","peripheral","networking","software",
+   "contract","knowbase","cartridge","consumable","phone","enterprise","contact","tracking","entity");
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
@@ -57,7 +58,7 @@ if (isset($_POST["add"]))
 			$name=$_FILES['filename']['name'];
 		}
 	}
-	logEvent($newID, "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG["log"][20]." ".$name.".");
+	logEvent($newID, "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$name.".");
 	glpi_header($_SERVER['HTTP_REFERER']);
 } 
 else if (isset($_POST["delete"]))
@@ -65,7 +66,7 @@ else if (isset($_POST["delete"]))
 	$doc->check($_POST["ID"],'w');
 
 	$doc->delete($_POST);
-	logEvent($_POST["ID"], "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+	logEvent($_POST["ID"], "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/document.php");
 }
 else if (isset($_POST["restore"]))
@@ -73,7 +74,7 @@ else if (isset($_POST["restore"]))
 	$doc->check($_POST["ID"],'w');
 
 	$doc->restore($_POST);
-	logEvent($_POST["ID"], "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG["log"][23]);
+	logEvent($_POST["ID"], "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG['log'][23]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/document.php");
 }
 else if (isset($_POST["purge"]))
@@ -81,7 +82,7 @@ else if (isset($_POST["purge"]))
 	$doc->check($_POST["ID"],'w');
 
 	$doc->delete($_POST,1);
-	logEvent($_POST["ID"], "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG["log"][24]);
+	logEvent($_POST["ID"], "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG['log'][24]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/document.php");
 }
 
@@ -90,7 +91,7 @@ else if (isset($_POST["update"]))
 	$doc->check($_POST["ID"],'w');
 
 	$doc->update($_POST);
-	logEvent($_POST["ID"], "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+	logEvent($_POST["ID"], "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 } 
 else if (isset($_POST["additem"])){
@@ -105,7 +106,7 @@ else if (isset($_POST["additem"])){
 
 	if ($_POST['type']>0&&$_POST['item']>0){
 		addDeviceDocument($_POST["conID"],$_POST['type'],$_POST['item']);
-		logEvent($_POST["conID"], "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG["log"][32]);
+		logEvent($_POST["conID"], "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG['log'][32]);
 	}
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
@@ -118,7 +119,7 @@ else if (isset($_POST["deleteitem"])){
 			deleteDeviceDocument($key);
 		}
 	}
-	logEvent($_POST["conID"], "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG["log"][33]);
+	logEvent($_POST["conID"], "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG['log'][33]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (isset($_GET["deleteitem"]) && isset($_GET["docid"]) && isset($_GET["devtype"]) && isset($_GET["devid"]) && isset($_GET["ID"])){
@@ -129,43 +130,13 @@ else if (isset($_GET["deleteitem"]) && isset($_GET["docid"]) && isset($_GET["dev
 
 	deleteDeviceDocument($_GET["ID"]);
 
-	logEvent($_GET["docid"], "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG["log"][33]);
+	logEvent($_GET["docid"], "documents", 4, "document", $_SESSION["glpiname"]." ".$LANG['log'][33]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else
 {
-	$doc->check($_GET["ID"],'r');
-
-	if (!isset($_SESSION['glpi_onglet'])) $_SESSION['glpi_onglet']=1;
-	if (isset($_GET['onglet'])) {
-		$_SESSION['glpi_onglet']=$_GET['onglet'];
-		//		glpi_header($_SERVER['HTTP_REFERER']);
-	}
-
-	commonHeader($LANG["Menu"][27],$_SERVER['PHP_SELF'],"financial","document");
-
-	if ($doc->showForm($_SERVER['PHP_SELF'],$_GET["ID"])){
-		switch ($_SESSION['glpi_onglet']){
-			case -1 :
-				showDeviceDocument($_GET["ID"]);
-				showDocumentAssociated(DOCUMENT_TYPE,$_GET["ID"]);
-				displayPluginAction(DOCUMENT_TYPE,$_GET["ID"],$_SESSION['glpi_onglet']);
-				break;
-			case 5 :
-				showDocumentAssociated(DOCUMENT_TYPE,$_GET["ID"]);
-				break;
-			case 10 :
-				showNotesForm($_SERVER['PHP_SELF'],DOCUMENT_TYPE,$_GET["ID"]);
-				break;
-			default :
-				if ($_GET["ID"]){
-					if (!displayPluginAction(DOCUMENT_TYPE,$_GET["ID"],$_SESSION['glpi_onglet'])){
-						showDeviceDocument($_GET["ID"]);
-					}
-				}
-				break;
-		}
-	}
+	commonHeader($LANG['Menu'][27],$_SERVER['PHP_SELF'],"financial","document");
+	$doc->showForm($_SERVER['PHP_SELF'],$_GET["ID"]);
 	commonFooter();
 }
 
