@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: document.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: document.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -40,13 +40,13 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("document","r");
 
-commonHeader($LANG["Menu"][27],$_SERVER['PHP_SELF'],"financial","document");
+commonHeader($LANG['Menu'][27],$_SERVER['PHP_SELF'],"financial","document");
 
 manageGetValuesInSearch(DOCUMENT_TYPE);
 
-searchForm(DOCUMENT_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+searchForm(DOCUMENT_TYPE,$_GET);
 
-showList(DOCUMENT_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+showList(DOCUMENT_TYPE,$_GET);
 
 commonFooter();
 
