@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: document.send.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: document.send.php 9089 2009-10-08 16:10:22Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -44,7 +44,7 @@ checkLoginUser();
 
 if (isset($_GET["file"])){
 
-	$splitter=split("/",$_GET["file"]);
+	$splitter=explode("/",$_GET["file"]);
 
 	if (count($splitter)==2){
 		$send=false;
@@ -60,20 +60,30 @@ if (isset($_GET["file"])){
 
 				if (isset($_SESSION["glpiactiveprofile"]["interface"])&&$_SESSION["glpiactiveprofile"]["interface"]=="central"){
 					// My doc Check and Common doc right access
-					if (haveRight("document","r")
-							||$doc->fields["FK_users"]==$_SESSION["glpiID"])
+					if ($doc->can($doc->fields['ID'],'r')
+							||$doc->fields["FK_users"]==$_SESSION["glpiID"]){
 						$send=true;
+               }
 
 					// Knowbase Case
 					if (!$send&&haveRight("knowbase","r")){
-						$query = "SELECT * FROM glpi_doc_device WHERE glpi_doc_device.device_type = '".KNOWBASE_TYPE."' AND glpi_doc_device.FK_doc='".$doc->fields["ID"]."'";
+						$query = "SELECT * 
+							FROM glpi_doc_device
+							WHERE glpi_doc_device.device_type = '".KNOWBASE_TYPE."'
+								AND glpi_doc_device.FK_doc='".$doc->fields["ID"]."' ";
 
 						$result=$DB->query($query);
-						if ($DB->numrows($result)>0)
+						if ($DB->numrows($result)>0){
 							$send=true;
+                  }
 					}
 					if (!$send&&haveRight("faq","r")){
-						$query = "SELECT * FROM glpi_doc_device LEFT JOIN glpi_kbitems ON (glpi_kbitems.ID = glpi_doc_device.Fk_device) WHERE glpi_doc_device.device_type = '".KNOWBASE_TYPE."' AND glpi_doc_device.FK_doc='".$doc->fields["ID"]."' AND glpi_kbitems.faq='1'";
+						$query = "SELECT * 
+							FROM glpi_doc_device 
+								LEFT JOIN glpi_kbitems ON (glpi_kbitems.ID = glpi_doc_device.Fk_device) 
+							WHERE glpi_doc_device.device_type = '".KNOWBASE_TYPE."' 
+								AND glpi_doc_device.FK_doc='".$doc->fields["ID"]."' 
+								AND glpi_kbitems.faq='1'";
 
 						$result=$DB->query($query);
 						if ($DB->numrows($result)>0)
@@ -87,7 +97,11 @@ if (isset($_GET["file"])){
 						$job->getFromDB($_GET["tracking"]);
 
 						if ($job->fields["author"]==$_SESSION["glpiID"]||$job->fields["assign"]==$_SESSION["glpiID"]){
-							$query = "SELECT * FROM glpi_doc_device WHERE glpi_doc_device.FK_device = '".$_GET["tracking"]."' AND glpi_doc_device.device_type = '".TRACKING_TYPE."' AND FK_doc='".$doc->fields["ID"]."'";
+							$query = "SELECT * 
+								FROM glpi_doc_device 
+								WHERE glpi_doc_device.FK_device = '".$_GET["tracking"]."' 
+									AND glpi_doc_device.device_type = '".TRACKING_TYPE."' 
+									AND FK_doc='".$doc->fields["ID"]."'";
 							$result=$DB->query($query);
 							if ($DB->numrows($result)>0)
 								$send=true;
@@ -101,7 +115,12 @@ if (isset($_GET["file"])){
 					} else {
 						if (haveRight("faq","r")||$CFG_GLPI["public_faq"]){
 							// Check if it is a FAQ document
-							$query = "SELECT * FROM glpi_doc_device LEFT JOIN glpi_kbitems ON (glpi_kbitems.ID = glpi_doc_device.Fk_device) WHERE glpi_doc_device.device_type = '".KNOWBASE_TYPE."' AND glpi_doc_device.FK_doc='".$doc->fields["ID"]."' AND glpi_kbitems.faq='1'";
+							$query = "SELECT * 
+								FROM glpi_doc_device 
+									LEFT JOIN glpi_kbitems ON (glpi_kbitems.ID = glpi_doc_device.Fk_device)
+								WHERE glpi_doc_device.device_type = '".KNOWBASE_TYPE."' 
+									AND glpi_doc_device.FK_doc='".$doc->fields["ID"]."'
+									AND glpi_kbitems.faq='1'";
 
 							$result=$DB->query($query);
 							if ($DB->numrows($result)>0)
@@ -114,7 +133,11 @@ if (isset($_GET["file"])){
 							$job->getFromDB($_GET["tracking"]);
 
 							if ($job->fields["author"]==$_SESSION["glpiID"]){
-								$query = "SELECT * FROM glpi_doc_device WHERE glpi_doc_device.FK_device = '".$_GET["tracking"]."' AND glpi_doc_device.device_type = '".TRACKING_TYPE."' AND FK_doc='".$doc->fields["ID"]."'";
+								$query = "SELECT * 
+									FROM glpi_doc_device 
+									WHERE glpi_doc_device.FK_device = '".$_GET["tracking"]."' 
+										AND glpi_doc_device.device_type = '".TRACKING_TYPE."' 
+										AND FK_doc='".$doc->fields["ID"]."'";
 								$result=$DB->query($query);
 								if ($DB->numrows($result)>0)
 									$send=true;
@@ -123,14 +146,14 @@ if (isset($_GET["file"])){
 
 					}
 				}
-			} else echo $LANG["document"][43];
+			} else echo $LANG['document'][43];
 		}
 
 
 		if ($send&&file_exists(GLPI_DOC_DIR."/".$_GET["file"]))
 			sendFile(GLPI_DOC_DIR."/".$_GET["file"],$splitter[1]);
-		else echo $LANG["document"][45];
-	} else echo $LANG["document"][44];
+		else echo $LANG['document'][45];
+	} else echo $LANG['document'][44];
 }
 
 
