@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: enterprise.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: enterprise.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -41,13 +41,13 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("contact_enterprise","r");
 
-commonHeader($LANG["Menu"][23],$_SERVER['PHP_SELF'],"financial","enterprise");
+commonHeader($LANG['Menu'][23],$_SERVER['PHP_SELF'],"financial","enterprise");
 
 manageGetValuesInSearch(ENTERPRISE_TYPE);
 
-searchForm(ENTERPRISE_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+searchForm(ENTERPRISE_TYPE,$_GET);
 
-showList(ENTERPRISE_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+showList(ENTERPRISE_TYPE,$_GET);
 
 commonFooter();
 
