@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: entity.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: entity.form.php 8413 2009-07-05 05:57:04Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -45,21 +45,23 @@ $entitydata=new EntityData();
 
 if (isset($_POST["update"]))
 {
-	checkRight("entity","w");
+	$entity->check($_POST["FK_entities"],'w');
+
 	$entitydata->update($_POST);
-	logEvent($_POST["ID"], "entity", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+
+	logEvent($_POST["ID"], "entity", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 } else if (isset($_POST["adduser"]))
 {
-	checkRight("entity","w");
+	$entity->check($_POST["FK_entities"],'w');
 
 	addUserProfileEntity($_POST);
 
-	logEvent($_POST["FK_entities"], "entity", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][61]);
+	logEvent($_POST["FK_entities"], "entity", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][61]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 } else if (isset($_POST["add_rule"]))
 {
-	checkRight("entity","w");
+	$entity->check($_POST["affectentity"],'w');
 
 
 	$rule = new OcsAffectEntityRule;
@@ -73,11 +75,11 @@ if (isset($_POST["update"]))
 		$ruleAction->addActionByAttributes("assign", $ruleid, "FK_entities", $_POST["affectentity"]);
 	}
 		
-	logEvent($ruleid, "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][20]);
+	logEvent($ruleid, "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][20]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 } else if (isset($_POST["add_user_rule"]))
 {
-	checkRight("entity","w");
+	$entity->check($_POST["affectentity"],'w');
 
 
 	$rule = new RightAffectRule;
@@ -95,12 +97,12 @@ if (isset($_POST["update"]))
 		$ruleAction->addActionByAttributes("assign", $ruleid, "recursive", $_POST["recursive"]);
 	}
 		
-	logEvent($ruleid, "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+	logEvent($ruleid, "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 
 } else if (isset($_POST["deleteuser"]))
 {
-	checkRight("entity","w");
+	$entity->check($_POST["FK_entities"],'w');
 
 	if (count($_POST["item"])){
 		foreach ($_POST["item"] as $key => $val){
@@ -108,11 +110,12 @@ if (isset($_POST["update"]))
 		}
 	}
 
-	logEvent($_POST["FK_entities"], "entity", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][62]);
+	logEvent($_POST["FK_entities"], "entity", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][62]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }elseif (isset($_POST["delete_computer_rule"]) || isset($_POST["delete_user_rule"]))
 {
-	checkRight("entity","w");
+	$entity->check($_POST["affectentity"],'w');
+
 	if (isset($_POST["delete_computer_rule"])){
 		$rule = new OcsAffectEntityRule;		
 	} else {
@@ -125,45 +128,13 @@ if (isset($_POST["update"]))
 		}
 	}
 
-	logEvent(0, "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+	logEvent(0, "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 
-commonHeader($LANG["Menu"][37],$_SERVER['PHP_SELF'],"admin","entity");
+commonHeader($LANG['Menu'][37],$_SERVER['PHP_SELF'],"admin","entity");
 
-if (!isset($_SESSION['glpi_onglet'])) $_SESSION['glpi_onglet']=1;
-if (isset($_GET['onglet'])) {
-	$_SESSION['glpi_onglet']=$_GET['onglet'];
-}	
-
-
-$ocsrule = new OcsAffectEntityRule;
-$ldaprule = new RightAffectRule;
-
-if ($entity->showForm($_SERVER['PHP_SELF'],$_GET["ID"])){
-	switch($_SESSION['glpi_onglet']){
-		case -1 :	
-			showEntityUser($_SERVER['PHP_SELF'],$_GET["ID"]);
-			displayPluginAction(ENTITY_TYPE,$_GET["ID"],$_SESSION['glpi_onglet']);
-			if ($CFG_GLPI["ocs_mode"])
-				$ocsrule->showAndAddRuleForm($_SERVER['PHP_SELF'],$_GET["ID"]);
-			$ldaprule->showAndAddRuleForm($_SERVER['PHP_SELF'],$_GET["ID"]);
-		break;
-		case 2 : 
-			showEntityUser($_SERVER['PHP_SELF'],$_GET["ID"]);
-		break;
-		case 3 :
-			$ldaprule->showAndAddRuleForm($_SERVER['PHP_SELF'],$_GET["ID"]);
-			if ($CFG_GLPI["ocs_mode"])
-				$ocsrule->showAndAddRuleForm($_SERVER['PHP_SELF'],$_GET["ID"]);
-			break;
-		default :
-			if (!displayPluginAction(ENTITY_TYPE,$_GET["ID"],$_SESSION['glpi_onglet'])){
-				
-			}
-		break;
-	}
-}
+$entity->showForm($_SERVER['PHP_SELF'],$_GET["ID"]);
 
 commonFooter();
-?>
\ No newline at end of file
+?>
