@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: entity.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: entity.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -40,7 +40,7 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("entity","r");
 
-commonHeader($LANG["Menu"][37],$_SERVER['PHP_SELF'],"admin","entity");
+commonHeader($LANG['Menu'][37],$_SERVER['PHP_SELF'],"admin","entity");
 
 $entity=new Entity();
 $entity->title();
@@ -48,9 +48,9 @@ $entity->title();
 
 manageGetValuesInSearch(ENTITY_TYPE);
 
-searchForm(ENTITY_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+searchForm(ENTITY_TYPE,$_GET);
 
-showList(ENTITY_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+showList(ENTITY_TYPE,$_GET);
 
 commonFooter();
 ?>
