@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: find_num.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: find_num.php 8515 2009-07-26 15:04:53Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -39,11 +39,12 @@ $NEEDED_ITEMS=array("user");
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-if(isset($_GET["name"]) && ($_GET["name"] == "Helpdesk") && ($CFG_GLPI["permit_helpdesk"] == "1"))
-{
+if($CFG_GLPI["permit_helpdesk"]){
 	$id = new Identification();
 	$id->initSession();
-} else exit();
+} else {
+	exit();
+}
 
 // Send UTF8 Headers
 header("Content-Type: text/html; charset=UTF-8");
@@ -76,15 +77,15 @@ function fillidfield(Type,Id){
 	<?php 
 
 	echo "<div align='center'>";
-	echo "<p><strong>".$LANG["help"][22]."</strong></p>";
+	echo "<p><strong>".$LANG['help'][22]."</strong></p>";
 	echo " <form name=\"form1\" method=\"post\"  action=\"".$_SERVER['PHP_SELF']."\">"; 
 
 	echo "<table cellspacing='1' width='100%'  class='tab_cadre'>";
-	echo "<tr><th align='center'  width='100%' height='29'>".$LANG["help"][23]."</th>";
+	echo "<tr><th align='center'  width='100%' height='29'>".$LANG['help'][23]."</th>";
 	echo "</tr><tr><td class='tab_bg_1' align='center' width='100%'>"; 
 	echo "<input name='NomContact' type='text' id='NomContact' >";
 	echo "<input type='hidden' name='send' value='1' />"; // bug IE ! La validation par enter ne fonctionne pas sans cette ligne  incroyable mais vrai !
-	echo "<input type='submit' name='send' value=\"". $LANG["buttons"][0]."\">";
+	echo "<input type='submit' name='send' value=\"". $LANG['buttons'][0]."\">";
 	echo "</td>  </tr> </table> </form></div>";
 
 
@@ -92,15 +93,19 @@ function fillidfield(Type,Id){
 {
 	echo "<table width='100%' class='tab_cadre'>";
 	echo " <tr class='tab_bg3'>";
-	echo " <td align='center' width='30%'><b>".$LANG["reports"][19]."</b></td>";
-	echo " <td align='center' width='20%'><b>".$LANG["help"][24]."</b></td>";
-	echo " <td align='center' width='30%'><b>".$LANG["common"][1]."</b></td>";
-	echo " <td align='center' width='5%'><b>".$LANG["common"][2]."</b></td>";
-	echo " <td align='center' width='20%'><b>".$LANG["common"][19]."&nbsp;/&nbsp;".$LANG["common"][20]."</b></td>";
+	echo " <td align='center' width='30%'><b>".$LANG['reports'][19]."</b></td>";
+	echo " <td align='center' width='20%'><b>".$LANG['help'][24]."</b></td>";
+	echo " <td align='center' width='30%'><b>".$LANG['common'][1]."</b></td>";
+	echo " <td align='center' width='5%'><b>".$LANG['common'][2]."</b></td>";
+	echo " <td align='center' width='20%'><b>".$LANG['common'][19]."&nbsp;/&nbsp;".$LANG['common'][20]."</b></td>";
 	echo " </tr>";
 
 
-	$query = "select name,ID,contact, serial, otherserial from glpi_computers where is_template='0' AND deleted='0' AND (contact like '%".$_POST["NomContact"]."%' OR name like '%".$_POST["NomContact"]."%' OR serial like '%".$_POST["NomContact"]."%' OR otherserial like '%".$_POST["NomContact"]."%')";
+	$query = "SELECT name, ID, contact, serial, otherserial 
+		FROM glpi_computers 
+		WHERE is_template='0' AND deleted='0' 
+			AND (contact LIKE '%".$_POST["NomContact"]."%' OR name LIKE '%".$_POST["NomContact"]."%' 
+				OR serial LIKE '%".$_POST["NomContact"]."%' OR otherserial LIKE '%".$_POST["NomContact"]."%')";
 	$result = $DB->query($query);
 	while($ligne = $DB->fetch_array($result))
 	{
@@ -111,7 +116,7 @@ function fillidfield(Type,Id){
 		$s2 = $ligne['otherserial'];
 		echo " <tr class='tab_find' onClick=\"fillidfield(".COMPUTER_TYPE.",".$Comp_num.")\">";
 		echo "<td width='25%' align='center'><b>&nbsp;$Contact</b></td>";
-		echo "<td width='25%' align='center'><b>&nbsp;".$LANG["help"][25]."</b></td>";
+		echo "<td width='25%' align='center'><b>&nbsp;".$LANG['help'][25]."</b></td>";
 		echo "<td width='25%' align='center'><b>&nbsp;$Computer&nbsp;</b></td>";
 		echo "<td  width='25%' align='center'>";
 		echo "<b>&nbsp;$Comp_num </b></td>";
@@ -123,7 +128,11 @@ function fillidfield(Type,Id){
 		echo "</tr>";
 	}
 
-	$query = "select name,ID,contact, serial, otherserial from glpi_networking where is_template='0' AND deleted='0' AND (contact like '%".$_POST["NomContact"]."%' OR name like '%".$_POST["NomContact"]."%' OR serial like '%".$_POST["NomContact"]."%' OR otherserial like '%".$_POST["NomContact"]."%')";
+	$query = "SELECT name, ID, contact, serial, otherserial 
+		FROM glpi_networking 
+		WHERE is_template='0' AND deleted='0' 
+			AND (contact LIKE '%".$_POST["NomContact"]."%' OR name LIKE '%".$_POST["NomContact"]."%' 
+				OR serial LIKE '%".$_POST["NomContact"]."%' OR otherserial LIKE '%".$_POST["NomContact"]."%')";
 	$result = $DB->query($query);
 	while($ligne = $DB->fetch_array($result))
 	{
@@ -134,7 +143,7 @@ function fillidfield(Type,Id){
 		$s2 = $ligne['otherserial'];
 		echo " <tr class='tab_find' onClick=\"fillidfield(".NETWORKING_TYPE.",".$Comp_num.")\">";
 		echo "<td width='25%' align='center'><b>&nbsp;$Contact </b></td>";
-		echo "<td width='25%' align='center'><b>&nbsp;".$LANG["help"][26]."</b></td>";
+		echo "<td width='25%' align='center'><b>&nbsp;".$LANG['help'][26]."</b></td>";
 		echo "<td width='25%' align='center'><b>&nbsp;$Computer </b></td>";
 		echo "<td  width='25%' align='center'>";
 		echo "<b>&nbsp;$Comp_num </b></td>";
@@ -146,7 +155,11 @@ function fillidfield(Type,Id){
 		echo "</tr>";
 	}
 
-	$query = "select name,ID,contact, serial, otherserial from glpi_printers where is_template='0' AND deleted='0' AND (contact like '%".$_POST["NomContact"]."%' OR name like '%".$_POST["NomContact"]."%' OR serial like '%".$_POST["NomContact"]."%' OR otherserial like '%".$_POST["NomContact"]."%')";
+	$query = "SELECT name, ID, contact, serial, otherserial 
+		FROM glpi_printers 
+		WHERE is_template='0' AND deleted='0' 
+			AND (contact LIKE '%".$_POST["NomContact"]."%' OR name LIKE '%".$_POST["NomContact"]."%' 
+				OR serial LIKE '%".$_POST["NomContact"]."%' OR otherserial LIKE '%".$_POST["NomContact"]."%')";
 	$result = $DB->query($query);
 	while($ligne = $DB->fetch_array($result))
 	{
@@ -157,7 +170,7 @@ function fillidfield(Type,Id){
 		$s2 = $ligne['otherserial'];
 		echo " <tr class='tab_find' onClick=\"fillidfield(".PRINTER_TYPE.",".$Comp_num.")\">";
 		echo "<td width='25%' align='center'><b>&nbsp;$Contact </b></td>";
-		echo "<td width='25%' align='center'><b>&nbsp;".$LANG["help"][27]."</b></td>";
+		echo "<td width='25%' align='center'><b>&nbsp;".$LANG['help'][27]."</b></td>";
 		echo "<td width='25%' align='center'><b>&nbsp;$Computer </b></td>";
 		echo "<td  width='25%' align='center'>";
 		echo "<b>&nbsp;$Comp_num </b></td>";
@@ -169,7 +182,11 @@ function fillidfield(Type,Id){
 		echo "</tr>";
 	}
 
-	$query = "select name,ID,contact, serial, otherserial from glpi_monitors where is_template='0' AND deleted='0' AND (contact like '%".$_POST["NomContact"]."%' OR name like '%".$_POST["NomContact"]."%' OR serial like '%".$_POST["NomContact"]."%' OR otherserial like '%".$_POST["NomContact"]."%')";
+	$query = "SELECT name, ID, contact, serial, otherserial 
+		FROM glpi_monitors 
+		WHERE is_template='0' AND deleted='0' 
+			AND (contact LIKE '%".$_POST["NomContact"]."%' OR name LIKE '%".$_POST["NomContact"]."%' 
+				OR serial LIKE '%".$_POST["NomContact"]."%' OR otherserial LIKE '%".$_POST["NomContact"]."%')";
 	$result = $DB->query($query);
 	while($ligne = $DB->fetch_array($result))
 	{
@@ -180,7 +197,7 @@ function fillidfield(Type,Id){
 		$s2 = $ligne['otherserial'];
 		echo " <tr class='tab_find' onClick=\"fillidfield(".MONITOR_TYPE.",".$Comp_num.")\">";
 		echo "<td width='25%' align='center'><b>&nbsp;$Contact </b></td>";
-		echo "<td width='25%' align='center'><b>&nbsp;".$LANG["help"][28]."</b></td>";
+		echo "<td width='25%' align='center'><b>&nbsp;".$LANG['help'][28]."</b></td>";
 		echo "<td width='25%' align='center'><b>&nbsp;$Computer </b></td>";
 		echo "<td  width='25%' align='center'>";
 		echo "<b>&nbsp;$Comp_num </b></td>";
@@ -192,7 +209,11 @@ function fillidfield(Type,Id){
 		echo "</tr>";
 	}
 
-	$query = "select name,ID,contact, serial, otherserial from glpi_peripherals where is_template='0' AND deleted='0' AND (contact like '%".$_POST["NomContact"]."%' OR name like '%".$_POST["NomContact"]."%' OR serial like '%".$_POST["NomContact"]."%' OR otherserial like '%".$_POST["NomContact"]."%')";
+	$query = "SELECT name, ID, contact, serial, otherserial 
+		FROM glpi_peripherals 
+		WHERE is_template='0' AND deleted='0' 
+			AND (contact LIKE '%".$_POST["NomContact"]."%' OR name LIKE '%".$_POST["NomContact"]."%' 
+				OR serial LIKE '%".$_POST["NomContact"]."%' OR otherserial LIKE '%".$_POST["NomContact"]."%')";
 	$result = $DB->query($query);
 	while($ligne = $DB->fetch_array($result))
 	{
@@ -203,7 +224,7 @@ function fillidfield(Type,Id){
 		$s2 = $ligne['otherserial'];
 		echo " <tr class='tab_find' onClick=\"fillidfield(".PERIPHERAL_TYPE.",".$Comp_num.")\">";
 		echo "<td width='25%' align='center'><b>&nbsp;$Contact </b></td>";
-		echo "<td width='25%' align='center'><b>&nbsp;".$LANG["help"][29]."</b></td>";
+		echo "<td width='25%' align='center'><b>&nbsp;".$LANG['help'][29]."</b></td>";
 		echo "<td width='25%' align='center'><b>&nbsp;$Computer </b></td>";
 		echo "<td  width='25%' align='center'>";
 		echo "<b>&nbsp;$Comp_num </b></td>";
@@ -215,7 +236,10 @@ function fillidfield(Type,Id){
 		echo "</tr>";
 	}
 
-	$query = "select name,ID from glpi_software where is_template='0' AND deleted='0' AND (name like '%".$_POST["NomContact"]."%' )";
+	$query = "SELECT name, ID 
+		FROM glpi_software 
+		WHERE is_template='0' AND deleted='0' 
+			AND (name LIKE '%".$_POST["NomContact"]."%' )";
 	$result = $DB->query($query);
 	while($ligne = $DB->fetch_array($result))
 	{
@@ -223,7 +247,7 @@ function fillidfield(Type,Id){
 		$Computer = $ligne['name'];
 		echo " <tr class='tab_find' onClick=\"fillidfield(".SOFTWARE_TYPE.",".$Comp_num.")\">";
 		echo "<td width='25%' align='center'>&nbsp;</td>";
-		echo "<td width='25%' align='center'><b>&nbsp;".$LANG["help"][31]."</b></td>";
+		echo "<td width='25%' align='center'><b>&nbsp;".$LANG['help'][31]."</b></td>";
 		echo "<td width='25%' align='center'><b>&nbsp;$Computer </b></td>";
 		echo "<td  width='25%' align='center'>";
 		echo "<b>&nbsp;$Comp_num </b></td>";
@@ -235,5 +259,5 @@ function fillidfield(Type,Id){
 
 	echo "</table>";
 }
-?>
-</body></html>
+echo '</body></html>';
+?>
\ No newline at end of file
