@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: group.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: group.form.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -43,79 +43,58 @@ if(empty($_GET["ID"])) $_GET["ID"] = "";
 $group=new Group;
 if (isset($_POST["add"]))
 {
-	checkRight("group","w");
+	$group->check(-1,'w',$_POST['FK_entities']);
 
 	$newID=$group->add($_POST);
-	logEvent($newID, "groups", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][20]." ".$_POST["name"].".");
+	logEvent($newID, "groups", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$_POST["name"].".");
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (isset($_POST["delete"]))
 {
-	checkRight("group","w");
+	$group->check($_POST["ID"],'w');
 
 	$group->delete($_POST);
-	logEvent($_POST["ID"], "groups", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+	logEvent($_POST["ID"], "groups", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/group.php");
 }
 else if (isset($_POST["update"]))
 {
-	checkRight("group","w");
+	$group->check($_POST["ID"],'w');
 
 	$group->update($_POST);
-	logEvent($_POST["ID"], "groups", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+	logEvent($_POST["ID"], "groups", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (isset($_POST["adduser"]))
 {
-	checkRight("group","w");
+	$group->check($_POST["FK_groups"],'w');
 
 	addUserGroup($_POST["FK_users"],$_POST["FK_groups"]);
 
-	logEvent($_POST["FK_groups"], "groups", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][48]);
+	logEvent($_POST["FK_groups"], "groups", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][48]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (isset($_POST["deleteuser"]))
 {
-	checkRight("group","w");
+	$group->check($_POST["FK_groups"],'w');
 
 	if (count($_POST["item"]))
 		foreach ($_POST["item"] as $key => $val)
 			deleteUserGroup($key);
 
-	logEvent($_POST["FK_groups"], "groups", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][49]);
+	logEvent($_POST["FK_groups"], "groups", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][49]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else
 {
-	checkRight("group","r");
-
-	if (!isset($_SESSION['glpi_onglet'])) $_SESSION['glpi_onglet']=1;
+	if (!isset($_SESSION['glpi_tab'])) $_SESSION['glpi_tab']=1;
 	if (isset($_GET['onglet'])) {
-		$_SESSION['glpi_onglet']=$_GET['onglet'];
+		$_SESSION['glpi_tab']=$_GET['onglet'];
 	}
 
-	commonHeader($LANG["Menu"][36],$_SERVER['PHP_SELF'],"admin","group");
+	commonHeader($LANG['Menu'][36],$_SERVER['PHP_SELF'],"admin","group");
 
-	if ($group->showForm($_SERVER['PHP_SELF'],$_GET["ID"])) {
-		if (!empty($_GET['ID'])){
-			switch($_SESSION['glpi_onglet']){
-				case -1 :	
-					showGroupUsers($_SERVER['PHP_SELF'],$_GET["ID"]);
-					showGroupDevice($_GET["ID"]);
-					displayPluginAction(GROUP_TYPE,$_GET["ID"],$_SESSION['glpi_onglet']);
-					break;
-				case 2 : 
-					showGroupDevice($_GET["ID"]);
-					break;
-
-				default :
-					if (!displayPluginAction(GROUP_TYPE,$_GET["ID"],$_SESSION['glpi_onglet'])){
-						showGroupUsers($_SERVER['PHP_SELF'],$_GET["ID"]);
-					}
-					break;
-			}
-		}
-	}	
+	$group->showForm($_SERVER['PHP_SELF'],$_GET["ID"]);	
 
 	commonFooter();
 }
