@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: group.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: group.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -40,16 +40,16 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("group","r");
 
-commonHeader($LANG["Menu"][36],$_SERVER['PHP_SELF'],"admin","group");
+commonHeader($LANG['Menu'][36],$_SERVER['PHP_SELF'],"admin","group");
 
 $group = new Group;
 $group->title();
 
 manageGetValuesInSearch(GROUP_TYPE);
 
-searchForm(GROUP_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+searchForm(GROUP_TYPE,$_GET);
 
-showList(GROUP_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+showList(GROUP_TYPE,$_GET);
 
 commonFooter();
 ?>
