@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: helpdesk.faq.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: helpdesk.faq.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -56,11 +56,11 @@ if (isset($_GET["redirect"])){
 	$name="";
 	checkFaqAccess();
 	if (isset($_SESSION["glpiID"])){
-		helpHeader($LANG["Menu"][20],$_SERVER['PHP_SELF'],$_SESSION["glpiname"]);
+		helpHeader($LANG['Menu'][20],$_SERVER['PHP_SELF'],$_SESSION["glpiname"]);
 	} else {
-		$_SESSION["glpilanguage"]=$CFG_GLPI['default_language'];
+		$_SESSION["glpilanguage"]=$CFG_GLPI['language'];
 		// Anonymous FAQ
-		simpleHeader($LANG["Menu"][20],array($LANG["Menu"][20]=>$_SERVER['PHP_SELF']));
+		simpleHeader($LANG['Menu'][20],array($LANG['Menu'][20]=>$_SERVER['PHP_SELF']));
 	}
 	
 	if(!isset($_GET["start"])) $_GET["start"] = 0;
