@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: helpdesk.resa.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: helpdesk.resa.php 8924 2009-09-07 07:13:09Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -50,7 +50,7 @@ if (isset($_GET["redirect"])){
 	checkRight("reservation_helpdesk","1");
 	$rr=new ReservationResa();
 	if (isset($_POST["edit_resa"])){
-		list($begin_year,$begin_month,$begin_day)=split("-",$_POST["begin_date"]);
+		list($begin_year,$begin_month,$begin_day)=explode("-",$_POST["begin_date"]);
 		$id_item=key($_POST["items"]);
 		if ($_SESSION["glpiID"]==$_POST["id_user"]){
 			$_POST['_target']=$_SERVER['PHP_SELF'];
@@ -64,14 +64,14 @@ if (isset($_GET["redirect"])){
 		}
 	}
 
-	helpHeader($LANG["title"][1],$_SERVER['PHP_SELF'],$_SESSION["glpiname"]);
+	helpHeader($LANG['title'][1],$_SERVER['PHP_SELF'],$_SESSION["glpiname"]);
 
 	if (isset($_POST["clear_resa"])){
 		$id_item=key($_POST["items"]);
 		if ($rr->delete($_POST)){ // delete() need an array !
 			logEvent($_POST["ID"], "reservation", 4, "inventory", $_SESSION["glpiname"]." delete a reservation.");
 		}
-		list($begin_year,$begin_month,$begin_day)=split("-",$_POST["begin_date"]);
+		list($begin_year,$begin_month,$begin_day)=explode("-",$_POST["begin_date"]);
 		$_GET["mois_courant"]=$begin_month;
 		$_GET["annee_courant"]=$begin_year;
 		printCalendrier($_SERVER['PHP_SELF'],$id_item);
@@ -95,17 +95,21 @@ if (isset($_GET["redirect"])){
 			$_POST['id_item']=$id_item;
 			$ok=true;
 			$times=$_POST["periodicity_times"];
-			list($begin_year,$begin_month,$begin_day)=split("-",$_POST["begin_date"]);
-			list($end_year,$end_month,$end_day)=split("-",$_POST["end_date"]);
+
+			$begin=$_POST["begin"];
+			list($begin_year,$begin_month,$begin_day)=explode("-",$_POST["begin"]);
+			$end=$_POST["end"];
+
 			$to_add=1;
 			if ($_POST["periodicity"]=="week") {
 				$to_add=7;
 			}
 			$_POST['_target']=$_SERVER['PHP_SELF'];
 			$_POST['_ok']=true;
-			for ($i=1;$i<=$times&&$_POST['_ok'];$i++){
-				$_POST["begin_date"]=date("Y-m-d",mktime(0,0,0,$begin_month,$begin_day+($i-1)*$to_add,$begin_year));
-				$_POST["end_date"]=date("Y-m-d",mktime(0,0,0,$end_month,$end_day+($i-1)*$to_add,$end_year));
+			for ($i=0;$i<$times&&$_POST['_ok'];$i++){
+				$_POST["begin"]=date('Y-m-d H:i:s', strtotime($begin)+$i*$to_add*DAY_TIMESTAMP);
+				$_POST["end"]=date('Y-m-d H:i:s', strtotime($end)+$i*$to_add*DAY_TIMESTAMP);
+
 				if ($_SESSION["glpiID"]==$_POST["id_user"]) {
 					unset($rr->fields["ID"]);
 					$_POST['_ok']=$rr->add($_POST);
