@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: infocom.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: infocom.form.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -43,26 +43,26 @@ $ic=new Infocom();
 
 if (isset($_GET["add"]))
 {
-	checkRight("contract_infocom","w");
+	checkRight("infocom","w");
 	
 	$newID=$ic->add($_GET, false);
-	logEvent($newID, "infocom", 4, "financial", $_SESSION["glpiname"]." ".$LANG["log"][20]);
+	logEvent($newID, "infocom", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][20]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 } 
 else if (isset($_POST["delete"]))
 {
-	checkRight("contract_infocom","w");
+	checkRight("infocom","w");
 
 	$ic->delete($_POST);
-	logEvent($_POST["ID"], "infocom", 4, "financial", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+	logEvent($_POST["ID"], "infocom", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (isset($_POST["update"]))
 {
-	checkRight("contract_infocom","w");
+	checkRight("infocom","w");
 
 	$ic->update($_POST);
-	logEvent($_POST["ID"], "infocom", 4, "financial", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+	logEvent($_POST["ID"], "infocom", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 } 
 
