@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: infocom.show.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: infocom.show.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -40,9 +40,9 @@ define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
 
-checkRight("contract_infocom","r");
+checkRight("infocom","r");
 
-popHeader($LANG["financial"][3],$_SERVER['PHP_SELF']);
+popHeader($LANG['financial'][3],$_SERVER['PHP_SELF']);
 
 $ci=new CommonItem();
 
@@ -54,7 +54,7 @@ if (isset($_GET["ID"])){
 }
 
 if(!isset($_GET["device_type"])||!isset($_GET["device_id"])||!$ci->getFromDB($_GET["device_type"],$_GET["device_id"]))
-echo "<div align='center'><br><br>".$LANG["financial"][85]."</div>";
+echo "<div align='center'><br><br>".$LANG['financial'][85]."</div>";
 else {
 
 	echo "<div align='center'><br><br><strong>".$ci->getType()." - ".$ci->getName()."</strong></div>";
