@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: knowbase.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: knowbase.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -46,7 +46,7 @@ if (isset($_GET["ID"])){
 	glpi_header($CFG_GLPI["root_doc"]."/front/knowbase.form.php?ID=".$_GET["ID"]);
 }
 
-commonHeader($LANG["title"][5],$_SERVER['PHP_SELF'],"utils","knowbase");
+commonHeader($LANG['title'][5],$_SERVER['PHP_SELF'],"utils","knowbase");
 
 
 if(!isset($_GET["start"])) $_GET["start"] = 0;
