@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ldap.import.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: ldap.import.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -34,14 +34,14 @@
 // ----------------------------------------------------------------------
 
 
-$NEEDED_ITEMS=array("ldap","user","profile","group","entity","rulesengine","rule.right");
+$NEEDED_ITEMS=array("ldap","user","profile","group","entity","rulesengine","rule.right","setup");
 
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
 checkSeveralRightsAnd(array("user"=>"w", "user_auth_method"=>"w"));
 
-commonHeader($LANG["setup"][3],$_SERVER['PHP_SELF'],"admin","user","ldap");
+commonHeader($LANG['setup'][3],$_SERVER['PHP_SELF'],"admin","user","ldap");
 
 if (isset($_GET['next']))
 {
@@ -64,8 +64,8 @@ if (isset($_SESSION["ldap_import"])){
 	   
 		displayProgressBar(400,100);
 
-		echo "<div align='center'><strong>".$LANG["ocsng"][8]."<br>";
-		echo "<a href='".$_SERVER['PHP_SELF']."'>".$LANG["buttons"][13]."</a>";
+		echo "<div align='center'><strong>".$LANG['ocsng'][8]."<br>";
+		echo "<a href='".$_SERVER['PHP_SELF']."'>".$LANG['buttons'][13]."</a>";
 		echo "</strong></div>";
 	}
 }
@@ -90,8 +90,8 @@ elseif (!isset($_POST["import_ok"])){
 	if (!testLDAPConnection($_SESSION["ldap_server"]))
 	{
 		unset($_SESSION["ldap_server"]);
-		echo "<div align='center'><strong>".$LANG["ldap"][6]."<br>";
-		echo "<a href='".$_SERVER['PHP_SELF']."?next=listservers'>".$LANG["buttons"][13]."</a>";
+		echo "<div align='center'><strong>".$LANG['ldap'][6]."<br>";
+		echo "<a href='".$_SERVER['PHP_SELF']."?next=listservers'>".$LANG['buttons'][13]."</a>";
 		echo "</strong></div>";
 	}
 	else
@@ -99,7 +99,13 @@ elseif (!isset($_POST["import_ok"])){
 			if (!isset($_SESSION["ldap_filter"])){
 				$_SESSION["ldap_filter"]='';
 			}
-			showLdapUsers($_SERVER['PHP_SELF'],$_GET['check'],$_GET['start'],0,$_SESSION["ldap_filter"]);
+
+			if (!isset($_SESSION["ldap_sortorder"]))
+				$_SESSION["ldap_sortorder"]="DESC";
+			else
+				$_SESSION["ldap_sortorder"]=(!isset($_GET["order"])?"DESC":$_GET["order"]);
+					
+			showLdapUsers($_SERVER['PHP_SELF'],$_GET['check'],$_GET['start'],0,$_SESSION["ldap_filter"],$_SESSION["ldap_sortorder"]);
 	}
 } else {
 
