@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ldap.parameters.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: ldap.parameters.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -55,7 +55,7 @@ if (isset($_POST["delete"])){
 
 checkRight("user","w");
 
-commonHeader($LANG["setup"][142]." ".$LANG["ruleldap"][1],$_SERVER['PHP_SELF'],"admin","rule",-1);
+commonHeader($LANG['Menu'][26]." ".$LANG['ruleldap'][1],$_SERVER['PHP_SELF'],"admin","rule",-1);
 
 $params = new LdapCriteria;
 $params->showForm($_SERVER['PHP_SELF']);
