@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ldap.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: ldap.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -38,17 +38,18 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkSeveralRightsAnd(array("user"=>"w", "user_auth_method"=>"w"));
 
-commonHeader($LANG["setup"][3],$_SERVER['PHP_SELF'],"admin","user","ldap");
+commonHeader($LANG['setup'][3],$_SERVER['PHP_SELF'],"admin","user","ldap");
 if (isset($_SESSION["ldap_import"])) unset($_SESSION["ldap_import"]);
 if (isset($_SESSION["ldap_sync"])) unset($_SESSION["ldap_sync"]);
 if (isset($_SESSION["ldap_server"])) unset($_SESSION["ldap_server"]);
+if (isset($_SESSION["ldap_sortorder"])) unset($_SESSION["ldap_sortorder"]);
 
 echo "<div align='center'><table class='tab_cadre' cellpadding='5'>";
-echo "<tr><th>".$LANG["ldap"][0]."</th></tr>";
+echo "<tr><th>".$LANG['ldap'][0]."</th></tr>";
 
-echo "<tr class='tab_bg_1'><td  align='center'><a href=\"ldap.sync.php?next=listservers\"><b>".$LANG["ldap"][1]."</b></a></td></tr>";
+echo "<tr class='tab_bg_1'><td  align='center'><a href=\"ldap.sync.php?next=listservers\"><b>".$LANG['ldap'][1]."</b></a></td></tr>";
 
-echo "<tr class='tab_bg_1'><td align='center'><a href=\"ldap.import.php?next=listservers\"><b>".$LANG["ldap"][2]."</b></a></td> </tr>";
+echo "<tr class='tab_bg_1'><td align='center'><a href=\"ldap.import.php?next=listservers\"><b>".$LANG['ldap'][2]."</b></a></td> </tr>";
 
 echo "</table></div>";
 
