@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: ldap.sync.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: ldap.sync.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -38,7 +38,7 @@
 $NEEDED_ITEMS = array (
 	"ldap",
 	"user",
-	"profile","entity","group","rulesengine","rule.right"
+	"profile","entity","group","rulesengine","rule.right","setup"
 );
 
 define('GLPI_ROOT', '..');
@@ -46,7 +46,7 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkSeveralRightsAnd(array("user"=>"w", "user_auth_method"=>"w"));
 
-commonHeader($LANG["setup"][3],$_SERVER['PHP_SELF'],"admin","user","ldap");
+commonHeader($LANG['setup'][3],$_SERVER['PHP_SELF'],"admin","user","ldap");
 
 if (isset ($_GET['next'])) {
 	ldapChooseDirectory($_SERVER['PHP_SELF']);
@@ -65,8 +65,8 @@ if (isset ($_GET['next'])) {
 			unset ($_SESSION["ldap_sync"]);
 			displayProgressBar(400, 100);
 
-			echo "<div align='center'><strong>" . $LANG["ocsng"][8] . "<br>";
-			echo "<a href='" . $_SERVER['PHP_SELF'] . "'>" . $LANG["buttons"][13] . "</a>";
+			echo "<div align='center'><strong>" . $LANG['ocsng'][8] . "<br>";
+			echo "<a href='" . $_SERVER['PHP_SELF'] . "'>" . $LANG['buttons'][13] . "</a>";
 			echo "</strong></div>";
 		}
 	}
@@ -92,16 +92,21 @@ elseif (!isset ($_POST["sync_ok"])) {
 		//If a connection to the server can not be established, display a page with a back link
 		if (!testLDAPConnection($_SESSION["ldap_server"])) {
 			unset ($_SESSION["ldap_server"]);
-			echo "<div align='center'><strong>" . $LANG["ldap"][6] . "<br>";
-			echo "<a href='" . $_SERVER['PHP_SELF'] . "?next=listservers'>" . $LANG["buttons"][13] . "</a>";
+			echo "<div align='center'><strong>" . $LANG['ldap'][6] . "<br>";
+			echo "<a href='" . $_SERVER['PHP_SELF'] . "?next=listservers'>" . $LANG['buttons'][13] . "</a>";
 			echo "</strong></div>";
 		} else
 		{
 			//Display users to synchronise
 			if (!isset($_SESSION["ldap_filter"]))
 				$_SESSION["ldap_filter"]='';
+
+			if (!isset($_SESSION["ldap_sortorder"]))
+				$_SESSION["ldap_sortorder"]="DESC";
+			else
+				$_SESSION["ldap_sortorder"]=(!isset($_GET["order"])?"DESC":$_GET["order"]);
 				
-			showLdapUsers($_SERVER['PHP_SELF'], $_GET['check'], $_GET['start'], 1,$_SESSION["ldap_filter"]);
+			showLdapUsers($_SERVER['PHP_SELF'], $_GET['check'], $_GET['start'], 1,$_SESSION["ldap_filter"],$_SESSION["ldap_sortorder"]);
 		}
 	} else {
 
