@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: link.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: link.form.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -46,54 +46,52 @@ $link=new Link();
 
 if (isset($_POST["add"]))
 {
-	checkRight("link","w");
+	$link->check(-1,'w');
 
 	$newID=$link->add($_POST);
-	logEvent($newID, "links", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][20]." ".$_POST["name"].".");
+	logEvent($newID, "links", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$_POST["name"].".");
 	glpi_header($CFG_GLPI["root_doc"]."/front/link.php");
 }
 else if (isset($_POST["delete"]))
 {
-	checkRight("link","w");
+	$link->check($_POST["ID"],'w');
 
 	$link->delete($_POST);
-	logEvent($_POST["ID"], "links", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+	logEvent($_POST["ID"], "links", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/link.php");
 }
 else if (isset($_POST["update"]))
 {
-	checkRight("link","w");
+	$link->check($_POST["ID"],'w');
 
 	$link->update($_POST);
-	logEvent($_POST["ID"], "links", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+	logEvent($_POST["ID"], "links", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (isset($_POST["adddevice"])){
-	checkRight("link","w");
+	$link->check($_POST["lID"],'w');
 
 	addLinkDevice($_POST["device_type"],$_POST["lID"]);
-	logEvent($_POST["lID"], "links", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][32]);
+	logEvent($_POST["lID"], "links", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][32]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/link.form.php?ID=".$_POST["lID"]);
 }
 else if (isset($_GET["deletedevice"])){
-	checkRight("link","w");
+	$link->check($_GET["lID"],'w');
 
 	deleteLinkDevice($_GET["ID"]);
-	logEvent(0, "links", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][33]);
+	logEvent($_GET["lID"], "links", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][33]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 
 else
 {
-	checkRight("link","r");
-
-	if (!isset($_SESSION['glpi_onglet'])) $_SESSION['glpi_onglet']=1;
+	if (!isset($_SESSION['glpi_tab'])) $_SESSION['glpi_tab']=1;
 	if (isset($_GET['onglet'])) {
-		$_SESSION['glpi_onglet']=$_GET['onglet'];
+		$_SESSION['glpi_tab']=$_GET['onglet'];
 		//		glpi_header($_SERVER['HTTP_REFERER']);
 	}
 
-	commonHeader($LANG["title"][33],$_SERVER['PHP_SELF'],"config","link");
+	commonHeader($LANG['title'][33],$_SERVER['PHP_SELF'],"config","link");
 
 	if ($link->showForm($_SERVER['PHP_SELF'],$_GET["ID"])&&!empty($_GET["ID"]))
 		showLinkDevice($_GET["ID"]);
