@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: link.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: link.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -40,13 +40,13 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("link","r");
 
-commonHeader($LANG["title"][33],$_SERVER['PHP_SELF'],"config","link");
+commonHeader($LANG['title'][33],$_SERVER['PHP_SELF'],"config","link");
 
 manageGetValuesInSearch(LINK_TYPE);
 
-searchForm(LINK_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+searchForm(LINK_TYPE,$_GET);
 
-showList(LINK_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+showList(LINK_TYPE,$_GET);
 
 commonFooter();
 ?>
