@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: link.send.php 7875 2009-01-23 15:16:47Z moyo $
+ * @version $Id: link.send.php 7889 2009-01-24 22:38:48Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -37,7 +37,9 @@ include (GLPI_ROOT . "/inc/includes.php");
 checkRight("link","r");
 
 if (isset($_GET["lID"])){
-	$query="SELECT glpi_links.ID as ID, glpi_links.link as link,glpi_links.data as data from glpi_links WHERE glpi_links.ID='".$_GET["lID"]."'";
+	$query="SELECT glpi_links.ID as ID, glpi_links.link as link,glpi_links.data as data 
+		FROM glpi_links 
+		WHERE glpi_links.ID='".$_GET["lID"]."'";
 
 	$result=$DB->query($query);
 	if ($DB->numrows($result)==1){
@@ -49,55 +51,58 @@ if (isset($_GET["lID"])){
 		$ci->getFromDB($_GET["type"],$_GET["ID"]);
 
 		// Manage Filename
-		if (ereg("\[NAME\]",$link)){
-			$link=ereg_replace("\[NAME\]",$ci->getName(),$link);
+		if (strstr($link,"[NAME]")){
+			$link=str_replace("[NAME]",$ci->getName(),$link);
 		}
 
-		if (ereg("\[ID\]",$link)){
-			$link=ereg_replace("\[ID\]",$_GET["ID"],$link);
+		if (strstr($link,"[ID]")){
+			$link=str_replace("[ID]",$_GET["ID"],$link);
 		}
 
 
 		// Manage File Content
 
-		if (ereg("\[NAME\]",$file)){
-			$file=ereg_replace("\[NAME\]",$ci->getName(),$file);
+		if (strstr($file,"[NAME]")){
+			$file=str_replace("[NAME]",$ci->getName(),$file);
 		}
 
-		if (ereg("\[ID\]",$file)){
-			$file=ereg_replace("\[ID\]",$_GET["ID"],$file);
+		if (strstr($file,"[ID]")){
+			$file=str_replace("[ID]",$_GET["ID"],$file);
 		}
 
-		if (ereg("\[SERIAL\]",$file)){
+		if (strstr($file,"[SERIAL]")){
 			if (isset($ci->obj->fields["serial"]))
-				$file=ereg_replace("\[SERIAL\]",$ci->obj->fields["serial"],$file);
+				$file=str_replace("[SERIAL]",$ci->obj->fields["serial"],$file);
 		}
-		if (ereg("\[OTHERSERIAL\]",$file)){
+		if (strstr($file,"[OTHERSERIAL]")){
 			if (isset($ci->obj->fields["otherserial"]))
-				$file=ereg_replace("\[OTHERSERIAL\]",$ci->obj->fields["otherserial"],$file);
+				$file=str_replace("[OTHERSERIAL]",$ci->obj->fields["otherserial"],$file);
 		}
 
 
-		if (ereg("\[LOCATIONID\]",$file)){
+		if (strstr($file,"[LOCATIONID]")){
 			if (isset($ci->obj->fields["location"]))
-				$file=ereg_replace("\[LOCATIONID\]",$ci->obj->fields["location"],$file);
+				$file=str_replace("[LOCATIONID]",$ci->obj->fields["location"],$file);
 		}
-		if (ereg("\[LOCATION\]",$file)){
+		if (strstr($file,"[LOCATION]")){
 			if (isset($ci->obj->fields["location"]))
-				$file=ereg_replace("\[LOCATION\]",getDropdownName("glpi_dropdown_locations",$ci->obj->fields["location"]),$file);
+				$file=str_replace("[LOCATION]",getDropdownName("glpi_dropdown_locations",$ci->obj->fields["location"]),$file);
 		}
-		if (ereg("\[NETWORK\]",$file)){
+		if (strstr($file,"[NETWORK]")){
 			if (isset($ci->obj->fields["network"]))
-				$file=ereg_replace("\[NETWORK\]",getDropdownName("glpi_dropdown_network",$ci->obj->fields["network"]),$file);
+				$file=str_replace("[NETWORK]",getDropdownName("glpi_dropdown_network",$ci->obj->fields["network"]),$file);
 		}
-		if (ereg("\[DOMAIN\]",$file)){
+		if (strstr($file,"[DOMAIN]")){
 			if (isset($ci->obj->fields["domain"]))
-				$file=ereg_replace("\[DOMAIN\]",getDropdownName("glpi_dropdown_domain",$ci->obj->fields["domain"]),$file);
+				$file=str_replace("[DOMAIN]",getDropdownName("glpi_dropdown_domain",$ci->obj->fields["domain"]),$file);
 		}
 		$ipmac=array();
 		$i=0;
-		if (ereg("\[IP\]",$file)||ereg("\[MAC\]",$file)){
-			$query2 = "SELECT ifaddr,ifmac FROM glpi_networking_ports WHERE (on_device = '".$_GET["ID"]."' AND device_type = '".$_GET["type"]."') ORDER BY logical_number";
+		if (strstr($file,"[IP]")||strstr($file,"[MAC]")){
+			$query2 = "SELECT ifaddr, ifmac 
+				FROM glpi_networking_ports 
+				WHERE (on_device = '".$_GET["ID"]."' AND device_type = '".$_GET["type"]."') 
+				ORDER BY logical_number";
 			$result2=$DB->query($query2);
 			if ($DB->numrows($result2)>0){
 				$data2=$DB->fetch_array($result2);
@@ -106,12 +111,12 @@ if (isset($_GET["lID"])){
 			}
 		}
 
-		if (ereg("\[IP\]",$file)||ereg("\[MAC\]",$file)){
+		if (strstr($file,"[IP]")||strstr($file,"[MAC]")){
 
 			if (count($ipmac)>0){
 				foreach ($ipmac as $key => $val){
-					$file=ereg_replace("\[IP\]",$val['ifaddr'],$file);
-					$file=ereg_replace("\[MAC\]",$val['ifmac'],$file);
+					$file=str_replace("[IP]",$val['ifaddr'],$file);
+					$file=str_replace("[MAC]",$val['ifmac'],$file);
 				}
 			}
 		}
