@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: log.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: log.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -44,7 +44,7 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("logs","r");
 
-commonHeader($LANG["Menu"][30],$_SERVER['PHP_SELF'],"admin","log");
+commonHeader($LANG['Menu'][30],$_SERVER['PHP_SELF'],"admin","log");
 
 //echo "<hr noshade>";
 
