@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: mailgate.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: mailgate.form.php 8481 2009-07-23 09:44:28Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -35,7 +35,7 @@
 
 
 
-$NEEDED_ITEMS=array("mailgate","setup","tracking","rulesengine","rule.tracking","user","mailing","document","group","enterprise");
+$NEEDED_ITEMS=array("mailgate","setup","tracking","rulesengine","rule.tracking","user","mailing","document","group","enterprise","computer","printer","networking","peripheral","monitor","software","infocom","phone","planning");
 
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
@@ -43,38 +43,42 @@ include (GLPI_ROOT . "/inc/includes.php");
 if(!isset($_GET["ID"])) $_GET["ID"] = "";
 
 $mailgate=new Mailgate();
-checkRight("config", "w");
+
+
 if (isset($_POST["add"]))
 {
-
+	$mailgate->check(-1,'w');
 	$newID=$mailgate->add($_POST);
 	logEvent($newID, "mailgate", 4, "setup", $_SESSION["glpiname"]." added ".$_POST["name"].".");
 	glpi_header($_SERVER['HTTP_REFERER']);
 } 
 else if (isset($_POST["delete"]))
 {
+	$mailgate->check($_POST['ID'],'w');
 	$mailgate->delete($_POST);
-	logEvent($_POST["ID"], "mailgate", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+	logEvent($_POST["ID"], "mailgate", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/mailgate.php");
 }
 else if (isset($_POST["update"]))
 {
-
+	$mailgate->check($_POST['ID'],'w');
 	$mailgate->update($_POST);
-	logEvent($_POST["ID"], "mailgate", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+	logEvent($_POST["ID"], "mailgate", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (isset($_POST["get_mails"]))
 {
+	$mailgate->check($_POST['ID'],'w');
+
 	$mc=new MailCollect();
 	if ($mailgate->getFromDB($_POST["ID"])){
-		$mc->collect($mailgate->fields["host"],$mailgate->fields["login"],$mailgate->fields["password"],$mailgate->fields["FK_entities"],1);
+		$mc->collect($mailgate->fields["host"],$mailgate->fields["login"],$mailgate->fields["password"],$mailgate->fields["FK_entities"],1,$_POST['ID']);
 	}
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else
 {
-	commonHeader($LANG["Menu"][39],$_SERVER['PHP_SELF'],"config","mailgate");
+	commonHeader($LANG['Menu'][39],$_SERVER['PHP_SELF'],"config","mailgate");
 	$mailgate->showForm($_SERVER['PHP_SELF'],$_GET["ID"]);
 	commonFooter();
 }
