@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: mailgate.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: mailgate.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -44,20 +44,20 @@ include (GLPI_ROOT . "/inc/includes.php");
 checkRight("config", "w");
 
 
-	commonHeader($LANG["Menu"][39], $_SERVER['PHP_SELF'], "config","mailgate");
+	commonHeader($LANG['Menu'][39], $_SERVER['PHP_SELF'], "config","mailgate");
 
 if (!canUseImapPop()) {
 	echo "<div align='center'>";
 	echo "<table class='tab_cadre_fixe'>";
-	echo "<tr><th colspan='2'>" . $LANG["Menu"][39] . "</th></tr>";
-	echo "<tr class='tab_bg_2'><td align='center'><p class='red'>" . $LANG["setup"][165] . "</p></td></tr></table>";
+	echo "<tr><th colspan='2'>" . $LANG['Menu'][39] . "</th></tr>";
+	echo "<tr class='tab_bg_2'><td align='center'><p class='red'>" . $LANG['setup'][165] . "</p></td></tr></table>";
 	echo "</div>";
 	commonFooter();
 	exit();
 } else {
 	manageGetValuesInSearch(MAILGATE_TYPE);
-	searchForm(MAILGATE_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
-	showList(MAILGATE_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+	searchForm(MAILGATE_TYPE,$_GET);
+	showList(MAILGATE_TYPE,$_GET);
 	
 	commonFooter();
 }
