@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: massiveaction.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: massiveaction.php 8465 2009-07-18 07:20:05Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -45,6 +45,7 @@ include (GLPI_ROOT . "/inc/includes.php");
 header("Content-Type: text/html; charset=UTF-8");
 header_nocache();
 
+
 if (isset($_GET['multiple_actions'])){
 	if (isset($_SESSION['glpi_massiveaction'])&&isset($_SESSION['glpi_massiveaction']['POST'])){
 		$_POST=$_SESSION['glpi_massiveaction']['POST'];
@@ -53,7 +54,7 @@ if (isset($_GET['multiple_actions'])){
 
 if (isset($_POST["device_type"])){
 
-
+	// Right check
 	switch ($_POST["device_type"]){
 		case TRACKING_TYPE :
 			switch ($_POST["action"]){
@@ -70,14 +71,14 @@ if (isset($_POST["device_type"])){
 			break;
 		default :
 			if (in_array($_POST["device_type"],$CFG_GLPI["infocom_types"])){
-				checkSeveralRightsOr(array($_POST["device_type"]=>"w","contract_infocom"=>"w"));
+				checkSeveralRightsOr(array($_POST["device_type"]=>"w","infocom"=>"w"));
 			} else {
 				checkTypeRight($_POST["device_type"],"w");
 			}
 			break;
 	}
 
-	commonHeader($LANG["title"][42],$_SERVER['PHP_SELF']);
+	commonHeader($LANG['title'][42],$_SERVER['PHP_SELF']);
 	
 	
 	if (isset($_GET['multiple_actions'])){
@@ -89,6 +90,7 @@ if (isset($_POST["device_type"])){
 	
 	
 	if (isset($_POST["action"])&&isset($_POST["device_type"])&&isset($_POST["item"])&&count($_POST["item"])){
+
 	
 	// Save selection
 	if (!isset($_SESSION['glpimassiveactionselected'])||count($_SESSION['glpimassiveactionselected'])==0){
@@ -155,7 +157,9 @@ if (isset($_POST["device_type"])){
 			case "disconnect":
 				foreach ($_POST["item"] as $key => $val){
 					if ($val==1) {
-						$query="SELECT * FROM glpi_connect_wire WHERE type='".$_POST["device_type"]."' AND end1 = '$key'";
+						$query="SELECT * 
+							FROM glpi_connect_wire 
+							WHERE type='".$_POST["device_type"]."' AND end1 = '$key'";
 						$result=$DB->query($query);
 						if ($DB->numrows($result)>0){
 							while ($data=$DB->fetch_assoc($result)){
@@ -228,7 +232,7 @@ if (isset($_POST["device_type"])){
 					} else { // Not infocoms
 						$ci=new CommonItem();
 						$ci->setType($_POST["device_type"],1);
-						$link_entity_type=-1;
+						$link_entity_type=array();
 						// Specific entity item
 						
 						if ($searchopt[$_POST["id_field"]]["table"]!=$LINK_ID_TABLE[$_POST["device_type"]]
@@ -240,7 +244,11 @@ if (isset($_POST["device_type"])){
 		
 							if ($ci2->getFromDB($_POST[$_POST["field"]])){
 								if (isset($ci2->fields["FK_entities"])&&$ci2->fields["FK_entities"]>=0){
-									$link_entity_type=$ci2->fields["FK_entities"];
+									if (isset($ci2->fields["recursive"])&&$ci2->fields["recursive"]){
+										$link_entity_type=getEntitySons($ci2->fields["FK_entities"]);
+									} else {
+										$link_entity_type[]=$ci2->fields["FK_entities"];
+									}
 								}
 		
 							}
@@ -249,11 +257,11 @@ if (isset($_POST["device_type"])){
 						foreach ($_POST["item"] as $key => $val){
 							if ($val==1) {
 								if ($ci->getFromDB($_POST["device_type"],$key)){
-									if ($link_entity_type<0
-									||$link_entity_type==$ci->obj->fields["FK_entities"]){
+									if (count($link_entity_type)==0
+										|| in_array($ci->obj->fields["FK_entities"], $link_entity_type)){
 										$ci->obj->update(array("ID"=>$key,$_POST["field"] => $_POST[$_POST["field"]]));
 									}
-									// else error_log("Access denied for update (not infocom)");
+									// else error_log("Access denied for update (not infocom) ci->obj->fields[FK_entities]=".$ci->obj->fields["FK_entities"]."  link_entity_type=".implode(",", $link_entity_type));
 								} 
 							}
 						}
@@ -265,7 +273,7 @@ if (isset($_POST["device_type"])){
 					if ($val==1) {
 						$comp=new Computer;
 						if ($comp->getFromDB($key)&&$comp->fields["FK_entities"]==$_SESSION["glpiactive_entity"]){
-							installSoftware($key,$_POST["lID"],$_POST["sID"]);
+							installSoftwareVersion($key,$_POST["vID"]);
 						}
 					}
 				}
@@ -297,9 +305,16 @@ if (isset($_POST["device_type"])){
 							// Items exists ?
 							if ($ci2->getFromDB($_POST["device_type"],$key)){
 								// Entity security
-								if (!isset($ci2->obj->fields["FK_entities"])
-								||$ci->obj->fields["FK_entities"]==$ci2->obj->fields["FK_entities"]
-								||($ci->obj->fields["recursive"] && in_array($ci->obj->fields["FK_entities"], getEntityAncestors($ci2->obj->fields["FK_entities"])))){
+								if ($_POST["device_type"]==ENTITY_TYPE) {
+								   $destentity = $ci2->obj->fields["ID"];
+								} else if (isset($ci2->obj->fields["FK_entities"])) {
+								   $destentity = $ci2->obj->fields["FK_entities"];
+								} else {
+								   $destentity = -1;
+								}
+								if ($destentity<0
+								|| $ci->obj->fields["FK_entities"]==$destentity
+								|| ($ci->obj->fields["recursive"] && in_array($ci->obj->fields["FK_entities"], getEntityAncestors($destentity)))){
 									addDeviceDocument($_POST['docID'],$_POST["device_type"],$key);
 								}
 							}
@@ -315,10 +330,17 @@ if (isset($_POST["device_type"])){
 						if ($val==1) {
 							// Items exists ?
 							if ($ci2->getFromDB($_POST["device_type"],$key)){
+								if ($_POST["device_type"]==ENTITY_TYPE) {
+								   $destentity = $ci2->obj->fields["ID"];
+								} else if (isset($ci2->obj->fields["FK_entities"])) {
+								   $destentity = $ci2->obj->fields["FK_entities"];
+								} else {
+								   $destentity = -1;
+								}
 								// Entity security
-								if (!isset($ci2->obj->fields["FK_entities"])
-								||$ci->obj->fields["FK_entities"]==$ci2->obj->fields["FK_entities"]
-								||($ci->obj->fields["recursive"] && in_array($ci->obj->fields["FK_entities"], getEntityAncestors($ci2->obj->fields["FK_entities"])))){
+								if ($destentity<0
+								||$ci->obj->fields["FK_entities"]==$destentity
+								||($ci->obj->fields["recursive"] && in_array($ci->obj->fields["FK_entities"], getEntityAncestors($destentity)))){
 									addContactEnterprise($key,$_POST["conID"]);
 								}
 							}
@@ -334,10 +356,17 @@ if (isset($_POST["device_type"])){
 						if ($val==1) {
 							// Items exists ?
 							if ($ci2->getFromDB($_POST["device_type"],$key)){
+								if ($_POST["device_type"]==ENTITY_TYPE) {
+								   $destentity = $ci2->obj->fields["ID"];
+								} else if (isset($ci2->obj->fields["FK_entities"])) {
+								   $destentity = $ci2->obj->fields["FK_entities"];
+								} else {
+								   $destentity = -1;
+								}
 								// Entity security
-								if (!isset($ci2->obj->fields["FK_entities"])
-								||$ci->obj->fields["FK_entities"]==$ci->obj->fields["FK_entities"]
-								||($ci->obj->fields["recursive"] && in_array($ci->obj->fields["FK_entities"], getEntityAncestors($ci2->obj->fields["FK_entities"])))){
+								if ($destentity<0
+								||$ci->obj->fields["FK_entities"]==$destentity
+								||($ci->obj->fields["recursive"] && in_array($ci->obj->fields["FK_entities"], getEntityAncestors($destentity)))){
 									addDeviceContract($_POST['conID'],$_POST["device_type"],$key);
 								}
 							}
@@ -364,6 +393,14 @@ if (isset($_POST["device_type"])){
 						}
 					}
 				}
+			break;
+			case "change_auth_method":
+				foreach ($_POST["item"] as $key => $val){
+					if ($val==1) 
+						$ids[]=$key;
+				}
+			changeUserAuthMethod($ids,$_POST["auth_method"],$_POST["auth_server"]);
+
 			break;
 			case "unlock_ocsng_field":
 				$fields=getOcsLockableFields();
@@ -384,6 +421,7 @@ if (isset($_POST["device_type"])){
 			case "unlock_ocsng_peripheral":
 			case "unlock_ocsng_software":
 			case "unlock_ocsng_ip":
+			case "unlock_ocsng_disk":
 				foreach ($_POST["item"] as $key => $val){
 					if ($val==1) {
 						switch ($_POST["action"]){
@@ -402,6 +440,9 @@ if (isset($_POST["device_type"])){
 							case "unlock_ocsng_ip":
 								ocsUnlockItems($key,"import_ip");
 								break;
+							case "unlock_ocsng_disk":
+								ocsUnlockItems($key,"import_disk");
+								break;
 						}
 					}
 				}
@@ -454,6 +495,7 @@ if (isset($_POST["device_type"])){
 						$soft->getFromDB($key);
 						$params["name"]=$soft->fields["name"];
 						$params["FK_glpi_enterprise"]=$soft->fields["FK_glpi_enterprise"];
+						$params["comments"]=$soft->fields["comments"];
 						
 						//Process rules
 						$soft->update($softcatrule->processAllRules(null,$soft->fields,$params));
@@ -480,7 +522,7 @@ if (isset($_POST["device_type"])){
 					if ($val==1)
 					{
 						$user->getFromDB($key);
-						if (($user->fields["auth_method"] == AUTH_LDAP) || ($user->fields["auth_method"] == AUTH_EXTERNAL)) 
+						if (($user->fields["auth_method"] == AUTH_LDAP) || ($user->fields["auth_method"] == AUTH_EXTERNAL))
 							ldapImportUserByServerId($user->fields["name"],1,$user->fields["id_auth"]);
 					} 
 				}
@@ -512,40 +554,40 @@ if (isset($_POST["device_type"])){
 				}
 			break;
 			default :
+
 				// Plugin specific actions
-				if ($_POST["device_type"]>1000){
-					if (isset($PLUGIN_HOOKS['plugin_types'][$_POST["device_type"]])){
-						$function='plugin_'.$PLUGIN_HOOKS['plugin_types'][$_POST["device_type"]].'_MassiveActionsProcess';
-						if (function_exists($function)){
-							$function($_POST);
-						} 
-					} 
-				} else {
-					// Need to search display item over plugins
-					$split=split('_',$_POST["action"]);
-					if (isset($split[1])){
-						$function='plugin_'.$split[1].'_MassiveActionsProcess';
-							if (function_exists($function)){
-								$function($_POST);
-							} 
-					}
+				$split=explode('_',$_POST["action"]);
+				if ($split[0]=='plugin' && isset($split[1])){
+					// Normalized name plugin_name_action
+					// Allow hook from any plugin on any (core or plugin) type
+					doOneHook($split[1],
+						'MassiveActionsProcess',
+						$_POST);
 				}
+				else if ($_POST["device_type"]>1000
+					&& isset($PLUGIN_HOOKS['plugin_types'][$_POST["device_type"]])){
+					// non-normalized name
+					// hook from the plugin defining the type
+					doOneHook($PLUGIN_HOOKS['plugin_types'][$_POST["device_type"]],
+						'MassiveActionsProcess',
+						$_POST);
+				} 
 	
 			break;
 		}
 	
-		addMessageAfterRedirect($LANG["common"][23]);
+		addMessageAfterRedirect($LANG['common'][23]);
 		glpi_header($REDIRECT);
 	
-	} else {
+	} else { //action, device_type or item not defined
 		
 		echo "<div align='center'><img src=\"".$CFG_GLPI["root_doc"]."/pics/warning.png\" alt=\"warning\"><br><br>";
-		echo "<b>".$LANG["common"][24]."</b></div>";
+		echo "<b>".$LANG['common'][24]."</b></div>";
 		
 		displayBackLink();
 	}
 	
 	commonFooter();
-}
+} // device_type defined
 
 ?>
