@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ocsng.clean.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: ocsng.clean.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -41,12 +41,12 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("ocsng","w");
 
-commonHeader($LANG["ocsng"][0],$_SERVER['PHP_SELF'],"utils","ocsng");
+commonHeader($LANG['ocsng'][0],$_SERVER['PHP_SELF'],"utils","ocsng");
 
 
 ocsCleanLinks($_SESSION["ocs_server_id"]);
 
-echo "<div align='center'><strong>".$LANG["ocsng"][3]." - ".$LANG["log"][45]."<br>";
+echo "<div align='center'><strong>".$LANG['ocsng'][3]." - ".$LANG['log'][45]."<br>";
 displayBackLink();
 echo "</strong></div>";
 
