@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ocsng.import.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: ocsng.import.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -34,14 +34,15 @@
 // ----------------------------------------------------------------------
 
 
-$NEEDED_ITEMS=array("ocsng","rulesengine","rule.ocs","computer","device","printer","networking","peripheral","monitor","software","infocom","phone","tracking","enterprise","reservation","setup","registry","admininfo","group","rule.softwarecategories","rule.dictionnary.software","rule.dictionnary.dropdown");
+$NEEDED_ITEMS=array("ocsng","rulesengine","rule.ocs","computer","device","printer","networking","peripheral","monitor","software","infocom","phone","tracking","enterprise","reservation","setup","registry",
+"admininfo","group","rule.softwarecategories","rule.dictionnary.software","rule.dictionnary.dropdown","entity");
 
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("ocsng","w");
 
-commonHeader($LANG["ocsng"][0],$_SERVER['PHP_SELF'],"utils","ocsng");
+commonHeader($LANG['ocsng'][0],$_SERVER['PHP_SELF'],"utils","ocsng");
 
 //First time this screen is displayed : set the import mode to 'basic'
 if (!isset($_SESSION["change_import_mode"])){
@@ -78,8 +79,8 @@ if (isset($_SESSION["ocs_import"]["ID"])){
 
 		displayProgressBar(400,100);
 
-		echo "<div align='center'><strong>".$LANG["ocsng"][8]."<br>";
-		echo "<a href='".$_SERVER['PHP_SELF']."'>".$LANG["buttons"][13]."</a>";
+		echo "<div align='center'><strong>".$LANG['ocsng'][8]."<br>";
+		echo "<a href='".$_SERVER['PHP_SELF']."'>".$LANG['buttons'][13]."</a>";
 		echo "</strong></div>";
 	}
 }
