@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ocsng.link.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: ocsng.link.php 8416 2009-07-05 06:30:42Z walid $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -41,7 +41,7 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("ocsng","w");
 
-commonHeader($LANG["ocsng"][0],$_SERVER['PHP_SELF'],"utils","ocsng");
+commonHeader($LANG['ocsng'][0],$_SERVER['PHP_SELF'],"utils","ocsng");
 
 $CFG_GLPI["use_ajax"] = 1; 
 
@@ -72,8 +72,8 @@ if (isset($_SESSION["ocs_link"])){
 		displayProgressBar(400,100);
 
 		unset($_SESSION["ocs_link"]);
-		echo "<div align='center'><strong>".$LANG["ocsng"][8]."<br>";
-		echo "<a href='".$_SERVER['PHP_SELF']."'>".$LANG["buttons"][13]."</a>";
+		echo "<div align='center'><strong>".$LANG['ocsng'][8]."<br>";
+		echo "<a href='".$_SERVER['PHP_SELF']."'>".$LANG['buttons'][13]."</a>";
 		echo "</strong></div>";
 	}
 }
@@ -85,7 +85,7 @@ if (!isset($_POST["import_ok"])){
 	if (!isset($_GET['start'])) $_GET['start']=0;
 
 	ocsManageDeleted($_SESSION["ocs_server_id"]);
-	ocsShowNewComputer($_SESSION["ocs_server_id"],$_SESSION["change_import_mode"],$_GET['check'],$_GET['start'],1);
+	ocsShowNewComputer($_SESSION["ocs_server_id"],$_SESSION["change_import_mode"],$_GET['check'],$_GET['start'],$_SESSION['glpiactive_entity'],1);
 
 } else {
 	if (count($_POST['tolink'])>0){
