@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: profile.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: profile.form.php 8166 2009-04-13 06:59:27Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -48,23 +48,21 @@ if (!isset($_GET['ID'])) {
 
 
 $prof=new Profile();
+//print_r($_POST);
 
 if (isset($_POST["add"])){
 
 	checkRight("profile","w");
 	$ID=$prof->add($_POST);
-	glpi_header($_SERVER['HTTP_REFERER']);
+
+	// We need to redirect to form to enter rights
+	glpi_header($CFG_GLPI["root_doc"]."/front/profile.form.php?ID=$ID");
+
 }else  if (isset($_POST["delete"])){
 	checkRight("profile","w");
 
 	$prof->delete($_POST);
 	glpi_header($CFG_GLPI["root_doc"]."/front/profile.php");
-}
-else  if (isset($_POST["update"])){
-	checkRight("profile","w");
-
-	$prof->update($_POST);
-	glpi_header($_SERVER['HTTP_REFERER']);
 } else if (isset($_POST["moveentity"])){
 	checkRight("user","w");
 	if (isset($_POST['FK_entities'])&&$_POST['FK_entities']>=0){
@@ -83,36 +81,27 @@ else  if (isset($_POST["update"])){
 		}
 	}
 	glpi_header($_SERVER['HTTP_REFERER']);
+} else  if (isset($_POST["update"]) || isset($_POST["interface"])){
+	checkRight("profile","w");
+
+	$prof->update($_POST);
+	glpi_header($_SERVER['HTTP_REFERER']);
 }
 
 
-commonHeader($LANG["Menu"][35],$_SERVER['PHP_SELF'],"admin","profile");
+commonHeader($LANG['Menu'][35],$_SERVER['PHP_SELF'],"admin","profile");
 
-if (!isset($_SESSION['glpi_onglet'])) $_SESSION['glpi_onglet']=1;
+if (!isset($_SESSION['glpi_tab'])) $_SESSION['glpi_tab']=1;
 if (isset($_GET['onglet'])) {
-	$_SESSION['glpi_onglet']=$_GET['onglet'];
+	$_SESSION['glpi_tab']=$_GET['onglet'];
 }	
 
-if ($prof->showForm($_SERVER['PHP_SELF'],$_GET["ID"])){
-	switch($_SESSION['glpi_onglet']){
-		case -1 :	
-			showProfileConfig($_SERVER['PHP_SELF'],$_GET["ID"],$prof);
-			showProfileEntityUser($_SERVER['PHP_SELF'],$_GET["ID"],$prof);
-			displayPluginAction(PROFILE_TYPE,$_GET["ID"],$_SESSION['glpi_onglet']);
-		break;
-		case 1:
-			showProfileConfig($_SERVER['PHP_SELF'],$_GET["ID"],$prof);
-		break;
-		case 2 : 
-			showProfileEntityUser($_SERVER['PHP_SELF'],$_GET["ID"],$prof);
-		break;
-		default :
-			if (!displayPluginAction(PROFILE_TYPE,$_GET["ID"],$_SESSION['glpi_onglet'])){
-				showProfileConfig($_SERVER['PHP_SELF'],$_GET["ID"],$prof);
-			}
-		break;
-	}
-}
+
+	$prof->showTabs($_GET["ID"],'',$_SESSION['glpi_tab']); 
+	echo "<div id='tabcontent'></div>";
+
+	echo "<script type='text/javascript'>loadDefaultTab();</script>";
+
 
 commonFooter();
 
