@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: profile.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: profile.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -42,13 +42,13 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("profile","r");
 
-commonHeader($LANG["Menu"][35],$_SERVER['PHP_SELF'],"admin","profile");
+commonHeader($LANG['Menu'][35],$_SERVER['PHP_SELF'],"admin","profile");
 
 manageGetValuesInSearch(PROFILE_TYPE);
 
-searchForm(PROFILE_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+searchForm(PROFILE_TYPE,$_GET);
 
-showList(PROFILE_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+showList(PROFILE_TYPE,$_GET);
 
 commonFooter();
 
