@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: reminder.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: reminder.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -42,7 +42,7 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkCentralAccess();
 
-commonHeader($LANG["title"][40],$_SERVER['PHP_SELF'],"utils","reminder");
+commonHeader($LANG['title'][40],$_SERVER['PHP_SELF'],"utils","reminder");
 
 showListReminder();
 
