@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.default.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: report.default.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -43,11 +43,11 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("reports","r");
 
-commonHeader($LANG["Menu"][6],$_SERVER['PHP_SELF'],"utils","report");
+commonHeader($LANG['Menu'][6],$_SERVER['PHP_SELF'],"utils","report");
 
 # Title
 
-echo "<div align='center'><big><b>GLPI ".$LANG["Menu"][6]."</b></big><br><br>";
+echo "<div align='center'><big><b>GLPI ".$LANG['Menu'][6]."</b></big><br><br>";
 
 # 1. Get some number data
 
@@ -70,7 +70,9 @@ $query = "SELECT count(*)
 $result = $DB->query($query);
 $number_of_printers = $DB->result($result,0,0);
 
-$query = "SELECT count(*) FROM glpi_networking where deleted ='0'  AND is_template = '0' ".getEntitiesRestrictRequest("AND","glpi_networking");
+$query = "SELECT count(*) 
+	FROM glpi_networking 
+	WHERE deleted ='0'  AND is_template = '0' ".getEntitiesRestrictRequest("AND","glpi_networking");
 $result = $DB->query($query);
 $number_of_networking = $DB->result($result,0,0);
 
@@ -102,16 +104,16 @@ $number_of_phones = $DB->result($result,0,0);
 # 2. Spew out the data in a table
 
 echo "<table class='tab_cadre' width='80%'>";
-echo "<tr class='tab_bg_2'><td>".$LANG["Menu"][0].":</td><td>$number_of_computers</td></tr>";	
-echo "<tr class='tab_bg_2'><td>".$LANG["Menu"][2].":</td><td>$number_of_printers</td></tr>";
-echo "<tr class='tab_bg_2'><td>".$LANG["Menu"][1].":</td><td>$number_of_networking</td></tr>";
-echo "<tr class='tab_bg_2'><td>".$LANG["Menu"][4].":</td><td>$number_of_software</td></tr>";
-echo "<tr class='tab_bg_2'><td>".$LANG["Menu"][3].":</td><td>$number_of_monitors</td></tr>";
-echo "<tr class='tab_bg_2'><td>".$LANG["Menu"][16].":</td><td>$number_of_peripherals</td></tr>";
-echo "<tr class='tab_bg_2'><td>".$LANG["Menu"][34].":</td><td>$number_of_phones</td></tr>";
+echo "<tr class='tab_bg_2'><td>".$LANG['Menu'][0].":</td><td>$number_of_computers</td></tr>";	
+echo "<tr class='tab_bg_2'><td>".$LANG['Menu'][2].":</td><td>$number_of_printers</td></tr>";
+echo "<tr class='tab_bg_2'><td>".$LANG['Menu'][1].":</td><td>$number_of_networking</td></tr>";
+echo "<tr class='tab_bg_2'><td>".$LANG['Menu'][4].":</td><td>$number_of_software</td></tr>";
+echo "<tr class='tab_bg_2'><td>".$LANG['Menu'][3].":</td><td>$number_of_monitors</td></tr>";
+echo "<tr class='tab_bg_2'><td>".$LANG['Menu'][16].":</td><td>$number_of_peripherals</td></tr>";
+echo "<tr class='tab_bg_2'><td>".$LANG['Menu'][34].":</td><td>$number_of_phones</td></tr>";
 
 echo "<tr><td colspan='2' height=10></td></tr>";
-echo  "<tr class='tab_bg_1'><td colspan='2'><b>".$LANG["setup"][5].":</b></td></tr>";
+echo  "<tr class='tab_bg_1'><td colspan='2'><b>".$LANG['setup'][5].":</b></td></tr>";
 
 
 # 3. Get some more number data (operating systems per computer)
@@ -131,7 +133,7 @@ while ($data=$DB->fetch_assoc($result)){
 
 
 echo "<tr><td colspan='2' height=10></td></tr>";
-echo  "<tr class='tab_bg_1'><td colspan='2'><b>".$LANG["Menu"][1].":</b></td></tr>";
+echo  "<tr class='tab_bg_1'><td colspan='2'><b>".$LANG['Menu'][1].":</b></td></tr>";
 
 # 4. Get some more number data (Networking)
 
@@ -150,7 +152,7 @@ while ($data=$DB->fetch_assoc($result)){
 
 
 echo "<tr><td colspan='2' height=10></td></tr>";
-echo  "<tr class='tab_bg_1'><td colspan='2'><b>".$LANG["Menu"][3].":</b></td></tr>";
+echo  "<tr class='tab_bg_1'><td colspan='2'><b>".$LANG['Menu'][3].":</b></td></tr>";
 
 # 4. Get some more number data (Monitor)
 
@@ -169,7 +171,7 @@ while ($data=$DB->fetch_assoc($result)){
 
 
 echo "<tr><td colspan='2' height=10></td></tr>";
-echo  "<tr class='tab_bg_1'><td colspan='2'><b>".$LANG["Menu"][2].":</b></td></tr>";
+echo  "<tr class='tab_bg_1'><td colspan='2'><b>".$LANG['Menu'][2].":</b></td></tr>";
 
 # 4. Get some more number data (Printers)
 
@@ -187,7 +189,7 @@ while ($data=$DB->fetch_assoc($result)){
 }
 
 echo "<tr><td colspan='2' height=10></td></tr>";
-echo  "<tr class='tab_bg_1'><td colspan='2'><b>".$LANG["Menu"][16].":</b></td></tr>";
+echo  "<tr class='tab_bg_1'><td colspan='2'><b>".$LANG['Menu'][16].":</b></td></tr>";
 
 # 4. Get some more number data (Peripherals)
 
@@ -206,7 +208,7 @@ while ($data=$DB->fetch_assoc($result)){
 }
 
 echo "<tr><td colspan='2' height=10></td></tr>";
-echo  "<tr class='tab_bg_1'><td colspan='2'><b>".$LANG["Menu"][34].":</b></td></tr>";
+echo  "<tr class='tab_bg_1'><td colspan='2'><b>".$LANG['Menu'][34].":</b></td></tr>";
 
 # 4. Get some more number data (Peripherals)
 
