@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.dynamic.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: report.dynamic.php 8674 2009-08-10 10:57:50Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -65,7 +65,6 @@ checkCentralAccess();
 
 if (isset($_GET["item_type"])&&isset($_GET["display_type"])){
 
-
 	if ($_GET["display_type"]<0) {
 		$_GET["display_type"]=-$_GET["display_type"];
 		$_GET["export_all"]=1;
@@ -119,10 +118,9 @@ if (isset($_GET["item_type"])&&isset($_GET["display_type"])){
 				} 
 			}
 
-
 			manageGetValuesInSearch($_GET["item_type"]);
 
-			showList($_GET["item_type"],$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+			showList($_GET["item_type"],$_GET);
 			break;
 	}
 }
