@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.location.list.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: report.location.list.php 8586 2009-07-31 13:10:42Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -37,18 +37,17 @@ include (GLPI_ROOT . "/inc/includes.php");
 checkRight("reports","r");
 
 if (isset($_POST["location"])&&$_POST["location"]){
-	commonHeader($LANG["Menu"][6],$_SERVER['PHP_SELF'],"utils","report");
+	commonHeader($LANG['Menu'][6],$_SERVER['PHP_SELF'],"utils","report");
 
 	// Titre
 	$name=getDropdownName("glpi_dropdown_locations",$_POST["location"]);
-	echo "<div align='center'><h2>".$LANG["reports"][54]." $name </h2></div>";
+	echo "<div align='center'><h2>".$LANG['reports'][54]." $name </h2></div>";
 
 	$query="SELECT glpi_dropdown_netpoint.name AS prise, glpi_networking_ports.name AS port, glpi_networking_ports.ifaddr  
 		AS ip, glpi_networking_ports.ifmac AS mac,glpi_networking_ports.ID AS IDport, glpi_dropdown_locations.ID as location,glpi_dropdown_locations.completename
 		FROM glpi_dropdown_locations
-		LEFT JOIN glpi_dropdown_netpoint ON glpi_dropdown_netpoint.location = 
-		glpi_dropdown_locations.ID
-		LEFT JOIN glpi_networking_ports ON glpi_networking_ports.netpoint=glpi_dropdown_netpoint.id 
+		INNER JOIN glpi_dropdown_netpoint ON glpi_dropdown_netpoint.location = glpi_dropdown_locations.ID
+		INNER JOIN glpi_networking_ports ON glpi_networking_ports.netpoint=glpi_dropdown_netpoint.id 
 		WHERE ".getRealQueryForTreeItem("glpi_dropdown_locations",$_POST["location"])." AND glpi_networking_ports.device_type=".NETWORKING_TYPE."
 		ORDER BY glpi_dropdown_locations.completename, glpi_networking_ports.name;";
 
@@ -57,16 +56,16 @@ if (isset($_POST["location"])&&$_POST["location"]){
 
 		echo "<div align='center'><table class='tab_cadre_report'>";
 		echo "<tr> ";
-		echo "<th>".$LANG["common"][15]."</th>";
-		echo "<th>".$LANG["reports"][37]."</th>";
-		echo "<th>".$LANG["reports"][52]."</th>";
-		echo "<th>".$LANG["reports"][38]."</th>";
-		echo "<th>".$LANG["reports"][46]."</th>";
-		echo "<th>".$LANG["device_iface"][2]."</th>";
-		echo "<th>".$LANG["reports"][47]."</th>";
-		echo "<th>".$LANG["reports"][38]."</th>";
-		echo "<th>".$LANG["device_iface"][2]."</th>";
-		echo "<th>".$LANG["reports"][36]."</th>";
+		echo "<th>".$LANG['common'][15]."</th>";
+		echo "<th>".$LANG['reports'][37]."</th>";
+		echo "<th>".$LANG['reports'][52]."</th>";
+		echo "<th>".$LANG['reports'][38]."</th>";
+		echo "<th>".$LANG['reports'][46]."</th>";
+		echo "<th>".$LANG['device_iface'][2]."</th>";
+		echo "<th>".$LANG['reports'][47]."</th>";
+		echo "<th>".$LANG['reports'][38]."</th>";
+		echo "<th>".$LANG['device_iface'][2]."</th>";
+		echo "<th>".$LANG['reports'][36]."</th>";
 		echo "</tr>";
 		while( $ligne = $DB->fetch_array($result)){
 			$lieu=$ligne["completename"];
@@ -81,8 +80,7 @@ if (isset($_POST["location"])&&$_POST["location"]){
 			$mac2="";
 			$portordi="";
 
-			if ($end1){
-				$np->getFromDB($end1);
+			if ($end1 && $np->getFromDB($end1)){
 				$np->getDeviceData($np->fields["on_device"],$np->fields["device_type"]);
 				$ordi=$np->device_name;
 				$ip2=$np->fields['ifaddr'];
