@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.networking.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: report.networking.php 8586 2009-07-31 13:10:42Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -40,7 +40,7 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("reports","r");
 
-commonHeader($LANG["Menu"][6],$_SERVER['PHP_SELF'],"utils","report");
+commonHeader($LANG['Menu'][6],$_SERVER['PHP_SELF'],"utils","report");
 
 # Titre
 
@@ -48,17 +48,17 @@ commonHeader($LANG["Menu"][6],$_SERVER['PHP_SELF'],"utils","report");
 
 
 echo "<table class='tab_cadre' >";
-echo "<tr><th align='center' colspan='3' >".$LANG["reports"][33]."</th></tr>";
+echo "<tr><th align='center' colspan='3' >".$LANG['reports'][33]."</th></tr>";
 echo "</table><br>";
 // 3. Selection d'affichage pour generer la liste
 
 echo "<form name='form' method='post' action='report.location.list.php'>";
 echo "<table class='tab_cadre'  width='500'>";
-echo "<tr class='tab_bg_1'><td>".$LANG["reports"][39]."</td>";
+echo "<tr class='tab_bg_1'><td>".$LANG['reports'][39]."</td>";
 echo "<td>";
 dropdownValue("glpi_dropdown_locations","location",0,1,$_SESSION["glpiactive_entity"]);
 echo "</td><td align='center' width='120'>";
-echo "<input type='submit' value='".$LANG["reports"][15]."' class='submit'>";
+echo "<input type='submit' value='".$LANG['reports'][15]."' class='submit'>";
 echo "</td></tr>";
 echo "</table>";
 echo "</form>";
@@ -66,11 +66,11 @@ echo "</form>";
 
 echo "<form name='form2' method='post' action='report.switch.list.php'>";
 echo "<table class='tab_cadre' width='500'>";
-echo "<tr class='tab_bg_1'><td>".$LANG["reports"][41]."</td>";
+echo "<tr class='tab_bg_1'><td>".$LANG['reports'][41]."</td>";
 echo "<td>";
 dropdownValue("glpi_networking", "switch");
 echo "</td><td align='center' width='120'>";
-echo "<input type='submit' value='".$LANG["reports"][15]."' class='submit'>";
+echo "<input type='submit' value='".$LANG['reports'][15]."' class='submit'>";
 echo "</td></tr>";
 echo "</table>";
 echo "</form>";
@@ -79,11 +79,11 @@ echo "</form>";
 if (countElementsInTableForMyEntities("glpi_dropdown_netpoint")>0){
 	echo "<form name='form3' method='post' action='report.netpoint.list.php'>";
 	echo "<table class='tab_cadre'  width='500'>";
-	echo "<tr class='tab_bg_1'><td>".$LANG["reports"][42]."</td>";
+	echo "<tr class='tab_bg_1'><td>".$LANG['reports'][42]."</td>";
 	echo "<td>";
-	dropdownNetpoint("prise",0,0,1,$_SESSION["glpiactive_entity"]);	
+	dropdownNetpoint("prise",0,-1,1,$_SESSION["glpiactive_entity"]);	
 	echo "</td><td align='center' width='120'>";
-	echo "<input type='submit' value='".$LANG["reports"][15]."' class='submit'>";
+	echo "<input type='submit' value='".$LANG['reports'][15]."' class='submit'>";
 	echo "</td></tr>";
 	echo "</table>";
 	echo "</form>";
