@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.reservation.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: report.reservation.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -41,7 +41,7 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("reports","r");
 
-commonHeader($LANG["Menu"][6],$_SERVER['PHP_SELF'],"utils","report");
+commonHeader($LANG['Menu'][6],$_SERVER['PHP_SELF'],"utils","report");
 
 if (!isset($_GET["ID"])) $_GET["ID"]=0;
 
@@ -50,7 +50,7 @@ echo "<table class='tab_cadre'><tr class='tab_bg_2'>";
 echo "<td rowspan='2' align='center'>";
 dropdownAllUsers("ID",$_GET["ID"],"reservation_helpdesk");
 echo "</td>";
-echo "<td rowspan='2' align='center'><input type=\"submit\" class='button' name=\"submit\" Value=\"". $LANG["buttons"][7] ."\" /></td></tr>";
+echo "<td rowspan='2' align='center'><input type=\"submit\" class='button' name=\"submit\" Value=\"". $LANG['buttons'][7] ."\" /></td></tr>";
 echo "</table></form></div>";
 
 if ($_GET["ID"]>0)
