@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.year.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: report.year.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -37,7 +37,7 @@ define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 checkRight("reports","r");
 
-commonHeader($LANG["Menu"][6],$_SERVER['PHP_SELF'],"utils","report");
+commonHeader($LANG['Menu'][6],$_SERVER['PHP_SELF'],"utils","report");
 
 
 
@@ -48,27 +48,27 @@ echo "<form name='form' method='post' action='report.year.list.php'>";
 
 echo "<div align='center'>";
 echo "<table class='tab_cadre' >";
-echo "<tr><th align='center' colspan='2' ><big><b>".$LANG["reports"][58]."</b></big></th></tr>";
+echo "<tr><th align='center' colspan='2' ><big><b>".$LANG['reports'][58]."</b></big></th></tr>";
 
 # 3. Selection d'affichage pour generer la liste
 
 echo "<tr class='tab_bg_2'>";
 echo "<td width='150'  align='center'>";
-echo "<p><b>".$LANG["reports"][12]."</b></p> ";
+echo "<p><b>".$LANG['reports'][12]."</b></p> ";
 echo "<p><select name='item_type[]' size='8'  multiple>";
-echo "<option value='0' selected>".$LANG["common"][66]."</option>";
-echo "<option value='".COMPUTER_TYPE."'>".$LANG["Menu"][0]."</option>";
-echo "<option value='".PRINTER_TYPE."'>".$LANG["Menu"][2]."</option>";
-echo "<option value='".NETWORKING_TYPE."'>".$LANG["help"][26]."</option>";
-echo "<option value='".MONITOR_TYPE."'>".$LANG["Menu"][3]."</option>";
-echo "<option value='".PERIPHERAL_TYPE."'>".$LANG["Menu"][16]."</option>";
-echo "<option value='".SOFTWARE_TYPE."'>".$LANG["Menu"][4]."</option>";
-echo "<option value='".PHONE_TYPE."'>".$LANG["Menu"][34]."</option>";
+echo "<option value='0' selected>".$LANG['common'][66]."</option>";
+echo "<option value='".COMPUTER_TYPE."'>".$LANG['Menu'][0]."</option>";
+echo "<option value='".PRINTER_TYPE."'>".$LANG['Menu'][2]."</option>";
+echo "<option value='".NETWORKING_TYPE."'>".$LANG['help'][26]."</option>";
+echo "<option value='".MONITOR_TYPE."'>".$LANG['Menu'][3]."</option>";
+echo "<option value='".PERIPHERAL_TYPE."'>".$LANG['Menu'][16]."</option>";
+echo "<option value='".SOFTWARE_TYPE."'>".$LANG['Menu'][4]."</option>";
+echo "<option value='".PHONE_TYPE."'>".$LANG['Menu'][34]."</option>";
 echo "</select> </p></td>";
 
-echo "<td width='150' align='center'><p><b>".$LANG["reports"][23]."</b></p> ";
+echo "<td width='150' align='center'><p><b>".$LANG['reports'][13]."</b></p> ";
 echo "<p> <select name='annee[]'  size='8' multiple>";
-echo " <option value='toutes' selected>".$LANG["common"][66]."</option>";
+echo " <option value='toutes' selected>".$LANG['common'][66]."</option>";
 $y = date("Y");
 for ($i=$y-10;$i<$y+10;$i++)
 {
@@ -76,7 +76,7 @@ for ($i=$y-10;$i<$y+10;$i++)
 }
 echo "</select></p></td></tr>";
 
-echo "<tr class='tab_bg_2'><td colspan='2'  align='center'><p><input type='submit' value='".$LANG["reports"][15]."' class='submit'></p></td></tr>";
+echo "<tr class='tab_bg_2'><td colspan='2'  align='center'><p><input type='submit' value='".$LANG['reports'][15]."' class='submit'></p></td></tr>";
 
 
 echo "</table>";
