@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: reservation.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: reservation.php 8953 2009-09-12 16:17:41Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -51,8 +51,10 @@ if (isset($_POST["clear_resa"])||isset($_POST["add_resa"])||isset($_POST["edit_r
 
 	checkRight("reservation_helpdesk","1");
 
+   commonHeader($LANG['Menu'][17],$_SERVER['PHP_SELF'],"utils","reservation");
+
 	if (isset($_POST["edit_resa"])){
-		list($begin_year,$begin_month,$begin_day)=split("-",$_POST["begin_date"]);
+		list($begin_year,$begin_month,$begin_day)=explode("-",$_POST["begin"]);
 		if (haveRight("reservation_central","w")||$_SESSION["glpiID"]==$_POST["id_user"]){
 			$_POST['_target']=$_SERVER['PHP_SELF'];
 			$_POST['_item']=key($_POST["items"]);
@@ -60,17 +62,13 @@ if (isset($_POST["clear_resa"])||isset($_POST["add_resa"])||isset($_POST["edit_r
 				glpi_header($CFG_GLPI["root_doc"]."/front/reservation.php?show=resa&ID=".$_POST['_item']."&mois_courant=$begin_month&annee_courante=$begin_year");
 			}
 		}
-	}
-
-
-	commonHeader($LANG["Menu"][17],$_SERVER['PHP_SELF'],"utils","reservation");
-	if (isset($_POST["clear_resa"])){
+	} else if (isset($_POST["clear_resa"])){
 		$id_item=key($_POST["items"]);
 		if ($rr->delete($_POST)){
-			logEvent($_POST["ID"], "reservation", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+			logEvent($_POST["ID"], "reservation", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 		}
 
-		list($begin_year,$begin_month,$begin_day)=split("-",$_POST["begin_date"]);
+		list($begin_year,$begin_month,$begin_day)=explode("-",$_POST["begin"]);
 		$_GET["mois_courant"]=$begin_month;
 		$_GET["annee_courant"]=$begin_year;
 		printCalendrier($_SERVER['PHP_SELF'],$id_item);
@@ -92,8 +90,9 @@ if (isset($_POST["clear_resa"])||isset($_POST["add_resa"])||isset($_POST["edit_r
 			$_POST['id_item']=$id_item;
 
 			$times=$_POST["periodicity_times"];
-			list($begin_year,$begin_month,$begin_day)=split("-",$_POST["begin_date"]);
-			list($end_year,$end_month,$end_day)=split("-",$_POST["end_date"]);
+			$begin=$_POST["begin"];
+			list($begin_year,$begin_month,$begin_day)=explode("-",$_POST["begin"]);
+			$end=$_POST["end"];
 			$to_add=1;
 	
 			if ($_POST["periodicity"]=="week") {
@@ -102,9 +101,9 @@ if (isset($_POST["clear_resa"])||isset($_POST["add_resa"])||isset($_POST["edit_r
 			$_POST['_target']=$_SERVER['PHP_SELF'];
 			
 			$_POST['_ok']=true;
-			for ($i=1;$i<=$times&&($_POST['_ok']);$i++){
-				$_POST["begin_date"]=date("Y-m-d",mktime(0,0,0,$begin_month,$begin_day+($i-1)*$to_add,$begin_year));
-				$_POST["end_date"]=date("Y-m-d",mktime(0,0,0,$end_month,$end_day+($i-1)*$to_add,$end_year));
+			for ($i=0;$i<$times&&($_POST['_ok']);$i++){
+				$_POST["begin"]=date('Y-m-d H:i:s', strtotime($begin)+$i*$to_add*DAY_TIMESTAMP);
+				$_POST["end"]=date('Y-m-d H:i:s', strtotime($end)+$i*$to_add*DAY_TIMESTAMP);
 	
 				if (haveRight("reservation_central","w")||$_SESSION["glpiID"]==$_POST["id_user"]) {
 					unset($rr->fields["ID"]);
@@ -117,7 +116,7 @@ if (isset($_POST["clear_resa"])||isset($_POST["add_resa"])||isset($_POST["edit_r
 			$_GET["annee_courant"]=$begin_year;
 	
 			if ($_POST['_ok']){
-				logEvent($_POST["id_item"], "reservation", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][20]);
+				logEvent($_POST["id_item"], "reservation", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][20]);
 			} else $all_ok=false;
 
 			if ($all_ok){
@@ -135,9 +134,9 @@ if (isset($_POST["clear_resa"])||isset($_POST["add_resa"])||isset($_POST["edit_r
 	}else {
 		manageGetValuesInSearch(RESERVATION_TYPE);
 
-		searchForm(RESERVATION_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+		searchForm(RESERVATION_TYPE,$_GET);
 
-		showList(RESERVATION_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+		showList(RESERVATION_TYPE,$_GET);
 
 //		printReservationItems($_SERVER['PHP_SELF']);
 	}
@@ -145,7 +144,7 @@ if (isset($_POST["clear_resa"])||isset($_POST["add_resa"])||isset($_POST["edit_r
 else {
 	checkSeveralRightsOr(array("reservation_central"=>"r","reservation_helpdesk"=>"1"));
 	if (!haveRight("reservation_central","r")){
-		commonHeader($LANG["Menu"][17],$_SERVER['PHP_SELF'],"utils","reservation");
+		commonHeader($LANG['Menu'][17],$_SERVER['PHP_SELF'],"utils","reservation");
 		printReservationItems($_SERVER['PHP_SELF']);
 	}
 	else {
@@ -153,7 +152,7 @@ else {
 		{
 			checkRight("reservation_central","w");
 			if ($newID=$ri->add($_GET)){
-				logEvent($newID, "reservation", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][20]." ".$_GET["device_type"]."-".$_GET["id_device"].".");
+				logEvent($newID, "reservation", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$_GET["device_type"]."-".$_GET["id_device"].".");
 			}
 			glpi_header($_SERVER['HTTP_REFERER']);
 		} 
@@ -161,13 +160,13 @@ else {
 		{
 			checkRight("reservation_central","w");
 			$ri->delete($_GET);
-			logEvent($_GET['ID'], "reservation", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+			logEvent($_GET['ID'], "reservation", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 			glpi_header($CFG_GLPI["root_doc"] . "/front/reservation.php");
 		} else if (isset($_GET["active"]))
 		{
 			checkRight("reservation_central","w");
 			$ri->update($_GET);
-			logEvent($_GET['ID'], "reservation", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+			logEvent($_GET['ID'], "reservation", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 			glpi_header($CFG_GLPI["root_doc"] . "/front/reservation.php");
 		}
 
@@ -175,12 +174,12 @@ else {
 		{
 			checkRight("reservation_central","w");
 			$ri->update($_POST);
-			logEvent($_POST['ID'], "reservation", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+			logEvent($_POST['ID'], "reservation", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 		} 
 
 		checkRight("reservation_central","r");
 
-		commonHeader($LANG["Menu"][17],$_SERVER['PHP_SELF'],"utils","reservation");
+		commonHeader($LANG['Menu'][17],$_SERVER['PHP_SELF'],"utils","reservation");
 
 		if (isset($_GET["comment"])){
 			showReservationCommentForm($_SERVER['PHP_SELF'],$_GET["comment"]);
@@ -188,9 +187,9 @@ else {
 
 			manageGetValuesInSearch(RESERVATION_TYPE);
 	
-			searchForm(RESERVATION_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+			searchForm(RESERVATION_TYPE,$_GET);
 	
-			showList(RESERVATION_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+			showList(RESERVATION_TYPE,$_GET);
 		}
 	}
 }
