@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.common.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: rule.common.form.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -44,9 +44,9 @@ checkRight($rule->right,"r");
 
 if(!isset($_GET["ID"])) $_GET["ID"] = "";
 
-if (!isset($_SESSION['glpi_onglet'])) $_SESSION['glpi_onglet']=1;
+if (!isset($_SESSION['glpi_tab'])) $_SESSION['glpi_tab']=1;
 if (isset($_GET['onglet'])) {
-	$_SESSION['glpi_onglet']=$_GET['onglet'];
+	$_SESSION['glpi_tab']=$_GET['onglet'];
 }	
 
 $rulecriteria = new RuleCriteria();
@@ -128,7 +128,7 @@ elseif (isset($_POST["update_rule"]))
 	}
 
 	$rule->update($_POST);
-	logEvent($_POST['ID'], "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+	logEvent($_POST['ID'], "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 
 	glpi_header($_SERVER['HTTP_REFERER']);
 } elseif (isset($_POST["add_rule"]))
@@ -136,7 +136,7 @@ elseif (isset($_POST["update_rule"]))
 	checkRight($rule->right,"w");
 
 	$newID=$rule->add($_POST);
-	logEvent($newID, "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][20]);
+	logEvent($newID, "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][20]);
 
 	glpi_header($_SERVER['HTTP_REFERER']."?ID=$newID");
 } elseif (isset($_POST["delete_rule"]))
@@ -144,17 +144,17 @@ elseif (isset($_POST["update_rule"]))
 	checkRight($rule->right,"w");
 	$rulecollection->deleteRuleOrder($_POST["ranking"]);
 	$rule->delete($_POST);
-	logEvent($_POST["ID"], "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+	logEvent($_POST["ID"], "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 
 	// Is a cached Rule ?
 	if(method_exists($rule,'deleteCacheByRuleId')){
 		$rule->deleteCacheByRuleId($_POST["ID"]);
 	}
 
-	glpi_header(ereg_replace('.form','',$_SERVER['PHP_SELF']));
+	glpi_header(str_replace('.form','',$_SERVER['PHP_SELF']));
 }
 
-commonHeader($LANG["common"][12],$_SERVER['PHP_SELF'],"admin",getCategoryNameToDisplay($rulecollection->rule_type),$rulecollection->rule_type);
+commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],"admin",getCategoryNameToDisplay($rulecollection->sub_type),$rulecollection->sub_type);
 
 $rule->showForm($_SERVER['PHP_SELF'],$_GET["ID"]);
 if (!empty($_GET["ID"])&&$_GET["ID"] >0) {
