@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.generic.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: rule.generic.form.php 7793 2009-01-10 16:41:33Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -45,7 +45,7 @@ if (isset($_GET["ID"]))
 	$generic_rule->getFromDB($_GET["ID"]);
 	checkRight($generic_rule->right,"r");
 	
-	$rulecollection=getRuleCollectionClass($generic_rule->fields["rule_type"]);
+	$rulecollection=getRuleCollectionClass($generic_rule->fields["sub_type"]);
 	include (GLPI_ROOT . "/front/rule.common.form.php");
 }
 ?>
