@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: rule.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -39,22 +39,22 @@ $NEEDED_ITEMS=array("rulesengine","affectentity");
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-commonHeader($LANG["common"][12],$_SERVER['PHP_SELF'],"admin","rule",-1);
+commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],"admin","rule",-1);
 
 	echo "<div align='center'><table class='tab_cadre' cellpadding='5'>";
-	echo "<tr><th>" . $LANG["rulesengine"][24] . "</th></tr>";
+	echo "<tr><th>" . $LANG['rulesengine'][24] . "</th></tr>";
 	if ($CFG_GLPI["ocs_mode"]&&haveRight("rule_ocs","r")){
-		echo "<tr class='tab_bg_1'><td  align='center'><a href=\"rule.ocs.php\"><strong>" . $LANG["rulesengine"][18] .
+		echo "<tr class='tab_bg_1'><td  align='center'><a href=\"rule.ocs.php\"><strong>" . $LANG['rulesengine'][18] .
  "</strong></a></td></tr>";
 	}
 	if (haveRight("rule_ldap","r")){
-		echo "<tr class='tab_bg_1'><td align='center'><a href=\"rule.right.php\"><strong>" .$LANG["rulesengine"][19] . "</strong></a></td> </tr>";
+		echo "<tr class='tab_bg_1'><td align='center'><a href=\"rule.right.php\"><strong>" .$LANG['rulesengine'][19] . "</strong></a></td> </tr>";
 	}
 	if (haveRight("rule_tracking","r")){
-		echo "<tr class='tab_bg_1'><td  align='center'><a href=\"rule.tracking.php\"><strong>" . $LANG["rulesengine"][28] . "</strong></a></td></tr>";
+		echo "<tr class='tab_bg_1'><td  align='center'><a href=\"rule.tracking.php\"><strong>" . $LANG['rulesengine'][28] . "</strong></a></td></tr>";
 	}
 	if (haveRight("rule_softwarecategories","r")){
-		echo "<tr class='tab_bg_1'><td  align='center'><a href=\"rule.softwarecategories.php\"><strong>" . $LANG["rulesengine"][37] . "</strong></a></td></tr>";
+		echo "<tr class='tab_bg_1'><td  align='center'><a href=\"rule.softwarecategories.php\"><strong>" . $LANG['rulesengine'][37] . "</strong></a></td></tr>";
 	}
 
 	echo "</table></div>";
