@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.test.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: rule.test.php 8077 2009-03-17 17:55:18Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -41,25 +41,25 @@ if(!defined('GLPI_ROOT')){
 }
 
 
-if (isset($_POST["rule_type"]))$rule_type=$_POST["rule_type"];
-elseif (isset($_GET["rule_type"]))$rule_type=$_GET["rule_type"];
-else $rule_type=0;
+if (isset($_POST["sub_type"]))$sub_type=$_POST["sub_type"];
+elseif (isset($_GET["sub_type"]))$sub_type=$_GET["sub_type"];
+else $sub_type=0;
 
 
 if (isset($_POST["rule_id"]))$rule_id=$_POST["rule_id"];
 elseif (isset($_GET["rule_id"]))$rule_id=$_GET["rule_id"];
 else $rule_id=0;
 
-$rule = getRuleClass($rule_type);
+$rule = getRuleClass($sub_type);
 checkRight($rule->right,"r");
 
 $test_rule_output=null;
 
-if (!ereg("popup",$_SERVER['PHP_SELF'])){
-	commonHeader($LANG["common"][12],$_SERVER['PHP_SELF'],"config","display");
+if (!strpos($_SERVER['PHP_SELF'],"popup")){
+	commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],"config","display");
 }
 
-$rule->showRulePreviewCriteriasForm($_SERVER['PHP_SELF'],$rule_id,array(),array());
+$rule->showRulePreviewCriteriasForm($_SERVER['PHP_SELF'],$rule_id);
 
 if (isset($_POST["test_rule"]))
 {
@@ -67,7 +67,7 @@ if (isset($_POST["test_rule"]))
 	//Unset values that must not be processed by the rule
 	unset($_POST["test_rule"]);
 	unset($_POST["rule_id"]);
-	unset($_POST["rule_type"]);
+	unset($_POST["sub_type"]);
 	$rule->getRuleWithCriteriasAndActions($rule_id,1,1);
 	
 	// Need for RuleEngines
@@ -83,11 +83,11 @@ if (isset($_POST["test_rule"]))
 	$rule->showRulePreviewResultsForm($_SERVER['PHP_SELF'],$input,$params);
 }
 
-if (!ereg("popup",$_SERVER['PHP_SELF'])){
+if (!strpos($_SERVER['PHP_SELF'],"popup")){
 	commonFooter();
 }
 
-if (!ereg("popup",$_SERVER['PHP_SELF'])){
+if (!strpos($_SERVER['PHP_SELF'],"popup")){
 	commonFooter();
 }
 
