@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rulesengine.test.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: rulesengine.test.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -40,15 +40,15 @@ if(!defined('GLPI_ROOT')){
 	include (GLPI_ROOT . "/inc/includes.php");
 }
 
-if (isset($_POST["rule_type"]))$rule_type=$_POST["rule_type"];
-elseif (isset($_GET["rule_type"]))$rule_type=$_GET["rule_type"];
-else $rule_type=0;
+if (isset($_POST["sub_type"]))$sub_type=$_POST["sub_type"];
+elseif (isset($_GET["sub_type"]))$sub_type=$_GET["sub_type"];
+else $sub_type=0;
 
-$rulecollection = getRuleCollectionClass($rule_type);
+$rulecollection = getRuleCollectionClass($sub_type);
 checkRight($rulecollection->right,"r");
 
-if (!ereg("popup",$_SERVER['PHP_SELF'])){
-	commonHeader($LANG["common"][12],$_SERVER['PHP_SELF'],"config","display");
+if (!strpos($_SERVER['PHP_SELF'],"popup")){
+	commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],"config","display");
 }
 
 // Need for RuleEngines
@@ -60,7 +60,7 @@ $input = $rulecollection->showRulesEnginePreviewCriteriasForm($_SERVER['PHP_SELF
 if (isset($_POST["test_all_rules"]))
 {
 	//Unset values that must not be processed by the rule
-	unset($_POST["rule_type"]);
+	unset($_POST["sub_type"]);
 	unset($_POST["test_all_rules"]);
 	
 	echo "<br>";
@@ -68,11 +68,7 @@ if (isset($_POST["test_all_rules"]))
 }
 
 
-if (!ereg("popup",$_SERVER['PHP_SELF'])){
-	commonFooter();
-}
-
-if (!ereg("popup",$_SERVER['PHP_SELF'])){
+if (!strpos($_SERVER['PHP_SELF'],"popup")){
 	commonFooter();
 }
 
