@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: search.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: search.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -35,28 +35,26 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-$NEEDED_ITEMS=array("computer","search","software");
+$NEEDED_ITEMS=array("computer","search","software","document");
 
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
 checkCentralAccess();
-commonHeader($LANG["search"][0],$_SERVER['PHP_SELF']);
+commonHeader($LANG['search'][0],$_SERVER['PHP_SELF']);
 
 if (isset($_GET["globalsearch"])){
 	$_GET["reset_before"]=1;
 	$_GET["display_type"]=GLOBAL_SEARCH;
-	$types=array(COMPUTER_TYPE,MONITOR_TYPE,SOFTWARE_TYPE,NETWORKING_TYPE,PERIPHERAL_TYPE,PRINTER_TYPE,PHONE_TYPE);
+	$types=array(COMPUTER_TYPE,MONITOR_TYPE,SOFTWARE_TYPE,NETWORKING_TYPE,PERIPHERAL_TYPE,PRINTER_TYPE,PHONE_TYPE,CONTACT_TYPE,ENTERPRISE_TYPE,DOCUMENT_TYPE);
 
 	$ci=new CommonItem();
 	
 	foreach($types as $type){
 		if (haveTypeRight($type,'r')){
-			$page=ereg_replace('front/','',ereg_replace('.form','',$INFOFORM_PAGES[$type]));
-
 			manageGetValuesInSearch($type,false,false);
 			$_GET["contains"][0]=$_GET["globalsearch"];
-			showList($type,$page,$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+			showList($type,$_GET);
 			echo "<hr>";
 		}
 	}
