@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: setup.config.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: setup.config.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -47,11 +47,6 @@ include (GLPI_ROOT . "/inc/includes.php");
 checkRight("config", "w");
 $config = new Config();
 
-if (!isset ($_SESSION['glpi_configgen']))
-	$_SESSION['glpi_configgen'] = 1;
-if (isset ($_GET['onglet']))
-	$_SESSION['glpi_configgen'] = $_GET['onglet'];
-
 
 if (!empty ($_POST["update"])) {
 	$config->update($_POST);
@@ -61,8 +56,37 @@ if (!empty ($_POST["update"])) {
 		glpi_header($CFG_GLPI["root_doc"] ."/front/setup.config.php");
 }
 
-commonHeader($LANG["common"][12], $_SERVER['PHP_SELF'],"config","config");
-$config->showForm($_SERVER['PHP_SELF']);
+commonHeader($LANG['common'][12], $_SERVER['PHP_SELF'],"config","config");
+
+$tabs[1]=array('title'=>$LANG['setup'][70],
+'url'=>$CFG_GLPI['root_doc']."/ajax/config.tabs.php",
+'params'=>"target=".$_SERVER['PHP_SELF']."&ID=-1&glpi_tab=1");
+	
+$tabs[2]=array('title'=>$LANG['setup'][119],
+'url'=>$CFG_GLPI['root_doc']."/ajax/config.tabs.php",
+'params'=>"target=".$_SERVER['PHP_SELF']."&ID=-1&glpi_tab=2");
+
+$tabs[6]=array('title'=>$LANG['setup'][6],
+'url'=>$CFG_GLPI['root_doc']."/ajax/config.tabs.php",
+'params'=>"target=".$_SERVER['PHP_SELF']."&ID=-1&glpi_tab=6");
+
+$tabs[3]=array('title'=>$LANG['setup'][184],
+'url'=>$CFG_GLPI['root_doc']."/ajax/config.tabs.php",
+'params'=>"target=".$_SERVER['PHP_SELF']."&ID=-1&glpi_tab=3");
+
+$tabs[4]=array('title'=>$LANG['connect'][0],
+'url'=>$CFG_GLPI['root_doc']."/ajax/config.tabs.php",
+'params'=>"target=".$_SERVER['PHP_SELF']."&ID=-1&glpi_tab=4");
+
+$tabs[5]=array('title'=>$LANG['setup'][800],
+'url'=>$CFG_GLPI['root_doc']."/ajax/config.tabs.php",
+'params'=>"target=".$_SERVER['PHP_SELF']."&ID=-1&glpi_tab=5");
+				
+echo "<div id='tabspanel' class='center-h'></div>";
+createAjaxTabs('tabspanel','tabcontent',$tabs,$_SESSION['glpi_tab']);
+echo "<div id='tabcontent'></div>";
+echo "<script type='text/javascript'>loadDefaultTab();</script>";
 
 commonFooter();
-?>
+
+?>
\ No newline at end of file
