@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: setup.display.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: setup.display.php 8086 2009-03-18 15:19:34Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -45,11 +45,8 @@ if (isset($_POST["type"]))$type=$_POST["type"];
 elseif (isset($_GET["type"]))$type=$_GET["type"];
 else $type=0;
 
-if (!isset($_SESSION['glpi_searchconfig'])) $_SESSION['glpi_searchconfig']=1;
-if (isset($_GET['onglet'])) $_SESSION['glpi_searchconfig']=$_GET['onglet'];
-
-if (!ereg("popup",$_SERVER['PHP_SELF'])){
-	commonHeader($LANG["common"][12],$_SERVER['PHP_SELF'],"config","display");
+if (!strpos($_SERVER['PHP_SELF'],"popup")){
+	commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],"config","display");
 }
 
 checkSeveralRightsOr(array("search_config_global"=>"w","search_config"=>"w"));
@@ -67,10 +64,22 @@ if (isset($_POST["activate"])) {
 } else if (isset($_POST["down"])||isset($_POST["down_x"])) {
 	$setupdisplay->down($_POST);
 }
-if ((ereg("popup",$_SERVER['PHP_SELF'])&&$type>0)/*||$type=$setupdisplay->title($_SERVER['PHP_SELF'],$type)*/){
-	$setupdisplay->showForm($_SERVER['PHP_SELF'],$type);
+if ((strpos($_SERVER['PHP_SELF'],"popup")&&$type>0)/*||$type=$setupdisplay->title($_SERVER['PHP_SELF'],$type)*/){
+	
+	$tabs[1]=array('title'=>$LANG['central'][13],
+	'url'=>$CFG_GLPI['root_doc']."/ajax/display.tabs.php",
+	'params'=>"target=".$_SERVER['PHP_SELF']."&ID=-1&glpi_tab=1&type=$type");
+		
+	$tabs[2]=array('title'=>$LANG['central'][12],
+	'url'=>$CFG_GLPI['root_doc']."/ajax/display.tabs.php",
+	'params'=>"target=".$_SERVER['PHP_SELF']."&ID=-1&glpi_tab=2&type=$type");
+						
+	echo "<div id='tabspanel' class='center-h'></div>";
+	createAjaxTabs('tabspanel','tabcontent',$tabs,$_SESSION['glpi_tab']);
+	echo "<div id='tabcontent'></div>";
+	echo "<script type='text/javascript'>loadDefaultTab();</script>";
 }
-if (!ereg("popup",$_SERVER['PHP_SELF'])){
+if (!strpos($_SERVER['PHP_SELF'],"popup")){
 	commonFooter();
 }
-?>
+?>
\ No newline at end of file
