@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: setup.mailing.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: setup.mailing.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -53,34 +53,28 @@ include (GLPI_ROOT . "/inc/includes.php");
 checkRight("config", "w");
 $config = new Config();
 
-if (!isset ($_SESSION['glpi_mailconfig']))
-	$_SESSION['glpi_mailconfig'] = 1;
-if (isset ($_GET['onglet']))
-	$_SESSION['glpi_mailconfig'] = $_GET['onglet'];
-
-
 if (!empty ($_POST["test_cron_consumables"])) {
-	addMessageAfterRedirect($LANG["install"][6]);
+	addMessageAfterRedirect($LANG['install'][6]);
 	cron_consumable(true);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (!empty ($_POST["test_cron_cartridges"])) {
-	addMessageAfterRedirect($LANG["install"][6]);
+	addMessageAfterRedirect($LANG['install'][6]);
 	cron_cartridge(true);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (!empty ($_POST["test_cron_contracts"])) {
-	addMessageAfterRedirect($LANG["install"][6]);
+	addMessageAfterRedirect($LANG['install'][6]);
 	cron_contract(true);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (!empty ($_POST["test_cron_infocoms"])) {
-	addMessageAfterRedirect($LANG["install"][6]);
+	addMessageAfterRedirect($LANG['install'][6]);
 	cron_infocom(true);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (!empty ($_POST["test_cron_softwares"])) {
-	addMessageAfterRedirect($LANG["install"][6]);
+	addMessageAfterRedirect($LANG['install'][6]);
 	cron_software(true);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
@@ -99,10 +93,27 @@ elseif (!empty ($_POST["update_notifications"])) {
 }
 
 
+commonHeader($LANG['title'][15], $_SERVER['PHP_SELF'],"config","mailing");
 
+$tabs[1]=array('title'=>$LANG['common'][12],
+'url'=>$CFG_GLPI['root_doc']."/ajax/mailing.tabs.php",
+'params'=>"target=".$_SERVER['PHP_SELF']."&type=mailing&glpi_tab=1");
+	
+$tabs[2]=array('title'=>$LANG['setup'][240],
+'url'=>$CFG_GLPI['root_doc']."/ajax/mailing.tabs.php",
+'params'=>"target=".$_SERVER['PHP_SELF']."&type=mailing&glpi_tab=2");
 
-commonHeader($LANG["title"][15], $_SERVER['PHP_SELF'],"config","mailing");
-$config->showFormMailing($_SERVER['PHP_SELF']);
+$tabs[3]=array('title'=>$LANG['setup'][242],
+'url'=>$CFG_GLPI['root_doc']."/ajax/mailing.tabs.php",
+'params'=>"target=".$_SERVER['PHP_SELF']."&type=mailing&glpi_tab=3");
+
+$plug_tabs=getPluginTabs($_SERVER['PHP_SELF'],"mailing","","");
+$tabs+=$plug_tabs;
+
+echo "<div id='tabspanel' class='center-h'></div>";
+createAjaxTabs('tabspanel','tabcontent',$tabs,$_SESSION['glpi_tab']);
+echo "<div id='tabcontent'></div>";
+echo "<script type='text/javascript'>loadDefaultTab();</script>";
 
 commonFooter();
 ?>
