@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: setup.ocsng.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: setup.ocsng.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -43,11 +43,11 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("config", "w");
 
-commonHeader($LANG["ocsng"][0], $_SERVER['PHP_SELF'], "config","ocsng");
+commonHeader($LANG['ocsng'][0], $_SERVER['PHP_SELF'], "config","ocsng");
 	
 manageGetValuesInSearch(OCSNG_TYPE);
-searchForm(OCSNG_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
-showList(OCSNG_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+searchForm(OCSNG_TYPE,$_GET);
+showList(OCSNG_TYPE,$_GET);
 	
 commonFooter();
 ?>
