@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: setup.plugins.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: setup.plugins.php 8058 2009-03-06 17:23:57Z walid $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -35,53 +35,27 @@
 
 
 
-$NEEDED_ITEMS=array("setup");
+$NEEDED_ITEMS=array();
 
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
+checkRight("config", "w");
 
+$plugin=new Plugin();
 
+commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],"config","plugins");
 
-$NEEDED_ITEMS=array("setup");
-include (GLPI_ROOT . "/inc/includes.php");
-
-
-commonHeader($LANG["common"][12],$_SERVER['PHP_SELF'],"config","plugins");
-$names=array();
-if (isset($PLUGIN_HOOKS["config_page"]) && is_array($PLUGIN_HOOKS["config_page"])) {
-	foreach ($PLUGIN_HOOKS["config_page"] as $plug => $page){
-		$function="plugin_version_$plug";
-		$infos[$plug]=$function();
-		$names[$plug]=$infos[$plug]["name"];
-		$pages[$plug]=$page;
-	}
-	asort($names);
-}
-
-
-
-
-echo "<div align='center'><table class='tab_cadre' cellpadding='5'>";
-
-// ligne a modifier en fonction de la modification des fichiers de langues
-echo "<tr><th colspan='2'>".$LANG["setup"][701]."</th></tr>";
-
-foreach ($names as $key => $name) {
-
-	$val = $infos[$key];
-	// Config page if not set if plugin not compatible (usePlugin function unset it)
-	if ($pages[$key]) {
-		echo "<tr class='tab_bg_1'><td align='center'><a href='".$CFG_GLPI["root_doc"]."/plugins/$key/".$pages[$key]."'><strong>".$val["name"]."</strong></a></td>" .
-				"<td><img src='../pics/greenbutton.png' /> #".$val["version"]."</td></tr>";		
+if (isset($_GET['action'])&& isset($_GET['ID'])){
+	if (method_exists($plugin,$_GET['action'])){
+		$plugin->$_GET['action']($_GET['ID']);
 	} else {
-		echo "<tr class='tab_bg_2'><td align='center'>".$val["name"]."</td><td><img src='../pics/redbutton.png' /> #".$val["version"]." : ".$LANG["setup"][702].
-			(isset($val["minGlpiVersion"]) ? "<br />GPLI >= " . $val["minGlpiVersion"] : "") .
-			(isset($val["maxGlpiVersion"]) ? "<br />GLPI <= " . $val["maxGlpiVersion"] : "") . "</td></tr>";
+		echo "Action ".$_GET['action']." undefined";
 	}
+	glpi_header($_SERVER['HTTP_REFERER']);
 }
 
-echo "</table></div>";
+$plugin->listPlugins();
 
 commonFooter();
 
