@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: setup.templates.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: setup.templates.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -47,9 +47,9 @@ $type="inventory";
 if ($_GET["type"]==OCSNG_TYPE){
 	$type="config";
 }
-$item=ereg_replace(".form.php","",$INFOFORM_PAGES[$_GET["type"]]);
-$item=ereg_replace("front/","",$item);
-commonHeader($LANG["common"][12],$_SERVER['PHP_SELF'],$type,$item);
+$item=str_replace(".form.php","",$INFOFORM_PAGES[$_GET["type"]]);
+$item=str_replace("front/","",$item);
+commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],$type,$item);
 
 listTemplates($_GET["type"],$CFG_GLPI["root_doc"]."/".$INFOFORM_PAGES[$_GET["type"]],$_GET["add"]);
 
