@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: setup.version.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: setup.version.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -40,7 +40,7 @@ $NEEDED_ITEMS=array("setup");
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-commonHeader($LANG["common"][12],$_SERVER['PHP_SELF'],"config");
+commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],"config");
 
 checkRight("check_update","r");
 
