@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: software.licenses.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: software.licenses.php 8299 2009-05-16 12:23:38Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -47,6 +47,8 @@ if(!isset($_GET["lID"])) $_GET["lID"] = "";
 if(!isset($_GET["sID"])) $_GET["sID"] = "";
 if(!isset($_GET["withtemplate"])) $_GET["withtemplate"] = 0;
 
+
+/*
 $lic=new License;
 
 if (isset($_POST["add"]))
@@ -68,6 +70,7 @@ if (isset($_POST["add"]))
 	logEvent($_POST["sID"], "software", 4, "inventory", $_SESSION["glpiname"]." added a license.");
 
 	glpi_header($_SERVER['PHP_SELF']."?form=add&sID=".$_POST["sID"]);
+
 }
 else if (isset($_POST["update_stock_licenses"])||isset($_POST["update_stock_licenses_x"])){
 	checkRight("software","w");
@@ -167,7 +170,7 @@ else if (isset($_POST["update"])){
 else if (isset($_GET["form"])){
 	checkRight("software","w");
 
-	commonHeader($LANG["Menu"][4],$_SERVER['PHP_SELF'],"inventory","software");
+	commonHeader($LANG['Menu'][4],$_SERVER['PHP_SELF'],"inventory","software");
 	showLicenseForm($_SERVER['PHP_SELF'],$_GET['form'],$_GET["sID"],$_GET["lID"]);
 	commonFooter();
 }
@@ -178,25 +181,76 @@ else if (isset($_GET["delete"])){
 	logEvent(0, "software", 4, "inventory", $_SESSION["glpiname"]." deleted a license.");
 	glpi_header($_SERVER['HTTP_REFERER']." ");
 }
-else if (isset($_POST["install"])){
-	checkRight("software","w");
+else 
+*/
 
-	installSoftware($_POST["cID"],$_POST["licenseID"],$_POST["sID"]);
+if (isset($_POST["install"])){
+	checkRight("software","w");
+	installSoftwareVersion($_POST["cID"],$_POST["vID"]);
 	logEvent($_POST["cID"], "computers", 5, "inventory", $_SESSION["glpiname"]." installed software.");
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
+else if (isset($_GET["install"])){
+	checkRight("software","w");
+	installSoftwareVersion($_GET["cID"],$_GET["vID"]);
+	logEvent($_GET["cID"], "computers", 5, "inventory", $_SESSION["glpiname"]." installed software.");
+	glpi_header($_SERVER['HTTP_REFERER']);
+}
 else if (isset($_GET["uninstall"])){
 	checkRight("software","w");
 
-	uninstallSoftware($_GET["ID"]);
+	uninstallSoftwareVersion($_GET["ID"]);
 	logEvent($_GET["cID"], "computers", 5, "inventory", $_SESSION["glpiname"]." uninstalled software.");
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
+else if (isset($_POST["deleteinstalls"])){
+	checkRight("software","w");
+
+	foreach ($_POST["item"] as $key => $val){
+		if ($val==1) {
+			uninstallSoftwareVersion($key);
+			logEvent($_POST["sID"], "software", 5, "inventory", $_SESSION["glpiname"]." uninstalled software for several computers.");
+		}
+	}
+	glpi_header($_SERVER['HTTP_REFERER']);
+}
+else if (isset($_POST["moveinstalls"])){
+	checkRight("software","w");
+	foreach ($_POST["item"] as $key => $val){
+		if ($val==1 && $_POST['versionID']>0) {
+			updateInstalledVersion($key, $_POST['versionID']);
+			logEvent($_POST["sID"], "software", 5, "inventory", $_SESSION["glpiname"]." change version of versions installed on computers.");
+		}
+	}
+	glpi_header($_SERVER['HTTP_REFERER']);
+}
+else if (isset($_POST["uninstall_license"])){
+	checkRight("software","w");
+	foreach ($_POST as $key => $val)
+		if (preg_match("/license_([0-9]+)/",$key,$ereg)){
+			$input["ID"]=$ereg[1];
+			uninstallSoftwareVersion($input["ID"]);
+		}
+	logEvent($_POST["cID"], "computers", 5, "inventory", $_SESSION["glpiname"]." uninstalled software.");	
+	glpi_header($_SERVER['HTTP_REFERER']);	
+}
+else if (isset($_POST["install_license"]) && isset($_POST["cID"])){
+	checkRight("software","w");
+	foreach ($_POST as $key => $val)
+		if (preg_match("/version_([0-9]+)/",$key,$ereg)){
+			if ($ereg[1]>0) {
+				installSoftwareVersion($_POST["cID"],$ereg[1]);
+			}
+		}
+	logEvent($_POST["cID"], "computers", 5, "inventory", $_SESSION["glpiname"]." installed software.");
+	glpi_header($_SERVER['HTTP_REFERER']);	
+}
+/*
 else if (isset($_GET["unglobalize"])&&isset($_GET["ID"])){
 	unglobalizeLicense($_GET["ID"]);
-	logEvent($_GET["sID"], "software", 4, "inventory", $_SESSION["glpiname"]." ".$LANG["log"][60]);
+	logEvent($_GET["sID"], "software", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][60]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/software.form.php?ID=".$_GET["sID"]);
-}
+}*/
 else if (isset($_GET["back"])){
 	glpi_header($_GET["back"]);
 }
