@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: software.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: software.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -42,13 +42,13 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("software","r");
 
-commonHeader($LANG["Menu"][4],$_SERVER['PHP_SELF'],"inventory","software");
+commonHeader($LANG['Menu'][4],$_SERVER['PHP_SELF'],"inventory","software");
 
 manageGetValuesInSearch(SOFTWARE_TYPE);
 
-searchForm(SOFTWARE_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+searchForm(SOFTWARE_TYPE,$_GET);
 
-showList(SOFTWARE_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+showList(SOFTWARE_TYPE,$_GET);
 
 commonFooter();
 
