@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: stat.item.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: stat.item.php 8189 2009-04-17 15:12:10Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -40,12 +40,10 @@ $NEEDED_ITEMS=array("tracking","computer","printer","monitor","peripheral","netw
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-commonHeader($LANG["Menu"][13],$_SERVER['PHP_SELF'],"maintain","stat");
+commonHeader($LANG['Menu'][13],$_SERVER['PHP_SELF'],"maintain","stat");
 
 checkRight("statistic","1");
 
-echo "<div align ='center'><p><b><span class='icon_consol'>".$LANG["stats"][46]."</span></b></p></div>";
-
 if (isset($_GET["date1"])) $_POST["date1"] = $_GET["date1"];
 if (isset($_GET["date2"])) $_POST["date2"] = $_GET["date2"];
 
@@ -56,7 +54,7 @@ if(empty($_POST["date1"])&&empty($_POST["date2"])) {
 	$_POST["date2"]=date("Y-m-d");
 }
 
-if ($_POST["date1"]!=""&&$_POST["date2"]!=""&&strcmp($_POST["date2"],$_POST["date1"])<0){
+if (!empty($_POST["date1"])&&!empty($_POST["date2"])&&strcmp($_POST["date2"],$_POST["date1"])<0){
 	$tmp=$_POST["date1"];
 	$_POST["date1"]=$_POST["date2"];
 	$_POST["date2"]=$tmp;
@@ -66,11 +64,12 @@ if(!isset($_GET["start"])) $_GET["start"] = 0;
 
 echo "<div align='center'><form method=\"post\" name=\"form\" action=\"stat.item.php\">";
 echo "<table class='tab_cadre'><tr class='tab_bg_2'><td align='right'>";
-echo $LANG["search"][8]." :</td><td>";
-showCalendarForm("form","date1",$_POST["date1"]);
-echo "</td><td rowspan='2' align='center'><input type=\"submit\" class='button' name=\"submit\" Value=\"". $LANG["buttons"][7] ."\" /></td></tr>";
-echo "<tr class='tab_bg_2'><td align='right'>".$LANG["search"][9]." :</td><td>";
-showCalendarForm("form","date2",$_POST["date2"]);
+echo $LANG['search'][8]." :</td><td>";
+showDateFormItem("date1",$_POST["date1"]);
+
+echo "</td><td rowspan='2' align='center'><input type=\"submit\" class='button' name=\"submit\" Value=\"". $LANG['buttons'][7] ."\"></td></tr>";
+echo "<tr class='tab_bg_2'><td align='right'>".$LANG['search'][9]." :</td><td>";
+showDateFormItem("date2",$_POST["date2"]);
 echo "</td></tr>";
 echo "</table></form></div>";
 
