@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: stat.location.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: stat.location.php 8189 2009-04-17 15:12:10Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -40,12 +40,10 @@ $NEEDED_ITEMS=array("stat","tracking","user","setup","device");
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-commonHeader($LANG["Menu"][13],$_SERVER['PHP_SELF'],"maintain","stat");
+commonHeader($LANG['Menu'][13],$_SERVER['PHP_SELF'],"maintain","stat");
 
 checkRight("statistic","1");
 
-echo "<div align='center'><p><b><span class='icon_consol'>".$LANG["Menu"][13]."</span></b></p>";
-
 if (isset($_GET["date1"])) $_POST["date1"] = $_GET["date1"];
 if (isset($_GET["date2"])) $_POST["date2"] = $_GET["date2"];
 
@@ -56,7 +54,7 @@ if(empty($_POST["date1"])&&empty($_POST["date2"])) {
 	$_POST["date2"]=date("Y-m-d");
 }
 
-if ($_POST["date1"]!=""&&$_POST["date2"]!=""&&strcmp($_POST["date2"],$_POST["date1"])<0){
+if (!empty($_POST["date1"])&&!empty($_POST["date2"])&&strcmp($_POST["date2"],$_POST["date1"])<0){
 	$tmp=$_POST["date1"];
 	$_POST["date1"]=$_POST["date2"];
 	$_POST["date2"]=$tmp;
@@ -72,11 +70,11 @@ echo "<form method=\"post\" name=\"form\" action=\"stat.location.php\">";
 echo "<table class='tab_cadre'><tr class='tab_bg_2'><td rowspan='2'>";
 echo "<select name=\"dropdown\">";
 
-echo "<option value=\"glpi_type_computers\" ".($_POST["dropdown"]=="glpi_type_computers"?"selected":"").">".$LANG["common"][17]."</option>";
-echo "<option value=\"glpi_dropdown_model\" ".($_POST["dropdown"]=="glpi_dropdown_model"?"selected":"").">".$LANG["common"][22]."</option>";
+echo "<option value=\"glpi_type_computers\" ".($_POST["dropdown"]=="glpi_type_computers"?"selected":"").">".$LANG['common'][17]."</option>";
+echo "<option value=\"glpi_dropdown_model\" ".($_POST["dropdown"]=="glpi_dropdown_model"?"selected":"").">".$LANG['common'][22]."</option>";
 
-echo "<option value=\"glpi_dropdown_os\" ".($_POST["dropdown"]=="glpi_dropdown_os"?"selected":"").">".$LANG["computers"][9]."</option>";
-echo "<option value=\"glpi_dropdown_locations\" ".($_POST["dropdown"]=="glpi_dropdown_locations"?"selected":"").">".$LANG["common"][15]."</option>";
+echo "<option value=\"glpi_dropdown_os\" ".($_POST["dropdown"]=="glpi_dropdown_os"?"selected":"").">".$LANG['computers'][9]."</option>";
+echo "<option value=\"glpi_dropdown_locations\" ".($_POST["dropdown"]=="glpi_dropdown_locations"?"selected":"").">".$LANG['common'][15]."</option>";
 
 $devices=getDictDeviceLabel(-1);
 
@@ -87,11 +85,11 @@ echo "</select></td>";
 
 
 echo "<td align='right'>";
-echo $LANG["search"][8]." :</td><td>";
-showCalendarForm("form","date1",$_POST["date1"]);
-echo "</td><td rowspan='2' align='center'><input type=\"submit\" class='button' name=\"submit\" Value=\"". $LANG["buttons"][7] ."\" /></td></tr>";
-echo "<tr class='tab_bg_2'><td align='right'>".$LANG["search"][9]." :</td><td>";
-showCalendarForm("form","date2",$_POST["date2"]);
+echo $LANG['search'][8]." :</td><td>";
+showDateFormItem("date1",$_POST["date1"]);
+echo "</td><td rowspan='2' align='center'><input type=\"submit\" class='button' name=\"submit\" Value=\"". $LANG['buttons'][7] ."\"></td></tr>";
+echo "<tr class='tab_bg_2'><td align='right'>".$LANG['search'][9]." :</td><td>";
+showDateFormItem("date2",$_POST["date2"]);
 echo "</td></tr>";
 echo "</table></form></div>";
 
