@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: stat.tracking.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: stat.tracking.php 8364 2009-06-08 22:41:29Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -42,7 +42,7 @@ define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
 
-commonHeader($LANG["Menu"][13],$_SERVER['PHP_SELF'],"maintain","stat");
+commonHeader($LANG['Menu'][13],$_SERVER['PHP_SELF'],"maintain","stat");
 
 checkRight("statistic","1");
 
@@ -59,7 +59,7 @@ if(empty($_POST["date1"])&&empty($_POST["date2"])) {
 	$_POST["date2"]=date("Y-m-d");
 }
 
-if ($_POST["date1"]!=""&&$_POST["date2"]!=""&&strcmp($_POST["date2"],$_POST["date1"])<0){
+if (!empty($_POST["date1"])&&!empty($_POST["date2"])&&strcmp($_POST["date2"],$_POST["date1"])<0){
 	$tmp=$_POST["date1"];
 	$_POST["date1"]=$_POST["date2"];
 	$_POST["date2"]=$tmp;
@@ -69,49 +69,57 @@ if(!isset($_GET["start"])) $_GET["start"] = 0;
 
 
 $items=array(
-	$LANG["job"][4]=> array(
+	$LANG['job'][4]=> array(
 		"user"=>array(	
-			"title"=>$LANG["common"][37],
+			"title"=>$LANG['common'][37],
 			"field"=>"glpi_tracking.author"
 			),
 		"recipient"=>array(	
-			"title"=>$LANG["job"][3],
+			"title"=>$LANG['job'][3],
 			"field"=>"glpi_tracking.recipient"
 			),
 		"group"=>array(	
-			"title"=>$LANG["common"][35],
+			"title"=>$LANG['common'][35],
 			"field"=>"glpi_tracking.FK_group"
 			),
+		"title"=>array(	
+			"title"=>$LANG['users'][1],
+			"field"=>"glpi_dropdown_user_titles.title"
+			),
+		"type"=>array(	
+			"title"=>$LANG['users'][2],
+			"field"=>"glpi_dropdown_user_titles.type"
+			),
 	),
-	$LANG["common"][32] => array(
+	$LANG['common'][32] => array(
 		"category"=>array(	
-			"title"=>$LANG["common"][36],
+			"title"=>$LANG['common'][36],
 			"field"=>"glpi_tracking.category"
 			),
 		"priority"=>array(	
-			"title"=>$LANG["joblist"][2],
+			"title"=>$LANG['joblist'][2],
 			"field"=>"glpi_tracking.priority"
 			),
 		"request_type"=>array(	
-			"title"=>$LANG["job"][44],
+			"title"=>$LANG['job'][44],
 			"field"=>"glpi_tracking.request_type"
 			),
 	),
-	$LANG["job"][5] => array(
+	$LANG['job'][5] => array(
 		"technicien"=>array(	
-			"title"=>$LANG["job"][6]." ".$LANG["stats"][48],
+			"title"=>$LANG['job'][6]." ".$LANG['stats'][48],
 			"field"=>"glpi_tracking.assign"
 			),
 		"technicien_followup"=>array(	
-				"title"=>$LANG["job"][6]." ".$LANG["stats"][49],
+				"title"=>$LANG['job'][6]." ".$LANG['stats'][49],
 				"field"=>"glpi_followup.author"
 				),
 		"assign_group"=>array(	
-			"title"=>$LANG["common"][35],
+			"title"=>$LANG['common'][35],
 			"field"=>"glpi_tracking.assign_group"
 			),
 		"enterprise"=>array(	
-				"title"=>$LANG["financial"][26],
+				"title"=>$LANG['financial'][26],
 				"field"=>"glpi_tracking.assign_ent"
 				),
 	)
@@ -123,7 +131,6 @@ $items=array(
 			// Current field
 			if ($key==$_POST["type"]){
 				$field=$val["field"];
-				$title=$val["title"];
 			}
 			$INSELECT.= "<option value='$key' ".($key==$_POST["type"]?"selected":"").">".$val['title']."</option>";
 		}
@@ -131,9 +138,6 @@ $items=array(
 	}
 
 
-
-	echo "<div align ='center'><p><b><span class='icon_consol'>".$title."</span></b></p></div>";
-
 	echo "<div align='center'><form method=\"post\" name=\"form\" action=\"stat.tracking.php\">";
 	echo "<table class='tab_cadre'><tr class='tab_bg_2'>";
 	echo "<td rowspan='2' align='center'>";
@@ -141,15 +145,15 @@ $items=array(
 	echo $INSELECT;
 	echo "</td>";
 	echo "<td align='right'>";
-	echo $LANG["search"][8]." :</td><td>";
-	showCalendarForm("form","date1",$_POST["date1"]);
-	echo "</td><td rowspan='2' align='center'><input type=\"submit\" class='button' name=\"submit\" Value=\"". $LANG["buttons"][7] ."\" /></td></tr>";
-	echo "<tr class='tab_bg_2'><td align='right'>".$LANG["search"][9]." :</td><td>";
-	showCalendarForm("form","date2",$_POST["date2"]);
+	echo $LANG['search'][8]." :</td><td>";
+	showDateFormItem("date1",$_POST["date1"]);
+	echo "</td><td rowspan='2' align='center'><input type=\"submit\" class='button' name=\"submit\" Value=\"". $LANG['buttons'][7] ."\"></td></tr>";
+	echo "<tr class='tab_bg_2'><td align='right'>".$LANG['search'][9]." :</td><td>";
+	showDateFormItem("date2",$_POST["date2"]);
 	echo "</td></tr>";
 	echo "</table></form></div>";
 
-
+	
 	$val=getStatsItems($_POST["date1"],$_POST["date2"],$_POST["type"]);
 	$params=array("type"=>$_POST["type"],"field"=>$field,"date1"=>$_POST["date1"],"date2"=>$_POST["date2"],"start"=>$_GET["start"]);
 	printPager($_GET['start'],count($val),$_SERVER['PHP_SELF'],"date1=".$_POST["date1"]."&amp;date2=".$_POST["date2"]."&amp;type=".$_POST["type"],STAT_TYPE,$params);
