@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: state.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: state.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -44,16 +44,16 @@ if (!isset($_GET["synthese"])) $_GET["synthese"] = "no";
 
 checkCentralAccess();
 
-commonHeader($LANG["title"][9],$_SERVER['PHP_SELF'],"inventory","state");
+commonHeader($LANG['title'][9],$_SERVER['PHP_SELF'],"inventory","state");
 
 if ($_GET["synthese"]=="yes"){
 	showStateSummary($_SERVER['PHP_SELF']);
 } else {
 	manageGetValuesInSearch(STATE_TYPE);
 
-	searchForm(STATE_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+	searchForm(STATE_TYPE,$_GET);
 
-	showList(STATE_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+	showList(STATE_TYPE,$_GET);
 }
 
 commonFooter();
