@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: tracking.form.php 8270 2009-05-11 13:27:23Z remi $
+ * @version $Id: tracking.form.php 8269 2009-05-11 12:44:58Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -44,49 +44,52 @@ checkCentralAccess();
 $fup=new Followup();
 $track=new Job();
 
-commonHeader($LANG["title"][10],$_SERVER['PHP_SELF'],"maintain","tracking");
+if (!isset($_GET['ID'])) {
+	$_GET['ID']="";
+}
+
+commonHeader($LANG['title'][10],$_SERVER['PHP_SELF'],"maintain","tracking");
 if (isset($_POST['update'])){
 	checkSeveralRightsOr(array("update_ticket"=>"1","assign_ticket"=>"1","steal_ticket"=>"1","comment_ticket"=>"1","comment_all_ticket"=>"1"));
 
 	$track->update($_POST);
-	logEvent($_POST["ID"], "tracking", 4, "tracking", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+	logEvent($_POST["ID"], "tracking", 4, "tracking", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 
 	glpi_header($CFG_GLPI["root_doc"]."/front/tracking.form.php?ID=".$_POST["ID"]);
 
 
-}else if (isset($_POST['add'])||isset($_POST['add_close'])) {
+}else if (isset($_POST['add'])||isset($_POST['add_close'])||isset($_POST['add_reopen'])) {
 	checkSeveralRightsOr(array("comment_ticket"=>"1","comment_all_ticket"=>"1","show_assign_ticket"=>"1"));
 	$newID=$fup->add($_POST);
 
-	logEvent($_POST["tracking"], "tracking", 4, "tracking", $_SESSION["glpiname"]." ".$LANG["log"][20]." $newID.");
-	glpi_header($CFG_GLPI["root_doc"]."/front/tracking.form.php?ID=".$_POST["tracking"]);
+	logEvent($_POST["tracking"], "tracking", 4, "tracking", $_SESSION["glpiname"]." ".$LANG['log'][20]." $newID.");
+	glpi_header($CFG_GLPI["root_doc"]."/front/tracking.form.php?ID=".$_POST["tracking"]."&glpi_tab=1");
 
 } else if (isset($_POST["update_followup"])){
 	checkRight("comment_all_ticket","1");
 	$fup->update($_POST);
 
-	logEvent($_POST["tracking"], "tracking", 4, "tracking", $_SESSION["glpiname"]."  ".$LANG["log"][21]." ".$_POST["ID"].".");
+	logEvent($_POST["tracking"], "tracking", 4, "tracking", $_SESSION["glpiname"]."  ".$LANG['log'][21]." ".$_POST["ID"].".");
 	glpi_header($CFG_GLPI["root_doc"]."/front/tracking.form.php?ID=".$_POST["tracking"]);
 } else if (isset($_POST["delete_followup"])){
 	checkRight("comment_all_ticket","1");
 	$fup->delete($_POST);
-	logEvent($_POST["tracking"], "tracking", 4, "tracking", $_SESSION["glpiname"]." ".$LANG["log"][22]." ".$_POST["ID"].".");
+	logEvent($_POST["tracking"], "tracking", 4, "tracking", $_SESSION["glpiname"]." ".$LANG['log'][22]." ".$_POST["ID"].".");
 	glpi_header($CFG_GLPI["root_doc"]."/front/tracking.form.php?ID=".$_POST["tracking"]);
 }
 
 // Manage All case which does not exist
-if (!isset($_SESSION['glpi_onglet'])||$_SESSION['glpi_onglet']==-1) $_SESSION['glpi_onglet']=1;
+if (!isset($_SESSION['glpi_tab'])) $_SESSION['glpi_tab']=1;
 if (isset($_GET['onglet'])) {
-	$_SESSION['glpi_onglet']=$_GET['onglet'];
-}
-if (isset($_GET["ID"]))
-if (showJobDetails($_SERVER['PHP_SELF'],$_GET["ID"])){
-	switch($_SESSION['glpi_onglet']){
-		default :
-			if (!displayPluginAction(TRACKING_TYPE,$_GET["ID"],$_SESSION['glpi_onglet'])){
-				showFollowupsSummary($_GET["ID"]);
-			}
-	}
-}
+	$_SESSION['glpi_tab']=$_GET['onglet'];
+}	
+
+	$track->check($_GET["ID"],'r');
+
+	$track->showTabs($_GET["ID"],'',$_SESSION['glpi_tab']);
+	echo "<div id='tabcontent'></div>";
+
+	echo "<script type='text/javascript'>loadDefaultTab();</script>";
+
 commonFooter();
 ?>
