@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: tracking.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: tracking.php 8985 2009-09-15 19:03:56Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -39,7 +39,7 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkCentralAccess();
 
-commonHeader($LANG["title"][10],$_SERVER['PHP_SELF'],"maintain","tracking");
+commonHeader($LANG['title'][10],$_SERVER['PHP_SELF'],"maintain","tracking");
 
 
 if (isset($_GET['reset'])&&$_GET['reset']=="reset_before") {
@@ -55,6 +55,22 @@ if (isset($_GET['reset'])&&$_GET['reset']=="reset_before") {
 	}
 if (isset($_GET['reset'])) unset($_SESSION['tracking']);
 
+// Default boookmark
+if (!isset($_SESSION['tracking'])){
+		$query="SELECT FK_bookmark
+			FROM glpi_display_default
+			WHERE FK_users='".$_SESSION['glpiID']."'
+				AND device_type='".TRACKING_TYPE."';";
+		if ($result=$DB->query($query)){
+			if ($DB->numrows($result)>0){
+				$IDtoload=$DB->result($result,0,0);
+				// Load bookmark on main window
+				$bookmark=new Bookmark();
+				$bookmark->load($IDtoload,false);
+			}
+		}
+}
+
 if (isset($_SESSION['tracking'])&&is_array($_SESSION['tracking']))
 foreach ($_SESSION['tracking'] as $key => $val)
 if (!isset($_GET[$key])) $_GET[$key]=$val;
@@ -90,24 +106,23 @@ if (!isset($_GET["extended"])) $_GET["extended"]=0;
 
 if (!isset($_GET["contains"])||isset($_GET['reset'])) $_GET["contains"]="";
 if (!isset($_GET["contains3"])||isset($_GET['reset'])) $_GET["contains3"]="";
-if (!isset($_GET["date1"])||isset($_GET['reset'])) $_GET["date1"]="0000-00-00";
-if (!isset($_GET["enddate1"])||isset($_GET['reset'])) $_GET["enddate1"]="0000-00-00";
-if (!isset($_GET["datemod1"])||isset($_GET['reset'])) $_GET["datemod1"]="0000-00-00";
-if (!isset($_GET["date2"])||isset($_GET['reset'])) $_GET["date2"]="0000-00-00";
-if (!isset($_GET["enddate2"])||isset($_GET['reset'])) $_GET["enddate2"]="0000-00-00";
-if (!isset($_GET["datemod2"])||isset($_GET['reset'])) $_GET["datemod2"]="0000-00-00";
+if (!isset($_GET["date1"])||isset($_GET['reset'])||$_GET["date1"]=="NULL") $_GET["date1"]="";
+if (!isset($_GET["enddate1"])||isset($_GET['reset'])||$_GET["enddate1"]=="NULL") $_GET["enddate1"]="";
+if (!isset($_GET["datemod1"])||isset($_GET['reset'])||$_GET["datemod1"]=="NULL") $_GET["datemod1"]="";
+if (!isset($_GET["date2"])||isset($_GET['reset'])||$_GET["date2"]=="NULL") $_GET["date2"]="";
+if (!isset($_GET["enddate2"])||isset($_GET['reset'])||$_GET["enddate2"]=="NULL") $_GET["enddate2"]="";
+if (!isset($_GET["datemod2"])||isset($_GET['reset'])||$_GET["datemod2"]=="NULL") $_GET["datemod2"]="";
 if (!isset($_GET["field"])||isset($_GET['reset'])) $_GET["field"]="";
 if (!isset($_GET["only_computers"])||isset($_GET['reset'])) $_GET["only_computers"] = "";
 if (!isset($_GET["recipient"])||isset($_GET['reset'])) $_GET["recipient"]=0;
 
-
-if ($_GET["date1"]!="0000-00-00"&&$_GET["date2"]!="0000-00-00"&&strcmp($_GET["date2"],$_GET["date1"])<0){
+if (!empty($_GET["date1"])&&!empty($_GET["date2"])&&strcmp($_GET["date2"],$_GET["date1"])<0){
 	$tmp=$_GET["date1"];
 	$_GET["date1"]=$_GET["date2"];
 	$_GET["date2"]=$tmp;
 }
 
-if ($_GET["enddate1"]!="0000-00-00"&&$_GET["enddate2"]!="0000-00-00"&&strcmp($_GET["enddate2"],$_GET["enddate1"])<0){
+if (!empty($_GET["enddate1"])&&!empty($_GET["enddate2"])&&strcmp($_GET["enddate2"],$_GET["enddate1"])<0){
 	$tmp=$_GET["enddate1"];
 	$_GET["enddate1"]=$_GET["enddate2"];
 	$_GET["enddate2"]=$tmp;
