@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: transfer.action.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: transfer.action.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -33,32 +33,36 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-$NEEDED_ITEMS=array("transfer","user","tracking","reservation","document","computer","device","printer","networking","peripheral","monitor","software","infocom","phone","link","ocsng","consumable","cartridge","contract","enterprise","contact","group","profile","search","mailgate","typedoc","setup","rulesengine","rule.softwarecategories");
+$NEEDED_ITEMS=array("transfer","user","tracking","reservation","document","computer","device","printer",
+	"networking","peripheral","monitor","software","infocom","phone","link","ocsng","consumable",
+	"cartridge","contract","enterprise","contact","group","profile","search","mailgate","typedoc","setup",
+	"rulesengine","rule.softwarecategories");
 
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
+
+
+
+commonHeader($LANG['transfer'][1],$_SERVER['PHP_SELF'],"admin","transfer");
+
 $transfer=new Transfer();
-
-
-commonHeader($LANG["transfer"][1],$_SERVER['PHP_SELF'],"admin","transfer");
-checkRight("transfer","r");
-
+$transfer->check(-1,"r");
 
 
 if (isset($_POST['transfer'])){
 	if (isset($_SESSION['glpitransfer_list'])){
 		$transfer->moveItems($_SESSION['glpitransfer_list'],$_POST['to_entity'],$_POST);
 		unset($_SESSION['glpitransfer_list']);
-		echo "<strong>".$LANG["common"][23]."</strong><br>";
-		echo "<a href=\"central.php\"><b>".$LANG["buttons"][13]."</b></a>";
+		echo "<strong>".$LANG['common'][23]."</strong><br>";
+		echo "<a href=\"central.php\"><b>".$LANG['buttons'][13]."</b></a>";
 		commonFooter();
 		exit();
 	}
 } else if (isset($_GET['clear'])){
 	unset($_SESSION['glpitransfer_list']);
-	echo "<strong>".$LANG["common"][23]."</strong><br>";
-	echo "<a href=\"central.php\"><b>".$LANG["buttons"][13]."</b></a>";
+	echo "<strong>".$LANG['common'][23]."</strong><br>";
+	echo "<a href=\"central.php\"><b>".$LANG['buttons'][13]."</b></a>";
 	commonFooter();
 	exit();
 }
