@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: transfer.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: transfer.form.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -46,36 +46,36 @@ $transfer=new Transfer();
 
 if (isset($_POST["add"]))
 {
-	checkRight("transfer","w");
+	$transfer->check(-1,'w');
 
 	$newID=$transfer->add($_POST);
-	logEvent($newID, "transfers", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][20]." ".$_POST["name"].".");
+	logEvent($newID, "transfers", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$_POST["name"].".");
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (isset($_POST["delete"]))
 {
-	checkRight("transfer","w");
+	$transfer->check($_POST["ID"],'w');
 
 	$transfer->delete($_POST);
-	logEvent($_POST["ID"], "transfers", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+	logEvent($_POST["ID"], "transfers", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/transfer.php");
 }else if (isset($_POST["update"]))
 {
-	checkRight("transfer","w");
+	$transfer->check($_POST["ID"],'w');
 
 	$transfer->update($_POST);
-	logEvent($_POST["ID"], "transfers", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+	logEvent($_POST["ID"], "transfers", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 
-commonHeader($LANG["transfer"][1],$_SERVER['PHP_SELF'],"admin","transfer");
+commonHeader($LANG['transfer'][1],$_SERVER['PHP_SELF'],"admin","transfer");
 
-if (!isset($_SESSION['glpi_onglet'])||$_SESSION['glpi_onglet']==-1) $_SESSION['glpi_onglet']=1;
+if (!isset($_SESSION['glpi_tab'])||$_SESSION['glpi_tab']==-1) $_SESSION['glpi_tab']=1;
 if (isset($_GET['onglet'])) {
-	$_SESSION['glpi_onglet']=$_GET['onglet'];
+	$_SESSION['glpi_tab']=$_GET['onglet'];
 }
 
-$transfer->showOnglets($_GET["ID"], '',$_SESSION['glpi_onglet']);
+$transfer->showTabs($_GET["ID"], '',$_SESSION['glpi_tab']);
 $transfer->showForm($_SERVER['PHP_SELF'],$_GET["ID"]);
 
 commonFooter();
