@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: transfer.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: transfer.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -42,13 +42,13 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("transfer","r");
 
-commonHeader($LANG["transfer"][1],$_SERVER['PHP_SELF'],"admin","transfer");
+commonHeader($LANG['transfer'][1],$_SERVER['PHP_SELF'],"admin","transfer");
 
 manageGetValuesInSearch(TRANSFER_TYPE);
 
-searchForm(TRANSFER_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+searchForm(TRANSFER_TYPE,$_GET);
 
-showList(TRANSFER_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"],$_GET["link2"],$_GET["contains2"],$_GET["field2"],$_GET["type2"]);
+showList(TRANSFER_TYPE,$_GET);
 
 commonFooter();
 
