@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: typedoc.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: typedoc.form.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -45,7 +45,7 @@ if(empty($_GET["ID"])) $_GET["ID"] = "";
 $typedoc=new TypeDoc();
 if (isset($_POST["add"]))
 {
-	checkRight("typedoc","w");
+	$typedoc->check(-1,'w');
 
 	if ($newID=$typedoc->add($_POST))
 	logEvent($newID, "typedocs", 4, "setup", $_SESSION["glpiname"]." added ".$_POST["name"].".");
@@ -53,27 +53,25 @@ if (isset($_POST["add"]))
 }
 else if (isset($_POST["delete"]))
 {
-	checkRight("typedoc","w");
+	$typedoc->check($_POST["ID"],'w');
 
 	$typedoc->delete($_POST,1);
 
-	logEvent($_POST["ID"], "typedocs", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][22]);
+	logEvent($_POST["ID"], "typedocs", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][22]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/typedoc.php");
 
 }
 else if (isset($_POST["update"]))
 {
-	checkRight("typedoc","w");
+	$typedoc->check($_POST["ID"],'w');
 
 	$typedoc->update($_POST);
-	logEvent($_POST["ID"], "typedocs", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][21]);
+	logEvent($_POST["ID"], "typedocs", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][21]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else
 {
-	checkRight("typedoc","r");
-
-	commonHeader($LANG["common"][12],$_SERVER['PHP_SELF'],"config","typedoc");
+	commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],"config","typedoc");
 	$typedoc->showForm($_SERVER['PHP_SELF'],$_GET["ID"]);
 	commonFooter();
 }
