@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: typedoc.list.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: typedoc.list.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -36,10 +36,10 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkLoginUser();
 
-popHeader($LANG["common"][12],$_SERVER['PHP_SELF']);
+popHeader($LANG['common'][12],$_SERVER['PHP_SELF']);
 
 manageGetValuesInSearch(TYPEDOC_TYPE);
-showList(TYPEDOC_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+showList(TYPEDOC_TYPE,$_GET);
 
 popFooter();
 
