@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: typedoc.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: typedoc.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -43,13 +43,13 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("typedoc","r");
 
-commonHeader($LANG["common"][12],$_SERVER['PHP_SELF'],"config","typedoc");
+commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],"config","typedoc");
 
 manageGetValuesInSearch(TYPEDOC_TYPE);
 
-searchForm(TYPEDOC_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+searchForm(TYPEDOC_TYPE,$_GET);
 
-showList(TYPEDOC_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+showList(TYPEDOC_TYPE,$_GET);
 
 commonFooter();
 ?>
