@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: user.form.my.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: user.form.my.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -48,31 +48,35 @@ $user = new User();
 
 if (isset ($_POST["update"]) && $_POST["ID"] == $_SESSION["glpiID"]) {
 	$user->update($_POST);
-	logEvent(0, "users", 5, "setup", $_SESSION["glpiname"] . "  " . $LANG["log"][21] . "  " . $_POST["name"] . ".");
+	logEvent(0, "users", 5, "setup", $_SESSION["glpiname"] . "  " . $LANG['log'][21] . "  " . $_SESSION["glpiname"] . ".");
 	glpi_header($_SERVER['HTTP_REFERER']);
 } else {
 
-	if (!isset($_SESSION['glpi_viewpreferences'])) $_SESSION['glpi_viewpreferences']="my";
-	if (isset($_GET['onglet'])) $_SESSION['glpi_viewpreferences']=$_GET['onglet'];
 
 	if ($_SESSION["glpiactiveprofile"]["interface"] == "central")
-		commonHeader($LANG["title"][13], $_SERVER['PHP_SELF']);
+		commonHeader($LANG['title'][13], $_SERVER['PHP_SELF']);
 	else
-		helpHeader($LANG["title"][13], $_SERVER['PHP_SELF']);
+		helpHeader($LANG['title'][13], $_SERVER['PHP_SELF']);
+
+
+	//forea
+	$tabs[1]=array('title'=>$LANG['title'][26],
+		'url'=>$CFG_GLPI['root_doc']."/ajax/preference.tabs.php",
+		'params'=>"target=".$_SERVER['PHP_SELF']."&type=prefs&glpi_tab=1");
+
+	$tabs[2]=array('title'=>$LANG['setup'][6],
+		'url'=>$CFG_GLPI['root_doc']."/ajax/preference.tabs.php",
+		'params'=>"target=".$_SERVER['PHP_SELF']."&type=prefs&glpi_tab=2");
+
+	$plug_tabs=getPluginTabs($_SERVER['PHP_SELF'],"prefs","","");
+
+	$tabs+=$plug_tabs;
+	
+	echo "<div id='tabspanel' class='center-h'></div>";
+	createAjaxTabs('tabspanel','tabcontent',$tabs,$_SESSION['glpi_tab']);
+	echo "<div id='tabcontent'></div>";
+	echo "<script type='text/javascript'>loadDefaultTab();</script>";
 
-showUserPreferencesOnglets($_SERVER['PHP_SELF'],$_SESSION['glpi_viewpreferences']);
-switch ($_SESSION['glpi_viewpreferences'])
-{
-	case "plugins":
-		echo "<table class='tab_cadre_fixe' ><tr><td>";
-		doHook("user_preferences",$_POST);
-		echo "</td></tr>";
-		echo "</table>";
-	break;
-	default:
-		$user->showMyForm($_SERVER['PHP_SELF'], $_SESSION["glpiID"]);
-	break;
-}
 
 if ($_SESSION["glpiactiveprofile"]["interface"] == "central")
 	commonFooter();
