@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: user.form.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: user.form.php 8213 2009-04-21 13:03:51Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -66,20 +66,20 @@ if (isset($_POST["add"])) {
 	// Pas de nom pas d'ajout	
 	if (!empty($_POST["name"])){
 		$newID=$user->add($_POST);
-		logEvent($newID, "users", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][20]." ".$_POST["name"].".");
+		logEvent($newID, "users", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$_POST["name"].".");
 	}
 	glpi_header($_SERVER['HTTP_REFERER']);
 } else if (isset($_POST["delete"])) {
 	checkRight("user","w");
 
 	$user->delete($_POST);
-	logEvent(0,"users", 4, "setup", $_SESSION["glpiname"]."  ".$LANG["log"][22]." ".$_POST["ID"].".");
+	logEvent(0,"users", 4, "setup", $_SESSION["glpiname"]."  ".$LANG['log'][22]." ".$_POST["ID"].".");
 	glpi_header($CFG_GLPI["root_doc"]."/front/user.php");
 } else if (isset($_POST["restore"]))
 {
 	checkRight("user","w");
 	$user->restore($_POST);
-	logEvent($_POST["ID"],"users", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][23]);
+	logEvent($_POST["ID"],"users", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][23]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/user.php");
 }
 else if (isset($_POST["purge"]))
@@ -87,7 +87,7 @@ else if (isset($_POST["purge"]))
 	checkRight("user","w");
 	$user->delete($_POST,1);
 	
-	logEvent($_POST["ID"], "users", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][24]);
+	logEvent($_POST["ID"], "users", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][24]);
 	glpi_header($CFG_GLPI["root_doc"]."/front/user.php");
 
 } else if (isset ($_POST["force_ldap_resynch"]))
@@ -95,13 +95,13 @@ else if (isset($_POST["purge"]))
 	checkSeveralRightsAnd(array("user"=>"w", "user_auth_method"=>"w"));
 	
 	$user->getFromDB($_POST["ID"]);
-	ldapImportUserByServerId($user->fields["name"],1,$user->fields["id_auth"]);
+	ldapImportUserByServerId($user->fields["name"],true,$user->fields["id_auth"],true);
 	glpi_header($_SERVER['HTTP_REFERER']);
 } else if (isset($_POST["update"])) {
 	checkRight("user","w");
 
 	$user->update($_POST);
-	logEvent(0,"users", 5, "setup", $_SESSION["glpiname"]."  ".$LANG["log"][21]."  ".$_POST["name"].".");
+	logEvent(0,"users", 5, "setup", $_SESSION["glpiname"]."  ".$LANG['log'][21]."  ".$_POST["name"].".");
 	glpi_header($_SERVER['HTTP_REFERER']);
 } else if (isset($_POST["addgroup"]))
 {
@@ -109,7 +109,7 @@ else if (isset($_POST["purge"]))
 
 	addUserGroup($_POST["FK_users"],$_POST["FK_groups"]);
 
-	logEvent($_POST["FK_users"], "users", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][48]);
+	logEvent($_POST["FK_users"], "users", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][48]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 }
 else if (isset($_POST["deletegroup"]))
@@ -119,15 +119,18 @@ else if (isset($_POST["deletegroup"]))
 		foreach ($_POST["item"] as $key => $val)
 			deleteUserGroup($key);
 
-	logEvent($_POST["FK_users"], "users", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][49]);
+	logEvent($_POST["FK_users"], "users", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][49]);
 	glpi_header($_SERVER['HTTP_REFERER']);
 } else if (isset($_POST["addright"]))
 {
 	checkRight("user","w");
 
-	addUserProfileEntity($_POST);
-
-	logEvent($_POST["FK_users"], "users", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][61]);
+	$prof=new Profile();
+	if ($prof->currentUserHaveMoreRightThan(array($_POST['FK_profiles']=>$_POST['FK_profiles']))){
+		addUserProfileEntity($_POST);
+		logEvent($_POST["FK_users"], "users", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][61]);
+	}
+	
 	glpi_header($_SERVER['HTTP_REFERER']);
 } else if (isset($_POST["deleteright"]))
 {
@@ -137,7 +140,7 @@ else if (isset($_POST["deletegroup"]))
 		foreach ($_POST["item"] as $key => $val){
 			deleteUserProfileEntity($key);
 		}
-		logEvent($_POST["FK_users"], "users", 4, "setup", $_SESSION["glpiname"]." ".$LANG["log"][62]);
+		logEvent($_POST["FK_users"], "users", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][62]);
 	}
 
 	glpi_header($_SERVER['HTTP_REFERER']);
@@ -174,55 +177,19 @@ else if (isset($_POST["deletegroup"]))
 } else {
 
 
-	if (!isset($_SESSION['glpi_onglet'])) $_SESSION['glpi_onglet']=1;
+	if (!isset($_SESSION['glpi_tab'])) $_SESSION['glpi_tab']=1;
 	if (isset($_GET['onglet'])) {
-		$_SESSION['glpi_onglet']=$_GET['onglet'];
+		$_SESSION['glpi_tab']=$_GET['onglet'];
 	}
 
 
 	if (!isset($_GET["ext_auth"])){
 		checkRight("user","r");
 
-		commonHeader($LANG["title"][13],$_SERVER['PHP_SELF'],"admin","user");
+		commonHeader($LANG['title'][13],$_SERVER['PHP_SELF'],"admin","user");
+
+		$user->showForm($_SERVER['PHP_SELF'],$_GET["ID"]);
 
-		if ($user->showForm($_SERVER['PHP_SELF'],$_GET["ID"])){
-			if (!empty($_GET["ID"]))
-			switch($_SESSION['glpi_onglet']){
-				case -1:
-					showUserRights($_SERVER['PHP_SELF'],$_GET["ID"]);
-					showGroupAssociated($_SERVER['PHP_SELF'],$_GET["ID"]);
-					showDeviceUser($_GET["ID"]);
-					showUserReservations($_SERVER['PHP_SELF'],$_GET["ID"]);
-					if (haveRight("show_all_ticket", "1")){
-						showTrackingList($_SERVER['PHP_SELF'],$_GET["start"],$_GET["sort"],$_GET["order"],"all",'','',$_GET["ID"],0);
-					}
-					displayPluginAction(USER_TYPE,$_GET["ID"],$_SESSION['glpi_onglet']);
-					break;
-				case 1 :
-					showUserRights($_SERVER['PHP_SELF'],$_GET["ID"]);
-					break;
-				case 2 :
-					showDeviceUser($_GET["ID"]);
-					break;
-				case 3 :
-					showTrackingList($_SERVER['PHP_SELF'],$_GET["start"],$_GET["sort"],$_GET["order"],"all",'','',$_GET["ID"],0);
-					break;
-				case 4 :
-					showGroupAssociated($_SERVER['PHP_SELF'],$_GET["ID"]);
-					break;
-				case 11 :
-					showUserReservations($_SERVER['PHP_SELF'],$_GET["ID"]);
-					break;
-				case 12:
-					showSynchronizationForm($_SERVER['PHP_SELF'],$_GET["ID"]);
-					break;
-				default : 
-					if (!displayPluginAction(USER_TYPE,$_GET["ID"],$_SESSION['glpi_onglet']))
-						showGroupAssociated($_SERVER['PHP_SELF'],$_GET["ID"]);
-					break;
-			}
-			
-		}
 		commonFooter();
 	} else {
 		checkRight("user","w");
@@ -235,12 +202,13 @@ else if (isset($_POST["deletegroup"]))
 		}
 		if (isset($_GET['add_ext_auth_simple'])){
 			if (isset($_GET['login'])&&!empty($_GET['login'])){
-				$user->add(array('name'=>$_GET['login'],'_extauth'=>1));
+				$newID=$user->add(array('name'=>$_GET['login'],'_extauth'=>1,'add'=>1));
+				logEvent($newID, "users", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$_GET['login'].".");
 			}
 			glpi_header($_SERVER['HTTP_REFERER']);
 		}
 
-		commonHeader($LANG["title"][13],$_SERVER['PHP_SELF'],"admin","user");
+		commonHeader($LANG['title'][13],$_SERVER['PHP_SELF'],"admin","user");
 		showAddExtAuthUserForm($_SERVER['PHP_SELF']);
 		commonFooter();
 	}
