@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: user.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: user.php 8027 2009-02-28 17:08:00Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -43,7 +43,7 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 checkRight("user","r");
 
-commonHeader($LANG["Menu"][14],$_SERVER['PHP_SELF'],"admin","user");	
+commonHeader($LANG['Menu'][14],$_SERVER['PHP_SELF'],"admin","user");	
 
 $user=new User();
 $user->title();
@@ -52,9 +52,9 @@ $user->title();
 
 manageGetValuesInSearch(USER_TYPE);
 
-searchForm(USER_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+searchForm(USER_TYPE,$_GET);
 
-showList(USER_TYPE,$_SERVER['PHP_SELF'],$_GET["field"],$_GET["contains"],$_GET["sort"],$_GET["order"],$_GET["start"],$_GET["deleted"],$_GET["link"],$_GET["distinct"]);
+showList(USER_TYPE,$_GET);
 
 commonFooter();
 
