@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: admininfo.class.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: admininfo.class.php 7762 2009-01-06 18:30:32Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -46,7 +46,7 @@ class AdminInfo extends CommonDBTM{
 	 *@return nothing
 	 *
 	**/
-	function AdminInfo () {
+	function __construct () {
 		$this->table="glpi_ocs_admin_link";		
 		
 	}
