@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: auth.function.php 7985 2009-02-20 10:57:41Z walid $
+ * @version $Id: auth.function.php 8111 2009-03-24 18:33:05Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -97,6 +97,7 @@ function haveTypeRight($type, $right) {
 		case GENERAL_TYPE :
 			return true;
 			break;
+		case COMPUTERDISK_TYPE:
 		case COMPUTER_TYPE :
 			return haveRight("computer", $right);
 			break;
@@ -113,6 +114,8 @@ function haveTypeRight($type, $right) {
 			return haveRight("peripheral", $right);
 			break;
 		case SOFTWARE_TYPE :
+		case SOFTWAREVERSION_TYPE :
+		case SOFTWARELICENSE_TYPE :
 			return haveRight("software", $right);
 			break;
 		case CONTACT_TYPE :
@@ -122,10 +125,10 @@ function haveTypeRight($type, $right) {
 			return haveRight("contact_enterprise", $right);
 			break;
 		case INFOCOM_TYPE :
-			return haveRight("contract_infocom", $right);
+			return haveRight("infocom", $right);
 			break;
 		case CONTRACT_TYPE :
-			return haveRight("contract_infocom", $right);
+			return haveRight("contract", $right);
 			break;
 		case CARTRIDGE_TYPE :
 			return haveRight("cartridge", $right);
@@ -160,9 +163,6 @@ function haveTypeRight($type, $right) {
 		case CONSUMABLE_ITEM_TYPE :
 			return haveRight("consumable", $right);
 			break;
-		case LICENSE_TYPE :
-			return haveRight("software", $right);
-			break;
 		case LINK_TYPE :
 			return haveRight("link", $right);
 			break;
@@ -231,19 +231,45 @@ function displayRightError() {
 	global $LANG, $CFG_GLPI, $HEADER_LOADED;
 	if (!$HEADER_LOADED) {
 		if (!isset ($_SESSION["glpiactiveprofile"]["interface"])){
-			nullHeader($LANG["login"][5], $_SERVER['PHP_SELF']);
+			nullHeader($LANG['login'][5], $_SERVER['PHP_SELF']);
 		} else {
 			if ($_SESSION["glpiactiveprofile"]["interface"] == "central"){
-				commonHeader($LANG["login"][5], $_SERVER['PHP_SELF']);
+				commonHeader($LANG['login'][5], $_SERVER['PHP_SELF']);
 			} else {
 				if ($_SESSION["glpiactiveprofile"]["interface"] == "helpdesk"){
-					helpHeader($LANG["login"][5], $_SERVER['PHP_SELF']);
+					helpHeader($LANG['login'][5], $_SERVER['PHP_SELF']);
 				}
 			}
 		}
 	}
 	echo "<div class='center'><br><br><img src=\"" . $CFG_GLPI["root_doc"] . "/pics/warning.png\" alt=\"warning\"><br><br>";
-	echo "<strong>" . $LANG["login"][5] . "</strong></div>";
+	echo "<strong>" . $LANG['common'][83] . "</strong></div>";
+	nullFooter();
+	exit ();
+}
+
+/**
+ * Display common message for item not found
+ *
+ * @return Nothing
+**/
+function displayNotFoundError() {
+	global $LANG, $CFG_GLPI, $HEADER_LOADED;
+	if (!$HEADER_LOADED) {
+		if (!isset ($_SESSION["glpiactiveprofile"]["interface"])){
+			nullHeader($LANG['login'][5], $_SERVER['PHP_SELF']);
+		} else {
+			if ($_SESSION["glpiactiveprofile"]["interface"] == "central"){
+				commonHeader($LANG['login'][5], $_SERVER['PHP_SELF']);
+			} else {
+				if ($_SESSION["glpiactiveprofile"]["interface"] == "helpdesk"){
+					helpHeader($LANG['login'][5], $_SERVER['PHP_SELF']);
+				}
+			}
+		}
+	}
+	echo "<div class='center'><br><br><img src=\"" . $CFG_GLPI["root_doc"] . "/pics/warning.png\" alt=\"warning\"><br><br>";
+	echo "<strong>" . $LANG['common'][54] . "</strong></div>";
 	nullFooter();
 	exit ();
 }
@@ -441,7 +467,14 @@ function loadLanguage($forcelang='') {
 	$file = "";
 
 	if (!isset($_SESSION["glpilanguage"])){
-		$_SESSION["glpilanguage"]=$CFG_GLPI["default_language"];
+		if (isset($CFG_GLPI["language"])) {
+			// Default config in GLPI >= 0.72
+			$_SESSION["glpilanguage"]=$CFG_GLPI["language"];
+			
+		} else if (isset($CFG_GLPI["default_language"])) {
+			// Default config in GLPI < 0.72 : keep it for upgrade process
+			$_SESSION["glpilanguage"]=$CFG_GLPI["default_language"];
+		}
 	}
 
 	$trytoload=$_SESSION["glpilanguage"];
@@ -451,7 +484,7 @@ function loadLanguage($forcelang='') {
 	}
 	// If not set try default lang file
 	if (empty($trytoload)){
-		$trytoload=$CFG_GLPI["default_language"];
+		$trytoload=$CFG_GLPI["language"];
 	}
 
 	if (isset ($CFG_GLPI["languages"][$trytoload][1])) {
@@ -484,10 +517,10 @@ function loadLanguage($forcelang='') {
 	}
 
 	// Debug display lang element with item
-	if ($CFG_GLPI["debug"] && $CFG_GLPI["debug_lang"]) {
+	if ($_SESSION['glpi_use_mode']==TRANSLATION_MODE && $CFG_GLPI["debug_lang"]) {
 		foreach ($LANG as $module => $tab) {
 			foreach ($tab as $num => $val) {
-				$LANG[$module][$num] .= "<span style='font-size:12px; color:red;'>$module/$num</span>";
+				$LANG[$module][$num] = "".$LANG[$module][$num]."/<span style='font-size:12px; color:red;'>$module/$num</span>";
 			}
 		}
 	}
@@ -503,31 +536,36 @@ function loadLanguage($forcelang='') {
 function initEntityProfiles($userID) {
 	global $DB;
 
-	$profile = new Profile;
+//	$profile = new Profile;
 
-	$query = "SELECT DISTINCT glpi_profiles.* FROM glpi_users_profiles INNER JOIN glpi_profiles ON (glpi_users_profiles.FK_profiles = glpi_profiles.ID)
-					WHERE glpi_users_profiles.FK_users='$userID'
+	$query = "SELECT DISTINCT glpi_profiles.* 
+		FROM glpi_users_profiles 
+			INNER JOIN glpi_profiles ON (glpi_users_profiles.FK_profiles = glpi_profiles.ID)
+		WHERE glpi_users_profiles.FK_users='$userID' 
 		ORDER BY glpi_profiles.name";
 	$result = $DB->query($query);
 	$_SESSION['glpiprofiles'] = array ();
 	if ($DB->numrows($result)) {
 		while ($data = $DB->fetch_assoc($result)) {
-			$profile->fields = array ();
-			$profile->getFromDB($data['ID']);
-			$profile->cleanProfile();
-			$_SESSION['glpiprofiles'][$data['ID']] = $profile->fields;
+//			$profile->fields = array ();
+//			$profile->getFromDB($data['ID']);
+//			$profile->cleanProfile();
+			$_SESSION['glpiprofiles'][$data['ID']]['name'] = $data['name'];
 		}
 
 		foreach ($_SESSION['glpiprofiles'] as $key => $tab) {
-			$query2 = "SELECT glpi_users_profiles.FK_entities as eID, glpi_users_profiles.ID as kID, glpi_users_profiles.recursive as recursive, glpi_entities.* FROM glpi_users_profiles LEFT JOIN glpi_entities ON (glpi_users_profiles.FK_entities = glpi_entities.ID)
-													WHERE glpi_users_profiles.FK_profiles='$key' AND glpi_users_profiles.FK_users='$userID'
-		ORDER BY glpi_entities.completename";
+			$query2 = "SELECT glpi_users_profiles.FK_entities as eID, glpi_users_profiles.ID as kID, 
+					glpi_users_profiles.recursive as recursive, glpi_entities.* 
+				FROM glpi_users_profiles 
+				LEFT JOIN glpi_entities ON (glpi_users_profiles.FK_entities = glpi_entities.ID)
+				WHERE glpi_users_profiles.FK_profiles='$key' AND glpi_users_profiles.FK_users='$userID' 
+				ORDER BY glpi_entities.completename";
 			$result2 = $DB->query($query2);
 			if ($DB->numrows($result2)) {
 				while ($data = $DB->fetch_array($result2)) {
 					$_SESSION['glpiprofiles'][$key]['entities'][$data['kID']]['ID'] = $data['eID'];
 					$_SESSION['glpiprofiles'][$key]['entities'][$data['kID']]['name'] = $data['name'];
-					$_SESSION['glpiprofiles'][$key]['entities'][$data['kID']]['completename'] = $data['completename'];
+//					$_SESSION['glpiprofiles'][$key]['entities'][$data['kID']]['completename'] = $data['completename'];
 					$_SESSION['glpiprofiles'][$key]['entities'][$data['kID']]['recursive'] = $data['recursive'];
 				}
 			}
@@ -544,50 +582,36 @@ function initEntityProfiles($userID) {
 function changeProfile($ID) {
 	global $CFG_GLPI,$LANG;
 	if (isset ($_SESSION['glpiprofiles'][$ID]) && count($_SESSION['glpiprofiles'][$ID]['entities'])) {
+		$profile=new Profile();
 		// glpiactiveprofile -> active profile
-		$_SESSION['glpiactiveprofile'] = $_SESSION['glpiprofiles'][$ID];
-		$_SESSION['glpi_entities_tree']=array();
-		$_SESSION['glpiactiveentities'] = array ();
-		// Init ancestors if needed
-		if (!isset($_SESSION['glpi_entities_ancestors'])){
-			$_SESSION['glpi_entities_ancestors']=array();
-		}
-		// glpiactiveentities -> active entities
-		foreach ($_SESSION['glpiactiveprofile']['entities'] as $key => $val) {
-			if (!$val['recursive']) {
-				if (!array_search($val["ID"], $_SESSION['glpiactiveentities'])) {
-					$_SESSION['glpiactiveentities'][$val['ID']] = $val['ID'];
-					$entity=array();
-					$entity[$val['ID']]['tree']=array();
-					
-					if ($val['ID']==0){
-						$entity[$val['ID']]['name'] = $LANG["entity"][2];
-					} else {
-						$entity[$val['ID']]['name'] = $val['name'];
-					}
-					$_SESSION['glpi_entities_tree'][] = $entity;
-				}
-			} else {
-				$entitytree = getTreeForItem("glpi_entities", $val['ID']);
-				$_SESSION['glpi_entities_tree'][]=$entitytree;
-				$entities = contructListFromTree($entitytree);
+		if ($profile->getFromDB($ID)){
+			$profile->cleanProfile();
+			$data = $profile->fields;
+			$data['entities']=$_SESSION['glpiprofiles'][$ID]['entities'];
 
-				if (count($entities)) {
-					foreach ($entities as $key2 => $val2) {
-						$_SESSION['glpiactiveentities'][$key2] = $key2;
+			$_SESSION['glpiactiveprofile'] = $data;
+			$_SESSION['glpiactiveentities'] = array ();
+	
+			$active_entity_done=false;
+			// Try to load default entity if it is a root entity
+			foreach ($data['entities'] as $key => $val){
+				if ($val['ID']==$_SESSION["glpidefault_entity"]){
+					if (changeActiveEntities($val['ID'],$val['recursive'])){
+						$active_entity_done=true;
 					}
 				}
 			}
+			if (!$active_entity_done){
+				// Try to load default entity 
+				if (!changeActiveEntities($_SESSION["glpidefault_entity"],true)){
+					// Load all entities
+					changeActiveEntities("all");
+				} 
+			}
+			doHook("change_profile");
 		}
-		if (isset($_SESSION['glpiactiveentities'][$_SESSION["glpidefault_entity"]])){
-			changeActiveEntities($_SESSION["glpidefault_entity"],true);
-		} else {
-			changeActiveEntities("all");
-		}
-
-		
-		doHook("change_profile");
 	}
+
 	cleanCache("GLPI_HEADER_".$_SESSION["glpiID"]);
 	// Clean specific datas 
 	if (isset($_SESSION['glpi_faqcategories'])){
@@ -607,49 +631,74 @@ function changeProfile($ID) {
 function changeActiveEntities($ID="all",$recursive=false) {
 	global $LANG;
 	$newentities=array();
+	$newroots=array();
 	if ($ID=="all"){
-		foreach ($_SESSION['glpi_entities_tree'] as $key => $tree){
-			$entities = contructListFromTree($tree);
+		$ancestors=array();
+		foreach ($_SESSION['glpiactiveprofile']['entities'] as $key => $val) {
+			$ancestors=array_unique(array_merge(getEntityAncestors($val['ID']),$ancestors));
+			$newroots[$val['ID']]=$val['recursive'];
+			$newentities[$val['ID']] = $val['ID'];
+			if ($val['recursive']) {
+				$entities = getSonsOfTreeItem("glpi_entities", $val['ID']);
+				if (count($entities)) {
+					foreach ($entities as $key2 => $val2) {
+						$newentities[$key2] = $key2;
+					}
+				}
+			}
+		}
+	} else {
+
+		// Check entity validity
+		$ancestors=getEntityAncestors($ID);
+		$ok=false;
+		foreach ($_SESSION['glpiactiveprofile']['entities'] as $key => $val) {
+			
+			if ($val['ID']== $ID || in_array($val['ID'], $ancestors)){
+				// Not recursive or recursive and root entity is recursive
+				if (! $recursive || $val['recursive']){
+					$ok=true;
+				}
+			}
+		}
+		if (!$ok){
+			return false;
+		}
+
+		$newroots[$ID]=$recursive;
+		$newentities[$ID] = $ID;
+		if ($recursive){
+			$entities = getSonsOfTreeItem("glpi_entities", $ID);
 			if (count($entities)) {
 				foreach ($entities as $key2 => $val2) {
 					$newentities[$key2] = $key2;
 				}
-			}		
-		}
-	} else {
-		$newentities[$ID] = $ID;
-		if ($recursive){
-			foreach ($_SESSION['glpi_entities_tree'] as $key => $tree){
-				$entities = contructListFromTree($tree);
-				$tofind=array($ID);
-				while (count($tofind)){
-					$founded=array();
-					foreach ($entities as $key2 => $val2){
-						if (in_array($val2,$tofind)){
-							$newentities[$key2] = $key2;
-							$founded[]=$key2;
-							unset($entities[$key2]);
-						}
-					}
-					$tofind=$founded;
-				}
 			}
+
 		}
 	}
+
 	if (count($newentities)>0){
 		$_SESSION['glpiactiveentities']=$newentities;
+		$_SESSION['glpiactiveentities_string']="'".implode("','",$newentities)."'";
+		$active = reset($newentities);
+		$_SESSION['glpiparententities']=$ancestors;
+		$_SESSION['glpiparententities_string']=implode("','",$ancestors);
+		if (!empty($_SESSION['glpiparententities_string'])){
+			$_SESSION['glpiparententities_string']="'".$_SESSION['glpiparententities_string']."'";
+		}
 		// Active entity loading
-		$active=key($_SESSION['glpiactiveentities']);
+		
 		$_SESSION["glpiactive_entity"] = $active;
 		$_SESSION["glpiactive_entity_name"] = getDropdownName("glpi_entities",$active);
 		$_SESSION["glpiactive_entity_shortname"] = getTreeLeafValueName("glpi_entities",$active);
 		if ($recursive){
-			$_SESSION["glpiactive_entity_name"] .= " (".$LANG["entity"][7].")";
-			$_SESSION["glpiactive_entity_shortname"] .= " (".$LANG["entity"][7].")";
+			$_SESSION["glpiactive_entity_name"] .= " (".$LANG['entity'][7].")";
+			$_SESSION["glpiactive_entity_shortname"] .= " (".$LANG['entity'][7].")";
 		}
 		if ($ID=="all"){
-			$_SESSION["glpiactive_entity_name"] .= " (".$LANG["buttons"][40].")";
-			$_SESSION["glpiactive_entity_shortname"] .= " (".$LANG["buttons"][40].")";
+			$_SESSION["glpiactive_entity_name"] .= " (".$LANG['buttons'][40].")";
+			$_SESSION["glpiactive_entity_shortname"] .= " (".$LANG['buttons'][40].")";
 		}
 		if (countElementsInTable('glpi_entities')<count($_SESSION['glpiactiveentities'])){
 			$_SESSION['glpishowallentities']=1;
@@ -669,7 +718,9 @@ function changeActiveEntities($ID="all",$recursive=false) {
 		loadGroups();
 		doHook("change_entity");
 		cleanCache("GLPI_HEADER_".$_SESSION["glpiID"]);
+		return true;
 	}
+	return false;
 }
 
 /**
@@ -681,17 +732,11 @@ function loadGroups() {
 
 	$_SESSION["glpigroups"] = array ();
 
-
-	$first=true;
-	$entities="";
-	foreach ($_SESSION['glpiactiveentities'] as $val){
-		if (!$first) $entities.=",";
-		else $first=false;
-		$entities.="'".$val."'";
-	}			
-
-
-	$query_gp = "SELECT FK_groups FROM glpi_users_groups LEFT JOIN glpi_groups ON (glpi_users_groups.FK_groups = glpi_groups.ID) WHERE glpi_users_groups.FK_users='" . $_SESSION['glpiID'] . "' AND glpi_groups.FK_entities IN ($entities)";
+	$query_gp = "SELECT FK_groups 
+			FROM glpi_users_groups 
+			LEFT JOIN glpi_groups ON (glpi_users_groups.FK_groups = glpi_groups.ID) 
+			WHERE glpi_users_groups.FK_users='" . $_SESSION['glpiID'] . "' " .
+			getEntitiesRestrictRequest(" AND ","glpi_groups","FK_entities",$_SESSION['glpiactiveentities'],true);
 
 	$result_gp = $DB->query($query_gp);
 	if ($DB->numrows($result_gp)) {
@@ -797,10 +842,6 @@ function getEntitiesRestrictRequest($separator = "AND", $table = "", $field = ""
 		}
 	}
 
-	if (!is_array($value)&&strlen($value)==0){
-		$value=$_SESSION['glpiactiveentities'];
-	}
-
 
 	if (!empty ($table)) {
 		$query .= $table . ".";
@@ -816,20 +857,13 @@ function getEntitiesRestrictRequest($separator = "AND", $table = "", $field = ""
 	$query.=$field;
 
 	if (is_array($value)){
-		$query.=" IN (";
-		$first=true;
-		
-		foreach ($value as $val){
-			if (!$first){
-				$query.=",";
-			} else {
-				$first=false;
-			}
-			$query.=$val;
-		}
-		$query.=") ";
+		$query .= " IN ('" . implode("','",$value) . "') ";
 	} else {
-		$query.= " = '$value' ";
+		if (strlen($value)==0){
+			$query.=" IN (".$_SESSION['glpiactiveentities_string'].") ";
+		} else {
+			$query.= " = '$value' ";
+		}
 	}
 
 	if ($recursive){
@@ -839,22 +873,18 @@ function getEntitiesRestrictRequest($separator = "AND", $table = "", $field = ""
 				$ancestors=array_unique(array_merge(getEntityAncestors($val),$ancestors));
 			}
 			$ancestors=array_diff($ancestors,$value);
+		} else if (strlen($value)==0){
+			$ancestors=$_SESSION['glpiparententities'];
 		} else {
 			$ancestors=getEntityAncestors($value);
 		}
 		
 		if (count($ancestors)){
-			$query.=" OR ( $table.recursive='1' AND $table.$field IN (";
-			$first=true;
-			foreach ($ancestors as $val){
-				if (!$first){
-					$query.=",";
-				} else {
-					$first=false;
-				}
-				$query.=$val;
+			if ($table=='glpi_entities') {
+				$query.=" OR `$table`.`$field` IN ('" . implode("','",$ancestors) . "')";
+			} else {
+				$query.=" OR ( `$table`.`recursive`='1' AND `$table`.`$field` IN ('" . implode("','",$ancestors) . "'))";
 			}
-			$query.="))";
 		}
 	}
 
@@ -1133,14 +1163,14 @@ function import_user_from_ldap_servers($login){
 		$userid = -1;
 		
 		foreach ($ldap_methods as $ldap_method){
-			$result=ldapImportUserByServerId($login, 0,$ldap_method["ID"]);
+			$result=ldapImportUserByServerId($login, 0,$ldap_method["ID"],true);
 			if ($result != false){
 				return $result;
 			}  
 		}
-		addMessageAfterRedirect($LANG["login"][15]);
+		addMessageAfterRedirect($LANG['login'][15],false,ERROR);
 	} else {
-		addMessageAfterRedirect($LANG["setup"][606]);
+		addMessageAfterRedirect($LANG['setup'][606],false,ERROR);
 	}
 	return false;
 	
@@ -1212,7 +1242,9 @@ function showReplicatesList($target,$master_id){
 
 	addNewReplicateForm($target, $master_id);
 	
-	$sql = "SELECT * FROM glpi_auth_ldap_replicate WHERE server_id='".$master_id."' ORDER BY name";
+	$sql = "SELECT * FROM glpi_auth_ldap_replicate 
+		WHERE server_id='".$master_id."' 
+		ORDER BY name";
 	$result = $DB->query($sql);
 	if ($DB->numrows($result)>0){
 		echo "<br>";
@@ -1223,8 +1255,8 @@ function showReplicatesList($target,$master_id){
 		echo "<div class='center'>";
 		echo "<table class='tab_cadre_fixe'>";
 	
-		echo "<tr><th colspan='4'><div class='relative'><span><strong>" . $LANG["ldap"][18] . "</strong></span></th></tr>";
-		echo "<tr class='tab_bg_1'><td class='center'></td><td class='center'>".$LANG["common"][16]."</td><td class='center'>".$LANG["ldap"][18]."</td><td class='center'></td>";
+		echo "<tr><th colspan='4'><div class='relative'><span><strong>" . $LANG['ldap'][18] . "</strong></span></th></tr>";
+		echo "<tr class='tab_bg_1'><td class='center'></td><td class='center'>".$LANG['common'][16]."</td><td class='center'>".$LANG['ldap'][18]."</td><td class='center'></td>";
 		while ($ldap_replicate = $DB->fetch_array($result)){
 			echo "<tr class='tab_bg_2'><td class='center'>";
 				
@@ -1238,18 +1270,18 @@ function showReplicatesList($target,$master_id){
 			echo "<td class='center'>" . $ldap_replicate["name"] . "</td>";
 			echo "<td class='center'>".$ldap_replicate["ldap_host"]." : ".$ldap_replicate["ldap_port"] . "</td>"; 
 			echo "<td align='center' colspan=4>"; 
-			echo"<input type=\"submit\" name=\"test_ldap_replicate[".$ldap_replicate["ID"]."]\" class=\"submit\" value=\"" . $LANG["buttons"][50] . "\" ></td>";
+			echo"<input type=\"submit\" name=\"test_ldap_replicate[".$ldap_replicate["ID"]."]\" class=\"submit\" value=\"" . $LANG['buttons'][50] . "\" ></td>";
 			echo"</tr>";
 				
 		}
 				
 		echo "<div class='center'>";
-		echo "<table width='950px'>";
+		echo "<table width='950px' class='tab_glpi'>";
 				
-		echo "<tr><td><img src=\"" . $CFG_GLPI["root_doc"] . "/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markAllRows('ldap_replicates_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?next=extauth_ldap&ID=$master_id&select=all'>" . $LANG["buttons"][18] . "</a></td>";
-		echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkAllRows('ldap_replicates_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?next=extauth_ldap&ID=$master_id&select=none'>" . $LANG["buttons"][19] . "</a>";
+		echo "<tr><td><img src=\"" . $CFG_GLPI["root_doc"] . "/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markCheckboxes('ldap_replicates_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?next=extauth_ldap&ID=$master_id&select=all'>" . $LANG['buttons'][18] . "</a></td>";
+		echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkCheckboxes('ldap_replicates_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?next=extauth_ldap&ID=$master_id&select=none'>" . $LANG['buttons'][19] . "</a>";
 		echo "</td><td align='left' width='80%'>";
-		echo "<input type='submit' name='delete_replicate' value=\"" . $LANG["buttons"][6] . "\" class='submit'></td>";
+		echo "<input type='submit' name='delete_replicate' value=\"" . $LANG['buttons'][6] . "\" class='submit'></td>";
 		echo "</tr>";
 				
 		echo "</table>";
@@ -1271,15 +1303,15 @@ function addNewReplicateForm($target, $master_id){
 	echo "<div class='center'>";
 	echo "<table class='tab_cadre_fixe'>";
 	
-	echo "<tr><th colspan='4'><div class='relative'><span><strong>" .$LANG["ldap"][20] . "</strong></span></th></tr>";
-	echo "<tr class='tab_bg_1'><td class='center'>".$LANG["common"][16]."</td><td class='center'>".$LANG["common"][52]."</td><td class='center'>".$LANG["setup"][175]."</td><td></td></tr>";
+	echo "<tr><th colspan='4'><div class='relative'><span><strong>" .$LANG['ldap'][20] . "</strong></span></th></tr>";
+	echo "<tr class='tab_bg_1'><td class='center'>".$LANG['common'][16]."</td><td class='center'>".$LANG['common'][52]."</td><td class='center'>".$LANG['setup'][175]."</td><td></td></tr>";
 	echo "<tr class='tab_bg_1'>"; 
 	echo "<td class='center'><input type='text' name='name'></td>";
 	echo "<td class='center'><input type='text' name='ldap_host'></td>"; 
 	echo "<td class='center'><input type='text' name='ldap_port'></td>";
 	echo "<input type='hidden' name='next' value=\"extauth_ldap\"></td>";
 	echo "<input type='hidden' name='server_id' value=\"".$master_id."\">";
-	echo "<td class='center'><input type='submit' name='add_replicate' value=\"" . $LANG["buttons"][2] . "\" class='submit'></td></tr>";
+	echo "<td class='center'><input type='submit' name='add_replicate' value=\"" . $LANG['buttons'][2] . "\" class='submit'></td></tr>";
 	echo "</table>";
 	echo "</div>";
 	echo "</form>";
@@ -1296,10 +1328,15 @@ function getAllReplicateForAMaster($master_id){
 	global $DB;
 	
 	$replicates = array();
-	$result = $DB->query("SELECT ID, ldap_host,ldap_port FROM glpi_auth_ldap_replicate WHERE server_id='".$master_id."'");
+	$query="SELECT ID, ldap_host, ldap_port 
+		FROM glpi_auth_ldap_replicate 
+		WHERE server_id='".$master_id."'";
+	$result = $DB->query($query);
 	if ($DB->numrows($result)>0){
 		while ($replicate = $DB->fetch_array($result)){
-			$replicates[] = array("ID"=>$replicate["ID"], "ldap_host"=>$replicate["ldap_host"], "ldap_port"=>$replicate["ldap_port"]);
+			$replicates[] = array("ID"=>$replicate["ID"], 
+					"ldap_host"=>$replicate["ldap_host"], 
+					"ldap_port"=>$replicate["ldap_port"]);
 		}
 	}
 	return $replicates;
@@ -1324,7 +1361,7 @@ function getAllReplicatesNamesForAMaster($master_id){
  * Check alternate authentication systems
  * 
  * @param $redirect : need to redirect (true) or get type of Auth system which match
- * @param $redirect_string : redirect string if exists 
+ * @param $redirect_string : redirect string if exists
  * @return nothing if redirect is true, else Auth system ID
 **/
 function checkAlternateAuthSystems($redirect=false,$redirect_string=''){
@@ -1333,14 +1370,15 @@ function checkAlternateAuthSystems($redirect=false,$redirect_string=''){
 		return false;
 	}
 
-	$redir_string=""; 
-	if (!empty($redirect_string)){ 
-		$redir_string="?redirect=".$redirect_string; 
-	} 
+	$redir_string="";
+	if (!empty($redirect_string)){
+		$redir_string="?redirect=".$redirect_string;
+	}
 
 	// Using x509 server
 	if (!empty($CFG_GLPI["x509_email_field"])
-		&&isset($_SERVER['SSL_CLIENT_S_DN'])&&ereg($CFG_GLPI["x509_email_field"],$_SERVER['SSL_CLIENT_S_DN'])) {
+		&&isset($_SERVER['SSL_CLIENT_S_DN'])
+		&&strstr($_SERVER['SSL_CLIENT_S_DN'],$CFG_GLPI["x509_email_field"])) {
 		if ($redirect){
 			glpi_header("login.php".$redir_string);
 		} else {
