@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: central.function.php 7906 2009-01-26 19:22:31Z remi $
+ * @version $Id: central.function.php 8652 2009-08-07 12:11:52Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -33,29 +33,6 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-/**
- *  Show onglet for central
- *
- * @param $target target URL
- * @param $actif which onglet is active ? (my, global or plugins)
- * @return nothing
- */
-function showCentralOnglets($target,$actif) {
-	global $LANG,$PLUGIN_HOOKS;
-	echo "<div id='barre_onglets'><ul id='onglet'>";
-	echo "<li ".($actif=="my"?"class='actif'":"")."><a href='$target?onglet=my'>".$LANG["central"][12]."</a></li>";
-	echo "<li ".($actif=="group"?"class='actif'":"")."><a href='$target?onglet=group'>".$LANG["central"][14]."</a></li>";
-	if (haveRight("show_all_ticket","1")||haveRight("logs","r")||haveRight("contract_infocom","r"))
-		echo "<li ".($actif=="global"?"class='actif'":"")."><a href='$target?onglet=global'>".$LANG["central"][13]."</a></li>";
-	if (isset($PLUGIN_HOOKS['central_action'])&&count($PLUGIN_HOOKS['central_action'])){
-		echo "<li ".($actif=="plugins"?"class='actif'":"")."><a href='$target?onglet=plugins'>".$LANG["common"][29]."</a></li>";
-	}
-	echo "<li class='invisible'>&nbsp;</li>";
-	echo "<li ".($actif=="all"?"class='actif'":"")."><a href='$target?onglet=all'>".$LANG["common"][66]."</a></li>";
-
-	echo "</ul></div>";
-}
-
 /**
  * Show the central global view
  *
@@ -77,7 +54,7 @@ function showCentralGlobalView(){
 		showCentralJobCount();
 		echo "</td></tr>";
 	}
-	if (haveRight("contract_infocom","r")){
+	if (haveRight("contract","r")){
 		echo "<tr>";
 		echo "<td class='top'  width='450px'>";
 		showCentralContract();
@@ -90,7 +67,7 @@ function showCentralGlobalView(){
 	if (haveRight("logs","r")){
 		echo "<td class='top' width='450px'>";
 		
-		if ($CFG_GLPI["num_of_events"]>0){
+		if ($_SESSION["glpinum_of_events"]>0){
 
 			//Show last add events
 			showAddEvents($_SERVER['PHP_SELF'],$_SESSION["glpiname"]);
@@ -107,14 +84,10 @@ function showCentralGlobalView(){
 	echo "</div>";
 
 
-	if ($CFG_GLPI["jobs_at_login"]&&$showticket){
+	if ($_SESSION["glpijobs_at_login"]&&$showticket){
 		echo "<br>";
 
-		echo "<div class='center'><strong>";
-		echo $LANG["central"][10];
-		echo "</strong></div>";
-
-		showTrackingList($_SERVER['PHP_SELF'],$_GET["start"],$_GET["sort"],$_GET["order"],"new");
+		showNewJobList();
 	}
 
 }
@@ -132,7 +105,7 @@ function showCentralMyView(){
 
 		if ($DB->isSlave() && !$DB->first_connection){	
 			echo "<tr><th colspan='2'><br>";	
-			displayTitle(GLPI_ROOT."/pics/warning.png", $LANG["setup"][809], $LANG["setup"][809]);
+			displayTitle(GLPI_ROOT."/pics/warning.png", $LANG['setup'][809], $LANG['setup'][809]);
 			echo "</th></tr>";
 		}
 		echo "<tr><td class='top'>";
@@ -141,10 +114,10 @@ function showCentralMyView(){
 	
 		if ($showticket){
 			echo "<tr><td class='top'  width='450px'><br>";
-			showCentralJobList($_SERVER['PHP_SELF'],$_GET['start'],"process",false);
+			showCentralJobList($_SERVER['PHP_SELF'],0,"process",false);
 			echo "</td></tr>";
 			echo "<tr><td   class='top' width='450px'>";
-			showCentralJobList($_SERVER['PHP_SELF'],$_GET['start'],"waiting",false);
+			showCentralJobList($_SERVER['PHP_SELF'],0,"waiting",false);
 			echo "</td></tr>";
 		}
 	
@@ -201,7 +174,7 @@ function showCentralGroupView(){
 	
 		if ($showticket){
 			echo "<tr><td class='top'  width='450px'><br>";
-			showCentralJobList($_SERVER['PHP_SELF'],$_GET['start'],"process",true);
+			showCentralJobList($_SERVER['PHP_SELF'],0,"process",true);
 			echo "</td></tr>";
 		}
 	
@@ -209,7 +182,7 @@ function showCentralGroupView(){
 
 		if ($showticket){
 			echo "<tr><td   class='top' width='450px'><br>";
-			showCentralJobList($_SERVER['PHP_SELF'],$_GET['start'],"waiting",true);
+			showCentralJobList($_SERVER['PHP_SELF'],0,"waiting",true);
 			echo "</td></tr>";
 		}
 
