@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: common.function.php 8321 2009-05-22 12:24:53Z remi $
+ * @version $Id: common.function.php 9126 2009-10-19 17:42:41Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -95,7 +95,7 @@ if (!defined('GLPI_ROOT')){
 	**/
 	function logInFile($name,$text,$force=false){
 		global $CFG_GLPI;
-		if ($CFG_GLPI["use_errorlog"]||$force){ 
+		if (isset($CFG_GLPI["use_errorlog"])&&$CFG_GLPI["use_errorlog"]||$force){ 
 			error_log(convDateTime(date("Y-m-d H:i:s"))."\n".$text,3,GLPI_LOG_DIR."/".$name.".log");
 		}
 	}
@@ -125,8 +125,7 @@ if (!defined('GLPI_ROOT')){
 			E_USER_ERROR         => 'User Error',
 			E_USER_WARNING       => 'User Warning',
 			E_USER_NOTICE        => 'User Notice',
-			// Need php 5.0
-			2048 	/*E_STRICT*/             => 'Runtime Notice',
+			E_STRICT             => 'Runtime Notice',
 			// Need php 5.2.0
 			4096 /*E_RECOVERABLE_ERROR*/  => 'Catchable Fatal Error',
 			// Need php 5.3.0
@@ -135,9 +134,6 @@ if (!defined('GLPI_ROOT')){
 			);			
 		// Les niveaux qui seront enregistrés
 		$user_errors = array(E_USER_ERROR, E_USER_WARNING, E_USER_NOTICE);
-
-		// In PHP 5.3 a lot of fonction are deprecated. Will be fixed in 0.72 
-		if ($errno==8192) return;			
 			
 		$err = $errortype[$errno] . "($errno): $errmsg\n";
 		if (in_array($errno, $user_errors)) {
@@ -156,7 +152,7 @@ if (!defined('GLPI_ROOT')){
 				}
 			}
 		} else {
-			$error .= "Script: $filename, Line: $linenum\n" ; 
+			$err .= "Script: $filename, Line: $linenum\n" ; 
 		}
 		
 		// sauvegarde de l'erreur, et mail si c'est critique
@@ -291,30 +287,35 @@ if (!defined('GLPI_ROOT')){
  	**/
 	function cron_cache(){
 		global $CFG_GLPI;
-		$max_recursion=5;
-		$lifetime=DEFAULT_CACHE_LIFETIME;
-		while ($max_recursion>0&&(($size=filesizeDirectory(GLPI_CACHE_DIR))>MAX_CACHE_SIZE)){
-			$cache_options = array(
-				'cacheDir' => GLPI_CACHE_DIR,
-				'lifeTime' => $lifetime,
-				'automaticSerialization' => true,
-				'caching' => $CFG_GLPI["use_cache"],
-				'hashedDirectoryLevel' => 2,
-				'fileLocking' => CACHE_FILELOCKINGCONTROL,
-				'writeControl' => CACHE_WRITECONTROL,
-				'readControl' => CACHE_READCONTROL,
-			);
-			$cache = new Cache_Lite($cache_options);
-			$cache->clean(false,"old");
-
-			logInFile("cron","Clean cache created since more than $lifetime seconds\n");
-			$lifetime/=2;
-			$max_recursion--;
-		}
-		if ($max_recursion>0){
-			return 1;
+		if ($CFG_GLPI["use_cache"]){
+			$max_recursion=5;
+			$lifetime=DEFAULT_CACHE_LIFETIME;
+			$max_size=$CFG_GLPI['cache_max_size']*1024*1024;
+			while ($max_recursion>0&&(($size=filesizeDirectory(GLPI_CACHE_DIR))>$max_size)){
+				$cache_options = array(
+					'cacheDir' => GLPI_CACHE_DIR,
+					'lifeTime' => $lifetime,
+					'automaticSerialization' => true,
+					'caching' => $CFG_GLPI["use_cache"],
+					'hashedDirectoryLevel' => 2,
+					'fileLocking' => CACHE_FILELOCKINGCONTROL,
+					'writeControl' => CACHE_WRITECONTROL,
+					'readControl' => CACHE_READCONTROL,
+				);
+				$cache = new Cache_Lite($cache_options);
+				$cache->clean(false,"old");
+	
+				logInFile("cron","Clean cache created since more than $lifetime seconds\n");
+				$lifetime/=2;
+				$max_recursion--;
+			}
+			if ($max_recursion>0){
+				return 1;
+			} else {
+				return -1;
+			}
 		} else {
-			return -1;
+			return 1;
 		}
 	}
 
@@ -371,22 +372,24 @@ function filesizeDirectory($path){
  * @return nothing
  **/
 function cleanCache($group=""){
-
-	include_once (GLPI_CACHE_LITE_DIR."/Lite.php");
-
-	$cache_options = array(
-		'cacheDir' => GLPI_CACHE_DIR,
-		'lifeTime' => 0,
-		'hashedDirectoryLevel' => 2,
-		'fileLocking' => CACHE_FILELOCKINGCONTROL,
-		'writeControl' => CACHE_WRITECONTROL,
-		'readControl' => CACHE_READCONTROL,
-		);
-	$CACHE = new Cache_Lite($cache_options);
-	if (empty($group)){
-		$CACHE->clean();
-	} else {
-		$CACHE->clean($group,"ingroup");
+	global $CFG_GLPI;
+	if (isset($CFG_GLPI["use_cache"]) && $CFG_GLPI["use_cache"]){
+		include_once (GLPI_CACHE_LITE_DIR."/Lite.php");
+	
+		$cache_options = array(
+			'cacheDir' => GLPI_CACHE_DIR,
+			'lifeTime' => 0,
+			'hashedDirectoryLevel' => 2,
+			'fileLocking' => CACHE_FILELOCKINGCONTROL,
+			'writeControl' => CACHE_WRITECONTROL,
+			'readControl' => CACHE_READCONTROL,
+			);
+		$CACHE = new Cache_Lite($cache_options);
+		if (empty($group)){
+			$CACHE->clean();
+		} else {
+			$CACHE->clean($group,"ingroup");
+		}
 	}
 
 }
@@ -450,11 +453,11 @@ function getSearchOptions(){
 	$cache = new Cache_Lite_File($options);
 
 	// Set a id for this cache : $file
-	if (!($SEARCH_OPTION = $cache->get("OPTIONS","GLPI_SEARCH_".$_SESSION["glpilanguage"]))) {
+	if (!($SEARCH_OPTION = $cache->get("OPTIONS","GLPI_SEARCH_".$_SESSION['glpilanguage']))) {
 		// Cache miss !
 		// Put in $SEARCH_OPTION datas to put in cache
 		include (GLPI_ROOT . "/inc/search.constant.php");
-		$cache->save($SEARCH_OPTION,"OPTIONS","GLPI_SEARCH_".$_SESSION["glpilanguage"]);
+		$cache->save($SEARCH_OPTION,"OPTIONS","GLPI_SEARCH_".$_SESSION['glpilanguage']);
 	}
 	
 	$plugsearch=getPluginSearchOption();
@@ -463,7 +466,7 @@ function getSearchOptions(){
 			if (!isset($SEARCH_OPTION[$key])){
 				$SEARCH_OPTION[$key]=array();
 			} else {
-				$SEARCH_OPTION[$key]+=array('plugins'=>$LANG["common"][29]);
+				$SEARCH_OPTION[$key]+=array('plugins'=>$LANG['common'][29]);
 			}
 
 			$SEARCH_OPTION[$key]+=$val;
@@ -546,6 +549,35 @@ function testWriteAccessToDirectory($dir){
 	return 0;
 }
 
+/**
+* Compute PHP memory_limit
+*
+* @return memory limit
+**/
+function getMemoryLimit () {
+	
+	$mem=ini_get("memory_limit");
+
+	preg_match("/([-0-9]+)([KMG]*)/",$mem,$matches);
+
+	$mem="";
+	// no K M or G
+	if (isset($matches[1])){ 
+		if (!isset($matches[2])){
+			$mem=$matches[1];
+		} else {
+			$mem=$matches[1];
+			switch ($matches[2]){
+				case "G" : $mem*=1024;
+				case "M" : $mem*=1024;
+				case "K" : $mem*=1024;
+				break;
+			}
+		}
+	}
+	return $mem;
+}
+
 /**
 * Common Checks needed to use GLPI
 *
@@ -554,44 +586,126 @@ function testWriteAccessToDirectory($dir){
 function commonCheckForUseGLPI(){
 	global $LANG;
 
-	// memory test
-	echo "<tr class='tab_bg_1'><td><b>".$LANG["install"][86]."</b></td>";
+	$error = 0;
 
-	$mem=ini_get("memory_limit");
+	// Title
+	echo "<tr><th>".$LANG['install'][6]."</th><th >".$LANG['install'][7]."</th></tr>";
 
-	// Cette bidouille me plait pas
-	//if(empty($mem)) {$mem=get_cfg_var("memory_limit");}  // Sous Win l'ini_get ne retourne rien.....
+	// Parser test
+	echo "<tr class='tab_bg_1'><td class='left'><b>".$LANG['install'][8]."</b></td>";
+	// PHP Version  - exclude PHP3, PHP 4 and zend.ze1 compatibility
+	if (substr(phpversion(),0,1) == "5") {
+		// PHP > 5 ok, now check PHP zend.ze1_compatibility_mode
+		if(ini_get("zend.ze1_compatibility_mode") == 1) {
+			$error = 2;
+			echo "<td  class='red'><img src=\"".GLPI_ROOT."/pics/redbutton.png\">".$LANG['install'][10]."</td></tr>";
+		}else{
+			echo "<td><img src=\"".GLPI_ROOT."/pics/greenbutton.png\" alt='".$LANG['install'][11]."' title='".$LANG['install'][11]."'></td></tr>";
+		}
+	} else { // PHP <5
+		$error = 2;
+		echo "<td  class='red'><img src=\"".GLPI_ROOT."/pics/redbutton.png\">".$LANG['install'][9]."</td></tr>";
+	}	
 
-	preg_match("/([-0-9]+)([KMG]*)/",$mem,$matches);
-
-	// no K M or G 
-	if (!isset($matches[2])){
-		$mem=$matches[1];
+	// Check for mysql extension ni php
+	echo "<tr class='tab_bg_1'><td class='left'><b>".$LANG['install'][71]."</b></td>";
+	if(!function_exists("mysql_query")) {
+		echo "<td  class='red'><img src=\"".GLPI_ROOT."/pics/redbutton.png\">".$LANG['install'][72]."</td></tr>";
+		$error = 2;
 	} else {
-		$mem=$matches[1];
-		switch ($matches[2]){
-			case "G" : $mem*=1024;
-			case "M" : $mem*=1024;
-			case "K" : $mem*=1024;
-			break;
+		echo "<td><img src=\"".GLPI_ROOT."/pics/greenbutton.png\" alt='".$LANG['install'][73]."' title='".$LANG['install'][73]."'></td></tr>";
+	}
+
+	// session test
+	echo "<tr class='tab_bg_1'><td class='left'><b>".$LANG['install'][12]."</b></td>";
+	// check whether session are enabled at all!!
+	if (!extension_loaded('session')) {
+		$error = 2;
+		echo "<td  class='red'><b>".$LANG['install'][13]."</b></td></tr>";
+	} else {
+		if ((isset($_SESSION["Test_session_GLPI"])&&$_SESSION["Test_session_GLPI"] == 1)			// From install
+			|| isset($_SESSION["glpi_currenttime"])) { 	// From Update
+			echo "<td><img src=\"".GLPI_ROOT."/pics/greenbutton.png\" alt='".$LANG['install'][14]."' title='".$LANG['install'][14]."'></td></tr>";
+		}
+		else {
+			if($error != 2) $error = 1;
+			echo "<td  class='red'><img src=\"".GLPI_ROOT."/pics/redbutton.png\">".$LANG['install'][15]."</td></tr>";
 		}
 	}
 
+	//Test for session auto_start
+	if(ini_get('session.auto_start')==1) {
+		echo "<tr class='tab_bg_1'><td class='left'><b>".$LANG['install'][68]."</b></td>";
+		echo "<td class='red'><img src=\"".GLPI_ROOT."/pics/redbutton.png\">".$LANG['install'][69]."</td></tr>";
+		$error = 2;
+	}
+
+	//Test for option session use trans_id loaded or not.
+	echo "<tr class='tab_bg_1'><td class='left'><b>".$LANG['install'][74]."</b></td>";
+	//if(ini_get('session.use_trans_sid')) {
+	if (isset($_POST[session_name()])||isset($_GET[session_name()])) {
+		echo "<td class='red'><img src=\"".GLPI_ROOT."/pics/redbutton.png\">".$LANG['install'][75]."</td></tr>";
+		$error = 2;
+	}
+	else {
+		echo "<td><img src=\"".GLPI_ROOT."/pics/greenbutton.png\" alt='".$LANG['install'][76]."' title='".$LANG['install'][76]."'></td></tr>";
+	}
+
+	//Test for sybase extension loaded or not.
+	echo "<tr class='tab_bg_1'><td class='left'><b>".$LANG['install'][65]."</b></td>";
+	if(ini_get('magic_quotes_sybase')) {
+		echo "<td class='red'><img src=\"".GLPI_ROOT."/pics/redbutton.png\">".$LANG['install'][66]."</td></tr>";
+		$error = 2;
+	}
+	else {
+		echo "<td><img src=\"".GLPI_ROOT."/pics/greenbutton.png\" alt='".$LANG['install'][67]."' title='".$LANG['install'][67]."'></td></tr>";
+	}
+
+	//Test for utf8_encode function.
+	echo "<tr class='tab_bg_1'><td class='left'><b>".$LANG['install'][83]."</b></td>";
+	if(!function_exists('utf8_encode')||!function_exists('utf8_decode')) {
+		echo "<td><img src=\"".GLPI_ROOT."/pics/redbutton.png\" >".$LANG['install'][84]."></td></tr>";
+		$error = 2;
+	}
+	else {
+		echo "<td><img src=\"".GLPI_ROOT."/pics/greenbutton.png\" alt='".$LANG['install'][85]."' title='".$LANG['install'][85]."'></td></tr>";
+
+	}
+
+	//Test for json_encode function.
+	echo "<tr class='tab_bg_1'><td class='left'><b>".$LANG['install'][102]."</b></td>";
+	if (!function_exists('json_encode')|!function_exists('json_decode')) {
+		echo "<td><img src=\"".GLPI_ROOT."/pics/redbutton.png\" >".$LANG['install'][103]."></td></tr>";
+		$error = 2;
+	}
+	else {
+		echo "<td><img src=\"".GLPI_ROOT."/pics/greenbutton.png\" alt='".$LANG['install'][85]."' title='".$LANG['install'][85]."'></td></tr>";
+
+	}
+	
+	// memory test
+	echo "<tr class='tab_bg_1'><td class='left'><b>".$LANG['install'][86]."</b></td>";
+
+	$mem = getMemoryLimit();
+	
 	if( $mem == "" ){          // memory_limit non compilé -> no memory limit
-		echo "<td>".$LANG["install"][95]." - ".$LANG["install"][89]."</td></tr>";
+		echo "<td><img src=\"".GLPI_ROOT."/pics/greenbutton.png\" alt='".$LANG['install'][95]." - ".$LANG['install'][89]."' title='".$LANG['install'][95]." - ".$LANG['install'][89]."'></td></tr>";
 	}
 	else if( $mem == "-1" ){   // memory_limit compilé mais illimité
-		echo "<td>".$LANG["install"][96]." - ".$LANG["install"][89]."</td></tr>";
+		echo "<td><img src=\"".GLPI_ROOT."/pics/greenbutton.png\" alt='".$LANG['install'][96]." - ".$LANG['install'][89]."' title='".$LANG['install'][96]." - ".$LANG['install'][89]."'></td></tr>";
 	}
 	else{	
-		if ($mem<32*1024*1024){ // memoire insuffisante
-			echo "<td  class='red'><b>".$LANG["install"][87]." $mem octets</b><br>".$LANG["install"][88]."<br>".$LANG["install"][90]."</td></tr>";
+		if ($mem<64*1024*1024){ // memoire insuffisante
+			echo "<td  class='red'><img src=\"".GLPI_ROOT."/pics/redbutton.png\"><b>".$LANG['install'][87]." $mem octets</b><br>".$LANG['install'][88]."<br>".$LANG['install'][90]."</td></tr>";
 		}
 		else{ // on a sufisament de mémoire on passe à la suite
-			echo "<td>".$LANG["install"][91]." - ".$LANG["install"][89]."</td></tr>";
+			echo "<td><img src=\"".GLPI_ROOT."/pics/greenbutton.png\" alt='".$LANG['install'][91]." - ".$LANG['install'][89]."' title='".$LANG['install'][91]." - ".$LANG['install'][89]."'></td></tr>";
 		}
 	}
-	return checkWriteAccessToDirs();
+	
+	$suberr = checkWriteAccessToDirs();
+
+	return ($suberr ? $suberr : $error);
 }
 
 /**
@@ -602,43 +716,51 @@ function commonCheckForUseGLPI(){
 function checkWriteAccessToDirs(){
 	global $LANG;
 	$dir_to_check=array(
-		GLPI_DUMP_DIR => $LANG["install"][16],
-		GLPI_DOC_DIR => $LANG["install"][21],
-		GLPI_CONFIG_DIR => $LANG["install"][23],
-		GLPI_SESSION_DIR => $LANG["install"][50],
-		GLPI_CRON_DIR => $LANG["install"][52],
-		GLPI_CACHE_DIR => $LANG["install"][99],
-		GLPI_LOG_DIR => $LANG["install"][53]
+		GLPI_DUMP_DIR => $LANG['install'][16],
+		GLPI_DOC_DIR => $LANG['install'][21],
+		GLPI_CONFIG_DIR => $LANG['install'][23],
+		GLPI_SESSION_DIR => $LANG['install'][50],
+		GLPI_CRON_DIR => $LANG['install'][52],
+		GLPI_CACHE_DIR => $LANG['install'][99]
 	);
 	$error=0;	
 	foreach ($dir_to_check as $dir => $message){
-		echo "<tr class='tab_bg_1'><td><strong>".$message."</strong></td>";
+		echo "<tr class='tab_bg_1' ><td class='left'><b>".$message."</b></td>";
 		$tmperror=testWriteAccessToDirectory($dir);
 	
 		switch($tmperror){
 			// Error on creation
 			case 4 :
-				echo "<td><p class='red'>".$LANG["install"][100]."</p> ".$LANG["install"][97]."'".$dir."'. ".$LANG["install"][98]."</td></tr>";
+				echo "<td><img src=\"".GLPI_ROOT."/pics/redbutton.png\"><p class='red'>".$LANG['install'][100]."</p> ".$LANG['install'][97]."'".$dir."'</td></tr>";
 				$error=2;
 				break;
 			case 3 :
-				echo "<td><p class='red'>".$LANG["install"][101]."</p> ".$LANG["install"][97]."'".$dir."'. ".$LANG["install"][98]."</td></tr>";
+				echo "<td><img src=\"".GLPI_ROOT."/pics/redbutton.png\"><p class='red'>".$LANG['install'][101]."</p> ".$LANG['install'][97]."'".$dir."'</td></tr>";
 				$error=1;
 				break;
 			// Error on creation
 			case 2 :
-				echo "<td><p class='red'>".$LANG["install"][17]."</p> ".$LANG["install"][97]."'".$dir."'. ".$LANG["install"][98]."</td></tr>";
+				echo "<td><img src=\"".GLPI_ROOT."/pics/redbutton.png\"><p class='red'>".$LANG['install'][17]."</p> ".$LANG['install'][97]."'".$dir."'</td></tr>";
 				$error=2;
 				break;
 			case 1 :
-				echo "<td><p class='red'>".$LANG["install"][19]."</p> ".$LANG["install"][97]."'".$dir."'. ".$LANG["install"][98]."</td></tr>";
+				echo "<td><img src=\"".GLPI_ROOT."/pics/redbutton.png\"><p class='red'>".$LANG['install'][19]."</p> ".$LANG['install'][97]."'".$dir."'</td></tr>";
 				$error=1;
 				break;
 			default :
-				echo "<td>".$LANG["install"][20]."</td></tr>";
+				echo "<td><img src=\"".GLPI_ROOT."/pics/greenbutton.png\" alt='".$LANG['install'][20]."' title='".$LANG['install'][20]."'></td></tr>";
 				break;
 		}
 	}
+	
+	// Only write test for GLPI_LOG as SElinux prevent removing log file.
+	echo "<tr class='tab_bg_1'><td class='left'><b>".$LANG['install'][53]."</b></td>";
+	if (error_log("Test\n", 3, GLPI_LOG_DIR."/php-errors.log")) {
+		echo "<td><img src=\"".GLPI_ROOT."/pics/greenbutton.png\" alt='".$LANG['install'][22]."' title='".$LANG['install'][22]."'></td></tr>";
+	} else {
+		echo "<td><img src=\"".GLPI_ROOT."/pics/redbutton.png\"><p class='red'>".$LANG['install'][19]."</p> ".$LANG['install'][97]."'".GLPI_LOG_DIR."'. ".$LANG['install'][98]."</td></tr>";
+		$error=1;
+	}
 	return $error;
 }
 
@@ -679,8 +801,8 @@ function addslashes_deep($value) {
  * @see unclean_cross_side_scripting_deep*
  */
 function clean_cross_side_scripting_deep($value) {
-	$in=array('<','>'); 
-	$out=array("&lt;","&gt;"); 
+	$in=array('<','>');
+	$out=array("&lt;","&gt;");
 	$value = is_array($value) ?
 		array_map('clean_cross_side_scripting_deep', $value) :
 			(is_null($value) ? NULL : str_replace($in,$out,$value));
@@ -694,8 +816,8 @@ function clean_cross_side_scripting_deep($value) {
  * @see clean_cross_side_scripting_deep
  */
 function unclean_cross_side_scripting_deep($value) {
-	$in=array('<','>'); 
-	$out=array("&lt;","&gt;"); 
+	$in=array('<','>');
+	$out=array("&lt;","&gt;");
 	$value = is_array($value) ?
 		array_map('unclean_cross_side_scripting_deep', $value) :
 			(is_null($value) ? NULL : str_replace($out,$in,$value));
@@ -823,6 +945,21 @@ function utf8_str_pad($ps_input, $pn_pad_length, $ps_pad_string = " ", $pn_pad_t
 
 */
 
+
+/**
+ * Clean post value for display in textarea
+ *
+ *@param $value string: string value
+ *
+ *@return clean value
+ **/
+function cleanPostForTextArea($value){
+   $order   = array('\r\n', '\n', "\\'", '\"', '\\\\');
+   $replace = array("\n",   "\n", "'",   '"',  "\\");
+	//echo rawurldecode($_POST["data"]);
+	return str_replace($order,$replace,$value);
+
+}
 /**
  * Clean display value deleting html tags
  *
@@ -901,11 +1038,10 @@ function html_clean($value){
 	return trim($value);
 */
 
-
 	$value = preg_replace("/<(p|br)( [^>]*)?".">/i", "\n", $value);
 
 	$search = array('@<script[^>]*?>.*?</script[^>]*?>@si',  // Strip out javascript
-               '@<style[^>]*?>.*?</style[^>]*?>@siU',    // Strip style tags properly
+               '@<style[^>]*?>.*?</style[^>]*?>@si',    // Strip style tags properly
                '@<[\/\!]*?[^<>]*?>@si',            // Strip out HTML tags
                '@<![\s\S]*?--[ \t\n\r]*>@'        // Strip multi-line comments including CDATA
 	);
@@ -920,7 +1056,6 @@ function html_clean($value){
 //	$value = preg_replace("/\n+$/", " ", $value);
 
 	$value = preg_replace("/\n{2,}/", "\n\n", $value,-1);
-
 	return trim($value);
 }
 
@@ -932,16 +1067,34 @@ function html_clean($value){
  * @return $time or $date
  */
 function convDateTime($time) { 
-	global $CFG_GLPI;
 	if (is_null($time)) return $time;
-	if (isset($CFG_GLPI["dateformat"])&&$CFG_GLPI["dateformat"]!=0) {
-		$date = substr($time,8,2)."-";        // jour 
-		$date = $date.substr($time,5,2)."-";  // mois 
-		$date = $date.substr($time,0,4). " "; // annÃ©e 
-		$date = $date.substr($time,11,5);     // heures et minutes 
-		return $date; 
-	}else {
-		return $time;
+
+	if (!isset($_SESSION["glpidateformat"])){
+		$_SESSION["glpidateformat"]=0;
+	}
+
+	
+	switch ($_SESSION['glpidateformat']){
+		case 1 : // DD-MM-YYYY
+			$date = substr($time,8,2)."-";        // day 
+			$date .= substr($time,5,2)."-";  // month
+			$date .= substr($time,0,4). " "; // year
+			$date .= substr($time,11,5);     // hours and minutes
+			return $date; 
+			break;
+		case 2 : // MM-DD-YYYY
+			$date = substr($time,5,2)."-";  // month
+			$date .= substr($time,8,2)."-";        // day 
+			$date .= substr($time,0,4). " "; // year
+			$date .= substr($time,11,5);     // hours and minutes
+			return $date; 
+			break;
+		default : // YYYY-MM-DD
+			if (strlen($time)>16){
+				return substr($time,0,16);
+			}
+			return $time;
+			break;
 	}
 }
 
@@ -954,14 +1107,30 @@ function convDateTime($time) {
 function convDate($time) { 
 	global $CFG_GLPI;
 	if (is_null($time)) return $time;
-	if (isset($CFG_GLPI["dateformat"])&&$CFG_GLPI["dateformat"]!=0) {
-		$date = substr($time,8,2)."-";        // jour 
-		$date = $date.substr($time,5,2)."-";  // mois 
-		$date = $date.substr($time,0,4); // annÃ©e 
-		//$date = $date.substr($time,11,5);     // heures et minutes 
-		return $date; 
-	}else {
-		return $time;
+
+	if (!isset($_SESSION["glpidateformat"])){
+		$_SESSION["glpidateformat"]=0;
+	}
+
+	switch ($_SESSION['glpidateformat']){
+		case 1 : // DD-MM-YYYY
+			$date = substr($time,8,2)."-";        // day 
+			$date .= substr($time,5,2)."-";  // month
+			$date .= substr($time,0,4); // year
+			return $date; 
+			break;
+		case 2 : // MM-DD-YYYY
+			$date = substr($time,5,2)."-";  // month
+			$date .= substr($time,8,2)."-";        // day 
+			$date .= substr($time,0,4); // year
+			return $date; 
+			break;
+		default : // YYYY-MM-DD
+			if (strlen($time)>10){
+				return substr($time,0,10);
+			}
+			return $time;
+			break;
 	}
 }
 
@@ -980,7 +1149,10 @@ function formatNumber($number,$edit=false,$forcedecimal=-1) {
 	// Php 5.3 : number_format() expects parameter 1 to be double,
 	if ($number=="") {
 		$number=0;	
+	} else if ($number=="-") { // used for not defines value (from TableauAmort, p.e.)
+		return "-";
 	}
+	
 	$decimal=$CFG_GLPI["decimal_number"];
 	if ($forcedecimal>=0){
 		$decimal=$forcedecimal;
@@ -992,7 +1164,7 @@ function formatNumber($number,$edit=false,$forcedecimal=-1) {
 	}
 
 	// Display : clean display
-	switch ($CFG_GLPI["numberformat"]){
+	switch ($_SESSION['glpinumberformat']){
 		case 2: // Other French
 			return number_format($number,$decimal,',',' ');
 			break;
@@ -1013,11 +1185,11 @@ function formatNumber($number,$edit=false,$forcedecimal=-1) {
  * @return nothing
  */
 function sendFile($file,$filename){
-	global $DB;
+	global $DB,$LANG;
 
 	// Test securite : document in DOC_DIR
-	$tmpfile=ereg_replace(GLPI_DOC_DIR,"",$file);
-	if (ereg("\.\.",$tmpfile)){
+	$tmpfile=str_replace(GLPI_DOC_DIR,"",$file);
+	if (strstr($tmpfile,"../") || strstr($tmpfile,"..\\")){
 		echo "Security attack !!!";
 		logEvent($file, "sendFile", 1, "security", $_SESSION["glpiname"]." try to get a non standard file.");
 		return;
@@ -1027,9 +1199,9 @@ function sendFile($file,$filename){
 		echo "Error file $file does not exist";
 		return;
 	} else {
-		$splitter=split("/",$file);
+		$splitter=explode("/",$file);
 		$filedb=$splitter[count($splitter)-2]."/".$splitter[count($splitter)-1];
-		$query="SELECT mime from glpi_docs WHERE filename LIKE '$filedb'";
+		$query="SELECT mime FROM glpi_docs WHERE filename LIKE '$filedb'";
 		$result=$DB->query($query);
 		$mime="application/octetstream";
 		if ($result&&$DB->numrows($result)==1){
@@ -1037,7 +1209,7 @@ function sendFile($file,$filename){
 		} else {
 			// fichiers DUMP SQL et XML
 			if ($splitter[count($splitter)-2]=="dump"){
-				$splitter2=split("\.",$file);
+				$splitter2=explode(".",$file);
 				switch ($splitter2[count($splitter2)-1]) {
 					case "sql" : 
 						$mime="text/x-sql";
@@ -1076,8 +1248,13 @@ function sendFile($file,$filename){
 			// Pour que les \x00 ne devienne pas \0
 			$mc=get_magic_quotes_runtime();
 			if ($mc) @set_magic_quotes_runtime(0); 
+			$fsize=filesize($file);
 
-			echo fread($f, filesize($file));
+			if ($fsize){
+				echo fread($f, filesize($file));
+			} else {
+				echo $LANG['document'][47];
+			}
 
 			if ($mc) @set_magic_quotes_runtime($mc); 
 		}
@@ -1114,7 +1291,7 @@ function return_bytes_from_ini_vars($val) {
  */
 function glpi_header($dest){
 	$toadd='';
-	if (!ereg("\?",$dest)){
+	if (!strpos($dest,"?")){
 		$toadd='?tokonq='.getRandomString(5);
 	} 	
 	echo "<script language=javascript>
@@ -1129,15 +1306,39 @@ function glpi_header($dest){
 }
 
 /**
- * Call cron
+ * Call cron without time check
+ *
+ * @return boolean : true if launched
+ */
+function callCronForce(){
+
+	global $CFG_GLPI;
+	
+	$path=$CFG_GLPI['root_doc']."/front/cron.php";
+
+	echo "<div style=\"background-image: url('$path');\"></div>";
+	return true;		
+}
+
+/**
+ * Call cron if time since last launch elapsed
  *
  * @return nothing
  */
 function callCron(){
-	if (ereg("front",$_SERVER['PHP_SELF'])){
-		echo "<div style=\"background-image: url('cron.php');\"></div>";
+	
+	if (isset($_SESSION["glpicrontimer"])){
+
+		// call function callcron() every 5min
+		if ((time()-$_SESSION["glpicrontimer"])>300){
+			if (callCronForce()) {
+				// Restart timer
+				$_SESSION["glpicrontimer"]=time();			
+			}
+		}
 	} else {
-		echo "<div style=\"background-image: url('front/cron.php');\"></div>";
+		// Start timer
+		$_SESSION["glpicrontimer"]=time();	
 	}
 }
 
@@ -1157,21 +1358,29 @@ function get_hour_from_sql($time){
 /**
  *  Optimize sql table
  *
+ * @param $progress_fct function to call to display progress message
+ *  
  * @return nothing
  */
-function optimize_tables (){
+function optimize_tables ($progress_fct=NULL){
 
 	global $DB;
+	
+	if (function_exists($progress_fct)) $progress_fct("optimize"); // Start
 	$result=$DB->list_tables();
 	while ($line = $DB->fetch_array($result))
 	{
-		if (ereg("glpi_",$line[0])){
+		if (strstr($line[0],"glpi_")){
 			$table = $line[0];
+			if (function_exists($progress_fct)) $progress_fct("optimize", $table);
+			
 			$query = "OPTIMIZE TABLE `".$table."` ;";
 			$DB->query($query);
 		}
 	}
 	$DB->free_result($result);
+
+	if (function_exists($progress_fct)) $progress_fct("optimize"); // End
 }
 
 /**
@@ -1379,17 +1588,17 @@ function makeTextSearch($val,$not=false){
  * 
  * @return content of the page (or empty)
  */
-//Note:  Depuis PHP 5, les valeurs par défaut peuvent être passées par référence.
-//function getURLContent ($url, &$msgerr=NULL, $rec=0) {
-function getURLContent ($url, &$msgerr, $rec=0) {
+function getURLContent ($url, &$msgerr=NULL, $rec=0) {
 
 	global $LANG,$CFG_GLPI;
 	
 	$content="";
 
+	$taburl=parse_url($url);
+
 	// Connection directe
 	if (empty($CFG_GLPI["proxy_name"])){
-		$taburl=parse_url($url);
+		
 		if ($fp=@fsockopen($taburl["host"], (isset($taburl["port"]) ? $taburl["port"] : 80), $errno, $errstr, 1)){
 
 			if (isset($taburl["path"]) && $taburl["path"]!='/') {
@@ -1402,7 +1611,7 @@ function getURLContent ($url, &$msgerr, $rec=0) {
 
 		} else {
 			if (isset($msgerr)) {
-				$msgerr=$LANG["setup"][304] . " ($errstr)"; // failed direct connexion - try proxy
+				$msgerr=$LANG['setup'][304] . " ($errstr)"; // failed direct connexion - try proxy
 			}
 			return "";
 		}
@@ -1420,7 +1629,7 @@ function getURLContent ($url, &$msgerr, $rec=0) {
 			
 		} else {
 			if (isset($msgerr)) {
-				$msgerr=$LANG["setup"][311] . " ($errstr)"; // failed proxy connexion
+				$msgerr=$LANG['setup'][311] . " ($errstr)"; // failed proxy connexion
 			}
 			return "";
 		}
@@ -1440,19 +1649,31 @@ function getURLContent ($url, &$msgerr, $rec=0) {
 				if (strlen(trim($buf))==0) {
 					// Empty line = end of header
 					$header=false;
-				} else if ($redir && ereg("^Location: (.*)$", $buf, $rep)) {
+				} else if ($redir && preg_match("/^Location: (.*)$/", $buf, $rep)) {
 					if ($rec<9) {
-						return (getURLContent(trim($rep[1]),$errstr,$rec+1));						
+						$desturl=trim($rep[1]);
+						$taburl2=parse_url($desturl);
+						if (isset($taburl2['host'])) {
+							// Redirect to another host
+							return (getURLContent($desturl,$errstr,$rec+1));
+						} else  {
+							// redirect to same host
+							return (getURLContent(
+								(isset($taburl['scheme'])?$taburl['scheme']:'http')."://".
+								$taburl['host'].
+								(isset($taburl['port'])?':'.$taburl['port']:'').
+								$desturl,$errstr,$rec+1));
+						}
 					} else {
 						$errstr="Too deep";
 						break;
 					}
-				} else if (ereg("^HTTP.*200.*OK", $buf)) {
+				} else if (preg_match("/^HTTP.*200.*OK/", $buf)) {
 					// HTTP 200 = OK
-				} else if (ereg("^HTTP.*302", $buf)) {
+				} else if (preg_match("/^HTTP.*302/", $buf)) {
 					// HTTP 302 = Moved Temporarily
 					$redir=true;
-				} else if (ereg("^HTTP", $buf)) {
+				} else if (preg_match("/^HTTP/", $buf)) {
 					// Other HTTP status = error
 					$errstr=trim($buf);
 					break;
@@ -1469,10 +1690,10 @@ function getURLContent ($url, &$msgerr, $rec=0) {
 
  	if (empty($content) && isset($msgerr)) {
  		if (empty($errstr)) {
- 			$msgerr=$LANG["setup"][312]; // no data
+ 			$msgerr=$LANG['setup'][312]; // no data
  		}
 		else {
-			$msgerr=$LANG["setup"][310] . " ($errstr)"; // HTTP error	
+			$msgerr=$LANG['setup'][310] . " ($errstr)"; // HTTP error	
 		}
 	}
 
@@ -1503,7 +1724,7 @@ function checkNewVersionAvailable($auto=true){
 			return $error;
 		}
 	} else {			
-		$splitted=split("\.",trim($CFG_GLPI["version"]));
+		$splitted=explode(".",trim($CFG_GLPI["version"]));
 
 		if ($splitted[0]<10) $splitted[0].="0";
 		if ($splitted[1]<10) $splitted[1].="0";
@@ -1513,7 +1734,7 @@ function checkNewVersionAvailable($auto=true){
 			$cur_version+=$splitted[2];
 		}
 
-		$splitted=split("\.",trim($latest_version));
+		$splitted=explode(".",trim($latest_version));
 
 		if ($splitted[0]<10) $splitted[0].="0";
 		if ($splitted[1]<10) $splitted[1].="0";
@@ -1530,16 +1751,16 @@ function checkNewVersionAvailable($auto=true){
 			$input["founded_new_version"]=$latest_version;
 			$config_object->update($input);
 			if (!$auto) {
-				echo "<div class='center'>".$LANG["setup"][301]." ".$latest_version."</div>";
-				echo "<div class='center'>".$LANG["setup"][302]."</div>";
+				echo "<div class='center'>".$LANG['setup'][301]." ".$latest_version."</div>";
+				echo "<div class='center'>".$LANG['setup'][302]."</div>";
 			} else {
-				return $LANG["setup"][301]." ".$latest_version;
+				return $LANG['setup'][301]." ".$latest_version;
 			}
 		}  else {
 			if (!$auto){
-				echo "<div class='center'>".$LANG["setup"][303]."</div>";
+				echo "<div class='center'>".$LANG['setup'][303]."</div>";
 			} else {
-				return $LANG["setup"][303];
+				return $LANG['setup'][303];
 			}
 		}
 	} 
@@ -1568,9 +1789,9 @@ function getWarrantyExpir($from,$addwarranty,$deletenotice=0){
 	global $LANG;
 	// Life warranty
 	if ($addwarranty==-1 && $deletenotice==0){
-		return $LANG["setup"][307];
+		return $LANG['setup'][307];
 	}
-	if ($from==NULL || $from=='0000-00-00')
+	if ($from==NULL || empty($from))
 		return "";
 	else {
 		return convDate(date("Y-m-d", strtotime("$from+$addwarranty month -$deletenotice month")));
@@ -1588,15 +1809,15 @@ function getWarrantyExpir($from,$addwarranty,$deletenotice=0){
 **/
 function getExpir($begin,$duration,$notice="0"){
 	global $LANG;
-	if ($begin==NULL || $begin=='0000-00-00'){
+	if ($begin==NULL || empty($begin)){
 		return "";
 	} else {
 		$diff=strtotime("$begin+$duration month -$notice month")-time();
 		$diff_days=floor($diff/60/60/24);
 		if($diff_days>0){
-			return $diff_days." ".$LANG["stats"][31];
+			return $diff_days." ".$LANG['stats'][31];
 		}else{
-			return "<span class='red'>".$diff_days." ".$LANG["stats"][31]."</span>";
+			return "<span class='red'>".$diff_days." ".$LANG['stats'][31]."</span>";
 		}
 	}
 }
@@ -1609,7 +1830,7 @@ function getExpir($begin,$duration,$notice="0"){
 function manageRedirect($where){
 	global $CFG_GLPI,$PLUGIN_HOOKS;
 	if (!empty($where)){
-		$data=split("_",$where);
+		$data=explode("_",$where);
 		if (count($data)>=2&&isset($_SESSION["glpiactiveprofile"]["interface"])&&!empty($_SESSION["glpiactiveprofile"]["interface"])){
 			switch ($_SESSION["glpiactiveprofile"]["interface"]){
 				case "helpdesk" :
@@ -1703,22 +1924,22 @@ function timestampToString($sec,$display_sec=true){
 	if ($sec<0) $sec=0;
 
 	if($sec < MINUTE_TIMESTAMP) {
-		return $sec." ".$LANG["stats"][34];
+		return $sec." ".$LANG['stats'][34];
 
 	} else if($sec < HOUR_TIMESTAMP) {
 		$min = floor($sec/MINUTE_TIMESTAMP);
 		$sec = $sec%MINUTE_TIMESTAMP;
 
-		$out=$min." ".$LANG["stats"][33];
-		if ($display_sec) $out.=" ".$sec." ".$LANG["stats"][34];
+		$out=$min." ".$LANG['stats'][33];
+		if ($display_sec) $out.=" ".$sec." ".$LANG['stats'][34];
 		return $out;
 
 	} else if($sec <  DAY_TIMESTAMP) {
 		$heure = floor($sec/HOUR_TIMESTAMP);
 		$min = floor(($sec%HOUR_TIMESTAMP)/(MINUTE_TIMESTAMP));
 		$sec = $sec%MINUTE_TIMESTAMP;
-		$out=$heure." ".$LANG["job"][21]." ".$min." ".$LANG["stats"][33];
-		if ($display_sec) $out.=" ".$sec." ".$LANG["stats"][34];
+		$out=$heure." ".$LANG['job'][21]." ".$min." ".$LANG['stats'][33];
+		if ($display_sec) $out.=" ".$sec." ".$LANG['stats'][34];
 		return $out;
 
 	} else {
@@ -1726,8 +1947,8 @@ function timestampToString($sec,$display_sec=true){
 		$heure = floor(($sec%DAY_TIMESTAMP)/(HOUR_TIMESTAMP));
 		$min = floor(($sec%HOUR_TIMESTAMP)/(MINUTE_TIMESTAMP));
 		$sec = $sec%MINUTE_TIMESTAMP;
-		$out=$jour." ".$LANG["stats"][31]." ".$heure." ".$LANG["job"][21]." ".$min." ".$LANG["stats"][33];
-		if ($display_sec) $out.=" ".$sec." ".$LANG["stats"][34];
+		$out=$jour." ".$LANG['stats'][31]." ".$heure." ".$LANG['job'][21]." ".$min." ".$LANG['stats'][33];
+		if ($display_sec) $out.=" ".$sec." ".$LANG['stats'][34];
 		return $out;
 
 	}
@@ -1765,9 +1986,8 @@ function deleteDir($dir) {
  * @param $login string: login to check
  * @return boolean 
  */
-function isValidLogin($login="")
-{
-	return preg_match( "/^[[:alnum:]@.\-_]+$/i", $login);
+function isValidLogin($login=""){
+	return preg_match( "/^[[:alnum:]@.\-_ ]+$/i", $login);
 }
 
 
@@ -1822,4 +2042,71 @@ function getSize($size) {
 	}
 	return round($size, 2)." ".$val;
 }
+
+/** Display how many logins since
+ *
+ * @return  nothing
+ */
+function getCountLogin() {
+	global $DB;
+	
+	$query="SELECT count(*) 
+		FROM `glpi_event_log` 
+		WHERE message LIKE '%logged in%'";
+	$query2="SELECT date 
+		FROM `glpi_event_log` 
+		ORDER BY date ASC LIMIT 1";
+	//$DB=new DB;
+	$result=$DB->query($query);
+	$result2=$DB->query($query2);
+	$nb_login=$DB->result($result,0,0);
+	$date=$DB->result($result2,0,0);
+
+	echo '<b>'.$nb_login.'</b> logins since '.$date ;
+}
+/** Initialise a list of items to use navigate through search results
+ *
+ * @param $device_type device type
+ * @param $title titre de la liste
+ * @param $sub_type of the device (for RULE_TYPE, ...)
+ */
+function initNavigateListItems($device_type,$title="",$sub_type=-1){
+	global $LANG;
+
+	if (empty($title)){
+		$title=$LANG['common'][53];
+	}
+	if (strpos($_SERVER['PHP_SELF'],"tabs")>0) {
+		$url=$_SERVER['HTTP_REFERER'];
+	} else {
+		$url=$_SERVER['PHP_SELF'];
+	}
+	if ($sub_type<0) {
+		$_SESSION['glpilisttitle'][$device_type]=$title;
+		$_SESSION['glpilistitems'][$device_type]=array();
+		$_SESSION['glpilisturl'][$device_type]=$url;
+	} else {
+		$_SESSION['glpilisttitle'][$device_type][$sub_type]=$title;
+		$_SESSION['glpilistitems'][$device_type][$sub_type]=array();
+		$_SESSION['glpilisturl'][$device_type][$sub_type]=$url;
+	}
+
+}
+
+/** Add an item to the navigate through search results list
+ *
+ * @param $device_type device type
+ * @param $ID ID of the item
+ * @param $sub_type of the device (for RULE_TYPE, ...)
+ */
+function addToNavigateListItems($device_type,$ID,$sub_type=-1){
+	if ($sub_type<0) {
+		$_SESSION['glpilistitems'][$device_type][]=$ID;
+	} else {
+		$_SESSION['glpilistitems'][$device_type][$sub_type][]=$ID;
+	}
+}
+
+
+
 ?>
