@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: commondbtm.class.php 7885 2009-01-23 19:28:11Z remi $
+ * @version $Id: commondbtm.class.php 8426 2009-07-07 01:05:34Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -49,8 +49,8 @@ class CommonDBTM {
 	var $may_be_recursive=false;
 	/// Is an item that can be private or assign to an entity
 	var $may_be_private=false;
-	/// Black list fields for date_mod updates
-	var $date_mod_blacklist	= array();
+	/// Black list fields for history log or date mod update
+	var $history_blacklist	= array();
 
 	/// set false to desactivate automatic message on action
 	var $auto_message_on_action=true;
@@ -58,7 +58,7 @@ class CommonDBTM {
 	/**
 	 * Constructor
 	 **/
-	function CommonDBTM () {
+	function __construct () {
 
 	}
 
@@ -73,7 +73,9 @@ class CommonDBTM {
 		global $CFG_GLPI;
 		cleanAllItemCache($ID,"GLPI_".$this->type);
 		cleanAllItemCache("comments_".$ID,"GLPI_".$this->type);
-		$CFG_GLPI["cache"]->remove("data_".$ID,"GLPI_".$this->table,true);
+		if ($CFG_GLPI["use_cache"]){
+			$CFG_GLPI["cache"]->remove("data_".$ID,"GLPI_".$this->table,true);
+		}
 		cleanRelationCache($this->table);
 	}
 
@@ -82,27 +84,61 @@ class CommonDBTM {
 	 *
 	 *@param $ID ID of the item to get
 	 *@return true if succeed else false
-	 *@todo Specific ones : Reservation Item
-	 *
-	**/
+	**/	
 	function getFromDB ($ID) {
 
 		// Make new database object and fill variables
-		global $DB,$CFG_GLPI;
+		global $DB;
 		// != 0 because 0 is consider as empty
 		if (strlen($ID)==0) return false;
-
-		$query = "SELECT * FROM `".$this->table."` WHERE (`".$this->getIndexName()."` = '".$ID."')";
-
+		
+		$query = "SELECT * FROM `".$this->table."` WHERE ".$this->getIndexName()." = '$ID'";
+		
 		if ($result = $DB->query($query)) {
 			if ($DB->numrows($result)==1){
 				$this->fields = $DB->fetch_assoc($result);
 				return true;
 			} 
-		}
+		} 
 		return false;;
+	}
+	/**
+	 * Retrieve all items from the database
+	 *
+	 *@param $condition condition used to search if needed (empty get all)
+	 *@param $order order field if needed
+	 *@param $limit limit retrieved datas if needed
+	 *@return true if succeed else false
+	**/	
+	function find ($condition="", $order="", $limit="") {
+
+		// Make new database object and fill variables
+		global $DB;
+		
+		$query = "SELECT * FROM `".$this->table."`";
+		if (!empty($condition)){
+			$query.=" WHERE $condition";
+		}
+
+		if (!empty($order)){
+			$query.=" ORDER BY $order";
+		}
+		if (!empty($limit)){
+			$query.=" LIMIT ".intval($limit);
+		}
+	
+		$data=array();
+		if ($result = $DB->query($query)) {
+			if ($DB->numrows($result)){
+				while ($line = $DB->fetch_assoc($result)){
+					$data[$line['ID']]=$line;
+				}
+			} 
+		} 
+		return $data;
 
 	}
+
 	/**
 	 * Get the name of the index field
 	 *
@@ -153,24 +189,31 @@ class CommonDBTM {
 	function updateInDB($updates,$oldvalues=array())  {
 
 		global $DB,$CFG_GLPI;
+		foreach ($updates as $field) {
+			if (isset($this->fields[$field])){
+				$query  = "UPDATE `".$this->table."` SET `";
+				$query .= $field."`";
+	
+				if ($this->fields[$field]=="NULL"){
+					$query .= " = ";
+					$query .= $this->fields[$field];
+				} else {
+					$query .= " = '";
+					$query .= $this->fields[$field]."'";
+				}
+				$query .= " WHERE ID ='";
+				$query .= $this->fields["ID"];	
+				$query .= "'";
 
-		for ($i=0; $i < count($updates); $i++) {
-			$query  = "UPDATE `".$this->table."` SET `";
-			$query .= $updates[$i]."`";
-
-			if ($this->fields[$updates[$i]]=="NULL"){
-				$query .= " = ";
-				$query .= $this->fields[$updates[$i]];
+				if (!$DB->query($query)){
+					if (isset($oldvalues[$field])){
+						unset($oldvalues[$field]);
+					}
+				}
 			} else {
-				$query .= " = '";
-				$query .= $this->fields[$updates[$i]]."'";
-			}
-			$query .= " WHERE ID ='";
-			$query .= $this->fields["ID"];	
-			$query .= "'";
-			if (!$DB->query($query)){
-				if (isset($oldvalues[$updates[$i]])){
-					unset($oldvalues[$updates[$i]]);
+				// Clean oldvalues
+				if (isset($oldvalues[$field])){
+					unset($oldvalues[$field]);
 				}
 			}
 		}
@@ -214,7 +257,11 @@ class CommonDBTM {
 			}
 			$query .= ") VALUES (";
 			for ($i=0; $i < $nb_fields; $i++) {
-				$query .= "'".$values[$i]."'";
+				if ($values[$i]=='NULL'){
+					$query .= $values[$i];
+				} else {
+					$query .= "'".$values[$i]."'";
+				}
 				if ($i!=$nb_fields-1) {
 					$query .= ",";
 				}
@@ -273,7 +320,7 @@ class CommonDBTM {
 
 			$this->cleanRelationData($ID);
 
-			$query = "DELETE from `".$this->table."` WHERE ID = '$ID'";
+			$query = "DELETE FROM `".$this->table."` WHERE ID = '$ID'";
 
 			if ($result = $DB->query($query)) {
 				$this->post_deleteFromDB($ID);
@@ -307,7 +354,8 @@ class CommonDBTM {
 	function cleanHistory($ID){
 		global $DB;
 		if ($this->dohistory){
-			$query = "DELETE FROM glpi_history WHERE ( device_type = '".$this->type."' AND FK_glpi_device = '$ID')";
+			$query = "DELETE FROM glpi_history 
+				WHERE ( device_type = '".$this->type."' AND FK_glpi_device = '$ID')";
 			$DB->query($query);
 		}
 	}
@@ -378,8 +426,6 @@ class CommonDBTM {
 	 *@param $input array : the _POST vars returned bye the item form when press add
 	 *
 	 *@return integer the new ID of the added item
-	 *@todo specific ones : reservationresa , planningtracking
-	 * 
 	**/
 	function add($input) {
 		global $DB;
@@ -403,9 +449,11 @@ class CommonDBTM {
 			$this->fields=array();
 			$table_fields=$DB->list_fields($this->table);
 
-			// fill array for udpate
+			// fill array for add
 			foreach ($input as $key => $val) {
-				if ($key[0]!='_'&& isset($table_fields[$key])&&(!isset($this->fields[$key]) || $this->fields[$key] != $input[$key])) {
+				if ($key[0]!='_'&& isset($table_fields[$key])
+					// TEST -> TO DELETE Not needed for add process : always copy data && (!isset($this->fields[$key]) || $this->fields[$key] != $input[$key])
+				) {
 					$this->fields[$key] = $input[$key];
 				}
 			}
@@ -417,7 +465,7 @@ class CommonDBTM {
 			if ($newID= $this->addToDB()){
 				$this->addMessageOnAddAction($input);
 				$this->post_addItem($newID,$input);
-				doHook("item_add",array("type"=>$this->type, "ID" => $newID));
+				doHook("item_add",array("type"=>$this->type, "ID" => $newID, "input" => $input));
 				return $newID;
 			} else {
 				return false;
@@ -450,7 +498,7 @@ class CommonDBTM {
 		}
 
 		if ($addMessAfterRedirect) {
-			addMessageAfterRedirect($LANG["common"][70] . 
+			addMessageAfterRedirect($LANG['common'][70] . 
 			": <a href='" . $CFG_GLPI["root_doc"]."/".$INFOFORM_PAGES[$this->type] . "?ID=" . $this->fields['ID'] . (isset($input['is_template'])?"&amp;withtemplate=1":"")."'>" .
 			(isset($this->fields["name"]) && !empty($this->fields["name"]) ? stripslashes($this->fields["name"]) : "(".$this->fields['ID'].")") . "</a>");
 		} 
@@ -488,10 +536,9 @@ class CommonDBTM {
 	 *
 	 *
 	 *@return Nothing (call to the class member)
-	 *@todo specific ones : reservationresa, planningtracking
 	 *
 	**/
-    function update($input,$history=1) {
+	function update($input,$history=1) {
 		global $DB;
 		if ($DB->isSlave())
 			return false;
@@ -501,13 +548,13 @@ class CommonDBTM {
 
 		$input=$this->prepareInputForUpdate($input);
 
-
 		if (isset($input['update'])){
 			$input['_update']=$input['update'];
 			unset($input['update']);
 		}
-
-		if ($this->getFromDB($input[$this->getIndexName()])){
+		// Valid input
+		if ($input&&is_array($input)
+		&&$this->getFromDB($input[$this->getIndexName()])){
 
 			// Fill the update-array with changes
 			$x=0;
@@ -515,16 +562,15 @@ class CommonDBTM {
 			$oldvalues=array();
 			foreach ($input as $key => $val) {
 				if (array_key_exists($key,$this->fields)){
-					// Secu for null values on history
-					// TODO : Int with NULL default value in DB -> default value 0
-/*					if (is_null($this->fields[$key])){
-						if (is_int($input[$key])||$input[$key]=='0') 	$this->fields[$key]=0;
+					// Prevent history for date statement (for date for example)
+					if ( is_null($this->fields[$key]) && $input[$key]=='NULL'){
+						$this->fields[$key]='NULL';
 					}
-*/
-					if ($this->fields[$key] != stripslashes($input[$key])) {
+					
+					if ( $this->fields[$key] != stripslashes($input[$key])) {
 						if ($key!="ID"){
-							// Do logs
-							if ($this->dohistory&&$history){
+							// Store old values
+							if (!in_array($key,$this->history_blacklist)){
 								$oldvalues[$key]=$this->fields[$key];
 							}
 							$this->fields[$key] = $input[$key];
@@ -534,26 +580,32 @@ class CommonDBTM {
 					}
 				}
 			}
-
 			if(count($updates)){
-				if (isset($this->fields['date_mod'])){
+				if (array_key_exists('date_mod',$this->fields)){
 					// is a non blacklist field exists
-					if (count(array_diff($updates,$this->date_mod_blacklist)) > 0){
+					if (count(array_diff($updates,$this->history_blacklist)) > 0){
 						$this->fields['date_mod']=$_SESSION["glpi_currenttime"];
 						$updates[$x++] = 'date_mod';
 					}
 				}
 
-				list($input,$updates)=$this->pre_updateInDB($input,$updates);
-				
+				list($input,$updates)=$this->pre_updateInDB($input,$updates,$oldvalues);
+
+				// CLean old_values history not needed
+				if (!$this->dohistory || !$history){
+					$oldvalues=array();
+				}
 
 				if ($this->updateInDB($updates,$oldvalues)){
 					$this->addMessageOnUpdateAction($input);
-					doHook("item_update",array("type"=>$this->type, "ID" => $input["ID"]));
+					doHook("item_update",array("type"=>$this->type, "ID" => $input["ID"], "input"=> $input, "updates" => $updates, "oldvalues" => $oldvalues));
 				}
 			} 
 			$this->post_updateItem($input,$updates,$history);
+		} else {
+			return false;
 		}
+		return true;
 	}
 
 	/**
@@ -576,9 +628,11 @@ class CommonDBTM {
 		if (isset($input['_no_message']) || !$this->auto_message_on_action){
 			$addMessAfterRedirect=false;
 		}
+		
 
 		if ($addMessAfterRedirect) {
-			addMessageAfterRedirect($LANG["common"][71].": ".(isset($this->fields["name"]) && !empty($this->fields["name"]) ? stripslashes($this->fields["name"]) : "(".$this->fields['ID'].")"));
+			addMessageAfterRedirect($LANG['common'][71].": <a href='" . $CFG_GLPI["root_doc"]."/".$INFOFORM_PAGES[$this->type] . "?ID=" . $this->fields['ID'] . "'>" .
+			(isset($this->fields["name"]) && !empty($this->fields["name"]) ? stripslashes($this->fields["name"]) : "(".$this->fields['ID'].")") . "</a>");
 		} 
 	}
 
@@ -612,11 +666,12 @@ class CommonDBTM {
 	 *
 	 *@param $input datas used to update the item
 	 *@param $updates array of the updated fields
+	 *@param $oldvalues old values of updated fields
 	 * 
 	 *@return nothing
 	 * 
 	**/
-	function pre_updateInDB($input,$updates) {
+	function pre_updateInDB($input,$updates,$oldvalues=array()) {
 		return array($input,$updates);
 	}
 
@@ -657,7 +712,7 @@ class CommonDBTM {
 				if ($this->deleteFromDB($this->fields["ID"],$force)){
 					if ($force){
 						$this->addMessageOnPurgeAction($input);
-						doHook("item_purge",array("type"=>$this->type, "ID" => $this->fields["ID"]));
+						doHook("item_purge",array("type"=>$this->type, "ID" => $this->fields["ID"], "input" => $input));
 					} else {
 						$this->addMessageOnDeleteAction($input);
 
@@ -667,7 +722,8 @@ class CommonDBTM {
 				
 							historyLog ($this->fields["ID"],$this->type,$changes,0,HISTORY_DELETE_ITEM);
 						}
-						doHook("item_delete",array("type"=>$this->type, "ID" => $this->fields["ID"]));
+
+						doHook("item_delete",array("type"=>$this->type, "ID" => $this->fields["ID"], "input" => $input));
 					}
 				}
 				return true;
@@ -706,7 +762,7 @@ class CommonDBTM {
 		}
 
 		if ($addMessAfterRedirect) {
-			addMessageAfterRedirect($LANG["common"][72] . 
+			addMessageAfterRedirect($LANG['common'][72] . 
 			": <a href='" . $CFG_GLPI["root_doc"]."/".$INFOFORM_PAGES[$this->type] . "?ID=" . $this->fields['ID'] . "'>" .
 			(isset($this->fields["name"]) && !empty($this->fields["name"]) ? stripslashes($this->fields["name"]) : "(".$this->fields['ID'].")") . "</a>");
 		} 
@@ -734,7 +790,7 @@ class CommonDBTM {
 		}
 
 		if ($addMessAfterRedirect) {
-			addMessageAfterRedirect($LANG["common"][73].": ".(isset($this->fields["name"]) && !empty($this->fields["name"]) ? stripslashes($this->fields["name"]) : "(".$this->fields['ID'].")"));
+			addMessageAfterRedirect($LANG['common'][73].": ".(isset($this->fields["name"]) && !empty($this->fields["name"]) ? stripslashes($this->fields["name"]) : "(".$this->fields['ID'].")"));
 		} 
 	}
 
@@ -758,7 +814,7 @@ class CommonDBTM {
 	 *@param $history boolean : do history log ?
 	 * 
 	 *@return Nothing () 
-	 *@todo specific ones : cartridges / consumables 
+	 *@todo specific ones : cartridges / consumables : more reuse than restore
 	 * 
 	**/ 
 	// specific ones : cartridges / consumables
@@ -783,7 +839,7 @@ class CommonDBTM {
 					historyLog ($input["ID"],$this->type,$changes,0,HISTORY_RESTORE_ITEM);
 				}
 	
-				doHook("item_restore",array("type"=>$this->type, "ID" => $input["ID"]));
+				doHook("item_restore",array("type"=>$this->type, "ID" => $input["ID"], "input" => $input));
 			}
 		}
 	}
@@ -810,7 +866,7 @@ class CommonDBTM {
 		}
 
 		if ($addMessAfterRedirect) {
-			addMessageAfterRedirect($LANG["common"][74] . 
+			addMessageAfterRedirect($LANG['common'][74] . 
 			": <a href='" . $CFG_GLPI["root_doc"]."/".$INFOFORM_PAGES[$this->type] . "?ID=" . $this->fields['ID'] . "'>" .
 			(isset($this->fields["name"]) && !empty($this->fields["name"]) ? stripslashes($this->fields["name"]) : "(".$this->fields['ID'].")") . "</a>");
 		} 
@@ -826,8 +882,9 @@ class CommonDBTM {
 	}
 
 	/**
-	 * Define onglets to display
-	 *
+	 * Define onglets to display / WILL BE DELETED : use defineTabs instead
+ 	 * Can define 'no_all_tab' item in array in order to not show all tab
+	 * 
 	 *@param $withtemplate is a template view ?
 	 * 
 	 *@return array containing the onglets
@@ -838,7 +895,19 @@ class CommonDBTM {
 	}
 
 	/**
-	 * Show onglets
+	 * Define tabs to display
+	 *
+	 *@param $withtemplate is a template view ?
+	 * 
+	 *@return array containing the onglets
+	 * 
+	**/
+	function defineTabs($ID,$withtemplate){
+		return array();
+	}
+
+	/**
+	 * Show onglets / WILL BE DELETED : use showTabs instead
 	 *
 	 *@param $ID ID of the item to display
 	 *@param $withtemplate is a template view ?
@@ -864,7 +933,7 @@ class CommonDBTM {
 	
 		if (count($onglets=$this->defineOnglets($withtemplate))){
 			//if (empty($withtemplate)&&haveRight("reservation_central","r")&&function_exists("isReservable")){
-			//	$onglets[11]=$LANG["Menu"][17];
+			//	$onglets[11]=$LANG['Menu'][17];
 			//	ksort($onglets);
 			//}
 			foreach ($onglets as $key => $val ) {
@@ -872,7 +941,7 @@ class CommonDBTM {
 			}
 			if(empty($withtemplate)){
 				echo "<li class='invisible'>&nbsp;</li>";
-				echo "<li "; if ($actif=="-1") {echo "class='actif'";} echo "><a href='$target&amp;onglet=-1$template$addurlparam'>".$LANG["common"][66]."</a></li>";
+				echo "<li "; if ($actif=="-1") {echo "class='actif'";} echo "><a href='$target&amp;onglet=-1$template$addurlparam'>".$LANG['common'][66]."</a></li>";
 			}
 		}
 	
@@ -888,16 +957,185 @@ class CommonDBTM {
 			$prev=getPreviousItem($this->table,$ID,$nextprevcondition,$nextprev_item);
 			$cleantarget=preg_replace("/\?ID=([0-9]+)/","",$target);
 			if ($prev>0) {
-				echo "<li><a href='$cleantarget?ID=$prev$addurlparam'><img src=\"".$CFG_GLPI["root_doc"]."/pics/left.png\" alt='".$LANG["buttons"][12]."' title='".$LANG["buttons"][12]."'></a></li>";
+				echo "<li><a href='$cleantarget?ID=$prev$addurlparam'><img src=\"".$CFG_GLPI["root_doc"]."/pics/left.png\" alt='".$LANG['buttons'][12]."' title='".$LANG['buttons'][12]."'></a></li>";
 			}
 			if ($next>0) {
-				echo "<li><a href='$cleantarget?ID=$next$addurlparam'><img src=\"".$CFG_GLPI["root_doc"]."/pics/right.png\" alt='".$LANG["buttons"][11]."' title='".$LANG["buttons"][11]."'></a></li>";
+				echo "<li><a href='$cleantarget?ID=$next$addurlparam'><img src=\"".$CFG_GLPI["root_doc"]."/pics/right.png\" alt='".$LANG['buttons'][11]."' title='".$LANG['buttons'][11]."'></a></li>";
 			}
 		}
 	
 		echo "</ul></div>";
 	} 
 
+
+	/**
+	 * Show onglets 
+	 *
+	 *@param $ID ID of the item to display
+	 *@param $withtemplate is a template view ?
+	 *@param $actif active onglet
+	 *@param $addparams array of parameters to add to URLs and ajax
+	 *@param $nextprevcondition condition used to find next/previous items
+	 *@param $nextprev_item field used to define next/previous items
+	 * 
+	 *@return Nothing () 
+	 *  
+	**/
+	function showTabs($ID,$withtemplate,$actif,$addparams=array(),$nextprevcondition="",$nextprev_item=""){
+		global $LANG,$CFG_GLPI,$INFOFORM_PAGES;
+
+		$target=$_SERVER['PHP_SELF'];
+		$template="";
+		$templatehtml="";
+		if(!empty($withtemplate)){
+			$template="&withtemplate=$withtemplate";
+			$templatehtml="&amp;withtemplate=$withtemplate";
+		}
+		$extraparamhtml="";
+		$extraparam="";
+		if (is_array($addparams)&&count($addparams)){
+			foreach ($addparams as $key => $val){
+				$extraparamhtml.="&amp;$key=$val";
+				$extraparam.="&$key=$val";
+			}
+		}
+
+
+		if (empty($withtemplate) && $ID && $this->type>0){
+			echo "<div id='menu_navigate'>";
+			//$next=getNextItem($this->table,$ID,$nextprevcondition,$nextprev_item);
+			//$prev=getPreviousItem($this->table,$ID,$nextprevcondition,$nextprev_item);
+
+//			if ($this->type==TRACKING_TYPE && !haveRight("show_all_ticket","1")){
+//				$next=0;
+//				$prev=0;
+//			}
+
+			if (isset($this->sub_type)) {
+				$glpilistitems =& $_SESSION['glpilistitems'][$this->type][$this->sub_type];
+				$glpilisttitle =& $_SESSION['glpilisttitle'][$this->type][$this->sub_type];
+				$glpilisturl   =& $_SESSION['glpilisturl'][$this->type][$this->sub_type];
+			} else {
+				$glpilistitems =& $_SESSION['glpilistitems'][$this->type];
+				$glpilisttitle =& $_SESSION['glpilisttitle'][$this->type];
+				$glpilisturl   =& $_SESSION['glpilisturl'][$this->type];
+			}
+			$next=$prev=$first=$last=-1;
+			$current=false;
+			if (is_array($glpilistitems)){
+				$current=array_search($ID,$glpilistitems);
+				
+				if ($current!==false){
+					if (isset($glpilistitems[$current+1])){
+						$next=$glpilistitems[$current+1];
+					}
+					if (isset($glpilistitems[$current-1])){
+						$prev=$glpilistitems[$current-1];
+					}
+					$first=$glpilistitems[0];
+					if ($first==$ID) {
+						$first= -1;
+					}
+					$last=$glpilistitems[count($glpilistitems)-1];
+					if ($last==$ID) {
+						$last= -1;
+					}
+				}
+			}
+			
+			$cleantarget=preg_replace("/\?ID=([0-9]+)/","",$target);
+			echo "<ul>";
+			echo "<li><a href=\"javascript:showHideDiv('tabsbody','tabsbodyimg','".$CFG_GLPI["root_doc"]."/pics/deplier_down.png','".$CFG_GLPI["root_doc"]."/pics/deplier_up.png')\">";
+			echo "<img alt='' name='tabsbodyimg' src=\"".$CFG_GLPI["root_doc"]."/pics/deplier_up.png\">";
+			echo "</a></li>";
+
+						
+			echo "<li><a href=\"".$glpilisturl."\">";
+			
+			if ($glpilisttitle){
+				if (utf8_strlen($glpilisttitle)>$_SESSION['glpidropdown_limit']) {
+					$glpilisttitle = utf8_substr($glpilisttitle, 0, $_SESSION['glpidropdown_limit']) . "&hellip;";
+				}
+				echo $glpilisttitle;
+			} else {
+				echo $LANG['common'][53];
+			}
+			echo "</a>:&nbsp;</li>";
+		
+
+
+
+			if ($first>0) {
+				echo "<li><a href='$cleantarget?ID=$first$extraparamhtml'><img src=\"".$CFG_GLPI["root_doc"]."/pics/first.png\" alt='".$LANG['buttons'][55]."' title='".$LANG['buttons'][55]."'></a></li>";
+			} else {
+				echo "<li><img src=\"".$CFG_GLPI["root_doc"]."/pics/first_off.png\" alt='".$LANG['buttons'][55]."' title='".$LANG['buttons'][55]."'></li>";
+			}
+			
+			if ($prev>0) {
+				echo "<li><a href='$cleantarget?ID=$prev$extraparamhtml'><img src=\"".$CFG_GLPI["root_doc"]."/pics/left.png\" alt='".$LANG['buttons'][12]."' title='".$LANG['buttons'][12]."'></a></li>";
+			} else {
+				echo "<li><img src=\"".$CFG_GLPI["root_doc"]."/pics/left_off.png\" alt='".$LANG['buttons'][12]."' title='".$LANG['buttons'][12]."'></li>";
+			}
+			
+			
+			if ($current!==false){
+				echo "<li>".($current+1) . "/" . count($glpilistitems)."</li>";
+			}
+			
+			if ($next>0) {
+				echo "<li><a href='$cleantarget?ID=$next$extraparamhtml'><img src=\"".$CFG_GLPI["root_doc"]."/pics/right.png\" alt='".$LANG['buttons'][11]."' title='".$LANG['buttons'][11]."'></a></li>";
+			} else {
+				echo "<li><img src=\"".$CFG_GLPI["root_doc"]."/pics/right_off.png\" alt='".$LANG['buttons'][11]."' title='".$LANG['buttons'][11]."'></li>";
+			}
+		
+			if ($last>0) {
+				echo "<li><a href='$cleantarget?ID=$last$extraparamhtml'><img src=\"".$CFG_GLPI["root_doc"]."/pics/last.png\" alt='".$LANG['buttons'][56]."' title='".$LANG['buttons'][56]."'></a></li>";
+			} else {
+				echo "<li><img src=\"".$CFG_GLPI["root_doc"]."/pics/last_off.png\" alt='".$LANG['buttons'][56]."' title='".$LANG['buttons'][56]."'></li>";
+			}
+
+			echo "</ul></div>";
+
+			echo "<div class='sep'></div>";
+
+		}
+	
+		
+		echo "<div id='tabspanel' class='center-h'></div>";
+		
+		$active=0;
+		$onglets=$this->defineTabs($ID,$withtemplate);
+		$display_all=true;
+		if (isset($onglets['no_all_tab'])){
+			$display_all=false;
+			unset($onglets['no_all_tab']);
+		}
+		if (count($onglets)){
+			$patterns[0] = '/front/';
+			$patterns[1] = '/form/';
+			$replacements[0] = 'ajax';
+			$replacements[1] = 'tabs';
+			$tabpage=preg_replace($patterns, $replacements, $INFOFORM_PAGES[$this->type]);
+			$tabs=array();
+			foreach ($onglets as $key => $val ) {
+				$tabs[$key]=array('title'=>$val,
+						'url'=>$CFG_GLPI['root_doc']."/$tabpage",
+						'params'=>"target=$target&type=".$this->type."&glpi_tab=$key&ID=$ID$template$extraparam");
+			}			
+			$plug_tabs=getPluginTabs($target,$this->type,$ID,$withtemplate);
+			$tabs+=$plug_tabs;
+			// Not all tab for templates and if only 1 tab
+			if($display_all && empty($withtemplate) && count($tabs)>1){
+				$tabs[-1]=array('title'=>$LANG['common'][66],
+						'url'=>$CFG_GLPI['root_doc']."/$tabpage",
+						'params'=>"target=$target&type=".$this->type."&glpi_tab=-1&ID=$ID$template$extraparam");
+			}
+
+			createAjaxTabs('tabspanel','tabcontent',$tabs,$actif);
+
+		}
+	} 
+
 	/**
 	 * Have I the right to "write" the Object
 	 * 
@@ -961,6 +1199,182 @@ class CommonDBTM {
 		return haveTypeRight($this->type,"r");
 	}
 
+	/**
+	 * Can I change recusvive flag to false
+	 * check if there is "linked" object in another entity
+	 * 
+	 * May be overloaded if needed
+	 *
+	 * @return booleen
+	 **/
+	function canUnrecurs () {
+
+		global $DB, $LINK_ID_TABLE, $CFG_GLPI;
+			
+		$ID  = $this->fields['ID'];	
+		
+		if ($ID<0 || !$this->fields['recursive']) {
+			return true;
+		}
+		$entities = "('".$this->fields['FK_entities']."'";
+		foreach (getEntityAncestors($this->fields['FK_entities']) as $papa) {
+			$entities .= ",'$papa'";
+		}
+		$entities .= ")";
+
+		$RELATION=getDbRelations();
+	
+		if (isset($RELATION[$this->table])){
+			foreach ($RELATION[$this->table] as $tablename => $field){
+				if (in_array($tablename,$CFG_GLPI["specif_entities_tables"])) {
+					// 1->N Relation
+					if (is_array($field)) {
+						foreach ($field as $f) {
+							if (countElementsInTable($tablename, "`$f`='$ID' AND FK_entities NOT IN $entities")>0) {
+								return false;
+							}
+						}
+					} else {
+						if (countElementsInTable($tablename, "`$field`='$ID' AND FK_entities NOT IN $entities")>0) {
+							return false;
+						}
+					}
+				} else {
+					foreach ($RELATION as $othertable => $rel) {	
+
+						// Search for a N->N Relation with devices
+						if ($othertable == "_virtual_device"					
+							&& isset($rel[$tablename])) {
+
+							$devfield  = $rel[$tablename][0]; // FK_device, on_device, end1...
+							$typefield = $rel[$tablename][1]; // device_type, type, ...
+							
+							$sql = "SELECT DISTINCT `$typefield` AS type FROM `$tablename` WHERE `$field`='$ID'";
+							$res = $DB->query($sql);
+							
+							// Search linked device of each type
+							if ($res) while ($data = $DB->fetch_assoc($res)) {
+								$type=$data["type"];
+								if (isset($LINK_ID_TABLE[$type]) && 
+									in_array($device=$LINK_ID_TABLE[$type], $CFG_GLPI["specif_entities_tables"])) {
+
+									if (countElementsInTable("$tablename, $device", 
+										"`$tablename`.`$field`='$ID' 
+										AND `$tablename`.`$typefield`='$type' 
+										AND `$tablename`.`$devfield`=`$device`.ID 
+										AND `$device`.FK_entities NOT IN $entities")>0) {
+											return false;											
+									}
+								}			
+							}
+							
+						// Search for another N->N Relation 			
+						} else if ($othertable != $this->table 
+								&& isset($rel[$tablename]) 
+								&& in_array($othertable,$CFG_GLPI["specif_entities_tables"])) {
+
+							if (is_array($rel[$tablename])) {
+								foreach ($rel[$tablename] as $otherfield){
+									if (countElementsInTable("$tablename, $othertable",
+										"`$tablename`.`$field`='$ID' 
+										AND `$tablename`.`$otherfield`=`$othertable`.ID 
+										AND `$othertable`.FK_entities NOT IN $entities")>0) {
+										return false;
+									}
+								}
+							} else {
+								$otherfield = $rel[$tablename];							
+								if (countElementsInTable("$tablename, $othertable", 
+									"`$tablename`.`$field`=$ID 
+									AND `$tablename`.`$otherfield`=`$othertable`.ID 
+									AND `$othertable`.FK_entities NOT IN $entities")>0) {
+									return false;
+								}
+							}						
+						}
+					}
+				}
+			}
+		}
+		
+		// Doc links to this item
+		if ($this->type > 0
+			&& countElementsInTable("glpi_doc_device, glpi_docs",
+				"glpi_doc_device.FK_device=$ID AND glpi_doc_device.device_type=".$this->type." AND glpi_doc_device.FK_doc=glpi_docs.ID AND glpi_docs.FK_entities NOT IN $entities")>0) {
+					return false;                       
+		} 
+		// TODO : do we need to check all relations in $RELATION["_virtual_device"] for this item
+
+		return true;
+	}
+
+	/**
+	 * 
+	 * Display a 2 columns Header 1 for ID, 1 for recursivity menu
+	 * 
+	 * @param $ID ID of the item (-1 if new item)
+	 * @param $withtemplate empty or 1 for newtemplate, 2 for newobject from template
+	 * @param $colspan for each column
+	 * 
+	 */
+	 function showFormHeader ($ID, $withtemplate='', $colspan=1) {
+	 	
+	 	global $LANG, $CFG_GLPI;
+	 	
+		echo "<tr><th colspan='$colspan'>";
+
+		if (!empty($withtemplate) && $withtemplate == 2 && $ID>0) {
+			
+			echo "<input type='hidden' name='tplname' value='".$this->fields["tplname"]."'>";
+			echo $LANG['buttons'][8] . " - " . $LANG['common'][13] . ": " . $this->fields["tplname"];
+			
+		} else if (!empty($withtemplate) && $withtemplate == 1) {
+			
+			echo "<input type='hidden' name='is_template' value='1' />\n";
+			echo $LANG['common'][6].": "; 
+			autocompletionTextField("tplname",$this->table,"tplname",$this->fields["tplname"],25,$this->fields["FK_entities"]); 			
+		
+		} else if (empty($ID)||$ID<0){
+
+			echo $LANG['common'][87];
+
+		} else {
+
+			echo $LANG['common'][2]." $ID";
+		}
+		
+		if (isMultiEntitiesMode()){
+			echo "&nbsp;(".getDropdownName("glpi_entities",$this->fields["FK_entities"]).")";
+		}
+		
+		echo "</th><th colspan='$colspan'>";
+
+		if ($this->may_be_recursive && isMultiEntitiesMode()){
+			echo $LANG['entity'][9].":&nbsp;";
+		
+			if (!$this->can($ID,'recursive')) {
+				echo getYesNo($this->fields["recursive"]);
+				$comment=$LANG['common'][86];
+				$image="/pics/lock.png";
+			} else if (!$this->canUnrecurs()) {
+				echo getYesNo($this->fields["recursive"]);
+				$comment=$LANG['common'][84];
+				$image="/pics/lock.png";
+			} else {
+				dropdownYesNo("recursive",$this->fields["recursive"]);
+				$comment=$LANG['common'][85];
+				$image="/pics/aide.png";
+			}
+			$rand=mt_rand();
+			echo "&nbsp;<img alt='' src='".$CFG_GLPI["root_doc"].$image."' onmouseout=\"cleanhide('comments_recursive$rand')\" onmouseover=\"cleandisplay('comments_recursive$rand')\">";
+			echo "<span class='over_link' id='comments_recursive$rand'>$comment</span>";
+			
+		} else {
+			echo "&nbsp;";
+		}
+		echo "</th></tr>\n";
+	 }
+	 
 	/**
 	 * Check right on an item
 	 *
@@ -976,7 +1390,9 @@ class CommonDBTM {
 		$recursive_state_to_check=0;
 		// Get item if not already loaded
 		if (empty($ID)||$ID<=0){
-			$this->getEmpty($ID);
+//			if (!isset($this->fields["ID"]) || strlen($this->fields["ID"])) {
+//				$this->getEmpty();
+//			}
 			// No entity define : adding process : use active entity
 			if ($entity==-1){
 				$entity_to_check=$_SESSION["glpiactive_entity"];
@@ -990,10 +1406,10 @@ class CommonDBTM {
 					return false;
 				}
 			}
-			if ($this->entity_assign){
-				$entity_to_check=$this->fields["FK_entities"];
-				if ($this->may_be_recursive){
-					$recursive_state_to_check=$this->fields["recursive"];
+			if ($this->isEntityAssign()){
+				$entity_to_check=$this->getEntityID();
+				if ($this->maybeRecursive()){
+					$recursive_state_to_check=$this->isRecursive();
 				}
 			}
 
@@ -1009,9 +1425,9 @@ class CommonDBTM {
 					// Check Global Right
 					if ($this->canView()){
 						// Is an item assign to an entity
-						if ($this->entity_assign){
+						if ($this->isEntityAssign()){
 							// Can be recursive check 
-							if ($this->may_be_recursive){
+							if ($this->maybeRecursive()){
 								return haveAccessToEntity($entity_to_check,$recursive_state_to_check);
 							} else { // Non recursive item
 								return haveAccessToEntity($entity_to_check);
@@ -1030,7 +1446,7 @@ class CommonDBTM {
 					// Check Global Right
 					if ($this->canCreate()){
 						// Is an item assign to an entity
-						if ($this->entity_assign){
+						if ($this->isEntityAssign()){
 							// Have access to entity
 							return haveAccessToEntity($entity_to_check);
 						} else { // Global item
@@ -1040,7 +1456,7 @@ class CommonDBTM {
 				}
 				break;
 			case 'recursive':
-				if ($this->entity_assign && $this->may_be_recursive){
+				if ($this->isEntityAssign() && $this->maybeRecursive()){
 					if ($this->canCreate() && haveAccessToEntity($entity_to_check)){
 						// Can make recursive if recursive access to entity
 						return haveRecursiveAccessToEntity($entity_to_check);
@@ -1062,15 +1478,69 @@ class CommonDBTM {
 	function check($ID,$right,$entity=-1) {
 		global $CFG_GLPI;
 	
-		if (!$this->can($ID,$right,$entity)) {
+		// Check item exists
+		if ($ID>0 && !$this->getFromDB($ID)){
 			// Gestion timeout session
 			if (!isset ($_SESSION["glpiID"])) {
 				glpi_header($CFG_GLPI["root_doc"] . "/index.php");
 				exit ();
 			}
-			displayRightError();
+
+			displayNotFoundError();			
+	
+		} else {
+			if (!$this->can($ID,$right,$entity)) {
+				// Gestion timeout session
+				if (!isset ($_SESSION["glpiID"])) {
+					glpi_header($CFG_GLPI["root_doc"] . "/index.php");
+					exit ();
+				}
+				displayRightError();
+			}
 		}
 	}
+	/**
+	 * Is the object assigned to an entity
+	 * 
+	 * @return boolean
+	**/
+	function isEntityAssign () {
+		return $this->entity_assign;
+	}
+	/**
+	 * Get the ID of entity assigned to the object
+	 * 
+	 * Can be overloaded (ex : infocom)
+	 * 
+	 * @return ID of the entity 
+	**/
+	function getEntityID () {
+		if ($this->entity_assign && isset($this->fields["FK_entities"])) {
+			return $this->fields["FK_entities"];		
+		} 
+		return  -1;
+	}	
+	/**
+	 * Is the object may be recursive
+	 * 
+	 * @return boolean
+	**/
+	function maybeRecursive () {
+		return $this->may_be_recursive;
+	}
+	/**
+	 * Is the object recursive
+	 * 
+	 * Can be overloaded (ex : infocom)
+	 * 
+	 * @return integer (0/1) 
+	**/
+	function isRecursive () {
+		if ($this->may_be_recursive && isset($this->fields["recursive"])) {
+			return $this->fields["recursive"];		
+		} 
+		return 0;
+	}	
 }
 
-?>
\ No newline at end of file
+?>
