@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: computer.function.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: computer.function.php 8126 2009-03-29 08:54:14Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -113,36 +113,36 @@ function showDeviceComputerForm($target,$ID,$withtemplate='') {
 
 	if (!empty($ID)){
 		//print devices.
-		if (!($CFG_GLPI["cache"]->start("device_".$ID."_".$_SESSION["glpilanguage"],"GLPI_".COMPUTER_TYPE))) {
+		if (!($CFG_GLPI["cache"]->start("device_".$ID."_".$_SESSION['glpilanguage'],"GLPI_".COMPUTER_TYPE))) {
 			echo "<div class='center'>";
 			echo "<form name='form_device_action' action=\"$target\" method=\"post\" >";
-			echo "<input type='hidden' name='ID' value='$ID'>";	
-			echo "<input type='hidden' name='device_action' value='$ID'>";			
+			echo "<input type='hidden' name='ID' value='$ID'>";
+			echo "<input type='hidden' name='device_action' value='$ID'>";
 			echo "<table class='tab_cadre_fixe' >";
-			echo "<tr><th colspan='65'>".$LANG["title"][30]."</th></tr>";
+			echo "<tr><th colspan='65'>".$LANG['title'][30]."</th></tr>";
 			foreach($comp->devices as $key => $val) {
 				$device = new Device($val["devType"]);
 				$device->getFromDB($val["devID"]);
 				printDeviceComputer($device,$val["quantity"],$val["specificity"],$comp->fields["ID"],$val["compDevID"],$withtemplate);
-	
+
 			}
 			$CFG_GLPI["cache"]->end();
 		}
 		if ($canedit&&!(!empty($withtemplate) && $withtemplate == 2)&&count($comp->devices))
-			echo "<tr><td colspan='65' align='center' class='tab_bg_1'><input type='submit' class='submit' name='update_device' value='".$LANG["buttons"][7]."'></td></tr>";
+			echo "<tr><td colspan='65' align='center' class='tab_bg_1'><input type='submit' class='submit' name='update_device' value='".$LANG['buttons'][7]."'></td></tr>";
 		echo "</table>";
 
 		echo "</form>";
 		//ADD a new device form.
-		device_selecter($_SERVER['PHP_SELF'],$comp->fields["ID"],$withtemplate);
-		echo "</div>";
-	}	
+		device_selecter($target,$comp->fields["ID"],$withtemplate);
+		echo "</div><br>";
+	}
 
 
 }
 
 /**
- * Print the computers or template local connections form. 
+ * Print the computers or template local connections form.
  *
  * Print the form for computers or templates connections to printers, screens or peripherals
  *
@@ -159,8 +159,9 @@ function showConnections($target,$ID,$withtemplate='') {
 
 
 	$ci=new CommonItem;
-
-	$items=array(PRINTER_TYPE=>$LANG["computers"][39],MONITOR_TYPE=>$LANG["computers"][40],PERIPHERAL_TYPE=>$LANG["computers"][46],PHONE_TYPE=>$LANG["computers"][55]);
+	$used = array();
+	
+	$items=array(PRINTER_TYPE=>$LANG['computers'][39],MONITOR_TYPE=>$LANG['computers'][40],PERIPHERAL_TYPE=>$LANG['computers'][46],PHONE_TYPE=>$LANG['computers'][55]);
 	$comp=new Computer();
 	$canedit=haveTypeRight(COMPUTER_TYPE,"w");
 
@@ -171,9 +172,9 @@ function showConnections($target,$ID,$withtemplate='') {
 	
 		}
 		if (count($items)){
-			echo "&nbsp;<div class='center'><table class='tab_cadre_fixe'>";
+			echo "<div class='center'><table class='tab_cadre_fixe'>";
 	
-			echo "<tr><th colspan='".max(2,count($items))."'>".$LANG["connect"][0].":</th></tr>";
+			echo "<tr><th colspan='".max(2,count($items))."'>".$LANG['connect'][0].":</th></tr>";
 	
 			echo "<tr>";
 			$header_displayed=0;
@@ -204,7 +205,8 @@ function showConnections($target,$ID,$withtemplate='') {
 					echo "</tr><tr class='tab_bg_1'>";
 				}
 				echo "<td class='center'>";
-				$query = "SELECT * FROM glpi_connect_wire WHERE end2='$ID' AND type='".$type."'";
+				$query = "SELECT * FROM glpi_connect_wire 
+					WHERE end2='$ID' AND type='".$type."'";
 				if ($result=$DB->query($query)) {
 					$resultnum = $DB->numrows($result);
 					if ($resultnum>0) {
@@ -214,6 +216,8 @@ function showConnections($target,$ID,$withtemplate='') {
 							$connID = $DB->result($result, $i, "ID");
 							$ci->getFromDB($type,$tID);
 	
+							$used[] = $tID;
+							
 							echo "<tr ".($ci->getField('deleted')?"class='tab_bg_2_2'":"").">";
 							echo "<td class='center'><strong>";
 							echo $ci->getLink();
@@ -225,7 +229,7 @@ function showConnections($target,$ID,$withtemplate='') {
 							echo "</td><td>";
 							if($canedit&&(empty($withtemplate) || $withtemplate != 2)) {
 								echo "<td class='center'><a 	href=\"".$CFG_GLPI["root_doc"]."/front/computer.form.php?cID=$ID&amp;ID=$connID&amp;disconnect=1&amp;withtemplate=".$withtemplate."\"><strong>";
-								echo $LANG["buttons"][10];
+								echo $LANG['buttons'][10];
 								echo "</strong></a></td>";
 							}
 							echo "</tr>";
@@ -234,16 +238,16 @@ function showConnections($target,$ID,$withtemplate='') {
 					} else {
 						switch ($type){
 							case PRINTER_TYPE:
-								echo $LANG["computers"][38];
+								echo $LANG['computers'][38];
 								break;
 							case MONITOR_TYPE:
-								echo $LANG["computers"][37];
+								echo $LANG['computers'][37];
 								break;
 							case PERIPHERAL_TYPE:
-								echo $LANG["computers"][47];
+								echo $LANG['computers'][47];
 								break;
 							case PHONE_TYPE:
-								echo $LANG["computers"][54];
+								echo $LANG['computers'][54];
 								break;
 						}
 						echo "<br>";
@@ -259,8 +263,8 @@ function showConnections($target,$ID,$withtemplate='') {
 							} else { // No history for template
 								echo "<input type='hidden' name='dohistory' value='0'>";
 							}
-							dropdownConnect($type,COMPUTER_TYPE,"item",$comp->fields["FK_entities"],$withtemplate);
-							echo "<input type='submit' value=\"".$LANG["buttons"][9]."\" class='submit'>";
+							dropdownConnect($type,COMPUTER_TYPE,"item",$comp->fields["FK_entities"],$withtemplate,$used);
+							echo "<input type='submit' value=\"".$LANG['buttons'][9]."\" class='submit'>";
 							echo "</form>";
 						}
 					}
@@ -275,7 +279,74 @@ function showConnections($target,$ID,$withtemplate='') {
 	}
 }
 
+/**
+ * Print the computers disks
+ *
+ *@param $ID integer: Computer or template ID
+ *@param $withtemplate=''  boolean : Template or basic item.
+ *
+ *@return Nothing (call to classes members)
+ *
+ **/
+function showComputerDisks($ID,$withtemplate='') {
+	global $DB, $CFG_GLPI, $LANG;
 
+	$comp = new Computer();
+	if (!$comp->getFromDB($ID) || ! $comp->can($ID, "r"))
+		return false;
+	$canedit = $comp->can($ID, "w");
+
+	echo "<div class='center'>";
+
+	$query = "SELECT glpi_dropdown_filesystems.name as fsname, glpi_computerdisks.* 
+		FROM glpi_computerdisks
+		LEFT JOIN glpi_dropdown_filesystems ON (glpi_computerdisks.FK_filesystems = glpi_dropdown_filesystems.ID)
+		WHERE (FK_computers = '$ID')";
+
+	if ($result=$DB->query($query)){
+		echo "<table class='tab_cadre_fixe'><tr>";
+		echo "<th colspan='6'>".$LANG['computers'][8]."</th></tr>";
+		if ($DB->numrows($result)){
+			//echo "<th colspan='6'>".$LANG['computers'][8]."</th></tr>";
+			echo "<tr><th>".$LANG['common'][16]."</th>";
+			echo "<th>".$LANG['computers'][6]."</th>";
+			echo "<th>".$LANG['computers'][5]."</th>";
+			echo "<th>".$LANG['computers'][4]."</th>";
+			echo "<th>".$LANG['computers'][3]."</th>";
+			echo "<th>".$LANG['computers'][2]."</th>";
+			echo "</tr>";
+
+			initNavigateListItems(COMPUTERDISK_TYPE, $LANG['help'][25]." = ".
+				(empty($comp->fields['name']) ? "($ID)" : $comp->fields['name']));
+
+			while ($data=$DB->fetch_assoc($result)){
+				echo "<tr class='tab_bg_2'>";
+				if ($canedit){
+					echo "<td><a href='computerdisk.form.php?ID=".$data['ID']."'>".$data['name'].(empty($data['name'])?$data['ID']:"")."</a></td>";
+				} else {
+						echo "<td>".$data['name'].(empty($data['name'])?$data['ID']:"")."</td>";
+				}
+				echo "<td>".$data['device']."</td>";
+				echo "<td>".$data['mountpoint']."</td>";
+				echo "<td>".$data['fsname']."</td>";
+				echo "<td>".formatNumber($data['totalsize'], false, 0)."&nbsp;".$LANG['common'][82]."</td>";
+				echo "<td>".formatNumber($data['freesize'], false, 0)."&nbsp;".$LANG['common'][82]."</td>";
+
+				addToNavigateListItems(COMPUTERDISK_TYPE,$data['ID']);
+			}
+			//echo "</table>";
+		} else {
+			echo "<tr><th colspan='6'>".$LANG['search'][15]."</th></tr>";
+		}
+	if ($canedit &&!(!empty($withtemplate) && $withtemplate == 2)){
+		echo "<tr class='tab_bg_2'><th colspan='6''><a href='computerdisk.form.php?cID=$ID&amp;withtemplate=".$withtemplate."'>".$LANG['computers'][7]."</a></th></tr>";
+	}
+	echo "</table>";
+	}
+	echo "</div><br>";
+
+
+}
 
 
 ?>
