@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: contact.function.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: contact.function.php 8026 2009-02-28 16:50:46Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -58,8 +58,9 @@ function showEnterpriseContact($instID) {
 	$contact=new Contact();
 	$canedit=$contact->can($instID,'w');
 
-	$query = "SELECT glpi_contact_enterprise.ID as ID, glpi_enterprises.ID as entID, glpi_enterprises.name as name, glpi_enterprises.website as website, glpi_enterprises.fax as fax, "
-		. " glpi_enterprises.phonenumber as phone, glpi_enterprises.type as type, glpi_enterprises.deleted as deleted, glpi_entities.ID AS entity"
+	$query = "SELECT glpi_contact_enterprise.ID as ID, glpi_enterprises.ID as entID, glpi_enterprises.name as name, 
+			glpi_enterprises.website as website, glpi_enterprises.fax as fax, glpi_enterprises.phonenumber as phone,
+			glpi_enterprises.type as type, glpi_enterprises.deleted as deleted, glpi_entities.ID AS entity"
 		. " FROM glpi_contact_enterprise, glpi_enterprises "
 		. " LEFT JOIN glpi_entities ON (glpi_entities.ID=glpi_enterprises.FK_entities) "
 		. " WHERE glpi_contact_enterprise.FK_contact = '$instID' AND glpi_contact_enterprise.FK_enterprise = glpi_enterprises.ID"
@@ -72,37 +73,41 @@ function showEnterpriseContact($instID) {
 
 	echo "<form method='post' action=\"".$CFG_GLPI["root_doc"]."/front/contact.form.php\">";
 	echo "<br><br><div class='center'><table class='tab_cadre_fixe'>";
-	echo "<tr><th colspan='7'>".$LANG["financial"][65].":</th></tr>";
-	echo "<tr><th>".$LANG["financial"][26]."</th>";
-	echo "<th>".$LANG["entity"][0]."</th>";
-	echo "<th>".$LANG["financial"][79]."</th>";
-	echo "<th>".$LANG["help"][35]."</th>";
-	echo "<th>".$LANG["financial"][30]."</th>";
-	echo "<th>".$LANG["financial"][45]."</th>";
+	echo "<tr><th colspan='7'>".$LANG['financial'][65].":</th></tr>";
+	echo "<tr><th>".$LANG['financial'][26]."</th>";
+	echo "<th>".$LANG['entity'][0]."</th>";
+	echo "<th>".$LANG['financial'][79]."</th>";
+	echo "<th>".$LANG['help'][35]."</th>";
+	echo "<th>".$LANG['financial'][30]."</th>";
+	echo "<th>".$LANG['financial'][45]."</th>";
 	echo "<th>&nbsp;</th></tr>";
 
 	$used=array();
-	while ($data= $DB->fetch_array($result)) {
-		$ID=$data["ID"];
-		$used[$data["entID"]]=$data["entID"];
-		$website=$data["website"];
-		if (!empty($website)){
+	if ($number>0){
+		initNavigateListItems(ENTERPRISE_TYPE,$LANG['common'][18]." = ".$contact->fields['name']);
+		while ($data= $DB->fetch_array($result)) {
+			$ID=$data["ID"];
+			addToNavigateListItems(ENTERPRISE_TYPE,$data["entID"]);
+			$used[$data["entID"]]=$data["entID"];
 			$website=$data["website"];
-			if (!ereg("https*://",$website)) $website="http://".$website;
-			$website="<a target=_blank href='$website'>".$data["website"]."</a>";
+			if (!empty($website)){
+				$website=$data["website"];
+				if (!preg_match("?https*://?",$website)) $website="http://".$website;
+				$website="<a target=_blank href='$website'>".$data["website"]."</a>";
+			}
+			echo "<tr class='tab_bg_1".($data["deleted"]?"_2":"")."'>";
+			echo "<td class='center'><a href='".$CFG_GLPI["root_doc"]."/front/enterprise.form.php?ID=".$data["entID"]."'>".getDropdownName("glpi_enterprises",$data["entID"])."</a></td>";
+			echo "<td class='center'>".getDropdownName("glpi_entities",$data["entity"])."</td>";
+			echo "<td class='center'>".getDropdownName("glpi_dropdown_enttype",$data["type"])."</td>";
+			echo "<td align='center'  width='100'>".$data["phone"]."</td>";
+			echo "<td align='center'  width='100'>".$data["fax"]."</td>";
+			echo "<td class='center'>".$website."</td>";
+			echo "<td align='center' class='tab_bg_2'>";
+			if ($canedit) 
+				echo "<a href='".$CFG_GLPI["root_doc"]."/front/contact.form.php?deleteenterprise=deleteenterprise&amp;ID=$ID&amp;cID=$instID'><strong>".$LANG['buttons'][6]."</strong></a>";
+			else echo "&nbsp;";
+			echo "</td></tr>";
 		}
-		echo "<tr class='tab_bg_1".($data["deleted"]?"_2":"")."'>";
-		echo "<td class='center'><a href='".$CFG_GLPI["root_doc"]."/front/enterprise.form.php?ID=".$data["entID"]."'>".getDropdownName("glpi_enterprises",$data["entID"])."</a></td>";
-		echo "<td class='center'>".getDropdownName("glpi_entities",$data["entity"])."</td>";
-		echo "<td class='center'>".getDropdownName("glpi_dropdown_enttype",$data["type"])."</td>";
-		echo "<td align='center'  width='100'>".$data["phone"]."</td>";
-		echo "<td align='center'  width='100'>".$data["fax"]."</td>";
-		echo "<td class='center'>".$website."</td>";
-		echo "<td align='center' class='tab_bg_2'>";
-		if ($canedit) 
-			echo "<a href='".$_SERVER['PHP_SELF']."?deleteenterprise=deleteenterprise&amp;ID=$ID&amp;cID=$instID'><strong>".$LANG["buttons"][6]."</strong></a>";
-		else echo "&nbsp;";
-		echo "</td></tr>";
 	}
 	if ($canedit){
 		if ($contact->fields["recursive"]) {
@@ -118,7 +123,7 @@ function showEnterpriseContact($instID) {
 			} else {
 				dropdown("glpi_enterprises","entID",1,$contact->fields["FK_entities"],$used);
 			}
-			echo "&nbsp;&nbsp;<input type='submit' name='addenterprise' value=\"".$LANG["buttons"][8]."\" class='submit'>";
+			echo "&nbsp;&nbsp;<input type='submit' name='addenterprise' value=\"".$LANG['buttons'][8]."\" class='submit'>";
 			echo "</div>";
 			echo "</td><td>&nbsp;</td><td>&nbsp;</td>";
 			echo "</tr>";
