@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: cron.class.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: cron.class.php 8263 2009-05-07 13:50:03Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -102,7 +102,7 @@ class Cron {
 	 * Constructor
 	 * @param $taches  task array for manual use
 	 **/
-	function Cron($taches=array()){
+	function __construct($taches=array()){
 		global $CFG_GLPI;
 		if(count($taches)>0){
 			$this->taches=$taches;
@@ -205,11 +205,17 @@ class Cron {
 		if ($this->touch($lock, $this->taches[$tache])) {
 			// preparer la tache
 			$this->timer('tache');
-
+		
 			$fonction = 'cron_' . $tache;
 
 			$fct_trouve=false;
-			if (!function_exists($fonction)){
+
+			$expl = explode('_',$tache);
+			if ($expl[0]=='plugin' && isset($expl[1])) {
+				// Plugin case / Load hook
+				usePlugin($expl[1],true);
+			}
+			else if (!function_exists($fonction)){
 				// pas trouvé de fonction -> inclusion de la fonction 
 				if(file_exists(GLPI_ROOT.'/inc/'.$tache.'.function.php')) include_once(GLPI_ROOT.'/inc/'.$tache.'.function.php');
 				if(file_exists(GLPI_ROOT.'/inc/'.$tache.'.class.php')) include_once(GLPI_ROOT.'/inc/'.$tache.'.class.php');
@@ -230,19 +236,19 @@ class Cron {
 					if ($code_de_retour < 0) {
 						@touch($lock, (0 - $code_de_retour));
 					} else {// Log Event 
-//						logEvent("-1", "system", 3, "cron", $tache." (" . $this->timer('tache') . ") ".$LANG["log"][45] );
-						logInFile("cron","$tache Successfull (" . $this->timer('tache') . ")\n");
+//						logEvent("-1", "system", 3, "cron", $tache." (" . $this->timer('tache') . ") ".$LANG['log'][45] );
+						logInFile("cron","$tache task was done (" . $this->timer('tache') . ")\n");
 					}
 				} else {
 					logInFile("cron","$tache Nothing to do (" . $this->timer('tache') . ")\n");
-				}
+				} 
 
-			} else {echo "Erreur fonction manquante";}
+			} else {
+				logInFile("cron","Can't run task ($tache: missing function $fonction)\n");
+			}
 
 
-
-
-		}
+		} // touch
 
 		// relacher le lock mysql
 		$this->release_lock('cron');
