@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: db.function.php 7876 2009-01-23 15:50:37Z moyo $
+ * @version $Id: db.function.php 9094 2009-10-08 19:44:41Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -47,8 +47,8 @@ if (!defined('GLPI_ROOT')){
  */
 function countElementsInTable($table,$condition=""){
 	global $DB;
-	$query="SELECT count(*) AS cpt
-		FROM `$table`";
+	$query="SELECT count(*) AS cpt 
+		FROM $table";
 	if (!empty($condition)){
 		$query.=" WHERE $condition ";
 	}
@@ -91,7 +91,7 @@ function countElementsInTableForEntity($table,$entity){
 function getAllDatasFromTable($table,$condition=""){
 	global $DB;
 	$datas=array();
-	$query="SELECT * FROM `$table` ";
+	$query="SELECT * FROM $table ";
 
 	if (!empty($condition)){
 		$query.=" WHERE $condition ";
@@ -120,13 +120,13 @@ function getTreeLeafValueName($table,$ID,$withcomments=false){
 	$name="";
 	$comments="";
 	if ($ID==0 && $table=="glpi_entities") {
-		$name = $LANG["entity"][2];
+		$name = $LANG['entity'][2];
 		
 	} else if ($ID==0 && $table=="glpi_dropdown_kbcategories") {
-		$name = $LANG["knowbase"][12];
+		$name = $LANG['knowbase'][12];
 		
 	} else {
-		$query = "SELECT *
+		$query = "SELECT * 
 			FROM `$table` 
 			WHERE (ID = '$ID')";
 		if ($result=$DB->query($query)){
@@ -159,13 +159,13 @@ function getTreeValueCompleteName($table,$ID,$withcomments=false){
 	$comments="";
 
 	if ($ID==0 && $table=="glpi_entities") {
-		$name = $LANG["entity"][2];
-
+		$name = $LANG['entity'][2];
+		
 	} else if ($ID==0 && $table=="glpi_dropdown_kbcategories") {
-		$name = $LANG["knowbase"][12];
+		$name = $LANG['knowbase'][12];
 		
 	} else {
-		$query = "SELECT *
+		$query = "SELECT * 
 			FROM `$table` 
 			WHERE (ID = '$ID')";
 		if ($result=$DB->query($query)){
@@ -200,8 +200,8 @@ function getTreeValueCompleteName($table,$ID,$withcomments=false){
 function getTreeValueName($table,$ID, $wholename="",$level=0){
 	global $DB,$LANG;
 
-	$query = "SELECT *
-		FROM `$table`
+	$query = "SELECT * 
+		FROM `$table` 
 		WHERE (ID = '$ID')";
 	$name="";
 
@@ -236,10 +236,14 @@ function getTreeValueName($table,$ID, $wholename="",$level=0){
  * @return array of IDs of the ancestors
  */
 function getEntityAncestors ($ID){
-	if (!isset($_SESSION['glpi_entities_ancestors'][$ID])){
-		$_SESSION['glpi_entities_ancestors'][$ID]=getAncestorsOfTreeItem("glpi_entities",$ID);
+	global $CFG_GLPI;
+
+	if (($ancestors = $CFG_GLPI['opcache']->get($ID,"GLPI_entities_ancestors"))===false) {
+		// Cache miss !
+		$ancestors=getAncestorsOfTreeItem("glpi_entities",$ID);
+		$CFG_GLPI['opcache']->save($ancestors,$ID,"GLPI_entities_ancestors");
 	}
-	return $_SESSION['glpi_entities_ancestors'][$ID];
+	return $ancestors;
 }
 
 /**
@@ -250,10 +254,14 @@ function getEntityAncestors ($ID){
  * @return array of IDs of the sons (including ID of the searched entity)
  */
 function getEntitySons ($ID){
-	if (!isset($_SESSION['glpi_entities_sons'][$ID])){
-		$_SESSION['glpi_entities_sons'][$ID]=getSonsOfTreeItem("glpi_entities",$ID);
+	global $CFG_GLPI;
+
+	if (!($sons = $CFG_GLPI['opcache']->get($ID,"GLPI_entities_sons"))) {
+		// Cache miss !
+		$sons=getSonsOfTreeItem("glpi_entities",$ID);
+		$CFG_GLPI['opcache']->save($sons,$ID,"GLPI_entities_sons");
 	}
-	return $_SESSION['glpi_entities_sons'][$ID];
+	return $sons;
 }
 
 /**
@@ -272,7 +280,7 @@ function getAncestorsOfTreeItem($table,$IDf){
 	// Get the leafs of previous founded item
 	while ($IDf>0){
 		// Get next elements
-		$query="SELECT parentID
+		$query="SELECT parentID 
 			FROM `$table` 
 			WHERE ID = '$IDf'";
 
@@ -282,8 +290,8 @@ function getAncestorsOfTreeItem($table,$IDf){
 		} else {
 			$IDf=0;
 		}
-		if ($IDf>=0&&!in_array($IDf,$id_found)){
-			$id_found[]=$IDf;
+		if (!isset($id_found[$IDf])){
+			$id_found[$IDf]=$IDf;
 		} else {
 			$IDf=0;
 		}
@@ -303,19 +311,18 @@ function getSonsOfTreeItem($table,$IDf){
 	global $DB;
 
 	// IDs to be present in the final array
-	$id_found=array($IDf);
+	$id_found[$IDf]=$IDf;
 	// current ID found to be added
 	$found=array();
 	// First request init the  varriables
-	$query="SELECT ID
+	$query="SELECT ID 
 		FROM `$table` 
 		WHERE parentID = '$IDf'
 		ORDER BY name";
-
 	if ( ($result=$DB->query($query)) && ($DB->numrows($result)>0) ){
 		while ($row=$DB->fetch_array($result)){
-			array_push($id_found,$row['ID']);
-			array_push($found,$row['ID']);
+			$id_found[$row['ID']]=$row['ID'];
+			$found[$row['ID']]=$row['ID'];
 		}
 	} else return $id_found;
 
@@ -323,15 +330,9 @@ function getSonsOfTreeItem($table,$IDf){
 	while (count($found)>0){
 		$first=true;
 		// Get next elements
-		$query="SELECT ID
+		$query="SELECT ID 
 			FROM `$table` 
-			WHERE ";
-		foreach ($found as $key => $val){
-			if (!$first) $query.=" OR ";
-			else $first=false;
-			$query.= " parentID = '$val' ";
-		}
-			
+			WHERE parentID IN ('" . implode("','",$found) . "')";
 
 		// CLear the found array
 		unset($found);
@@ -340,9 +341,9 @@ function getSonsOfTreeItem($table,$IDf){
 		$result=$DB->query($query);
 		if ($DB->numrows($result)>0){
 			while ($row=$DB->fetch_array($result)){
-				if (!in_array($row['ID'],$id_found)){
-					array_push($id_found,$row['ID']);
-					array_push($found,$row['ID']);
+				if (!isset($id_found[$row['ID']])){
+					$id_found[$row['ID']]=$row['ID'];
+					$found[$row['ID']]=$row['ID'];
 				}
 			}		
 		}
@@ -367,30 +368,24 @@ function getTreeForItem($table,$IDf){
 	// current ID found to be added
 	$found=array();
 	// First request init the  varriables
-	$query="SELECT *
+	$query="SELECT * 
 		FROM `$table` 
 		WHERE parentID = '$IDf' ORDER BY name";
 	if ( ($result=$DB->query($query)) && ($DB->numrows($result)>0) ){
 		while ($row=$DB->fetch_array($result)){
 			$id_found[$row['ID']]['parent']=$IDf;
 			$id_found[$row['ID']]['name']=$row['name'];
-			array_push($found,$row['ID']);
+			$found[$row['ID']]=$row['ID'];
 		}
-	}
+	} 
 
 	// Get the leafs of previous founded item
 	while (count($found)>0){
 		$first=true;
 		// Get next elements
-		$query="SELECT *
+		$query="SELECT * 
 			FROM `$table` 
-			WHERE ";
-		foreach ($found as $key => $val){
-			if (!$first) $query.=" OR ";
-			else $first=false;
-			$query.= " parentID = '$val' ";
-		}
-		$query.=" ORDER BY name";
+			WHERE parentID IN ('" . implode("','",$found)."') ORDER BY name";
 		// CLear the found array
 		unset($found);
 		$found=array();
@@ -398,10 +393,10 @@ function getTreeForItem($table,$IDf){
 		$result=$DB->query($query);
 		if ($DB->numrows($result)>0){
 			while ($row=$DB->fetch_array($result)){
-				if (!in_array($row['ID'],$id_found)){
+				if (!isset($id_found[$row['ID']])){
 					$id_found[$row['ID']]['parent']=$row['parentID'];
 					$id_found[$row['ID']]['name']=$row['name'];
-					array_push($found,$row['ID']);
+					$found[$row['ID']]=$row['ID'];
 				}
 			}		
 		}
@@ -535,14 +530,14 @@ function getTreeItemLevel($table,$ID){
  */
 function regenerateTreeCompleteName($table){
 	global $DB;
-	$query="SELECT ID
+	$query="SELECT ID 
 		FROM `$table`";
 	$result=$DB->query($query);
 	if ($DB->numrows($result)>0){
 		while ($data=$DB->fetch_array($result)){
 			list($name,$level)=getTreeValueName($table,$data['ID']);
-			$query="UPDATE $table 
-				SET completename='".addslashes($name)."', level='$level' 
+			$query="UPDATE `$table` 
+				SET completename='".addslashes($name)."'
 				WHERE ID='".$data['ID']."'";
 			$DB->query($query);
 		}
@@ -561,11 +556,11 @@ function regenerateTreeCompleteNameUnderID($table,$ID){
 
 	list($name,$level)=getTreeValueName($table,$ID);
 
-	$query="UPDATE $table
-		SET completename='".addslashes($name)."', level='$level'
+	$query="UPDATE `$table` 
+		SET completename='".addslashes($name)."', level='$level' 
 		WHERE ID='".$ID."'";
 	$DB->query($query);
-	$query="SELECT ID
+	$query="SELECT ID 
 		FROM `$table` 
 		WHERE parentID='$ID'";
 	$result=$DB->query($query);
@@ -590,14 +585,14 @@ function getNextItem($table,$ID,$condition="",$nextprev_item=""){
 	global $DB,$CFG_GLPI;
 
 	if (empty($nextprev_item)){
-		$nextprev_item=$CFG_GLPI["nextprev_item"];
+		$nextprev_item=$_SESSION["glpinextprev_item"];
 	}
 
 	$search=$ID;
 
 	if ($nextprev_item!="ID"){
-		$query="SELECT `".$nextprev_item."`
-			FROM `$table`
+		$query="SELECT `".$nextprev_item."` 
+			FROM `$table` 
 			WHERE ID='$ID'";
 		if ($result=$DB->query($query)){
 			if ($DB->numrows($result)>0){
@@ -611,9 +606,9 @@ function getNextItem($table,$ID,$condition="",$nextprev_item=""){
 	$LEFTJOIN='';
 	if ($table=="glpi_users"){
 		$LEFTJOIN=' LEFT JOIN glpi_users_profiles ON (glpi_users.ID = glpi_users_profiles.FK_users)';
-	}
+	}	
 
-	$query = "SELECT `$table`.ID
+	$query = "SELECT `$table`.ID 
 		FROM `$table` $LEFTJOIN
 		WHERE ( `$table`.`".$nextprev_item."` > '$search' ";
 
@@ -625,15 +620,17 @@ function getNextItem($table,$ID,$condition="",$nextprev_item=""){
 	$query.=" ) ";
 
 	if (!empty($condition)){
-		$query.=" AND $condition";
+		$query.=" AND $condition ";
 	}
 	if (in_array($table,$CFG_GLPI["deleted_tables"]))
 		$query.=" AND `$table`.deleted='0' ";
 	if (in_array($table,$CFG_GLPI["template_tables"]))
-		$query.=" AND `$table`.is_template='0' ";
+		$query.=" AND `$table`.is_template='0' ";	
 
 	// Restrict to active entities
-	if (in_array($table,$CFG_GLPI["specif_entities_tables"])){
+	if ($table=="glpi_entities") {
+		$query.=getEntitiesRestrictRequest("AND",$table,'','',true);
+	} else if (in_array($table,$CFG_GLPI["specif_entities_tables"])){
 		$query.=getEntitiesRestrictRequest("AND",$table,'','',in_array($table,$CFG_GLPI["recursive_type"]));
 	} else if ($table=="glpi_users"){
 		$query.=getEntitiesRestrictRequest("AND","glpi_users_profiles");
@@ -662,13 +659,13 @@ function getPreviousItem($table,$ID,$condition="",$nextprev_item=""){
 	global $DB,$CFG_GLPI;
 
 	if (empty($nextprev_item)){
-		$nextprev_item=$CFG_GLPI["nextprev_item"];
+		$nextprev_item=$_SESSION["glpinextprev_item"];
 	}
 
 	$search=$ID;
 	if ($nextprev_item!="ID"){
-		$query="SELECT `".$nextprev_item."`
-			FROM `$table`
+		$query="SELECT `".$nextprev_item."` 
+			FROM `$table` 
 			WHERE ID='$ID'";
 		$result=$DB->query($query);
 		if ($DB->numrows($result)>0){
@@ -681,9 +678,9 @@ function getPreviousItem($table,$ID,$condition="",$nextprev_item=""){
 	$LEFTJOIN='';
 	if ($table=="glpi_users"){
 		$LEFTJOIN=' LEFT JOIN glpi_users_profiles ON (glpi_users.ID = glpi_users_profiles.FK_users)';
-	}
+	}	
 
-	$query = "SELECT `$table`.ID
+	$query = "SELECT `$table`.ID 
 		FROM `$table` $LEFTJOIN
 		WHERE  (`$table`.`".$nextprev_item."` < '$search' ";
 
@@ -696,16 +693,18 @@ function getPreviousItem($table,$ID,$condition="",$nextprev_item=""){
 
 
 	if (!empty($condition)){
-		$query.=" AND $condition";
+		$query.=" AND $condition ";
 	}
 
 	if (in_array($table,$CFG_GLPI["deleted_tables"]))
 		$query.="AND `$table`.deleted='0'";
 	if (in_array($table,$CFG_GLPI["template_tables"]))
-		$query.="AND `$table`.is_template='0'";
+		$query.="AND `$table`.is_template='0'";	
 
 	// Restrict to active entities
-	if (in_array($table,$CFG_GLPI["specif_entities_tables"])){
+	if ($table=="glpi_entities") {
+		$query.=getEntitiesRestrictRequest("AND",$table,'','',true);
+	} else if (in_array($table,$CFG_GLPI["specif_entities_tables"])){
 		$query.=getEntitiesRestrictRequest("AND",$table,'','',in_array($table,$CFG_GLPI["recursive_type"]));
 	} else if ($table=="glpi_users"){
 		$query.=getEntitiesRestrictRequest("AND","glpi_users_profiles");
@@ -721,7 +720,7 @@ function getPreviousItem($table,$ID,$condition="",$nextprev_item=""){
 }
 
 /**
- * Format a user name
+ * Format a user name 
  *
  *@param $ID int : ID of the user.
  *@param $login string : login of the user
@@ -741,7 +740,13 @@ function formatUserName($ID,$login,$realname,$firstname,$link=0,$cut=0){
 	if (strlen($realname)>0) {
 		$temp=$realname;
 		
-		if (strlen($firstname)>0)$temp.=" ".$firstname;
+		if (strlen($firstname)>0){
+			if ($CFG_GLPI["name_display_order"]==FIRSTNAME_BEFORE){
+				$temp=$firstname." ".$temp;
+			} else {
+				$temp.=" ".$firstname;
+			}
+		}
 
 		if($cut>0&&strlen($temp) > $cut){
 			$temp=utf8_substr($temp,0,$cut);
@@ -752,7 +757,7 @@ function formatUserName($ID,$login,$realname,$firstname,$link=0,$cut=0){
 		$temp=$login;
 	}
 
-	if ($ID>0&&(strlen($temp)==0||$CFG_GLPI["view_ID"])){
+	if ($ID>0&&(strlen($temp)==0||$_SESSION["glpiview_ID"])){
 		$viewID="&nbsp;($ID)";
 	}
 
@@ -798,17 +803,21 @@ function getUserName($ID,$link=0){
 			if ($link==2){
 				$user["name"]=$username;
 				$user["link"]=$CFG_GLPI["root_doc"]."/front/user.form.php?ID=".$ID;
-				$user["comments"]=$LANG["common"][16].": ".$username."<br>";
-				$user["comments"].=$LANG["setup"][18].": ".$data["name"]."<br>";
+				$user["comments"]=$LANG['common'][16].": ".$username."<br>";
+				$user["comments"].=$LANG['setup'][18].": ".$data["name"]."<br>";
 				if (!empty($data["email"]))
-					$user["comments"].=$LANG["setup"][14].": ".$data["email"]."<br>";
+					$user["comments"].=$LANG['setup'][14].": ".$data["email"]."<br>";
 				if (!empty($data["phone"]))
-					$user["comments"].=$LANG["help"][35].": ".$data["phone"]."<br>";
+					$user["comments"].=$LANG['help'][35].": ".$data["phone"]."<br>";
 				if (!empty($data["mobile"]))
-					$user["comments"].=$LANG["common"][42].": ".$data["mobile"]."<br>";
+					$user["comments"].=$LANG['common'][42].": ".$data["mobile"]."<br>";
 				if ($data["location"]>0){
-					$user["comments"].=$LANG["common"][15].": ".getDropdownName("glpi_dropdown_locations",$data["location"])."<br>";
+					$user["comments"].=$LANG['common'][15].": ".getDropdownName("glpi_dropdown_locations",$data["location"])."<br>";
 				}
+				if ($data["title"]>0)
+					$user["comments"].=$LANG['users'][1].": ".getDropdownName("glpi_dropdown_user_titles",$data["title"])."<br>";
+				if ($data["type"]>0)
+					$user["comments"].=$LANG['users'][2].": ".getDropdownName("glpi_dropdown_user_types",$data["type"])."<br>";
 			} else {
 				$user=$username;
 			}
@@ -956,9 +965,9 @@ function autoName($objectName, $field, $isTemplate, $type,$FK_entities=-1){
 				$first = 1;
 				foreach($LINK_ID_TABLE as $t=>$table){
 					if ($t == COMPUTER_TYPE || $t == MONITOR_TYPE  || $t == NETWORKING_TYPE || $t == PERIPHERAL_TYPE || $t == PRINTER_TYPE || $t == PHONE_TYPE){
-						$query .= ($first ? "SELECT " : " UNION SELECT  ")." `$field` AS code
-							FROM `$table`
-							WHERE `$field` LIKE '$like'
+						$query .= ($first ? "SELECT " : " UNION SELECT  ")." $field AS code 
+							FROM $table 
+							WHERE $field LIKE '$like' 
 							AND deleted = '0' 
 							AND is_template = '0'";
 							if ($CFG_GLPI["autoname_entity"]&&$FK_entities>=0){
@@ -972,8 +981,8 @@ function autoName($objectName, $field, $isTemplate, $type,$FK_entities=-1){
 			} else	{
 				$table = $LINK_ID_TABLE[$type];
 				$query = "SELECT CAST(SUBSTRING($field, $pos, $len) AS unsigned) AS no 
-					FROM `$table`
-					WHERE `$field` LIKE '$like' ";
+					FROM $table 
+					WHERE $field LIKE '$like' ";
 				if ($type != INFOCOM_TYPE){
 					$query .= " AND deleted = '0' AND is_template = '0'";
 					if ($CFG_GLPI["autoname_entity"]&&$FK_entities>=0){
@@ -1037,10 +1046,34 @@ function checkEmailForUser($ID){
  *
  **/
 function formatOutputWebLink($link){
-	if (!ereg("^https?",$link)){
+	if (!preg_match("/^https?/",$link)){
 		return "http://".$link;
 	} 
 	return $link;
 }
 
+/**
+ * Add dates for request
+ *
+ * @param $field : table.field to request
+ * @param $begin date : begin date
+ * @param $end date : end date
+ *
+ * @return sql
+ */
+function getDateRequest($field,$begin, $end) {
+
+   $sql = '';
+   if (!empty($begin)) {
+         $sql .= " $field >= '$begin' ";
+   }
+   if (!empty($end)) {
+      if (!empty($sql)){
+         $sql.= " AND ";
+      }
+      $sql .= " $field <= ADDDATE('$end' , INTERVAL 1 DAY) ";
+   }
+   return " (".$sql.") ";
+}
+
 ?>
