@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: enterprise.function.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: enterprise.function.php 8026 2009-02-28 16:50:46Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -54,7 +54,10 @@ function showInfocomEnterprise($instID) {
 
 	if (!haveRight("contact_enterprise","r")) return false;
 
-	$query = "SELECT DISTINCT device_type FROM glpi_infocoms WHERE FK_enterprise = '$instID' ORDER BY device_type";
+	$query = "SELECT DISTINCT device_type 
+		FROM glpi_infocoms 
+		WHERE FK_enterprise = '$instID' 
+		ORDER BY device_type";
 
 	$result = $DB->query($query);
 	$number = $DB->numrows($result);
@@ -62,19 +65,19 @@ function showInfocomEnterprise($instID) {
 
 	echo "<br><br><div class='center'><table class='tab_cadrehov'>";
 	echo "<tr><th colspan='2'>";
-	printPagerForm($_SERVER["REQUEST_URI"]);
-	echo "</th><th colspan='3'>".$LANG["document"][19].":</th></tr>";
-	echo "<tr><th>".$LANG["common"][17]."</th>";
-	echo "<th>".$LANG["entity"][0]."</th>";
-	echo "<th>".$LANG["common"][16]."</th>";
-	echo "<th>".$LANG["common"][19]."</th>";
-	echo "<th>".$LANG["common"][20]."</th>";
+	printPagerForm();
+	echo "</th><th colspan='3'>".$LANG['document'][19].":</th></tr>";
+	echo "<tr><th>".$LANG['common'][17]."</th>";
+	echo "<th>".$LANG['entity'][0]."</th>";
+	echo "<th>".$LANG['common'][16]."</th>";
+	echo "<th>".$LANG['common'][19]."</th>";
+	echo "<th>".$LANG['common'][20]."</th>";
 	echo "</tr>";
 	$ci=new CommonItem;
 	$num=0;
 	while ($i < $number) {
 		$type=$DB->result($result, $i, "device_type");
-		if (haveTypeRight($type,"r")&&$type!=CONSUMABLE_ITEM_TYPE&&$type!=CARTRIDGE_ITEM_TYPE&&$type!=LICENSE_TYPE){
+		if (haveTypeRight($type,"r")&&$type!=CONSUMABLE_ITEM_TYPE&&$type!=CARTRIDGE_ITEM_TYPE&&$type!=SOFTWARELICENSE_TYPE){
 			$query = "SELECT ".$LINK_ID_TABLE[$type].".* "
 				." FROM glpi_infocoms "
 				." INNER JOIN ".$LINK_ID_TABLE[$type]." ON (".$LINK_ID_TABLE[$type].".ID = glpi_infocoms.FK_device) "
@@ -85,19 +88,19 @@ function showInfocomEnterprise($instID) {
 			$result_linked=$DB->query($query);
 			$nb=$DB->numrows($result_linked);
 			$ci->setType($type);
-			if ($nb>$_SESSION["glpilist_limit"] && isset($SEARCH_PAGES["$type"])) {
+			if ($nb>$_SESSION['glpilist_limit'] && isset($SEARCH_PAGES["$type"])) {
 				
 				echo "<tr class='tab_bg_1'>";
 				echo "<td class='center'>".$ci->getType()."<br />$nb</td>";
 				echo "<td class='center' colspan='2'><a href='"
 					. $CFG_GLPI["root_doc"]."/".$SEARCH_PAGES["$type"] . "?" . rawurlencode("contains[0]") . "=" . rawurlencode('$$$$'.$instID) . "&" . rawurlencode("field[0]") . "=53&sort=80&order=ASC&deleted=0&start=0"
-					. "'>" . $LANG["reports"][57]."</a></td>";
+					. "'>" . $LANG['reports'][57]."</a></td>";
 				
 				echo "<td class='center'>-</td><td class='center'>-</td></tr>";		
 			} else if ($nb){
 				for ($prem=true;$data=$DB->fetch_assoc($result_linked);$prem=false){
 					$ID="";
-					if($CFG_GLPI["view_ID"]||empty($data["name"])) $ID= " (".$data["ID"].")";
+					if($_SESSION["glpiview_ID"]||empty($data["name"])) $ID= " (".$data["ID"].")";
 					$name= "<a href=\"".$CFG_GLPI["root_doc"]."/".$INFOFORM_PAGES[$type]."?ID=".$data["ID"]."\">".$data["name"]."$ID</a>";
 
 					echo "<tr class='tab_bg_1'>";
@@ -151,31 +154,36 @@ function showAssociatedContact($instID) {
 
 
 	echo "<br><div class='center'><table class='tab_cadre_fixe'>";
-	echo "<tr><th colspan='9'>".$LANG["financial"][46].":</th></tr>";
-	echo "<tr><th>".$LANG["common"][16]."</th><th>".$LANG["entity"][0]."</th><th>".$LANG["help"][35]."</th>";
-	echo "<th>".$LANG["help"][35]." 2</th><th>".$LANG["common"][42]."</th><th>".$LANG["financial"][30]."</th>";
-	echo "<th>".$LANG["setup"][14]."</th><th>".$LANG["common"][17]."</th>";
+	echo "<tr><th colspan='9'>".$LANG['financial'][46].":</th></tr>";
+	echo "<tr><th>".$LANG['common'][16]."</th><th>".$LANG['entity'][0]."</th><th>".$LANG['help'][35]."</th>";
+	echo "<th>".$LANG['help'][35]." 2</th><th>".$LANG['common'][42]."</th><th>".$LANG['financial'][30]."</th>";
+	echo "<th>".$LANG['setup'][14]."</th><th>".$LANG['common'][17]."</th>";
 	echo "<th>&nbsp;</th></tr>";
 
 	$used=array();
-	if ($number) while ($data=$DB->fetch_array($result)) {
-		$ID=$data["ID_ent"];
-		$used[$data["ID"]]=$data["ID"];
-		echo "<tr class='tab_bg_1".($data["deleted"]?"_2":"")."'>";
-		echo "<td class='center'><a href='".$CFG_GLPI["root_doc"]."/front/contact.form.php?ID=".$data["ID"]."'>".$data["name"]." ".$data["firstname"]."</a></td>";
-		echo "<td align='center'  width='100'>".getDropdownName("glpi_entities",$data["entity"])."</td>";
-		echo "<td align='center'  width='100'>".$data["phone"]."</td>";
-		echo "<td align='center'  width='100'>".$data["phone2"]."</td>";
-		echo "<td align='center'  width='100'>".$data["mobile"]."</td>";
-		echo "<td align='center'  width='100'>".$data["fax"]."</td>";
-		echo "<td class='center'><a href='mailto:".$data["email"]."'>".$DB->result($result, $i, "glpi_contacts.email")."</a></td>";
-		echo "<td class='center'>".getDropdownName("glpi_dropdown_contact_type",$data["type"])."</td>";
-		echo "<td align='center' class='tab_bg_2'>";
-		if ($canedit)
-			echo "<a href='".$_SERVER['PHP_SELF']."?deletecontact=deletecontact&amp;ID=$ID&amp;eID=$instID'><strong>".$LANG["buttons"][6]."</strong></a>";
-		else echo "&nbsp;";
-		echo "</td></tr>";
-		$i++;
+	if ($number) {
+		initNavigateListItems(CONTACT_TYPE,$LANG['financial'][26]." = ".$enterprise->fields['name']);
+
+		while ($data=$DB->fetch_array($result)) {
+			$ID=$data["ID_ent"];
+			$used[$data["ID"]]=$data["ID"];
+			addToNavigateListItems(CONTACT_TYPE,$data["ID"]);
+			echo "<tr class='tab_bg_1".($data["deleted"]?"_2":"")."'>";
+			echo "<td class='center'><a href='".$CFG_GLPI["root_doc"]."/front/contact.form.php?ID=".$data["ID"]."'>".$data["name"]." ".$data["firstname"]."</a></td>";
+			echo "<td align='center'  width='100'>".getDropdownName("glpi_entities",$data["entity"])."</td>";
+			echo "<td align='center'  width='100'>".$data["phone"]."</td>";
+			echo "<td align='center'  width='100'>".$data["phone2"]."</td>";
+			echo "<td align='center'  width='100'>".$data["mobile"]."</td>";
+			echo "<td align='center'  width='100'>".$data["fax"]."</td>";
+			echo "<td class='center'><a href='mailto:".$data["email"]."'>".$DB->result($result, $i, "glpi_contacts.email")."</a></td>";
+			echo "<td class='center'>".getDropdownName("glpi_dropdown_contact_type",$data["type"])."</td>";
+			echo "<td align='center' class='tab_bg_2'>";
+			if ($canedit)
+				echo "<a href='".$CFG_GLPI["root_doc"]."/front/enterprise.form.php?deletecontact=deletecontact&amp;ID=$ID&amp;eID=$instID'><strong>".$LANG['buttons'][6]."</strong></a>";
+			else echo "&nbsp;";
+			echo "</td></tr>";
+			$i++;
+		}
 	}
 
 	echo "</table><br>"    ;
@@ -188,7 +196,7 @@ function showAssociatedContact($instID) {
 		if ($nb>count($used)) {
 			echo "<form method='post' action=\"".$CFG_GLPI["root_doc"]."/front/enterprise.form.php\">";
 			echo "<table  class='tab_cadre_fixe'>";
-			echo "<tr class='tab_bg_1'><th colspan='2'>".$LANG["financial"][33]."</tr><tr><td class='tab_bg_2' align='center'>";
+			echo "<tr class='tab_bg_1'><th colspan='2'>".$LANG['financial'][33]."</tr><tr><td class='tab_bg_2' align='center'>";
 			echo "<input type='hidden' name='eID' value='$instID'>";
 			if ($enterprise->fields["recursive"]) {
 				dropdown("glpi_contacts","cID",1,getEntitySons($enterprise->fields["FK_entities"]),$used);
@@ -196,7 +204,7 @@ function showAssociatedContact($instID) {
 				dropdown("glpi_contacts","cID",1,$enterprise->fields["FK_entities"],$used);
 			}
 			echo "</td><td align='center' class='tab_bg_2'>";
-			echo "<input type='submit' name='addcontact' value=\"".$LANG["buttons"][8]."\" class='submit'>";
+			echo "<input type='submit' name='addcontact' value=\"".$LANG['buttons'][8]."\" class='submit'>";
 			echo "</td></tr>";
 		}
 		echo "</table></form>";
@@ -227,7 +235,7 @@ function addContactEnterprise($eID,$cID){
 function deleteContactEnterprise($ID){
 
 	global $DB;
-	$query="DELETE FROM glpi_contact_enterprise WHERE ID= '$ID';";
+	$query="DELETE FROM glpi_contact_enterprise WHERE ID = '$ID';";
 	$result = $DB->query($query);
 }
 
@@ -250,10 +258,10 @@ function getEnterpriseLinks($value,$withname=false){
 
 		if (!empty($ent->fields['website'])){
 			$ret.= "&nbsp;&nbsp;";
-			$ret.= "<a href='".formatOutputWebLink($ent->fields['website'])."' target='_blank'><img src='".$CFG_GLPI["root_doc"]."/pics/web.png' class='middle' alt='".$LANG["common"][4]."' title='".$LANG["common"][4]."' ></a>";
+			$ret.= "<a href='".formatOutputWebLink($ent->fields['website'])."' target='_blank'><img src='".$CFG_GLPI["root_doc"]."/pics/web.png' class='middle' alt='".$LANG['common'][4]."' title='".$LANG['common'][4]."' ></a>";
 		}
 		$ret.= "&nbsp;&nbsp;&nbsp;&nbsp;";
-		$ret.= "<a href='".$CFG_GLPI["root_doc"]."/front/enterprise.form.php?ID=".$ent->fields['ID']."'><img src='".$CFG_GLPI["root_doc"]."/pics/edit.png' class='middle' alt='".$LANG["buttons"][14]."' title='".$LANG["buttons"][14]."'></a>";
+		$ret.= "<a href='".$CFG_GLPI["root_doc"]."/front/enterprise.form.php?ID=".$ent->fields['ID']."'><img src='".$CFG_GLPI["root_doc"]."/pics/edit.png' class='middle' alt='".$LANG['buttons'][14]."' title='".$LANG['buttons'][14]."'></a>";
 	}
 
 	return $ret;
