@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: entity.function.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: entity.function.php 9132 2009-10-21 20:18:26Z walid $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -41,39 +41,40 @@ if (!defined('GLPI_ROOT')){
  * Show users of an entity
  *
  * @param $target string : where to go on action
- * @param $ID integer : enterprise ID
+ * @param $ID integer : entity ID
  */
 function showEntityUser($target,$ID){
 	global $DB,$CFG_GLPI, $LANG;
 	
 	if (!haveRight("entity","r")||!haveRight("user","r"))	return false;
 
-	$canedit=haveRight("entity","w");
+	$entity=new Entity();
+
+	//$canedit=haveRight("entity","w");
+	$canedit = $entity->can($ID,"w");
 	$canshowuser=haveRight("user","r");
 	$nb_per_line=3;
 	if ($canedit) $headerspan=$nb_per_line*2;
 	else $headerspan=$nb_per_line;
+	$rand=mt_rand();
+	echo "<form name='entityuser_form$rand' id='entityuser_form$rand' method='post' action=\"$target\">";
 
-	echo "<form name='entityuser_form' id='entityuser_form' method='post' action=\"$target\">";
-
-	$entity=new Entity();
-	
 	if ($entity->getFromDB($ID)||$ID==0){
 		if ($canedit){
 	
 			echo "<div class='center'>";
 			echo "<table  class='tab_cadre_fixe'>";
-			echo "<tr class='tab_bg_1'><th colspan='5'>".$LANG["setup"][603]."</tr><tr><td class='tab_bg_2' align='center'>";
+			echo "<tr class='tab_bg_1'><th colspan='5'>".$LANG['setup'][603]."</tr><tr><td class='tab_bg_2' align='center'>";
 			echo "<input type='hidden' name='FK_entities' value='$ID'>";
 			dropdownAllUsers("FK_users",0,1);
 			echo "</td><td align='center' class='tab_bg_2'>";
-			echo $LANG["profiles"][22].":";
+			echo $LANG['profiles'][22].":";
 			dropdownUnderProfiles("FK_profiles");
 			echo "</td><td align='center' class='tab_bg_2'>";
-			echo $LANG["profiles"][28].":";
+			echo $LANG['profiles'][28].":";
 			dropdownYesNo("recursive",0);
 			echo "</td><td align='center' class='tab_bg_2'>";
-			echo "<input type='submit' name='adduser' value=\"".$LANG["buttons"][8]."\" class='submit'>";
+			echo "<input type='submit' name='adduser' value=\"".$LANG['buttons'][8]."\" class='submit'>";
 			echo "</td></tr>";
 	
 			echo "</table></div><br>";
@@ -82,7 +83,7 @@ function showEntityUser($target,$ID){
 	
 	
 	
-		echo "<div class='center'><table class='tab_cadrehov'><tr><th colspan='$headerspan'>".$LANG["Menu"][14]." (D=".$LANG["profiles"][29].", R=".$LANG["profiles"][28].")</th></tr>";
+		echo "<div class='center'><table class='tab_cadrehov'><tr><th colspan='$headerspan'>".$LANG['Menu'][14]." (D=".$LANG['profiles'][29].", R=".$LANG['profiles'][28].")</th></tr>";
 
 
 
@@ -142,7 +143,7 @@ function showEntityUser($target,$ID){
 					echo "</tr>";
 
 				} else {
-					echo "<tr colspan='$headerspan'>".$LANG["common"][54]."</tr>";
+					echo "<tr colspan='$headerspan'>".$LANG['common'][54]."</tr>";
 				}
 
 
@@ -155,12 +156,12 @@ function showEntityUser($target,$ID){
 	
 		if ($canedit){
 			echo "<div class='center'>";
-			echo "<table width='80%'>";
-			echo "<tr><td><img src=\"".$CFG_GLPI["root_doc"]."/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markAllRows('entityuser_form') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=all'>".$LANG["buttons"][18]."</a></td>";
+			echo "<table width='80%' class='tab_glpi'>";
+			echo "<tr><td><img src=\"".$CFG_GLPI["root_doc"]."/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markCheckboxes('entityuser_form$rand') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=all'>".$LANG['buttons'][18]."</a></td>";
 	
-			echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkAllRows('entityuser_form') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=none'>".$LANG["buttons"][19]."</a>";
+			echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkCheckboxes('entityuser_form$rand') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=none'>".$LANG['buttons'][19]."</a>";
 			echo "</td><td align='left' width='80%'>";
-			echo "<input type='submit' name='deleteuser' value=\"".$LANG["buttons"][6]."\" class='submit'>";
+			echo "<input type='submit' name='deleteuser' value=\"".$LANG['buttons'][6]."\" class='submit'>";
 			echo "</td>";
 			echo "</table>";
 	
@@ -208,13 +209,13 @@ function deleteUserProfileEntity($ID){
 
 	global $DB;
 
-	$query="SELECT FK_users FROM glpi_users_profiles WHERE ID= '$ID';";
+	$query="SELECT FK_users FROM glpi_users_profiles WHERE ID = '$ID';";
 	$result = $DB->query($query);
 	$data=$DB->fetch_assoc($result);
 	$user=new User();
 	$user->cleanCache($data['FK_users']);
 	
-	$query="DELETE FROM glpi_users_profiles WHERE ID= '$ID';";
+	$query="DELETE FROM glpi_users_profiles WHERE ID = '$ID';";
 	$result = $DB->query($query);
 }
 
@@ -227,8 +228,32 @@ function deleteUserProfileEntity($ID){
 function moveUserProfileEntity($ID,$FK_entities){
 
 	global $DB;
-	$query="UPDATE glpi_users_profiles SET FK_entities='$FK_entities' WHERE ID= '$ID';";
+	$query="UPDATE glpi_users_profiles SET FK_entities='$FK_entities' WHERE ID = '$ID';";
 	return $DB->query($query);
 }
 
+
+
+function getEntityIDByField($field,$value)
+{
+	global $DB;
+	$sql = "SELECT FK_entities FROM glpi_entities_data WHERE ".$field."='".$value."'";
+	
+	$result = $DB->query($sql);
+	if ($DB->numrows($result)==1)
+		return $DB->result($result,0,"FK_entities");
+	else
+		return -1;	
+}
+
+function getEntityIDByDN($value)
+{
+	return getEntityIDByField("ldap_dn",$value);
+}
+
+function getEntityIDByTag($value)
+{
+	return getEntityIDByField("tag",$value);
+}
+
 ?>
\ No newline at end of file
