@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: export.function.php 7870 2009-01-20 20:24:42Z moyo $
+ * @version $Id: export.function.php 8363 2009-06-08 20:21:48Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -110,10 +110,12 @@ function displaySearchItem($type,$value,&$num,$row,$extraparam=''){
 		case PDF_OUTPUT_LANDSCAPE : //pdf
 		case PDF_OUTPUT_PORTRAIT :
 			global $PDF_ARRAY,$PDF_HEADER;
+			$value = weblink_extract($value);
 			$PDF_ARRAY[$row][$num]=utf8_decode(html_clean($value));
 			break;
 		case SYLK_OUTPUT : //sylk
 			global $SYLK_ARRAY,$SYLK_HEADER,$SYLK_SIZE;
+			$value = weblink_extract($value);
 			$SYLK_ARRAY[$row][$num]=sylk_clean($value);
 			$SYLK_SIZE[$num]=max($SYLK_SIZE[$num],strlen($SYLK_ARRAY[$row][$num]));
 
@@ -121,10 +123,11 @@ function displaySearchItem($type,$value,&$num,$row,$extraparam=''){
 //			$out.= "C;N;K\"".sylk_clean($value)."\"\n"; 
 			break;
       		case CSV_OUTPUT : //csv
+			$value = weblink_extract($value);
             		$out="\"".csv_clean($value)."\";";
             		break;
 		default :
-			$out="<td $extraparam>".$value."</td>\n";
+			$out="<td $extraparam valign='top'>".$value."</td>\n";
 			break;
 	}
 	$num++;
@@ -153,7 +156,7 @@ function displaySearchError($type){
         	case CSV_OUTPUT : //csv
             		break;
 		default :
-			$out= "<div class='center'><strong>".$LANG["search"][15]."</strong></div>\n";
+			$out= "<div class='center'><strong>".$LANG['search'][15]."</strong></div>\n";
 			break;
 	}
 	return $out;
@@ -177,7 +180,7 @@ function displaySearchFooter($type,$title=""){
 			global $PDF_HEADER,$PDF_ARRAY;
 			$pdf= new Cezpdf('a4','landscape');
 			$pdf->selectFont(GLPI_ROOT."/lib/ezpdf/fonts/Helvetica.afm");
-			$pdf->ezStartPageNumbers(750,10,10,'left',"GLPI PDF export - ".convDate(date("Y-m-d"))." - ".count($PDF_ARRAY)." ".utf8_decode($LANG["pager"][5])."- {PAGENUM}/{TOTALPAGENUM}");
+			$pdf->ezStartPageNumbers(750,10,10,'left',"GLPI PDF export - ".convDate(date("Y-m-d"))." - ".count($PDF_ARRAY)." ".utf8_decode($LANG['pager'][5])."- {PAGENUM}/{TOTALPAGENUM}");
 			$options=array('fontSize'=>8,'colGap'=>2,'maxWidth'=>800,'titleFontSize'=>8,);
 			$pdf->ezTable($PDF_ARRAY,$PDF_HEADER,utf8_decode($title),$options);
 			$pdf->ezStream();
@@ -187,7 +190,7 @@ function displaySearchFooter($type,$title=""){
 			global $PDF_HEADER,$PDF_ARRAY;
 			$pdf= new Cezpdf('a4','portrait');
 			$pdf->selectFont(GLPI_ROOT."/lib/ezpdf/fonts/Helvetica.afm");
-			$pdf->ezStartPageNumbers(550,10,10,'left',"GLPI PDF export - ".convDate(date("Y-m-d"))." - ".count($PDF_ARRAY)." ".utf8_decode($LANG["pager"][5])."- {PAGENUM}/{TOTALPAGENUM}");
+			$pdf->ezStartPageNumbers(550,10,10,'left',"GLPI PDF export - ".convDate(date("Y-m-d"))." - ".count($PDF_ARRAY)." ".utf8_decode($LANG['pager'][5])."- {PAGENUM}/{TOTALPAGENUM}");
 			$options=array('fontSize'=>8,'colGap'=>2,'maxWidth'=>565,'titleFontSize'=>8,);
 			$pdf->ezTable($PDF_ARRAY,$PDF_HEADER,utf8_decode($title),$options);
 			$pdf->ezStream();
@@ -385,13 +388,29 @@ function csv_clean($value){
 	if (get_magic_quotes_runtime()) $value=stripslashes($value);
 //	$value=preg_replace('/\x0A/',' ',$value);
 //	$value=preg_replace('/\x0D/',NULL,$value);
-	$value=ereg_replace("\"","''",$value);
+	$value=str_replace("\"","''",$value);
 //	$value=str_replace(';', ',', $value);
 	$value=html_clean($value);
 
 	return $value;
 }
 
+/**
+ * Extract url from web link
+ *
+ *
+ *@param $value string value
+ *
+ *@return clean value
+ *
+ **/
+function weblink_extract($value){
+
+        $value = preg_replace('/<a\s+href\="(https?\:\/\/[^"]+)"[^>]*>[^<]*<\/a>/i', '$1', $value);
+
+        return $value;
+}
+
 /**
  * Clean display value for sylk export
  *
@@ -407,7 +426,7 @@ function sylk_clean($value){
 	if (get_magic_quotes_runtime()) $value=stripslashes($value);
 	$value=preg_replace('/\x0A/',' ',$value);
 	$value=preg_replace('/\x0D/',NULL,$value);
-	$value=ereg_replace("\"","''",$value);
+	$value=str_replace("\"","''",$value);
 	$value=str_replace(';', ';;', $value);
 	$value=html_clean($value);
 
