@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: group.function.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: group.function.php 8223 2009-04-22 14:40:54Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -47,19 +47,24 @@ function showGroupDevice($ID){
 	global $DB,$CFG_GLPI, $LANG,$LINK_ID_TABLE,$INFOFORM_PAGES;
 
 	$ci=new CommonItem();
-	echo "<div class='center'><table class='tab_cadre'><tr><th>".$LANG["common"][17]."</th><th>".$LANG["common"][16]."</th></tr>";
-	foreach ($CFG_GLPI["linkuser_types"] as $type){
-		$query="SELECT * from ".$LINK_ID_TABLE[$type]." WHERE FK_groups='$ID'";
+	echo "<div class='center'><table class='tab_cadre'><tr><th>".$LANG['common'][17]."</th>" .
+			"<th>".$LANG['common'][16]."</th><th>".$LANG['entity'][0]."</th></tr>";
+	foreach ($CFG_GLPI["linkgroup_types"] as $type){
+		$query="SELECT * 
+			FROM ".$LINK_ID_TABLE[$type]." 
+			WHERE FK_groups='$ID' " .
+			getEntitiesRestrictRequest(" AND ", $LINK_ID_TABLE[$type], '', '', isset($CFG_GLPI["recursive_type"][$type]));
 		$result=$DB->query($query);
 		if ($DB->numrows($result)>0){
 			$ci->setType($type);
 			$type_name=$ci->getType();
 			$cansee=haveTypeRight($type,"r");
 			while ($data=$DB->fetch_array($result)){
-				$link=$data["name"];
+				$link=($data["name"] ? $data["name"] : "(".$data["ID"].")");
 				if ($cansee) $link="<a href='".$CFG_GLPI["root_doc"]."/".$INFOFORM_PAGES[$type]."?ID=".$data["ID"]."'>".$link."</a>";
 				$linktype="";
-				echo "<tr class='tab_bg_1'><td>$type_name</td><td>$link</td></tr>";
+				echo "<tr class='tab_bg_1'><td>$type_name</td><td>$link</td>";
+				echo "<td>".getDropdownName("glpi_entities",$data['FK_entities'])."</td></tr>";
 			}
 		}
 
@@ -78,22 +83,25 @@ function showGroupUsers($target,$ID){
 
 	if (!haveRight("user","r")||!haveRight("group","r"))	return false;
 
-	$canedit=haveRight("group","w");
-
-	$nb_per_line=3;
-	if ($canedit) $headerspan=$nb_per_line*2;
-	else $headerspan=$nb_per_line;
-
-
 	$group=new Group();
-
+	$rand=mt_rand();
 	if ($group->getFromDB($ID)){
+		$canedit=$group->can($ID,"w");
 	
+		$nb_per_line=3;
 		if ($canedit) {
-			echo "<form name='groupuser_form' id='groupuser_form' method='post' action=\"$target\">";
+			$headerspan=$nb_per_line*2;	
+			echo "<form name='groupuser_form$rand' id='groupuser_form$rand' method='post' action=\"$target\">";
+		} else {
+			$headerspan=$nb_per_line;
 		}
-		echo "<div class='center'><table class='tab_cadrehov'><tr><th colspan='$headerspan'>".$LANG["Menu"][14]."</th></tr>";
-		$query="SELECT glpi_users.*,glpi_users_groups.ID as linkID from glpi_users_groups LEFT JOIN glpi_users ON (glpi_users.ID = glpi_users_groups.FK_users) WHERE glpi_users_groups.FK_groups='$ID' ORDER BY glpi_users.name, glpi_users.realname, glpi_users.firstname";
+	
+		echo "<div class='center'><table class='tab_cadrehov'><tr><th colspan='$headerspan'>".$LANG['Menu'][14]."</th></tr>";
+		$query="SELECT glpi_users.*, glpi_users_groups.ID as linkID 
+			FROM glpi_users_groups 
+			LEFT JOIN glpi_users ON (glpi_users.ID = glpi_users_groups.FK_users) 
+			WHERE glpi_users_groups.FK_groups='$ID'
+			ORDER BY glpi_users.name, glpi_users.realname, glpi_users.firstname";
 	
 		$used = array();
 
@@ -116,7 +124,7 @@ function showGroupUsers($target,$ID){
 	
 				$used[$data["ID"]]=$data["ID"];
 				
-				echo "<td>";
+				echo "<td class='tab_bg_1".($data["deleted"]=='1'?"_2":"")."'>";
 				echo formatUserName($data["ID"],$data["name"],$data["realname"],$data["firstname"],1);
 				echo "</td>";
 				$i++;
@@ -134,28 +142,36 @@ function showGroupUsers($target,$ID){
 		if ($canedit){
 
 			echo "<div class='center'>";
-			echo "<table width='80%'>";
-			echo "<tr><td><img src=\"".$CFG_GLPI["root_doc"]."/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markAllRows('groupuser_form') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=all'>".$LANG["buttons"][18]."</a></td>";
+			echo "<table width='80%' class='tab_glpi'>";
+			echo "<tr><td><img src=\"".$CFG_GLPI["root_doc"]."/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markCheckboxes('groupuser_form$rand') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=all'>".$LANG['buttons'][18]."</a></td>";
 	
-			echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkAllRows('groupuser_form') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=none'>".$LANG["buttons"][19]."</a>";
+			echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkCheckboxes('groupuser_form$rand') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=none'>".$LANG['buttons'][19]."</a>";
 			echo "</td><td align='left' width='80%'>";
 			echo "<input type='hidden' name='FK_groups' value='$ID'>";
-			echo "<input type='submit' name='deleteuser' value=\"".$LANG["buttons"][6]."\" class='submit'>";
+			echo "<input type='submit' name='deleteuser' value=\"".$LANG['buttons'][6]."\" class='submit'>";
 			echo "</td>";
 			echo "</table>";
 			echo "</div>";
 
-			$res=dropdownUsersSelect (true, "all", $group->fields["FK_entities"], 0, $used);
+			if ($group->fields["recursive"]) {
+				$res=dropdownUsersSelect (true, "all", getEntitySons($group->fields["FK_entities"]), 0, $used);
+			} else {
+				$res=dropdownUsersSelect (true, "all", $group->fields["FK_entities"], 0, $used);
+			}		
 			$nb=($res ? $DB->result($res,0,"CPT") : 0);
 			
 			if ($nb) {		
 				echo "<div class='center'>";
 				echo "<table  class='tab_cadre_fixe'>";
-				echo "<tr class='tab_bg_1'><th colspan='2'>".$LANG["setup"][603]."</tr><tr><td class='tab_bg_2' align='center'>";
-				dropdownUsers("FK_users",0,"all",-1,1,$group->fields["FK_entities"],0,$used);
+				echo "<tr class='tab_bg_1'><th colspan='2'>".$LANG['setup'][603]."</tr><tr><td class='tab_bg_2' align='center'>";
+				if ($group->fields["recursive"]) {
+					dropdownUsers("FK_users",0,"all",-1,1,getEntitySons($group->fields["FK_entities"]),0,$used);
+				} else {
+					dropdownUsers("FK_users",0,"all",-1,1,$group->fields["FK_entities"],0,$used);
+				}
 				//dropdownAllUsers("FK_users",0,1,$group->fields["FK_entities"],0,$used);
 				echo "</td><td align='center' class='tab_bg_2'>";
-				echo "<input type='submit' name='adduser' value=\"".$LANG["buttons"][8]."\" class='submit'>";
+				echo "<input type='submit' name='adduser' value=\"".$LANG['buttons'][8]."\" class='submit'>";
 				echo "</td></tr>";
 		
 				echo "</table></div><br>";
@@ -189,21 +205,29 @@ function addUserGroup($uID,$gID){
 function deleteUserGroup($ID){
 
 	global $DB;
-	$query="DELETE FROM glpi_users_groups WHERE ID= '$ID';";
+	$query="DELETE FROM glpi_users_groups WHERE ID = '$ID';";
 	$result = $DB->query($query);
 }
 
-/* // NOT_USED
-function searchGroupID($name,$FK_entities){
+/**
+ * Indicates if a group is present in an entity
+ * @param group the group ID to look for
+ * @param entity_request the entity to search into
+ * @return true if group was found, false is not 
+ */
+function isGroupVisibleInEntity($group,$entity_restrict)
+{
 	global $DB;
-	$query ="SELECT ID from glpi_groups where name='$name' AND FK_entities='$FK_entities'";
+	$query = "SELECT ID 
+		FROM glpi_groups 
+		WHERE ID='$group' ".
+		getEntitiesRestrictRequest(" AND","glpi_groups","FK_entities",$entity_restrict,true);
 	$result = $DB->query($query);
-	if ($DB->numrows($result) > 0){
-		$data= $DB->fetch_array($result);
-		$groupID = $data['ID'];
-		return $groupID;
-	} 
-	else return -1;
+	$found = false;
+
+	if ($DB->numrows($result) ==1)
+		return true;
+	else
+		return false;	
 }
-*/
 ?>
