@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: includes.php 8352 2009-06-01 18:57:03Z moyo $
+ * @version $Id: includes.php 7933 2009-02-01 20:29:33Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -55,19 +55,16 @@ include_once (GLPI_ROOT . "/inc/dropdown.function.php");
 include_once (GLPI_ROOT . "/inc/config.class.php");
 include_once (GLPI_ROOT . "/config/config.php");
 include_once (GLPI_ROOT . "/inc/plugin.function.php");
+include_once (GLPI_ROOT . "/inc/plugin.class.php");
 
 // Load Language file
 loadLanguage();
 
-if ($CFG_GLPI["debug"]){
-	if ($CFG_GLPI["debug_profile"]){		
-		$SQL_TOTAL_REQUEST=0;
-	}
-	if ($CFG_GLPI["debug_sql"]){		
-		$DEBUG_SQL["queries"]=array();
-		$DEBUG_SQL["errors"]=array();
-		$DEBUG_SQL["times"]=array();
-	}
+if ($_SESSION['glpi_use_mode']==DEBUG_MODE){
+	$SQL_TOTAL_REQUEST=0;
+	$DEBUG_SQL["queries"]=array();
+	$DEBUG_SQL["errors"]=array();
+	$DEBUG_SQL["times"]=array();
 }
 
 
@@ -81,6 +78,7 @@ if (!isset($AJAX_INCLUDE)){
 	include_once (GLPI_ROOT . "/inc/export.function.php");
 	include_once (GLPI_ROOT . "/inc/log.function.php");
 	include_once (GLPI_ROOT . "/inc/bookmark.function.php");
+	include_once (GLPI_ROOT . "/inc/bookmark.class.php");
 	include_once (GLPI_ROOT . "/inc/alert.class.php");
 }
 
@@ -102,6 +100,7 @@ if (isset($_GET)){
 }
 
 
+
 // Mark if Header is loaded or not :
 $HEADER_LOADED=false;
 $FOOTER_LOADED=false;
@@ -124,28 +123,16 @@ if (isset($NEEDED_ITEMS)&&is_array($NEEDED_ITEMS)){
 if (!isset($AJAX_INCLUDE)&&!isset($PLUGINS_INCLUDED)){
 	// PLugin already included
 	$PLUGINS_INCLUDED=1;
-
+	$LOADED_PLUGINS=array();
 	if (!isset($_SESSION["glpi_plugins"])) {
 		initPlugins();
 	}
-
 	if (isset($_SESSION["glpi_plugins"]) && is_array($_SESSION["glpi_plugins"])) {
 		//doHook("config");
 
 		if (count($_SESSION["glpi_plugins"])){
 			foreach ($_SESSION["glpi_plugins"] as $name) {
-
-				if (isset($_SESSION["glpilanguage"])&&file_exists(GLPI_ROOT . "/plugins/$name/locales/".$CFG_GLPI["languages"][$_SESSION["glpilanguage"]][1]))
-					include_once (GLPI_ROOT . "/plugins/$name/locales/".$CFG_GLPI["languages"][$_SESSION["glpilanguage"]][1]);
-				else if (file_exists(GLPI_ROOT . "/plugins/$name/locales/".$CFG_GLPI["languages"][$CFG_GLPI["default_language"]][1]))
-					include_once (GLPI_ROOT . "/plugins/$name/locales/".$CFG_GLPI["languages"][$CFG_GLPI["default_language"]][1]);
-				else if (file_exists(GLPI_ROOT . "/plugins/$name/locales/en_GB.php"))
-					include_once (GLPI_ROOT . "/plugins/$name/locales/en_GB.php");
-				else if (file_exists(GLPI_ROOT . "/plugins/$name/locales/fr_FR.php"))
-					include_once (GLPI_ROOT . "/plugins/$name/locales/fr_FR.php");
-
 				usePlugin($name);
-
 			}
 		}
 	}
@@ -157,4 +144,14 @@ if (isset($NEEDED_ITEMS)&&in_array('search', $NEEDED_ITEMS)){
 }
 
 if (!isset($_SESSION["MESSAGE_AFTER_REDIRECT"])) $_SESSION["MESSAGE_AFTER_REDIRECT"]="";
+
+// Manage tabs
+if (isset($_REQUEST['glpi_tab'])) {
+	$_SESSION['glpi_tab']=$_REQUEST['glpi_tab'];
+}
+// Override list-limit if choosen
+if (isset($_REQUEST['glpilist_limit'])) {
+	$_SESSION['glpilist_limit']=$_REQUEST['glpilist_limit'];
+}
+
 ?>
