@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: ldap.function.php 8186 2009-04-16 22:29:11Z walid $
+ * @version $Id: ldap.function.php 8208 2009-04-20 21:07:35Z walid $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -39,27 +39,6 @@ if (!defined('GLPI_ROOT')) {
 	die("Sorry. You can't access directly to this file");
 }
 
-/** Computes the difference of arrays using keys for comparison
- * parameters are unlimited number of arrays
- * REPLACE array_diff_key for PHP 4 compatibility
- * 
- * @return  Returns an array containing all the entries from first array  that are not present in any of the other arrays.
- */
-function diff_key() {
-	$argCount  = func_num_args();
-	$diff_arg_prefix = 'diffArg';
-	$diff_arg_names = array();
-	for ($i=0; $i < $argCount; $i++) {
-		$diff_arg_names[$i] = 'diffArg'.$i;
-		$$diff_arg_names[$i] = array_keys((array)func_get_arg($i));
-	}
-	$diffArrString = '';
-	if (!empty($diff_arg_names)) {
-		$diffArrString =  '$'.implode(', $', $diff_arg_names);
-	}
-	eval("\$result = array_diff(".$diffArrString.");");
-	return $result;
-}
 /** Converts an array of parameters into a query string to be appended to a URL.
  *
  * @param   $group_dn  dn of the group to import
@@ -95,10 +74,11 @@ function ldapImportGroup ($group_dn,$ldap_server,$entity,$type){
  *
  * @param   $login  dn of the user to import
  * @param   $sync synchoronise (true) or import (false)
+ * @param   $display display message information on redirect
  * @return  nothing
  */
-function ldapImportUser ($login,$sync){
-	ldapImportUserByServerId($login, $sync,$_SESSION["ldap_server"]);
+function ldapImportUser ($login,$sync,$display=false){
+	ldapImportUserByServerId($login, $sync,$_SESSION["ldap_server"],$display);
 }
 
 /** Import a user from a specific ldap server
@@ -106,9 +86,10 @@ function ldapImportUser ($login,$sync){
  * @param   $login  dn of the user to import
  * @param   $sync synchoronise (true) or import (false)
  * @param   $ldap_server ID of the LDAP server to use
+ * @param   $display display message information on redirect
  * @return  nothing
  */
-function ldapImportUserByServerId($login, $sync,$ldap_server) {
+function ldapImportUserByServerId($login, $sync,$ldap_server,$display=false) {
 	global $DB, $LANG;
 
 	$config_ldap = new AuthLDAP();
@@ -134,8 +115,11 @@ function ldapImportUserByServerId($login, $sync,$ldap_server) {
 			//Get informations from LDAP
 			if ($user->getFromLDAP($ds, $config_ldap->fields, $user_dn, addslashes($login), "")){
 				//Add the auth method
-				$user->fields["auth_method"] = AUTH_LDAP;
-				$user->fields["id_auth"] = $ldap_server;
+				if (!$sync){
+					$user->fields["auth_method"] = AUTH_LDAP;
+					$user->fields["id_auth"] = $ldap_server;
+				}
+				// Force date mod
 				$user->fields["date_mod"]=$_SESSION["glpi_currenttime"];
 				
 				//$rule->processAllRules($groups,$user->fields,array("type"=>"LDAP","ldap_server"=>$ldap_server,"connection"=>$ds,"userdn"=>$user_dn));
@@ -143,14 +127,21 @@ function ldapImportUserByServerId($login, $sync,$ldap_server) {
 					//Save informations in database !
 					$input = $user->fields;
 					unset ($user->fields);
-	
+					// Display message after redirect
+					if ($display){
+						$input['add']=1;
+					}
 					$user->fields["ID"] = $user->add($input);
 	//				$user->applyRightRules($groups);
 					return $user->fields["ID"];
 				} else
 				{
 	//				$user->applyRightRules($groups);
-					$user->update($user->fields);
+					$input=$user->fields;
+					if ($display){
+						$input['update']=1;
+					}
+					$user->update($input);
 					return true;
 				}
 			} else {
@@ -181,22 +172,22 @@ function ldapChooseDirectory($target) {
 
 	echo "<form action=\"$target\" method=\"post\">";
 	echo "<div class='center'>";
-	echo "<p >" . $LANG["ldap"][5] . "</p>";
+	echo "<p >" . $LANG['ldap'][5] . "</p>";
 	echo "<table class='tab_cadre'>";
-	echo "<tr class='tab_bg_2'><th colspan='2'>" . $LANG["ldap"][4] . "</th></tr>";
+	echo "<tr class='tab_bg_2'><th colspan='2'>" . $LANG['ldap'][4] . "</th></tr>";
 	//If more than one ldap server
 	if ($DB->numrows($result) > 1) {
-		echo "<tr class='tab_bg_2'><td class='center'>" . $LANG["common"][16] . "</td><td class='center'>";
+		echo "<tr class='tab_bg_2'><td class='center'>" . $LANG['common'][16] . "</td><td class='center'>";
 		echo "<select name='ldap_server'>";
 		while ($ldap = $DB->fetch_array($result))
 			echo "<option value=" . $ldap["ID"] . ">" . $ldap["name"] . "</option>";
 
 		echo "</select></td></tr>";
-		echo "<tr class='tab_bg_2'><td align='center' colspan='2'><input class='submit' type='submit' name='ldap_showusers' value='" . $LANG["buttons"][2] . "'></td></tr>";
+		echo "<tr class='tab_bg_2'><td align='center' colspan='2'><input class='submit' type='submit' name='ldap_showusers' value='" . $LANG['buttons'][2] . "'></td></tr>";
 
 	} else
 		//No ldap server
-		echo "<tr class='tab_bg_2'><td align='center' colspan='2'>" . $LANG["ldap"][7] . "</td></tr>";
+		echo "<tr class='tab_bg_2'><td align='center' colspan='2'>" . $LANG['ldap'][7] . "</td></tr>";
 
 	echo "</table></div></form>";
 }
@@ -262,7 +253,7 @@ function getGroupCNByDn($ldap_connection,$group_dn)
  * @param   $entity entity to search
  * @return  array of the groups
  */
-function getAllGroups($id_auth,$filter,$filter2,$entity){
+function getAllGroups($id_auth,$filter,$filter2,$entity,$order='DESC'){
 	global $DB, $LANG,$CFG_GLPI;
 	$config_ldap = new AuthLDAP();
 	$res = $config_ldap->getFromDB($id_auth);
@@ -309,6 +300,11 @@ function getAllGroups($id_auth,$filter,$filter2,$entity){
 					$ligne++;
 				}
 			}
+		if ($order=='DESC')
+			ksort($groups);
+		else
+			sort($groups);	
+			
 		}
 	}
 	return $groups;		
@@ -322,14 +318,15 @@ function getAllGroups($id_auth,$filter,$filter2,$entity){
  * @param   $sync synchronise or add ?
  * @param   $filter ldap filter to use
  * @param   $entity working entity
+ * @param   $order display order 
  * @return  nothing
  */
-function showLdapGroups($target, $check, $start, $sync = 0,$filter='',$filter2='',$entity) {
+function showLdapGroups($target, $check, $start, $sync = 0,$filter='',$filter2='',$entity,$order='DESC') {
 	global $DB, $CFG_GLPI, $LANG;
 
 	displayLdapFilter($target,false);
 	echo "<br>";	
-	$ldap_groups = getAllGroups($_SESSION["ldap_server"],$filter,$filter2,$entity);
+	$ldap_groups = getAllGroups($_SESSION["ldap_server"],$filter,$filter2,$entity,$order);
 
 	if (is_array($ldap_groups)){
 		$numrows = count($ldap_groups);
@@ -342,17 +339,20 @@ function showLdapGroups($target, $check, $start, $sync = 0,$filter='',$filter2='
 			printPager($start, $numrows, $target, $parameters);
 	
 			// delete end 
-			array_splice($ldap_groups, $start + $_SESSION["glpilist_limit"]);
+			array_splice($ldap_groups, $start + $_SESSION['glpilist_limit']);
 			// delete begin
 			if ($start > 0)
 				array_splice($ldap_groups, 0, $start);
 	
 			echo "<div class='center'>";
-			echo "<form method='post' id='ldap_form'  name='ldap_form' action='" . $target . "'>";
-			echo "<a href='" . $target . "?check=all' onclick= \"if ( markAllRows('ldap_form') ) return false;\">" . $LANG["buttons"][18] . "</a>&nbsp;/&nbsp;<a href='" . $target . "?check=none' onclick= \"if ( unMarkAllRows('ldap_form') ) return false;\">" . $LANG["buttons"][19] . "</a>";
+			echo "<form method='post' id='ldap_form' name='ldap_form'  action='" . $target . "'>";
+			echo "<a href='" . $target . "?check=all' onclick= \"if ( markCheckboxes('ldap_form') ) return false;\">" . $LANG['buttons'][18] . "</a>&nbsp;/&nbsp;<a href='" . $target . "?check=none' onclick= \"if ( unMarkCheckboxes('ldap_form') ) return false;\">" . $LANG['buttons'][19] . "</a>";
 			echo "<table class='tab_cadre'>";
-			echo "<tr><th>" . $LANG["buttons"][37]. "</th><th colspan='2'>" . $LANG["common"][35] . "</th><th>".$LANG["setup"][261]."</th>"; 
-			echo"<th>".$LANG["ocsng"][36]."</th></tr>";
+			echo "<tr><th>" . $LANG['buttons'][37]. "</th>"; 
+			//echo"<th colspan='2'>" . $LANG['common'][35] . "</th>";
+			echo displaySearchHeaderItem(HTML_OUTPUT,0,$LANG['common'][35],$header_num=0,$target."?order=".($order=="DESC"?"ASC":"DESC"),1,$order);
+			echo "<th>".$LANG['setup'][261]."</th>"; 
+			echo"<th>".$LANG['ocsng'][36]."</th></tr>";
 	
 			foreach ($ldap_groups as $groupinfos) {
 				$group = $groupinfos["cn"];
@@ -362,7 +362,7 @@ function showLdapGroups($target, $check, $start, $sync = 0,$filter='',$filter2='
 				echo "<tr align='center' class='tab_bg_2'>";
 				//Need to use " instead of ' because it doesn't work with names with ' inside !
 				echo "<td><input type='checkbox' name=\"" . $action . "[" .$group_dn . "]\" " . ($check == "all" ? "checked" : "") ."></td>";
-				echo "<td colspan='2'>" . $group . "</td>";
+				echo "<td>" . $group . "</td>";
 				echo "<td>" .$group_dn. "</td>";
 				echo "<td>";
 				dropdownValue("glpi_entities", "toimport_entities[" .$group_dn . "]=".$entity, $entity);
@@ -370,17 +370,17 @@ function showLdapGroups($target, $check, $start, $sync = 0,$filter='',$filter2='
 				echo "<input type='hidden' name=\"toimport_type[".$group_dn."]\" value=\"".$search_type."\">";		
 				echo "</tr>";
 			}
-			echo "<tr class='tab_bg_1'><td colspan='5' align='center'>";
-			echo "<input class='submit' type='submit' name='" . $form_action . "' value='" . $LANG["buttons"][37] . "'>";
+			echo "<tr class='tab_bg_1'><td colspan='4' align='center'>";
+			echo "<input class='submit' type='submit' name='" . $form_action . "' value='" . $LANG['buttons'][37] . "'>";
 			echo "</td></tr>";
 			echo "</table>";
 			echo "</form></div>";
 			printPager($start, $numrows, $target, $parameters);
 		} else {
-			echo "<div class='center'><strong>" . $LANG["ldap"][25] . "</strong></div>";
+			echo "<div class='center'><strong>" . $LANG['ldap'][25] . "</strong></div>";
 		}
 	} else {
-		echo "<div class='center'><strong>" . $LANG["ldap"][25] . "</strong></div>";
+		echo "<div class='center'><strong>" . $LANG['ldap'][25] . "</strong></div>";
 	}
 }
 
@@ -392,7 +392,7 @@ function showLdapGroups($target, $check, $start, $sync = 0,$filter='',$filter2='
  * @param   $myfilter ldap filter to use
  * @return  array of the user
  */
-function getAllLdapUsers($id_auth, $sync = 0,$myfilter='') {
+function getAllLdapUsers($id_auth, $sync = 0,$myfilter='',$order='DESC') {
 	global $DB, $LANG,$CFG_GLPI;
 
 	$config_ldap = new AuthLDAP();
@@ -403,7 +403,10 @@ function getAllLdapUsers($id_auth, $sync = 0,$myfilter='') {
 	if (!$res) {
 		return false;
 	}
-
+	if ($order!="DESC"){
+		$order="ASC";
+	}
+	
 	$ds = connect_ldap($config_ldap->fields['ldap_host'], $config_ldap->fields['ldap_port'], $config_ldap->fields['ldap_rootdn'], $config_ldap->fields['ldap_pass'], $config_ldap->fields['ldap_use_tls'], $config_ldap->fields['ldap_opt_deref']);
 	if ($ds) {
 
@@ -458,8 +461,10 @@ function getAllLdapUsers($id_auth, $sync = 0,$myfilter='') {
 	$glpi_users = array ();
 	$sql = "SELECT name, date_mod FROM glpi_users ";
 	if ($sync){
-		$sql.=" WHERE auth_method IN (-1,".AUTH_LDAP.") ";
+		$sql.=" WHERE auth_method IN (-1,".AUTH_LDAP.",".AUTH_EXTERNAL.") ";
 	}
+	$sql.="ORDER BY name ".$order;
+	
 	$result = $DB->query($sql);
 	if ($DB->numrows($result) > 0)
 		while ($user = $DB->fetch_array($result))
@@ -472,23 +477,28 @@ function getAllLdapUsers($id_auth, $sync = 0,$myfilter='') {
 			//Ldap synchronisation : look if the user exists in the directory and compares the modifications dates (ldap and glpi db)
 				if (!empty ($ldap_users[$user['name']]))
 				{
-					if ($ldap_users[$user['name']] - strtotime($user['date_mod']) > 0)
+					//If entry was modified or if script should synchronize all the users
+					if ( ($sync ==2) || ($ldap_users[$user['name']] - strtotime($user['date_mod']) > 0))
 					{
 						$glpi_users[] = array("user" => $user['name'], "timestamp"=>$user_infos[$user['name']]['timestamp'],"date_mod"=>$user['date_mod']);
 					}
 				}		
 		}
 		}
-		
 	//If add, do the difference between ldap users and glpi users
 	if (!$sync)
 	{
-		$diff = 	diff_key($ldap_users,$glpi_users);
+		$diff = 	array_diff_ukey($ldap_users,$glpi_users,'strcasecmp');
 		$list = array();
 		
 		foreach ($diff as $user)
 			$list[] = array("user" => $user, "timestamp" => $user_infos[$user]["timestamp"], "date_mod"=> "-----");
 		
+		if ($order=='DESC')
+			rsort($list);
+		else
+			sort($list);
+			
 		return $list;	
 	}
 	else
@@ -506,12 +516,12 @@ function getAllLdapUsers($id_auth, $sync = 0,$myfilter='') {
  * @param   $filter ldap filter to use
  * @return  nothing
  */
-function showLdapUsers($target, $check, $start, $sync = 0,$filter='') {
+function showLdapUsers($target, $check, $start, $sync = 0,$filter='',$order='DESC') {
 	global $DB, $CFG_GLPI, $LANG;
 
 	displayLdapFilter($target);
 	echo "<br>";	
-	$ldap_users = getAllLdapUsers($_SESSION["ldap_server"], $sync,$filter);
+	$ldap_users = getAllLdapUsers($_SESSION["ldap_server"], $sync,$filter,$order);
 
 	if (is_array($ldap_users)){
 		$numrows = count($ldap_users);
@@ -529,16 +539,22 @@ function showLdapUsers($target, $check, $start, $sync = 0,$filter='') {
 			printPager($start, $numrows, $target, $parameters);
 	
 			// delete end 
-			array_splice($ldap_users, $start + $_SESSION["glpilist_limit"]);
+			array_splice($ldap_users, $start + $_SESSION['glpilist_limit']);
 			// delete begin
 			if ($start > 0)
 				array_splice($ldap_users, 0, $start);
 	
 			echo "<div class='center'>";
 			echo "<form method='post' id='ldap_form' name='ldap_form' action='" . $target . "'>";
-			echo "<a href='" . $target . "?check=all' onclick= \"if ( markAllRows('ldap_form') ) return false;\">" . $LANG["buttons"][18] . "</a>&nbsp;/&nbsp;<a href='" . $target . "?check=none' onclick= \"if ( unMarkAllRows('ldap_form') ) return false;\">" . $LANG["buttons"][19] . "</a>";
+			echo "<a href='" . $target . "?check=all' onclick= \"if ( markCheckboxes('ldap_form') ) return false;\">" . $LANG['buttons'][18] . "</a>&nbsp;/&nbsp;<a href='" . $target . "?check=none' onclick= \"if ( unMarkCheckboxes('ldap_form') ) return false;\">" . $LANG['buttons'][19] . "</a>";
 			echo "<table class='tab_cadre'>";
-			echo "<tr><th>" . (!$sync?$LANG["buttons"][37]:$LANG["ldap"][15]) . "</th><th colspan='2'>" . $LANG["Menu"][14] . "</th><th>".$LANG["common"][26]." ".$LANG["ldap"][13]."</th><th>".$LANG["common"][26]." ".$LANG["ldap"][14]."</th></tr>";
+			echo "<tr>"; 
+			echo "<th>" . (!$sync?$LANG['buttons'][37]:$LANG['ldap'][15]) . "</th>"; 
+			$num=0;
+			echo displaySearchHeaderItem(0,$LANG['Menu'][14],$num,$target."?order=".($order=="DESC"?"ASC":"DESC"),1,$order);
+			echo "<th>".$LANG['common'][26]." ".$LANG['ldap'][13]."</th>"; 
+			echo "<th>".$LANG['common'][26]." ".$LANG['ldap'][14]."</th>";
+			echo "</tr>";
 	
 			foreach ($ldap_users as $userinfos) {
 				$user = $userinfos["user"];
@@ -555,7 +571,7 @@ function showLdapUsers($target, $check, $start, $sync = 0,$filter='') {
 				echo "<tr align='center' class='tab_bg_2'>";
 				//Need to use " instead of ' because it doesn't work with names with ' inside !
 				echo "<td><input type='checkbox' name=\"" . $action . "[" . $user . "]\" " . ($check == "all" ? "checked" : "") ."></td>";
-				echo "<td colspan='2'>" . $user . "</td>";
+				echo "<td>" . $user . "</td>";
 				
 				if ($stamp != '')
 					echo "<td>" .convDateTime(date("Y-m-d H:i:s",$stamp)). "</td>";
@@ -569,16 +585,17 @@ function showLdapUsers($target, $check, $start, $sync = 0,$filter='') {
 				echo "</tr>";
 			}
 			echo "<tr class='tab_bg_1'><td colspan='5' align='center'>";
-			echo "<input class='submit' type='submit' name='" . $form_action . "' value='" . (!$sync?$LANG["buttons"][37]:$LANG["ldap"][15]) . "'>";
+			echo "<input class='submit' type='submit' name='" . $form_action . "' value='" . (!$sync?$LANG['buttons'][37]:$LANG['ldap'][15]) . "'>";
 			echo "</td></tr>";
 			echo "</table>";
 			echo "</form></div>";
+			echo "<a href='" . $target . "?check=all' onclick= \"if ( markCheckboxes('ldap_form') ) return false;\">" . $LANG['buttons'][18] . "</a>&nbsp;/&nbsp;<a href='" . $target . "?check=none' onclick= \"if ( unMarkCheckboxes('ldap_form') ) return false;\">" . $LANG['buttons'][19] . "</a>";
 			printPager($start, $numrows, $target, $parameters);
 		} else {
-			echo "<div class='center'><strong>" . $LANG["ldap"][3] . "</strong></div>";
+			echo "<div class='center'><strong>" . $LANG['ldap'][3] . "</strong></div>";
 		}
 	} else {
-		echo "<div class='center'><strong>" . $LANG["ldap"][3] . "</strong></div>";
+		echo "<div class='center'><strong>" . $LANG['ldap'][3] . "</strong></div>";
 	}
 }
 
@@ -633,23 +650,23 @@ function showSynchronizationForm($target, $ID) {
 		$sql = "SELECT auth_method, id_auth FROM glpi_users WHERE ID='" . $ID."'";
 		$result = $DB->query($sql);
 		
-		if ($DB->numrows($result) > 0) {
+		if ($DB->numrows($result) == 1) {
 			$data = $DB->fetch_array($result);
-			
+			echo "<div class='center'>";
+			echo "<form method='post' action=\"$target\">";
+
 			switch($data["auth_method"])
 			{
 				case AUTH_LDAP :
-					echo "<div class='center'>";
-					echo "<form method='post' action=\"$target\">";
-
+						
+					//Look it the auth server still exists ! <- Bad idea : id not exists unable to change anything
 					$sql = "SELECT name FROM glpi_auth_ldap WHERE ID='" . $data["id_auth"]."'";
 					$result = $DB->query($sql);
-					if ($DB->numrows($result) > 0) {
-						//Look it the auth server still exists !
 
+					if ($DB->numrows($result) > 0) {
 						echo "<table class='tab_cadre'><tr class='tab_bg_2'><td>";
 						echo "<input type='hidden' name='ID' value='" . $ID . "'>";
-						echo "<input class=submit type='submit' name='force_ldap_resynch' value='" . $LANG["ocsng"][24] . "'>";
+						echo "<input class=submit type='submit' name='force_ldap_resynch' value='" . $LANG['ocsng'][24] . "'>";
 						echo "</td></tr></table>";
 					}
 	
@@ -657,36 +674,49 @@ function showSynchronizationForm($target, $ID) {
 					echo "<br>";
 					formChangeAuthMethodToMail($ID);
 							
-					echo "</form></div>";
 				break;	
 				case AUTH_DB_GLPI :
-					echo "<div class='center'>";
-					echo "<form method='post' action=\"$target\">";
 					formChangeAuthMethodToLDAP($ID);
 					echo "<br>";
 					formChangeAuthMethodToMail($ID);
-					echo "</form></div>";
 				break;
 				case AUTH_MAIL :
-					echo "<div class='center'>";
-					echo "<form method='post' action=\"$target\">";
 					formChangeAuthMethodToDB($ID);
 					echo "<br>";
 					formChangeAuthMethodToLDAP($ID);
-					echo "</form></div>";
 				break;
+				case AUTH_CAS :
 				case AUTH_EXTERNAL :
+
+					if ($data["id_auth"]){
+						//Look it the auth server still exists ! <- Bad idea : id not exists unable to change anything
+						$sql = "SELECT name FROM glpi_auth_ldap WHERE ID='" . $data["id_auth"]."'";
+						$result = $DB->query($sql);
+	
+						if ($DB->numrows($result) > 0) {
+							echo "<table class='tab_cadre'><tr class='tab_bg_2'><td>";
+							echo "<input type='hidden' name='ID' value='" . $ID . "'>";
+							echo "<input class=submit type='submit' name='force_ldap_resynch' value='" . $LANG['ocsng'][24] . "'>";
+							echo "</td></tr></table>";
+						}
+					}
+					echo "<br>";
+					formChangeAuthMethodToDB($ID);
+					echo "<br>";
+					formChangeAuthMethodToLDAP($ID);
+					echo "<br>";
+					formChangeAuthMethodToMail($ID);
+					break;
 				case AUTH_X509 :
-					echo "<div class='center'>";
-					echo "<form method='post' action=\"$target\">";
 					formChangeAuthMethodToDB($ID);
 					echo "<br>";
 					formChangeAuthMethodToLDAP($ID);
 					echo "<br>";
 					formChangeAuthMethodToMail($ID);
-					echo "</form></div>";
 				break;
 			} 
+			echo "</form></div>";
+
 		}
 	}
 }
@@ -699,9 +729,9 @@ function showSynchronizationForm($target, $ID) {
 function formChangeAuthMethodToDB($ID){
 	global $LANG;
 	echo "<br><table class='tab_cadre'>";
-	echo "<tr><th colspan='2' colspan='2'>" . $LANG["login"][30]."</th></tr>";
+	echo "<tr><th colspan='2' colspan='2'>" . $LANG['login'][30]."</th></tr>";
 	echo "<input type='hidden' name='ID' value='" . $ID . "'>";
-	echo "<tr class='tab_bg_2'><td colspan='2' align='center'><input class=submit type='submit' name='switch_auth_internal' value='" . $LANG["login"][32] . "'>";
+	echo "<tr class='tab_bg_2'><td colspan='2' align='center'><input class=submit type='submit' name='switch_auth_internal' value='" . $LANG['login'][32] . "'>";
 	echo "</td></tr></table>";
 }
 
@@ -718,12 +748,12 @@ function formChangeAuthMethodToLDAP($ID)
 	$result = $DB->query($sql);
 	if ($DB->numrows($result) > 0){
 		echo "<table class='tab_cadre'>";
-		echo "<tr><th colspan='2' colspan='2'>" . $LANG["login"][30]." : ".$LANG["login"][2]."</th></tr>";
+		echo "<tr><th colspan='2' colspan='2'>" . $LANG['login'][30]." : ".$LANG['login'][2]."</th></tr>";
 		echo "<tr class='tab_bg_1'><td><input type='hidden' name='ID' value='" . $ID . "'>";
-		echo $LANG["login"][31]."</td><td>";
+		echo $LANG['login'][31]."</td><td>";
 		dropdownValue("glpi_auth_ldap","id_auth");
 		echo "</td>";
-		echo "<tr class='tab_bg_2'><td colspan='2' align='center'><input class=submit type='submit' name='switch_auth_ldap' value='" . $LANG["buttons"][2] . "'>";
+		echo "<tr class='tab_bg_2'><td colspan='2' align='center'><input class=submit type='submit' name='switch_auth_ldap' value='" . $LANG['buttons'][2] . "'>";
 		echo "</td></tr></table>";
 	}
 }
@@ -739,12 +769,12 @@ function formChangeAuthMethodToMail($ID){
 	$result = $DB->query($sql);
 	if ($DB->numrows($result) > 0){
 		echo "<table class='tab_cadre'>";
-		echo "<tr><th colspan='2' colspan='2'>" . $LANG["login"][30]." : ".$LANG["login"][3]."</th></tr>";
+		echo "<tr><th colspan='2' colspan='2'>" . $LANG['login'][30]." : ".$LANG['login'][3]."</th></tr>";
 		echo "<tr class='tab_bg_1'><td><input type='hidden' name='ID' value='" . $ID . "'>";
-		echo $LANG["login"][33]."</td><td>";
+		echo $LANG['login'][33]."</td><td>";
 		dropdownValue("glpi_auth_mail","id_auth");
 		echo "</td>";
-		echo "<tr class='tab_bg_2'><td colspan='2' align='center'><input class=submit type='submit' name='switch_auth_mail' value='" . $LANG["buttons"][2] . "'>";
+		echo "<tr class='tab_bg_2'><td colspan='2' align='center'><input class=submit type='submit' name='switch_auth_mail' value='" . $LANG['buttons'][2] . "'>";
 		echo "</td></tr></table>";
 	}
 }
@@ -753,7 +783,7 @@ function formChangeAuthMethodToMail($ID){
 /* // NOT_USED
 function getAuthMethodFromDB($ID) {
 	global $DB;
-	$sql = "SELECT auth_method FROM glpi_users WHERE ID=" . $ID;
+	$sql = "SELECT auth_method FROM glpi_users WHERE ID='".$ID."'";
 	$result = $DB->query($sql);
 	if ($DB->numrows($result) > 0) {
 		$data = $DB->fetch_array($result);
@@ -839,7 +869,7 @@ function displayLdapFilter($target,$users=true){
 	echo "<div class='center'>";
 	echo "<form method='post' action=\"$target\">";
 	echo "<table class='tab_cadre'>"; 
-	echo "<tr><th colspan='2'>" . ($users?$LANG["setup"][263]:$LANG["setup"][253]) . "</th></tr>";
+	echo "<tr><th colspan='2'>" . ($users?$LANG['setup'][263]:$LANG['setup'][253]) . "</th></tr>";
 	echo "<tr class='tab_bg_2'><td>";
 	echo "<input type='text' name='ldap_filter' value='" . $_SESSION[$filter_var] . "' size='70'>";
 	
@@ -850,14 +880,14 @@ function displayLdapFilter($target,$users=true){
 			$_SESSION["ldap_group_filter2"]=$config_ldap->fields[$filter_name2];
 
 		echo "</td></tr>";
-		echo "<tr><th colspan='2'>" . $LANG["setup"][263] . "</th></tr>";		
+		echo "<tr><th colspan='2'>" . $LANG['setup'][263] . "</th></tr>";		
 		echo "<tr class='tab_bg_2'><td>";
 		echo "<input type='text' name='ldap_filter2' value='" . $_SESSION["ldap_group_filter2"] . "' size='70'>";
 		echo "</td></tr>";
 	}	
 
 	echo "<tr class='tab_bg_2'><td align='center'>";
-	echo "<input class=submit type='submit' name='change_ldap_filter' value='" . $LANG["buttons"][2] . "'>";
+	echo "<input class=submit type='submit' name='change_ldap_filter' value='" . $LANG['buttons'][2] . "'>";
 	echo "</td></tr></table>";
 	echo "</form></div>";	
 }
