@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: ldap.parameters.class.php 7882 2009-01-23 18:24:05Z moyo $
+ * @version $Id: ldap.parameters.class.php 8026 2009-02-28 16:50:46Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -43,7 +43,7 @@ class LdapCriteria extends CommonDBTM {
 	/**
 	 * Constructor
 	**/
-	function LdapCriteria() {
+	function __construct() {
 		$this->table = "glpi_rules_ldap_parameters";
 
 	}
@@ -52,8 +52,8 @@ class LdapCriteria extends CommonDBTM {
 	function getParametersList() {
 		global $DB;
 		$sql = "SELECT * 
-			FROM `" . $this->table . "` 
-			WHERE rule_type=".RULE_AFFECT_RIGHTS." 
+			FROM `".$this->table."` 
+			WHERE sub_type='".RULE_AFFECT_RIGHTS."' 
 			ORDER BY name ASC";
 		$result = $DB->query($sql);
 		$parameters = array ();
@@ -80,24 +80,24 @@ class LdapCriteria extends CommonDBTM {
 		if ($canedit) {
 			echo "<div class='center'>";
 			echo "<table  class='tab_cadre_fixe'>";
-			echo "<tr class='tab_bg_1'><th colspan='5'>" .$LANG["ruleldap"][3] . "</tr><tr><td class='tab_bg_2' align='center'>";
+			echo "<tr class='tab_bg_1'><th colspan='5'>" .$LANG['ruleldap'][3] . "</tr><tr><td class='tab_bg_2' align='center'>";
 			echo "</td><td align='center' class='tab_bg_2'>";
-			echo $LANG["common"][16] . ":";
-			autocompletionTextField("name", $this->table, "name", "", 30);
-			echo $LANG["setup"][601] . ":";
-			autocompletionTextField("value", $this->table, "value", "", 30);
-			echo "<input type=hidden name='rule_type' value=\"" . RULE_AFFECT_RIGHTS . "\">";
-			echo "<input type='submit' name='add' value=\"" . $LANG["buttons"][8] . "\" class='submit'>";
+			echo $LANG['common'][16] . ":";
+			autocompletionTextField("name", $this->table, "name", "", 40);
+			echo $LANG['setup'][601] . ":";
+			autocompletionTextField("value", $this->table, "value", "", 40);
+			echo "<input type=hidden name='sub_type' value=\"" . RULE_AFFECT_RIGHTS . "\">";
+			echo "<input type='submit' name='add' value=\"" . $LANG['buttons'][8] . "\" class='submit'>";
 			echo "</td></tr>";
 			
 			echo "</table></div><br>";
 		}
 
 		if (!count($parameters)){
-			echo "<center>".$LANG["ruleldap"][2]."</center>";
+			echo "<center>".$LANG['ruleldap'][2]."</center>";
 		} else {
-			echo "<div class='center'><table class='tab_cadrehov'><tr><th colspan='3'>" . $LANG["common"][53]." ".$LANG["ruleldap"][1] . "</th></tr>";
-			echo "<tr class='tab_bg_1'><td class='tab_bg_2' colspan='2'>" .  $LANG["common"][16]."</td><td class='tab_bg_2'>".$LANG["setup"][601] . "</td></tr>";
+			echo "<div class='center'><table class='tab_cadrehov'><tr><th colspan='3'>" . $LANG['common'][53]." ".$LANG['ruleldap'][1] . "</th></tr>";
+			echo "<tr class='tab_bg_1'><td class='tab_bg_2' colspan='2'>" .  $LANG['common'][16]."</td><td class='tab_bg_2'>".$LANG['setup'][601] . "</td></tr>";
 
 			foreach ($parameters as $parameter) {
 				echo "<tr class='tab_bg_1'>";
@@ -120,11 +120,11 @@ class LdapCriteria extends CommonDBTM {
 			if ($canedit) {
 				echo "<div class='center'>";
 				echo "<table  width='80%'>";
-				echo "<tr><td><img src=\"" . $CFG_GLPI["root_doc"] . "/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markAllRows('ldapcriterias_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?ID=$ID&amp;select=all'>" . $LANG["buttons"][18] . "</a></td>";
+				echo "<tr><td><img src=\"" . $CFG_GLPI["root_doc"] . "/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markCheckboxes('ldapcriterias_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?ID=$ID&amp;select=all'>" . $LANG['buttons'][18] . "</a></td>";
 	
-				echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkAllRows('ldapcriterias_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?ID=$ID&amp;select=none'>" . $LANG["buttons"][19] . "</a>";
+				echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkCheckboxes('ldapcriterias_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?ID=$ID&amp;select=none'>" . $LANG['buttons'][19] . "</a>";
 				echo "</td><td align='left' width='80%'>";
-				echo "<input type='submit' name='delete' value=\"" . $LANG["buttons"][6] . "\" class='submit'>";
+				echo "<input type='submit' name='delete' value=\"" . $LANG['buttons'][6] . "\" class='submit'>";
 				echo "</td>";
 				echo "</table>";
 	
