@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: link.function.php 7875 2009-01-23 15:16:47Z moyo $
+ * @version $Id: link.function.php 8026 2009-02-28 16:50:46Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -54,18 +54,32 @@ if (!defined('GLPI_ROOT')){
 function showLinkDevice($instID) {
 	global $DB,$CFG_GLPI, $LANG;
 
+	$link = new Link();
+	if ($instID > 0){
+		$link->check($instID,'r');
+	} else {
+		// Create item 
+		$link->check(-1,'w');
+		$use_cache=false;
+		$link->getEmpty();
+	} 
+
+	$canedit=$link->can($instID,'w');
+	$canrecu=$link->can($instID,'recursive');
+
 	if (!haveRight("link","r")) return false;
-	$canedit= haveRight("link","w");
+	//$canedit= haveRight("link","w");
 	$ci = new CommonItem();
-	$query = "SELECT * from glpi_links_device WHERE FK_links='$instID' ORDER BY device_type";
+	$query = "SELECT * FROM glpi_links_device WHERE FK_links='$instID' ORDER BY device_type";
 	$result = $DB->query($query);
 	$number = $DB->numrows($result);
 	$i = 0;
 
+
 	echo "<form method='post' action=\"".$CFG_GLPI["root_doc"]."/front/link.form.php\">";
-	echo "<br><br><div class='center'><table class='tab_cadre_fixe'>";
-	echo "<tr><th colspan='2'>".$LANG["links"][4].":</th></tr>";
-	echo "<tr><th>".$LANG["common"][17]."</th>";
+	echo "<div class='center'><table class='tab_cadre_fixe'>";
+	echo "<tr><th colspan='2'>".$LANG['links'][4].":</th></tr>";
+	echo "<tr><th>".$LANG['common'][17]."</th>";
 	echo "<th>&nbsp;</th></tr>";
 
 	while ($i < $number) {
@@ -73,7 +87,7 @@ function showLinkDevice($instID) {
 		$ci->setType($DB->result($result, $i, "device_type"));
 		echo "<tr class='tab_bg_1'>";
 		echo "<td class='center'>".$ci->getType()."</td>";
-		echo "<td align='center' class='tab_bg_2'><a href='".$_SERVER['PHP_SELF']."?deletedevice=deletedevice&amp;ID=$ID'><strong>".$LANG["buttons"][6]."</strong></a></td></tr>";
+		echo "<td align='center' class='tab_bg_2'><a href='".$_SERVER['PHP_SELF']."?deletedevice=deletedevice&amp;ID=$ID&amp;lID=$instID'><strong>".$LANG['buttons'][6]."</strong></a></td></tr>";
 		$i++;
 	}
 	if ($canedit){
@@ -89,7 +103,7 @@ function showLinkDevice($instID) {
 		$types[]=CONTRACT_TYPE;
 		dropdownDeviceTypes("device_type",0,$types);
 	
-		echo "&nbsp;&nbsp;<input type='submit' name='adddevice' value=\"".$LANG["buttons"][8]."\" class='submit'>";
+		echo "&nbsp;&nbsp;<input type='submit' name='adddevice' value=\"".$LANG['buttons'][8]."\" class='submit'>";
 		echo "</div>";
 		echo "</td>";
 	
@@ -136,17 +150,23 @@ function addLinkDevice($tID,$lID){
 function showLinkOnDevice($type,$ID){
 	global $DB,$LANG,$CFG_GLPI;
 
+	$commonitem = new CommonItem;
+	$commonitem->getFromDB($type,$ID);
+	
 	if (!haveRight("link","r")) return false;
 
-	$query="SELECT glpi_links.ID as ID, glpi_links.link as link, glpi_links.name as name , glpi_links.data as data from glpi_links INNER JOIN glpi_links_device ON glpi_links.ID= glpi_links_device.FK_links WHERE glpi_links_device.device_type='$type' ORDER BY glpi_links.name";
+	$query="SELECT glpi_links.ID as ID, glpi_links.link as link, glpi_links.name as name , glpi_links.data as data 
+		FROM glpi_links 
+		INNER JOIN glpi_links_device ON glpi_links.ID= glpi_links_device.FK_links
+		WHERE glpi_links_device.device_type='$type' " .
+			getEntitiesRestrictRequest(" AND","glpi_links","FK_entities",$commonitem->obj->fields["FK_entities"],true).
+		" ORDER BY glpi_links.name";
 
 	$result=$DB->query($query);
-
-	echo "<br>";
-
+	
 	$ci=new CommonItem;
 	if ($DB->numrows($result)>0){
-		echo "<div class='center'><table class='tab_cadre'><tr><th>".$LANG["title"][33]."</th></tr>";
+		echo "<div class='center'><table class='tab_cadre'><tr><th>".$LANG['title'][33]."</th></tr>";
 
 		while ($data=$DB->fetch_assoc($result)){
 
@@ -159,48 +179,65 @@ function showLinkOnDevice($type,$ID){
 			if (empty($file)){
 
 				$ci->getFromDB($type,$ID);
-				if (ereg("\[NAME\]",$link)){
-					$link=ereg_replace("\[NAME\]",$ci->getName(),$link);
+				if (strstr($link,"[NAME]")){
+					$link=str_replace("[NAME]",$ci->getName(),$link);
 				}
-				if (ereg("\[ID\]",$link)){
-					$link=ereg_replace("\[ID\]",$ID,$link);
+				if (strstr($link,"[ID]")){
+					$link=str_replace("[ID]",$ID,$link);
 				}
 
-				if (ereg("\[SERIAL\]",$link)){
+				if (strstr($link,"[LOGIN]")){
+					if (isset($_SESSION["glpiname"])){
+						$link=str_replace("[LOGIN]",$_SESSION["glpiname"],$link);
+					}
+				}
+
+				if (strstr($link,"[SERIAL]")){
 					if ($tmp=$ci->getField('serial')){
-						$link=ereg_replace("\[SERIAL\]",$tmp,$link);
+						$link=str_replace("[SERIAL]",$tmp,$link);
 					}
 				}
-				if (ereg("\[OTHERSERIAL\]",$link)){
+				if (strstr($link,"[OTHERSERIAL]")){
 					if ($tmp=$ci->getField('otherserial')){
-						$link=ereg_replace("\[OTHERSERIAL\]",$tmp,$link);
+						$link=str_replace("[OTHERSERIAL]",$tmp,$link);
 					}
 				}
 
-				if (ereg("\[LOCATIONID\]",$link)){
+				if (strstr($link,"[LOCATIONID]")){
 					if ($tmp=$ci->getField('location')){
-						$link=ereg_replace("\[LOCATIONID\]",$tmp,$link);
+						$link=str_replace("[LOCATIONID]",$tmp,$link);
 					}
 				}
 
-				if (ereg("\[LOCATION\]",$link)){
+				if (strstr($link,"[LOCATION]")){
 					if ($tmp=$ci->getField('location')){
-						$link=ereg_replace("\[LOCATION\]",getDropdownName("glpi_dropdown_locations",$tmp),$link);
+						$link=str_replace("[LOCATION]",getDropdownName("glpi_dropdown_locations",$tmp),$link);
 					}
 				}
-				if (ereg("\[NETWORK\]",$link)){
+				if (strstr($link,"[NETWORK]")){
 					if ($tmp=$ci->getField('network')){
-						$link=ereg_replace("\[NETWORK\]",getDropdownName("glpi_dropdown_network",$tmp),$link);
+						$link=str_replace("[NETWORK]",getDropdownName("glpi_dropdown_network",$tmp),$link);
 					}
 				}
-				if (ereg("\[DOMAIN\]",$link)){
+				if (strstr($link,"[DOMAIN]")){
 					if ($tmp=$ci->getField('domain'))
-						$link=ereg_replace("\[DOMAIN\]",getDropdownName("glpi_dropdown_domain",$tmp),$link);
+						$link=str_replace("[DOMAIN]",getDropdownName("glpi_dropdown_domain",$tmp),$link);
+				}
+				if (strstr($link,"[USER]")){
+					if ($tmp=$ci->getField('FK_users'))
+						$link=str_replace("[USER]",getDropdownName("glpi_users",$tmp),$link);
+				}
+				if (strstr($link,"[GROUP]")){
+					if ($tmp=$ci->getField('FK_groups'))
+						$link=str_replace("[GROUP]",getDropdownName("glpi_groups",$tmp),$link);
 				}
 				$ipmac=array();
 				$i=0;
-				if (ereg("\[IP\]",$link)||ereg("\[MAC\]",$link)){
-					$query2 = "SELECT ifaddr,ifmac,logical_number FROM glpi_networking_ports WHERE (on_device = '$ID' AND device_type = '$type') ORDER BY logical_number";
+				if (strstr($link,"[IP]")||strstr($link,"[MAC]")){
+					$query2 = "SELECT ifaddr, ifmac, logical_number 
+						FROM glpi_networking_ports 
+						WHERE on_device = '$ID' AND device_type = '$type' 
+						ORDER BY logical_number";
 					$result2=$DB->query($query2);
 					if ($DB->numrows($result2)>0)
 						while ($data2=$DB->fetch_array($result2)){
@@ -211,12 +248,12 @@ function showLinkOnDevice($type,$ID){
 						}
 				}
 
-				if (ereg("\[IP\]",$link)||ereg("\[MAC\]",$link)){
+				if (strstr($link,"[IP]")||strstr($link,"[MAC]")){
 					// Add IP/MAC internal switch
 					if ($type==NETWORKING_TYPE){
 						$tmplink=$link;
-						$tmplink=ereg_replace("\[IP\]",$ci->getField('ifaddr'),$tmplink);
-						$tmplink=ereg_replace("\[MAC\]",$ci->getField('ifmac'),$tmplink);
+						$tmplink=str_replace("[IP]",$ci->getField('ifaddr'),$tmplink);
+						$tmplink=str_replace("[MAC]",$ci->getField('ifmac'),$tmplink);
 						echo "<tr class='tab_bg_2'><td><a target='_blank' href='$tmplink'>$name - $tmplink</a></td></tr>";
 					}
 
@@ -224,18 +261,18 @@ function showLinkOnDevice($type,$ID){
 						foreach ($ipmac as $key => $val){
 							$tmplink=$link;
 							$disp=1;
-							if (ereg("\[IP\]",$link)) {
+							if (strstr($link,"[IP]")) {
 								if (empty($val['ifaddr'])) {
 									$disp=0;
 								} else {
-									$tmplink=ereg_replace("\[IP\]",$val['ifaddr'],$tmplink);
+									$tmplink=str_replace("[IP]",$val['ifaddr'],$tmplink);
 								}
 							}
-							if (ereg("\[MAC\]",$link)) {
+							if (strstr($link,"[MAC]")) {
 								if (empty($val['ifmac'])) {
 									$disp=0;
 								} else {
-									$tmplink=ereg_replace("\[MAC\]",$val['ifmac'],$tmplink);
+									$tmplink=str_replace("[MAC]",$val['ifmac'],$tmplink);
 								}
 							}
 							if ($disp) {
@@ -251,12 +288,18 @@ function showLinkOnDevice($type,$ID){
 				$ci->getFromDB($type,$ID);
 
 				// Manage Filename
-				if (ereg("\[NAME\]",$link)){
-					$link=ereg_replace("\[NAME\]",$ci->getName(),$link);
+				if (strstr($link,"[NAME]")){
+					$link=str_replace("[NAME]",$ci->getName(),$link);
 				}
 
-				if (ereg("\[ID\]",$link)){
-					$link=ereg_replace("\[ID\]",$_GET["ID"],$link);
+				if (strstr($link,"[LOGIN]")){
+					if (isset($_SESSION["glpiname"])){
+						$link=str_replace("[LOGIN]",$_SESSION["glpiname"],$link);
+					}
+				}
+
+				if (strstr($link,"[ID]")){
+					$link=str_replace("[ID]",$_GET["ID"],$link);
 				}
 
 				echo "<tr class='tab_bg_2'><td><a href='".$CFG_GLPI["root_doc"]."/front/link.send.php?lID=".$data['ID']."&amp;type=$type&amp;ID=$ID' target='_blank'>".$name."</a></td></tr>";
@@ -265,7 +308,7 @@ function showLinkOnDevice($type,$ID){
 
 		}
 		echo "</table></div>";
-	} else echo "<div class='center'><strong>".$LANG["links"][7]."</strong></div>";
+	} else echo "<div class='center'><strong>".$LANG['links'][7]."</strong></div>";
 
 }
 
