@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: log.function.php 7908 2009-01-26 19:35:55Z remi $
+ * @version $Id: log.function.php 9131 2009-10-20 20:37:33Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -68,8 +68,11 @@ function historyLog ($id_device,$device_type,$changes,$device_internal_type='0',
 			$username="";
 
 		// Build query
-		$query = "INSERT INTO glpi_history (FK_glpi_device,device_type,device_internal_type,linked_action,user_name,date_mod,id_search_option,old_value,new_value)  VALUES ('$id_device','$device_type','$device_internal_type','$linked_action','". addslashes($username)."','$date_mod','$id_search_option','".utf8_substr($old_value,0,250)."','".utf8_substr($new_value,0,250)."');";
-		$DB->query($query)  or die($DB->error());
+		$query = "INSERT INTO glpi_history (FK_glpi_device, device_type, device_internal_type, linked_action, user_name, date_mod,
+		id_search_option, old_value, new_value)  
+		VALUES ('$id_device', '$device_type', '$device_internal_type', '$linked_action','". addslashes($username)."', '$date_mod',
+		'$id_search_option', '".utf8_substr($old_value,0,250)."', '".utf8_substr($new_value,0,250)."');";
+		$DB->query($query);
 	}
 
 }
@@ -101,7 +104,7 @@ function constructHistory($id_device,$device_type,&$oldvalues,&$values) {
 					$real_device_type=$ic->fields['device_type'];
 					$id_device=$ic->fields['FK_device'];
 					if (isset($SEARCH_OPTION[$real_device_type])) foreach($SEARCH_OPTION[$real_device_type] as $key2 => $val2){
-						if(($val2["field"]==$key&&ereg('infocoms',$val2['table'])) || 
+						if(($val2["field"]==$key&&strpos($val2['table'],'infocoms')) || 
 							($key=='budget'&&$val2['table']=='glpi_dropdown_budget') ||
 							($key=='FK_enterprise'&&$val2['table']=='glpi_enterprises_infocoms')) {
 							$id_search_option=$key2; // Give ID of the $SEARCH_OPTION
@@ -122,23 +125,25 @@ function constructHistory($id_device,$device_type,&$oldvalues,&$values) {
 			} else {
 				$real_device_type=$device_type;
 				// Parsing $SEARCH_OPTION, check if an entry exists matching $key
-				foreach($SEARCH_OPTION[$device_type] as $key2 => $val2){
-			
-					// Linkfield or standard field not massive action enable
-					if($val2["linkfield"]==$key 
-						|| ( empty($val2["linkfield"]) && $key == $val2["field"]) ){
-						$id_search_option=$key2; // Give ID of the $SEARCH_OPTION
-			
-						if($val2["table"]==$LINK_ID_TABLE[$device_type]){
-							// 1st case : text field -> keep datas
-							$changes=array($id_search_option, addslashes($oldval),$values[$key]);
-						}else {
-							// 2nd case ; link field -> get data from dropdown
-							$changes=array($id_search_option,  addslashes(getDropdownName( $val2["table"],$oldval)), addslashes(getDropdownName( $val2["table"],$values[$key])));
+				if (isset($SEARCH_OPTION[$device_type])){
+					foreach($SEARCH_OPTION[$device_type] as $key2 => $val2){
+				
+						// Linkfield or standard field not massive action enable
+						if($val2["linkfield"]==$key 
+							|| ( empty($val2["linkfield"]) && $key == $val2["field"]) ){
+							$id_search_option=$key2; // Give ID of the $SEARCH_OPTION
+				
+							if($val2["table"]==$LINK_ID_TABLE[$device_type]){
+								// 1st case : text field -> keep datas
+								$changes=array($id_search_option, addslashes($oldval),$values[$key]);
+							}else {
+								// 2nd case ; link field -> get data from dropdown
+								$changes=array($id_search_option,  addslashes(getDropdownName( $val2["table"],$oldval)), addslashes(getDropdownName( $val2["table"],$values[$key])));
+							}
+							break;
 						}
-						break;
-					}
-				} 
+					} 
+				}
 			}
 		
 			if (count($changes)){
@@ -162,34 +167,45 @@ function constructHistory($id_device,$device_type,&$oldvalues,&$values) {
 function showHistory($device_type,$id_device){
 
 	global $DB, $LINK_ID_TABLE,$LANG;	
-
+	
 	$SEARCH_OPTION=getSearchOptions();
+	
+	if (isset($_REQUEST["start"])) {
+		$start = $_REQUEST["start"];
+	} else {
+		$start = 0;
+	}
 
-	$query="SELECT * FROM glpi_history WHERE FK_glpi_device='".$id_device."' AND device_type='".$device_type."' ORDER BY  ID DESC;";
+	// Total Number of events
+	$number = countElementsInTable("glpi_history", "FK_glpi_device=$id_device AND device_type=$device_type");
+
+	// No Events in database
+	if ($number < 1) {
+		echo "<div class='center'>";
+		echo "<table class='tab_cadre_fixe'>";
+		echo "<tr><th>".$LANG['event'][20]."</th></tr>";
+		echo "</table>";
+		echo "</div><br>";
+		return;
+	}
+
+	// Display the pager
+	printAjaxPager($LANG['title'][38],$start,$number);
+
+	$query="SELECT * 
+		FROM glpi_history 
+		WHERE FK_glpi_device='".$id_device."' AND device_type='".$device_type."'
+		ORDER BY  ID DESC LIMIT ".intval($start)."," . intval($_SESSION['glpilist_limit']);
 
 	//echo $query;
 
 	// Get results
 	$result = $DB->query($query);
 
-	// Number of results
-	$number = $DB->numrows($result);
-
-	// No Events in database
-	if ($number < 1) {
-		echo "<br><div class='center'>";
-		echo "<table class='tab_cadre_fixe'>";
-		echo "<tr><th>".$LANG["event"][20]."</th></tr>";
-		echo "</table>";
-		echo "</div><br>";
-		return;
-	}
-
 	// Output events
-
-	echo "<div class='center'><br><table class='tab_cadre_fixe'>";
-	echo "<tr><th colspan='5'>".$LANG["title"][38]."</th></tr>";
-	echo "<tr><th>".$LANG["common"][2]."</th><th>".$LANG["common"][27]."</th><th>".$LANG["common"][34]."</th><th>".$LANG["event"][18]."</th><th>".$LANG["event"][19]."</th></tr>";
+	echo "<div class='center'><table class='tab_cadre_fixe'>";
+	//echo "<tr><th colspan='5'>".$LANG['title'][38]."</th></tr>";
+	echo "<tr><th>".$LANG['common'][2]."</th><th>".$LANG['common'][27]."</th><th>".$LANG['common'][34]."</th><th>".$LANG['event'][18]."</th><th>".$LANG['event'][19]."</th></tr>";
 	while ($data =$DB->fetch_array($result)){ 
 		$display_history = true;
 		$ID = $data["ID"];
@@ -203,15 +219,15 @@ function showHistory($device_type,$id_device){
 			switch ($data["linked_action"]){
 
 				case HISTORY_DELETE_ITEM :
-					$change = $LANG["log"][22];	
+					$change = $LANG['log'][22];	
 					break;
 				case HISTORY_RESTORE_ITEM :
-					$change = $LANG["log"][23];	
+					$change = $LANG['log'][23];	
 					break;
 
 				case HISTORY_ADD_DEVICE :
 					$field=getDictDeviceLabel($data["device_internal_type"]);
-					$change = $LANG["devices"][25]."&nbsp;<strong>:</strong>&nbsp;\"".$data[ "new_value"]."\"";	
+					$change = $LANG['devices'][25]."&nbsp;<strong>:</strong>&nbsp;\"".$data[ "new_value"]."\"";	
 					break;
 
 				case HISTORY_UPDATE_DEVICE :
@@ -221,32 +237,32 @@ function showHistory($device_type,$id_device){
 
 				case HISTORY_DELETE_DEVICE :
 					$field=getDictDeviceLabel($data["device_internal_type"]);
-					$change = $LANG["devices"][26]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["old_value"]."\"";	
+					$change = $LANG['devices'][26]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["old_value"]."\"";	
 					break;
 				case HISTORY_INSTALL_SOFTWARE :
-					$field=$LANG["help"][31];
-					$change = $LANG["software"][44]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["new_value"]."\"";	
+					$field=$LANG['help'][31];
+					$change = $LANG['software'][44]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["new_value"]."\"";	
 					break;				
 				case HISTORY_UNINSTALL_SOFTWARE :
-					$field=$LANG["help"][31];
-					$change = $LANG["software"][45]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["old_value"]."\"";	
+					$field=$LANG['help'][31];
+					$change = $LANG['software'][45]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["old_value"]."\"";	
 					break;	
 				case HISTORY_DISCONNECT_DEVICE:
 					$ci=new CommonItem();
 					$ci->setType($data["device_internal_type"]);
 					$field=$ci->getType();
-					$change = $LANG["central"][6]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["old_value"]."\"";	
+					$change = $LANG['log'][26]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["old_value"]."\"";	
 					break;	
 				case HISTORY_CONNECT_DEVICE:
 					$ci=new CommonItem();
 					$ci->setType($data["device_internal_type"]);
 					$field=$ci->getType();
-					$change = $LANG["log"][55]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["new_value"]."\"";	
+					$change = $LANG['log'][27]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["new_value"]."\"";	
 					break;	
 				case HISTORY_OCS_IMPORT:
 					if (haveRight("view_ocsng","r")){
 						$field="";
-						$change = $LANG["ocsng"][7]." ".$LANG["ocsng"][45]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["new_value"]."\"";	
+						$change = $LANG['ocsng'][7]." ".$LANG['ocsng'][45]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["new_value"]."\"";	
 					} else {
 						$display_history = false;
 					}
@@ -255,7 +271,7 @@ function showHistory($device_type,$id_device){
 				case HISTORY_OCS_DELETE:
 					if (haveRight("view_ocsng","r")){
 						$field="";
-						$change = $LANG["ocsng"][46]." ".$LANG["ocsng"][45]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["old_value"]."\"";	
+						$change = $LANG['ocsng'][46]." ".$LANG['ocsng'][45]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["old_value"]."\"";	
 					} else {
 						$display_history = false;
 					}
@@ -266,7 +282,7 @@ function showHistory($device_type,$id_device){
 						$ci=new CommonItem();
 						$ci->setType($data["device_internal_type"]);
 						$field=$ci->getType();
-						$change = $LANG["ocsng"][47]." ".$LANG["ocsng"][45]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["new_value"]."\"";	
+						$change = $LANG['ocsng'][47]." ".$LANG['ocsng'][45]."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["new_value"]."\"";	
 					} else {
 						$display_history = false;
 					}
@@ -275,7 +291,7 @@ function showHistory($device_type,$id_device){
 				case HISTORY_OCS_IDCHANGED:
 					if (haveRight("view_ocsng","r")){
 						$field="";
-						$change = $LANG["ocsng"][48]." "."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["old_value"]."\" --> &nbsp;<strong>:</strong>&nbsp;"."\"".$data["new_value"]."\"";	
+						$change = $LANG['ocsng'][48]." "."&nbsp;<strong>:</strong>&nbsp;"."\"".$data["old_value"]."\" --> &nbsp;<strong>:</strong>&nbsp;"."\"".$data["new_value"]."\"";	
 					} else {
 						$display_history = false;
 					}
@@ -300,10 +316,10 @@ function showHistory($device_type,$id_device){
 
 			switch ($fieldname){
 				case "comments" : 
-					$change =$LANG["log"][64];
+					$change =$LANG['log'][64];
 					break;
 				case "notes" : 
-					$change =$LANG["log"][67];
+					$change =$LANG['log'][67];
 					break;
 				default :
 					$change = "\"".$data[ "old_value"]."\"&nbsp;<strong>--></strong>&nbsp;\"".$data[ "new_value"]."\"";
@@ -357,48 +373,49 @@ function logArray(){
 
 	global $LANG;
 
-	$logItemtype=array("system"=>$LANG["log"][1],
-			"computers"=>$LANG["log"][2],
-			"monitors"=>$LANG["log"][3],
-			"printers"=>$LANG["log"][4],
-			"software"=>$LANG["log"][5],
-			"networking"=>$LANG["log"][6],
-			"cartridges"=>$LANG["log"][7],
-			"peripherals"=>$LANG["log"][8],
-			"consumables"=>$LANG["log"][9],
-			"tracking"=>$LANG["log"][10],
-			"contacts"=>$LANG["log"][11],
-			"enterprises"=>$LANG["log"][12],
-			"documents"=>$LANG["log"][13],
-			"knowbase"=>$LANG["log"][14],
-			"users"=>$LANG["log"][15],
-			"infocom"=>$LANG["log"][19],
-			"devices"=>$LANG["log"][18],
-			"links"=>$LANG["log"][38],
-			"typedocs"=>$LANG["log"][39],
-			"planning"=>$LANG["log"][16],
-			"reservation"=>$LANG["log"][42],
-			"contracts"=>$LANG["log"][17],
-			"phones"=>$LANG["log"][43],
-			"dropdown"=>$LANG["log"][44],
-			"groups"=>$LANG["log"][47],
-			"entity"=>$LANG["log"][63],
-			"reminder"=>$LANG["title"][37],
-			"rules"=>$LANG["log"][65]);
+	$logItemtype=array("system"=>$LANG['log'][1],
+			"computers"=>$LANG['log'][2],
+			"monitors"=>$LANG['log'][3],
+			"printers"=>$LANG['log'][4],
+			"software"=>$LANG['log'][5],
+			"networking"=>$LANG['log'][6],
+			"cartridges"=>$LANG['log'][7],
+			"peripherals"=>$LANG['log'][8],
+			"consumables"=>$LANG['log'][9],
+			"tracking"=>$LANG['log'][10],
+			"contacts"=>$LANG['log'][11],
+			"enterprises"=>$LANG['log'][12],
+			"documents"=>$LANG['log'][13],
+			"knowbase"=>$LANG['log'][14],
+			"users"=>$LANG['log'][15],
+			"infocom"=>$LANG['log'][19],
+			"devices"=>$LANG['log'][18],
+			"links"=>$LANG['log'][38],
+			"typedocs"=>$LANG['log'][39],
+			"planning"=>$LANG['log'][16],
+			"reservation"=>$LANG['log'][42],
+			"contracts"=>$LANG['log'][17],
+			"phones"=>$LANG['log'][43],
+			"dropdown"=>$LANG['log'][44],
+			"groups"=>$LANG['log'][47],
+			"entity"=>$LANG['log'][63],
+			"rules"=>$LANG['log'][65],
+			"reminder"=>$LANG['log'][81],
+			"transfers"=>$LANG['transfer'][1]);
 
 
-	$logService=array("inventory"=>$LANG["log"][50],
-			"tracking"=>$LANG["log"][51],
-			"planning"=>$LANG["Menu"][29],
-			"tools"=>$LANG["log"][53],
-			"financial"=>$LANG["log"][54],
-			"login"=>$LANG["log"][55],
-			"setup"=>$LANG["common"][12],
-			"security"=>$LANG["log"][66],
-			"reservation"=>$LANG["log"][58],
-			"cron"=>$LANG["log"][59],
-			"document"=>$LANG["Menu"][27],
-			"plugin"=>$LANG["common"][29]);
+	$logService=array("inventory"=>$LANG['Menu'][38],
+			"tracking"=>$LANG['Menu'][5],
+			"planning"=>$LANG['Menu'][29],
+			"tools"=>$LANG['Menu'][18],
+			"financial"=>$LANG['Menu'][26],
+			"login"=>$LANG['log'][55],
+			"setup"=>$LANG['common'][12],
+			"security"=>$LANG['log'][66],
+			"reservation"=>$LANG['log'][58],
+			"cron"=>$LANG['log'][59],
+			"document"=>$LANG['Menu'][27],
+			"plugin"=>$LANG['common'][29]);
 
 	return array($logItemtype,$logService);
 
@@ -452,6 +469,8 @@ function displayItemLogID($itemtype,$item){
  *
  *
  * @param $target where to go when complete
+ * @param $order order by clause occurences (eg: ) 
+ * @param $sort order by clause occurences (eg: date) 
  * @param $user
  **/
 function showAddEvents($target,$user="") {
@@ -461,12 +480,17 @@ function showAddEvents($target,$user="") {
 
 	list($logItemtype,$logService)=logArray();
 
+	// define default sorting
+
 	$usersearch="%";
 	if (!empty($user))
 		$usersearch=$user." ";
 
 	// Query Database
-	$query = "SELECT * FROM glpi_event_log WHERE message LIKE '".$usersearch.addslashes($LANG["log"][20])."%' ORDER BY `date` DESC LIMIT 0,".$CFG_GLPI["num_of_events"];
+	$query = "SELECT * 
+		FROM glpi_event_log 
+		WHERE message LIKE '".$usersearch.addslashes($LANG['log'][20])."%' 
+		ORDER BY date DESC LIMIT 0,".intval($_SESSION["glpinum_of_events"]);
 
 	// Get results
 	$result = $DB->query($query);
@@ -479,7 +503,7 @@ function showAddEvents($target,$user="") {
 	if ($number < 1) {
 		echo "<br>";
 		echo "<table class='tab_cadrehov'>";
-		echo "<tr><th>".$LANG["central"][4]."</th></tr>";
+		echo "<tr><th>".$LANG['central'][4]."</th></tr>";
 		echo "</table>";
 		echo "<br>";
 		return;
@@ -489,13 +513,16 @@ function showAddEvents($target,$user="") {
 	$i = 0;
 
 	echo "<br><table  class='tab_cadrehov'>";
-	echo "<tr><th colspan='5'><a href=\"".$CFG_GLPI["root_doc"]."/front/log.php\">".$LANG["central"][2]." ".$CFG_GLPI["num_of_events"]." ".$LANG["central"][8]."</a></th></tr>";
+	echo "<tr><th colspan='5'><a href=\"".$CFG_GLPI["root_doc"]."/front/log.php\">".$LANG['central'][2]." ".$_SESSION["glpinum_of_events"]." ".$LANG['central'][8]."</a></th></tr>";
 	echo "<tr>";
 
-	echo "<th colspan='2'>".$LANG["event"][0]."</th>";
-	echo "<th><img src='".$CFG_GLPI["root_doc"]."/pics/puce-down.png' alt='' title=''>".$LANG["common"][27]."</a></th>";
-	echo "<th width='8%'>".$LANG["event"][2]."</th>";
-	echo "<th width='60%'>".$LANG["event"][4]."</th></tr>";
+	echo "<th colspan='2'>".$LANG['event'][0]."</th>";
+
+	echo "<th>".$LANG['common'][27]."</th>";
+
+	echo "<th width='8%'>".$LANG['event'][2]."</th>";
+
+	echo "<th width='60%'>".$LANG['event'][4]."</th></tr>";
 
 	while ($i < $number) {
 		$ID = $DB->result($result, $i, "ID");
@@ -539,14 +566,14 @@ function showEvents($target,$order,$sort,$start=0) {
 
 	// Columns of the Table
 	$items = array(
-		"item"		=> array($LANG["event"][0], "colspan='2'"),
-		"date"		=> array($LANG["common"][27], ""),
-		"service"	=> array($LANG["event"][2], "width='8%'"),
-		"level"		=> array($LANG["event"][3], "width='8%'"),
-		"message"	=> array($LANG["event"][4], "width='50%'")
+		"item"		=> array($LANG['event'][0], "colspan='2'"),
+		"date"		=> array($LANG['common'][27], ""),
+		"service"	=> array($LANG['event'][2], "width='8%'"),
+		"level"		=> array($LANG['event'][3], "width='8%'"),
+		"message"	=> array($LANG['event'][4], "width='50%'")
 		);
-	// define default sorting
 
+	// define default sorting
 	if (!isset($items[$sort])) {
 		$sort = "date";
 	}
@@ -555,7 +582,7 @@ function showEvents($target,$order,$sort,$start=0) {
 	}
 
 	// Query Database
-	$query_limit = "SELECT * FROM glpi_event_log ORDER BY `$sort` $order LIMIT ".intval($start).",".intval($_SESSION["glpilist_limit"]);
+	$query_limit = "SELECT * FROM glpi_event_log ORDER BY `$sort` $order LIMIT ".intval($start).",".intval($_SESSION['glpilist_limit']);
 
 	// Number of results
 	$numrows = countElementsInTable("glpi_event_log");
@@ -565,7 +592,7 @@ function showEvents($target,$order,$sort,$start=0) {
 
 	// No Events in database
 	if ($number < 1) {
-		echo "<div class='center'><strong>".$LANG["central"][4]."</strong></div>";
+		echo "<div class='center'><strong>".$LANG['central'][4]."</strong></div>";
 		return;
 	}
 
@@ -578,7 +605,6 @@ function showEvents($target,$order,$sort,$start=0) {
 
 	echo "<table class='tab_cadre_fixe'>";
 	echo "<tr>";
-
 	foreach ($items as $field => $args) {
 		echo "<th ".$args[1].">";
 		
