@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: mailgate.class.php 8284 2009-05-14 17:29:09Z remi $
+ * @version $Id: mailgate.class.php 8840 2009-09-01 10:12:12Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -44,7 +44,7 @@ class Mailgate  extends CommonDBTM {
 	/**
 	 * Constructor
 	**/
-	function Mailgate () {
+	function __construct () {
 		$this->table="glpi_mailgate";
 		$this->type=MAILGATE_TYPE;
 	}
@@ -79,89 +79,84 @@ class Mailgate  extends CommonDBTM {
 
 		if (!haveRight("config","r")) return false;
 
-		$spotted = false;
-
-		if(empty($ID)) {
-			if($this->getEmpty()) $spotted = true;
+		if ($ID > 0){
+			$this->check($ID,'r');
 		} else {
-			if($this->getFromDB($ID)) $spotted = true;
+			// Create item 
+			$this->check(-1,'w');
+			$use_cache=false;
+			$this->getEmpty();
+		} 
+
+
+		echo "<div class='center'><form method='post' name=form action=\"$target\">";
+
+		echo "<table class='tab_cadre' cellpadding='2'>";
+
+		echo "<tr><th align='center' colspan='2'>";
+		if (empty($ID)){
+			echo $LANG['mailgate'][1];
+		} else {
+			echo $LANG['mailgate'][0].": ".$this->fields["ID"];
 		}
 
-		if ($spotted){
+		echo "</th></tr>";
+		if (!function_exists('mb_list_encodings')||!function_exists('mb_convert_encoding')){
+			echo "<tr class='tab_bg_1'><td align='center' colspan='2'>";
+			echo $LANG['mailgate'][4];
+			echo "</td></tr>";
+		}
+		echo "<tr class='tab_bg_2'><td>".$LANG['common'][16].":	</td><td>";
+		autocompletionTextField("name","glpi_mailgate","name",$this->fields["name"],40);
+		echo "</td></tr>";
 
-			echo "<div class='center'><form method='post' name=form action=\"$target\">";
+		echo "<tr class='tab_bg_2'><td>".$LANG['entity'][0].":	</td><td>";
+		dropdownValue("glpi_entities", "FK_entities",$this->fields["FK_entities"],1,$_SESSION['glpiactiveentities']);
+		echo "</td></tr>";
 
-			echo "<table class='tab_cadre' cellpadding='2'>";
+		showMailServerConfig($this->fields["host"]);
 
-			echo "<tr><th align='center' colspan='2'>";
-			if (empty($ID)){
-				echo $LANG["mailgate"][1];
+		echo "<tr class='tab_bg_2'><td>".$LANG['login'][6].":	</td><td>";
+		autocompletionTextField("login","glpi_mailgate","login",$this->fields["login"],40);
+		echo "</td></tr>";
+
+		echo "<tr class='tab_bg_2'><td>".$LANG['login'][7].":	</td><td>";
+		echo "<input type='password' name='password' value='' size='20'>";
+		echo "</td></tr>";
+
+
+		if (haveRight("config","w")) {
+
+			echo "<tr class='tab_bg_1'>";
+			if(empty($ID)){
+
+				echo "<td valign='top' colspan='2'>";
+				echo "<div class='center'><input type='submit' name='add' value=\"".$LANG['buttons'][8]."\" class='submit'></div>";
+				echo "</td>";
+				echo "</tr>";
 			} else {
-				echo $LANG["mailgate"][0].": ".$this->fields["ID"];
-			}
 
-			echo "</th></tr>";
-			if (!function_exists('mb_list_encodings')||!function_exists('mb_convert_encoding')){
-				echo "<tr class='tab_bg_1'><td align='center' colspan='2'>";
-				echo $LANG["mailgate"][4];
+				echo "<td valign='top' align='center'>";
+				echo "<input type='hidden' name='ID' value=\"$ID\">\n";
+				echo "<input type='submit' name='update' value=\"".$LANG['buttons'][7]."\" class='submit'>";
+				echo "</td>";
+				echo "<td valign='top'>\n";
+				echo "<div class='center'>";
+				echo "<input type='submit' name='delete' value=\"".$LANG['buttons'][6]."\" class='submit'>";
+				echo "</div>";
+				echo "</td>";
+				echo "</tr>";
+				echo "<tr class='tab_bg_1'><td colspan='2' align='center'><input type='submit' name='get_mails' value=\"".$LANG['mailgate'][2]."\" class='submit'>";
 				echo "</td></tr>";
 			}
-			echo "<tr class='tab_bg_2'><td>".$LANG["common"][16].":	</td><td>";
-			autocompletionTextField("name","glpi_mailgate","name",$this->fields["name"],20);
-			echo "</td></tr>";
-
-			echo "<tr class='tab_bg_2'><td>".$LANG["entity"][0].":	</td><td>";
-			dropdownValue("glpi_entities", "FK_entities",$this->fields["FK_entities"],1,$_SESSION['glpiactiveentities']);
-			echo "</td></tr>";
-
-			showMailServerConfig($this->fields["host"]);
-
-			echo "<tr class='tab_bg_2'><td>".$LANG["login"][6].":	</td><td>";
-			autocompletionTextField("login","glpi_mailgate","login",$this->fields["login"],20);
-			echo "</td></tr>";
-
-			echo "<tr class='tab_bg_2'><td>".$LANG["login"][7].":	</td><td>";
-			echo "<input type='password' name='password' value='' size='20'>";
-			echo "</td></tr>";
 
 
-			if (haveRight("config","w")) {
-
-				echo "<tr class='tab_bg_1'>";
-				if(empty($ID)){
-
-					echo "<td valign='top' colspan='2'>";
-					echo "<div class='center'><input type='submit' name='add' value=\"".$LANG["buttons"][8]."\" class='submit'></div>";
-					echo "</td>";
-					echo "</tr>";
-				} else {
-
-					echo "<td valign='top' align='center'>";
-					echo "<input type='hidden' name='ID' value=\"$ID\">\n";
-					echo "<input type='submit' name='update' value=\"".$LANG["buttons"][7]."\" class='submit'>";
-					echo "</td>";
-					echo "<td valign='top'>\n";
-					echo "<div class='center'>";
-					echo "<input type='submit' name='delete' value=\"".$LANG["buttons"][6]."\" class='submit'>";
-					echo "</div>";
-					echo "</td>";
-					echo "</tr>";
-					echo "<tr class='tab_bg_1'><td colspan='2' align='center'><input type='submit' name='get_mails' value=\"".$LANG["mailgate"][2]."\" class='submit'>";
-					echo "</td></tr>";
-				}
-
-
-			}
-
-			echo "</table></form></div>";
-
-			return true;	
-		}
-		else {
-			echo "<div class='center'><strong>".$LANG["common"][54]."</strong></div>";
-			return false;
 		}
 
+		echo "</table></form></div>";
+
+		return true;	
+
 	}
 	
 }
@@ -210,7 +205,7 @@ class MailCollect {
 	* @param $display display messages in MessageAfterRedirect or just return error
 	* @return if $display = false return messages result string
 	*/
-	function collect($server,$username,$password,$entity,$display=0){
+	function collect($server,$username,$password,$entity,$display=0,$mailgateID=0){
 		global $LANG;
 		$this->entity=$entity;
 
@@ -230,11 +225,13 @@ class MailCollect {
 
 			for($i=1;$i<=$tot && $i<= MAX_MAILS_RETRIEVED;$i++){
 				$tkt= $this->buildTicket($i);
+				$tkt['_mailgate']=$mailgateID;
+
 				$this->deleteMails($i); // Delete Mail from Mail box
 				$result=imap_fetchheader($this->marubox,$i);
 
 				// Is a mail responding of an already existgin ticket ?
-				if (array_key_exists('tracking',$tkt) ) {
+				if (isset($tkt['tracking']) ) {
 					// Deletion of message with sucess
 					if (false === is_array($result)){
 						$fup=new Followup();
@@ -245,7 +242,7 @@ class MailCollect {
 				} else { // New ticket
 					// Deletion of message with sucess
 					if (false === is_array($result)){
-						$track=new job;
+						$track=new Job();
 						$track->add($tkt);
 					} else {
 						$error++;
@@ -257,16 +254,20 @@ class MailCollect {
 			$this->close_mailbox();   //Close Mail Box
 
 			if ($display){
-				addMessageAfterRedirect($LANG["mailgate"][3].": ".$this->fetch_emails." ".($error>0?"($error ".$LANG["common"][63].")":""));
+				if ($error==0){
+					addMessageAfterRedirect($LANG['mailgate'][3].": ".$this->fetch_emails);
+				} else {
+					addMessageAfterRedirect($LANG['mailgate'][3].": ".$this->fetch_emails." ($error ".$LANG['common'][63].")",false,ERROR);
+				}
 			} else {
-				return $LANG["mailgate"][3].": ".$this->fetch_emails." ".($error>0?"($error ".$LANG["common"][63].")":"");
+				return "Number of messages available and collected : ".$this->fetch_emails." ".($error>0?"($error error(s))":"");
 			}
 			
 		}else{
 			if ($display){
-				addMessageAfterRedirect($LANG["log"][41]);
+				addMessageAfterRedirect($LANG['log'][41],false,ERROR);
 			} else {
-				return $LANG["log"][41];
+				return "Could not connect to mailgate server";
 			}
 //			return 0;
 		}
@@ -282,7 +283,7 @@ class MailCollect {
 		global $DB,$LANG,$CFG_GLPI;
 	
 		$head=$this->getHeaders($i);  // Get Header Info Return Array Of Headers **Key Are (subject,to,toOth,toNameOth,from,fromName)
-	
+
 		$tkt= array ();
 
 		// max size = 0 : no import attachments
@@ -296,7 +297,9 @@ class MailCollect {
 
 		//  Who is the user ?
 		$tkt['author']=0;
-		$query="SELECT ID from glpi_users WHERE email='".$head['from']."'";
+		$query="SELECT ID 
+			FROM glpi_users 
+			WHERE email='".$head['from']."'";
 		$result=$DB->query($query);
 		if ($result&&$DB->numrows($result)){
 			$tkt['author']=$DB->result($result,0,"ID");
@@ -304,9 +307,12 @@ class MailCollect {
 
 		// AUto_import
 		$tkt['_auto_import']=1;
+		// For followup : do not check author = login user
 		$tkt['_do_not_check_author']=1;
+
 		$body=$this->getBody($i);
 
+
 		// Do it before using charset variable
 		$head['subject']=$this->decodeMimeString($head['subject']);
 
@@ -322,18 +328,36 @@ class MailCollect {
 		if ($this->addtobody) {
 			$tkt['contents'] .= $this->addtobody;
 		}
-
-		$exists = false;
-		if ( preg_match('/\[GLPI #(\d+)\]/',$head['subject'],$match) ) {
-			// it's a reply to a previous ticket
-			$ID = (int)$match[1];
-			$tkt['tracking'] = $ID;
-			$job=new Job();
-			$job->getfromDB($ID);
-			// the job exists and the author is the same
-			if ( $job->getFromDB($ID) && ($job->fields["author"] == $tkt['author']) ) {
 		
-				$exists = true;
+		//// Detect if it is a mail reply
+		$glpi_message_match="/GLPI-([0-9]+)\.[0-9]+\.[0-9]+@\w*/";
+		// See In-Reply-To field
+		if (isset($head['in_reply_to'])){
+			if (preg_match($glpi_message_match,$head['in_reply_to'],$match)){
+				$tkt['tracking'] = (int)$match[1];
+			}
+		}
+		// See in References
+		if (!isset($tkt['tracking']) && isset($head['references'])){
+			if (preg_match($glpi_message_match,$head['references'],$match)){
+				$tkt['tracking'] = (int)$match[1];
+			}
+		}
+
+		// See in title
+		if (!isset($tkt['tracking']) && preg_match('/\[GLPI #(\d+)\]/',$head['subject'],$match)){
+				$tkt['tracking']=(int)$match[1];
+		}
+		// Found ticket link
+		if ( isset($tkt['tracking']) ) {
+			// it's a reply to a previous ticket
+			$job=new Job();
+
+			// Check if tracking exists and author exists in GLPI
+			/// TODO check if author have right to add a followup to the ticket
+			if ( $job->getFromDB($tkt['tracking'])
+               &&  ($tkt['author'] > 0 || !strcasecmp($job->fields['uemail'],$head['from'])) ) {
+		
 				$content=explode("\n",$tkt['contents']);
 				$tkt['contents']="";
 				$first_comment=true;
@@ -363,11 +387,12 @@ class MailCollect {
 				foreach($to_keep as $ID ){
 					$tkt['contents'].=$content[$ID]."\n";
 				}
+			} else {
+				unset($tkt['tracking']);
 			}
 		}
 
-                if ( ! $exists ) {
-			unset($tkt['tracking']);
+                if ( ! isset($tkt['tracking']) ) {
 			// Mail followup
 			$tkt['uemail']=$head['from'];
 			$tkt['emailupdates']=1;
@@ -382,12 +407,15 @@ class MailCollect {
 			$tkt['device_type']="0";
 			// Mail request type
 			$tkt['request_type']="2";
+		} else {
+			// Reopen if needed
+			$tkt['add_reopen']=1;
 		}
 
 		$tkt['contents']=clean_cross_side_scripting_deep(html_clean($tkt['contents']));
 
 		$tkt=addslashes_deep($tkt);
-		
+
 		return $tkt;
 	}
 
@@ -460,7 +488,7 @@ class MailCollect {
 	 ///Connect To the Mail Box
 	function connect()
 	{
-		$this->marubox=imap_open($this->server,$this->username,$this->password);
+		$this->marubox=@imap_open($this->server,$this->username,$this->password, 1);
 	}
 
 	/**
@@ -494,18 +522,25 @@ class MailCollect {
 	function getHeaders($mid) // Get Header info
 	{	
 		$mail_header=imap_header($this->marubox,$mid);
+		
 		$sender=$mail_header->from[0];
-		$sender_replyto=$mail_header->reply_to[0];
+		//$sender_replyto=$mail_header->reply_to[0];
 		if(strtolower($sender->mailbox)!='mailer-daemon' && strtolower($sender->mailbox)!='postmaster')
 		{
 			$mail_details=array(
 					'from'=>strtolower($sender->mailbox).'@'.$sender->host,
+					'subject'=>$mail_header->subject,
 					//'fromName'=>$sender->personal,
 					//'toOth'=>strtolower($sender_replyto->mailbox).'@'.$sender_replyto->host,
 					//'toNameOth'=>$sender_replyto->personal,
-					'subject'=>$mail_header->subject,
 					//'to'=>strtolower($mail_header->toaddress)
 				);
+			if (isset($mail_header->references)){
+					$mail_details['references'] = $mail_header->references;
+			}
+			if (isset($mail_header->in_reply_to)){
+					$mail_details['in_reply_to'] = $mail_header->in_reply_to;
+			}
 		}
 		return $mail_details;
 	}
@@ -540,12 +575,24 @@ class MailCollect {
 				} 
 				$text = imap_fetchbody($stream, $msg_number, $part_number); 
 				if($structure->encoding == 3) { 
-					return imap_base64($text); 
+					$text =  imap_base64($text); 
 				} else if($structure->encoding == 4) { 
-					return imap_qprint($text); 
-				} else { 
-					return $text; 
+					$text =  imap_qprint($text); 
 				} 
+                                 //else { return $text; } 
+                                 if( $structure->subtype && $structure->subtype=="HTML"){ 
+					$text = str_replace("\r","",$text);  
+					$text = str_replace("\n","",$text);  
+				}
+
+				if (count($structure->parameters)>0){ 
+   				  foreach ($structure->parameters as $param){ 
+				    if ((strtoupper($param->attribute)=='CHARSET') && function_exists('mb_convert_encoding') && strtoupper($param->value) != 'UTF-8'){ 
+                                       $text = mb_convert_encoding($text, 'utf-8',$param->value); 
+                                       } 
+                                   } 
+                                } 
+                            return $text;
 			} 
 			if($structure->type == 1){ /* multipart */ 
 				$prefix="";
@@ -663,17 +710,17 @@ class MailCollect {
 			$filename=$this->decodeMimeString($filename);
 
 			if ($structure->bytes > $maxsize) {
-				$this->addtobody .= "<br>".$LANG["mailgate"][6]." (" . getSize($structure->bytes) . "): ".$filename;
+				$this->addtobody .= "<br>".$LANG['mailgate'][6]." (" . getSize($structure->bytes) . "): ".$filename;
 				return false;
 			}
 			if (!isValidDoc($filename)){
-				$this->addtobody .= "<br>".$LANG["mailgate"][5]." (" . $this->get_mime_type($structure) . "): ".$filename;
+				$this->addtobody .= "<br>".$LANG['mailgate'][5]." (" . $this->get_mime_type($structure) . "): ".$filename;
 				return false;
 			}
 			if ($message=imap_fetchbody($this->marubox, $mid, $part)) {
 				switch ($structure->encoding)
 				{
-					case 0:	$message = imap_8bit($message); break;
+					// case 0:	$message = imap_7bit($message); break;
 					case 1:	$message = imap_8bit($message); break;
 					case 2: $message = imap_binary($message); break;
 					case 3: $message = imap_base64($message); break;
