@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: mailgate.function.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: mailgate.function.php 8481 2009-07-23 09:44:28Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -52,7 +52,7 @@ function cron_mailgate(){
 			while ($data=$DB->fetch_assoc($result)){
 				
 				logInFile("cron","Collect mails from ".$data["host"]." for  ".getDropdownName("glpi_entities",$data["FK_entities"])."\n");
-				$message=$mc->collect($data["host"],$data["login"],$data["password"],$data["FK_entities"]); 
+				$message=$mc->collect($data["host"],$data["login"],$data["password"],$data["FK_entities"],0,$data['ID']); 
  				logInFile("cron","$message\n");
 
 				$already_retrieve+=$mc->fetch_emails;
