@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: mailing.class.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: mailing.class.php 8913 2009-09-06 12:33:54Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -37,7 +37,7 @@ if (!defined('GLPI_ROOT')){
 	die("Sorry. You can't access directly to this file");
 	}
 
-require_once(GLPI_ROOT . "/lib/phpmailer/class.phpmailer.php");
+require_once(GLPI_PHPMAILER_DIR . "/class.phpmailer.php");
 
 /**
  *  glpi_phpmailer class extends 
@@ -53,33 +53,33 @@ class glpi_phpmailer extends phpmailer {
 	/**
 	 * Constructor
 	**/
-	function glpi_phpmailer(){
+	function __construct(){
 		global $CFG_GLPI;
 
 		// Comes from config
-		$this->SetLanguage("en", GLPI_ROOT . "/lib/phpmailer/language/");
-		if($CFG_GLPI['smtp_mode'] == '1') {
-			$this->Host = $CFG_GLPI['smtp_host'];
-			$this->Port = $CFG_GLPI['smtp_port'];
+		$this->SetLanguage("en", GLPI_PHPMAILER_DIR . "/language/");
 
+		if ($CFG_GLPI['smtp_mode'] != MAIL_MAIL){
+			$this->Mailer = "smtp";
+			$this->Host = $CFG_GLPI['smtp_host'];
 			if($CFG_GLPI['smtp_username'] != '') {
 				$this->SMTPAuth  = true;
 				$this->Username  = $CFG_GLPI['smtp_username'];
 				$this->Password  =  $CFG_GLPI['smtp_password'];
 			}
-
-			/*if($CFG_GLPI['debug']=="2"){
-				$this->SMTPDebug    = TRUE;
-			}*/
-
-			$this->Mailer = "smtp";
+			if ($CFG_GLPI['smtp_mode'] == MAIL_SMTPSSL){
+				$this->SMTPSecure = "ssl";
+			}
+			if ($CFG_GLPI['smtp_mode'] == MAIL_SMTPTLS){
+				$this->SMTPSecure = "tls";
+			}
+			
+		}
+		if ($_SESSION['glpi_use_mode']==DEBUG_MODE){ 
+			$this->do_debug = 3;
 		}
-
 	} 
 
-
-
-
 }
 
 
@@ -110,7 +110,7 @@ class Mailing
 	 * @param $followupisprivate true if the currently added/modified followup is private
 	 * @return nothing 
 	 */
-	function Mailing ($type="",$job=NULL,$user=NULL,$followupisprivate=false)
+	function __construct ($type="",$job=NULL,$user=NULL,$followupisprivate=false)
 	{
 		$this->type=$type;
 		if (!isset($job->hardwaredatas)||!count($job->hardwaredatas)){
@@ -121,6 +121,27 @@ class Mailing
 		$this->followupisprivate=$followupisprivate;
 	}
 
+	/**
+	 * Add new mail with lang to current email array
+	 * 
+	 * @param $emails : emails array
+	 * @param $mail : new email to add
+	 * @param $lang used with this email - default to config language
+	 *
+	 */
+	function addToEmailList(&$emails,$mail,$lang=''){
+		global $CFG_GLPI;
+
+		$new_mail=trim($mail);
+		$new_lang=trim($lang);
+
+		if (!empty($new_mail)){
+		
+			if (isValidEmail($new_mail)&&!isset($emails[$new_mail])){
+				$emails[$new_mail] = (empty($new_lang) ? $CFG_GLPI["language"] : $new_lang);
+			}
+		}
+	}
 	/**
 	 * Give mails to send the mail
 	 * 
@@ -160,21 +181,17 @@ class Mailing
 						switch($data["FK_item"]){
 							// ADMIN SEND
 							case ADMIN_MAILING :
-								if (isValidEmail($CFG_GLPI["admin_email"])&&!isset($emails[$CFG_GLPI["admin_email"]])){
-									$emails[$CFG_GLPI["admin_email"]]=$CFG_GLPI["default_language"];
-								}
+								$this->addToEmailList($emails,$CFG_GLPI["admin_email"]);
 								break;
 							// ADMIN ENTITY SEND
 							case ADMIN_ENTITY_MAILING :
 								$query2 = "SELECT admin_email AS EMAIL 
 									FROM glpi_entities_data 
-									WHERE (FK_entities = '".$this->job->fields["FK_entities"]."')";
+									WHERE FK_entities = '".$this->job->fields["FK_entities"]."'";
 								if ($result2 = $DB->query($query2)) {
 									if ($DB->numrows($result2)==1){
 										$row = $DB->fetch_array($result2);
-										if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-											$emails[$row['EMAIL']]=$CFG_GLPI["default_language"];
-										}
+										$this->addToEmailList($emails,$row['EMAIL']);
 									}
 								}
 								break;
@@ -183,13 +200,11 @@ class Mailing
 								if (isset($this->job->fields["assign"])&&$this->job->fields["assign"]>0){
 									$query2 = "SELECT DISTINCT glpi_users.email AS EMAIL, glpi_users.language AS LANG 
 										FROM glpi_users $join 
-										WHERE (glpi_users.ID = '".$this->job->fields["assign"]."')";
+										WHERE glpi_users.ID = '".$this->job->fields["assign"]."'";
 									if ($result2 = $DB->query($query2)) {
 										if ($DB->numrows($result2)==1){
 											$row = $DB->fetch_array($result2);
-											if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-												$emails[$row['EMAIL']]=$row['LANG'];
-											}
+											$this->addToEmailList($emails,$row['EMAIL'],$row['LANG']);
 										}
 									}
 								}
@@ -200,13 +215,11 @@ class Mailing
 								if (!$sendprivate&&isset($this->job->fields["assign_ent"])&&$this->job->fields["assign_ent"]>0){
 									$query2 = "SELECT DISTINCT glpi_enterprises.email AS EMAIL 
 									FROM glpi_enterprises 
-									WHERE (glpi_enterprises.ID = '".$this->job->fields["assign_ent"]."')";
+									WHERE glpi_enterprises.ID = '".$this->job->fields["assign_ent"]."'";
 									if ($result2 = $DB->query($query2)) {
 										if ($DB->numrows($result2)==1){
 											$row = $DB->fetch_array($result2);
-											if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-												$emails[$row['EMAIL']]=$CFG_GLPI["default_language"];
-											}
+											$this->addToEmailList($emails,$row['EMAIL']);
 										}
 									}
 								}
@@ -222,9 +235,7 @@ class Mailing
 									if ($result2= $DB->query($query)){
 										if ($DB->numrows($result2)){
 											while ($row=$DB->fetch_assoc($result2)){
-												if (isValidEmail($row["EMAIL"])&&!isset($emails[$row['EMAIL']])){
-													$emails[$row['EMAIL']]=$row['LANG'];
-												}
+												$this->addToEmailList($emails,$row['EMAIL'],$row['LANG']);
 											}
 										}
 									}
@@ -236,13 +247,11 @@ class Mailing
 									$query2 = "SELECT DISTINCT glpi_users.email AS EMAIL, glpi_users.language AS LANG 
 									FROM glpi_groups 
 									LEFT JOIN glpi_users ON (glpi_users.ID = glpi_groups.FK_users) $join 
-									WHERE (glpi_groups.ID = '".$this->job->fields["assign_group"]."')";
+									WHERE glpi_groups.ID = '".$this->job->fields["assign_group"]."'";
 									if ($result2 = $DB->query($query2)) {
 										if ($DB->numrows($result2)==1){
 											$row = $DB->fetch_array($result2);
-											if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-												$emails[$row['EMAIL']]=$row['LANG'];
-											}
+											$this->addToEmailList($emails,$row['EMAIL'],$row['LANG']);
 										}
 									}
 								}
@@ -254,13 +263,11 @@ class Mailing
 								if (isset($this->job->fields["recipient"])&&$this->job->fields["recipient"]>0){
 									$query2 = "SELECT DISTINCT glpi_users.email AS EMAIL, glpi_users.language AS LANG  
 										FROM glpi_users $join 
-										WHERE (glpi_users.ID = '".$this->job->fields["recipient"]."')";
+										WHERE glpi_users.ID = '".$this->job->fields["recipient"]."'";
 									if ($result2 = $DB->query($query2)) {
 										if ($DB->numrows($result2)==1){
 											$row = $DB->fetch_array($result2);
-											if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-												$emails[$row['EMAIL']]=$row['LANG'];
-											}
+											$this->addToEmailList($emails,$row['EMAIL'],$row['LANG']);
 										}
 									}
 								}
@@ -268,11 +275,11 @@ class Mailing
 
 							// AUTHOR SEND
 							case AUTHOR_MAILING :
-								if ($this->job->fields["emailupdates"]&&isValidEmail($this->job->fields["uemail"])&&!isset($emails[$this->job->fields["uemail"]])){
+								if ($this->job->fields["emailupdates"]){
 									// Uemail = mail of the author ? -> use right of the author to see private followups
 									// Else not see private
 									$authorsend=false;
-									$authorlang=$CFG_GLPI["default_language"];
+									$authorlang=$CFG_GLPI["language"];
 									if (!$sendprivate){
 										$authorsend=true;
 									} 
@@ -280,7 +287,7 @@ class Mailing
 									// Is the user have the same mail that uemail ?
 									$query2 = "SELECT DISTINCT glpi_users.email AS EMAIL, glpi_users.language AS LANG   
 									FROM glpi_users $join 
-									WHERE (glpi_users.ID = '".$this->job->fields["author"]."')";
+									WHERE glpi_users.ID = '".$this->job->fields["author"]."'";
 									if ($result2 = $DB->query($query2)) {
 										if ($DB->numrows($result2)==1){
 											$row = $DB->fetch_array($result2);
@@ -290,9 +297,20 @@ class Mailing
 											}
 										}
 									}
+                                                                       //don't send email if last followup from user, STOP spamming user!
+                                                                       $query3 = "SELECT * FROM glpi_followups WHERE tracking = '".$this->job->fields["ID"]."'  ORDER by date DESC LIMIT 1"; 
+                                                                       $result3=$DB->query($query3); 
+                                                                       if($data=$DB->fetch_array($result3)){ 
+                                                                           $fup=new Followup(); 
+                                                                           $fup->getFromDB($data['ID']); 
+                                                                           if($this->job->fields["author"] == $fup->fields["author"]) {
+										$authorsend=false; 
+                                                                           }
+									} 
+									$DB->free_result($result3);
 
 									if ($authorsend){
-										$emails[$this->job->fields["uemail"]]=$authorlang;
+										$this->addToEmailList($emails,$this->job->fields["uemail"],$authorlang);
 									}
 								}
 								break;
@@ -302,13 +320,11 @@ class Mailing
 									$query2 = "SELECT DISTINCT glpi_users.email AS EMAIL, glpi_users.language AS LANG 
 										FROM glpi_groups 
 										LEFT JOIN glpi_users ON (glpi_users.ID = glpi_groups.FK_users) $join 
-										WHERE (glpi_groups.ID = '".$this->job->fields["FK_group"]."')";
+										WHERE glpi_groups.ID = '".$this->job->fields["FK_group"]."'";
 									if ($result2 = $DB->query($query2)) {
 										if ($DB->numrows($result2)==1){
 											$row = $DB->fetch_array($result2);
-											if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-												$emails[$row['EMAIL']]=$row['LANG'];
-											}
+											$this->addToEmailList($emails,$row['EMAIL'],$row['LANG']);
 										}
 									}
 								}
@@ -319,13 +335,11 @@ class Mailing
 								if (isset($this->job->fields["_old_assign"])&&$this->job->fields["_old_assign"]>0){
 									$query2 = "SELECT DISTINCT glpi_users.email AS EMAIL, glpi_users.language AS LANG  
 										FROM glpi_users $join 
-										WHERE (glpi_users.ID = '".$this->job->fields["_old_assign"]."')";
+										WHERE glpi_users.ID = '".$this->job->fields["_old_assign"]."'";
 									if ($result2 = $DB->query($query2)) {
 										if ($DB->numrows($result2)==1){
 											$row = $DB->fetch_array($result2);
-											if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-												$emails[$row['EMAIL']]=$row['LANG'];
-											}
+											$this->addToEmailList($emails,$row['EMAIL'],$row['LANG']);
 										}
 									}
 								}
@@ -338,13 +352,11 @@ class Mailing
 									if ($tmp=$ci->getField('tech_num')){
 										$query2 = "SELECT DISTINCT glpi_users.email AS EMAIL, glpi_users.language AS LANG 
 											FROM glpi_users $join 
-											WHERE (glpi_users.ID = '".$tmp."')";
+											WHERE glpi_users.ID = '".$tmp."'";
 										if ($result2 = $DB->query($query2)) {
 											if ($DB->numrows($result2)==1){
 												$row = $DB->fetch_array($result2);
-												if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-													$emails[$row['EMAIL']]=$row['LANG'];
-												}
+												$this->addToEmailList($emails,$row['EMAIL'],$row['LANG']);
 											}
 										}
 									}
@@ -358,13 +370,11 @@ class Mailing
 									if ($tmp=$ci->getField('FK_users')){
 										$query2 = "SELECT DISTINCT glpi_users.email AS EMAIL, glpi_users.language AS LANG 
 											FROM glpi_users $join 
-											WHERE (glpi_users.ID = '".$tmp."')";
+											WHERE glpi_users.ID = '".$tmp."'";
 										if ($result2 = $DB->query($query2)) {
 											if ($DB->numrows($result2)==1){
 												$row = $DB->fetch_array($result2);
-												if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-													$emails[$row['EMAIL']]=$row['LANG'];
-												}
+												$this->addToEmailList($emails,$row['EMAIL'],$row['LANG']);
 											}
 										}
 									}
@@ -374,7 +384,7 @@ class Mailing
 						}
 						break;
 					case PROFILE_MAILING_TYPE :
-						$query="SELECT glpi_users.email AS EMAIL, glpi_users.language AS LANG 
+						$query="SELECT DISTINCT glpi_users.email AS EMAIL, glpi_users.language AS LANG 
 						FROM glpi_users_profiles 
 						INNER JOIN glpi_users ON (glpi_users_profiles.FK_users = glpi_users.ID) $joinprofile 
 						WHERE glpi_users.deleted=0 AND glpi_users_profiles.FK_profiles='".$data["FK_item"]."' ".
@@ -383,14 +393,12 @@ class Mailing
 						if ($result2= $DB->query($query)){
 							if ($DB->numrows($result2))
 								while ($row=$DB->fetch_assoc($result2)){
-									if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-										$emails[$row['EMAIL']]=$row['LANG'];
-									}
+									$this->addToEmailList($emails,$row['EMAIL'],$row['LANG']);
 								}
 						}
 						break;
 					case GROUP_MAILING_TYPE :
-						$query="SELECT glpi_users.email AS EMAIL, glpi_users.language AS LANG 
+						$query="SELECT DISTINCT glpi_users.email AS EMAIL, glpi_users.language AS LANG 
 							FROM glpi_users_groups 
 							INNER JOIN glpi_users ON (glpi_users_groups.FK_users = glpi_users.ID) $join 
 							WHERE glpi_users.deleted=0 AND glpi_users_groups.FK_groups='".$data["FK_item"]."'";
@@ -398,9 +406,7 @@ class Mailing
 						if ($result2= $DB->query($query)){
 							if ($DB->numrows($result2))
 								while ($row=$DB->fetch_assoc($result2)){
-									if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-										$emails[$row['EMAIL']]=$row['LANG'];
-									}
+									$this->addToEmailList($emails,$row['EMAIL'],$row['LANG']);
 								}
 						}
 						break;
@@ -426,7 +432,7 @@ class Mailing
 
 		if($format=="html"){
 			if ($CFG_GLPI["url_in_mail"]&&!empty($CFG_GLPI["url_base"])){
-				$body.="URL :<a href=\"".$CFG_GLPI["url_base"]."/index.php?redirect=tracking_".$this->job->fields["ID"]."\">".$CFG_GLPI["url_base"]."/index.php?redirect=tracking_".$this->job->fields["ID"]." </a><br><br>";
+				$body.="URL: <a href=\"".$CFG_GLPI["url_base"]."/index.php?redirect=tracking_".$this->job->fields["ID"]."\">".$CFG_GLPI["url_base"]."/index.php?redirect=tracking_".$this->job->fields["ID"]." </a><br><br>";
 
 			}
 
@@ -435,12 +441,12 @@ class Mailing
 
 			$body.="<br>-- <br>".$CFG_GLPI["mailing_signature"];
 			$body.="</body></html>";
-			$body=ereg_replace("\n","<br>\n",$body);
+			$body=str_replace("\n","<br>\n",$body);
 
 		}else{ // text format
 
 			if ($CFG_GLPI["url_in_mail"]&&!empty($CFG_GLPI["url_base"])){
-				$body.=$LANG["mailing"][1]."\n"; $body.="URL : ".$CFG_GLPI["url_base"]."/index.php?redirect=tracking_".$this->job->fields["ID"]."\n";
+				$body.=$LANG['mailing'][1]."\n"; $body.="URL: ".$CFG_GLPI["url_base"]."/index.php?redirect=tracking_".$this->job->fields["ID"]."\n";
 
 			}
 
@@ -448,8 +454,8 @@ class Mailing
 			$body.=$this->job->textFollowups($format, $sendprivate);
 
 			$body.="\n-- \n".$CFG_GLPI["mailing_signature"];
-			$body=ereg_replace("<br />","\n",$body);
-			$body=ereg_replace("<br>","\n",$body);
+			$body=str_replace("<br />","\n",$body);
+			$body=str_replace("<br>","\n",$body);
 		}
 
 		return $body;
@@ -462,7 +468,9 @@ class Mailing
 	function get_mail_sender(){
 		global $CFG_GLPI,$DB;
 
-		$query = "SELECT admin_email AS EMAIL FROM glpi_entities_data WHERE (FK_entities = '".$this->job->fields["FK_entities"]."')";
+		$query = "SELECT admin_email AS EMAIL 
+			FROM glpi_entities_data 
+			WHERE FK_entities = '".$this->job->fields["FK_entities"]."'";
 		if ($result=$DB->query($query)){
 			if ($DB->numrows($result)){
 				$data=$DB->fetch_assoc($result);
@@ -486,28 +494,28 @@ class Mailing
 		// Create the message subject 
 		$subject=sprintf("%s%07d%s","[GLPI #",$this->job->fields["ID"],"] ");
 
-		if (isMultiEntitiesMode()){
-			$subject.=getDropdownName("glpi_entities",$this->job->fields['FK_entities'])." | ";
-		}
+//		if (isMultiEntitiesMode()){
+//			$subject.=getDropdownName("glpi_entities",$this->job->fields['FK_entities'])." | ";
+//		}
 
 		switch ($this->type){
 			case "new":
-				$subject.=$LANG["mailing"][9];
+				$subject.=$LANG['mailing'][9];
 			break;
 			case "attrib":
-				$subject.=$LANG["mailing"][12];
+				$subject.=$LANG['mailing'][12];
 			break;
 			case "followup":
-				$subject.=$LANG["mailing"][10];
+				$subject.=$LANG['mailing'][10];
 			break;
 			case "update":
-				$subject.=$LANG["mailing"][30];
+				$subject.=$LANG['mailing'][30];
 			break;
 			case "finish":
-				$subject.=$LANG["mailing"][11]." ".convDateTime($this->job->fields["closedate"]);			
+				$subject.=$LANG['mailing'][11]." ".convDateTime($this->job->fields["closedate"]);			
 			break;
 			default :
-			$subject.=$LANG["mailing"][13];
+			$subject.=$LANG['mailing'][13];
 			break;
 		}
 		
@@ -531,7 +539,9 @@ class Mailing
 		$replyto=$CFG_GLPI["admin_email"];
 
 		// Entity  conf
-		$query = "SELECT admin_email AS EMAIL, admin_reply AS REPLY FROM glpi_entities_data WHERE (FK_entities = '".$this->job->fields["FK_entities"]."')";
+		$query = "SELECT admin_email AS EMAIL, admin_reply AS REPLY 
+			FROM glpi_entities_data 
+			WHERE FK_entities = '".$this->job->fields["FK_entities"]."'";
 		if ($result=$DB->query($query)){
 			if ($DB->numrows($result)){
 				$data=$DB->fetch_assoc($result);
@@ -606,8 +616,9 @@ class Mailing
 				// get reply-to address : user->email ou job_email if not set OK
 				$replyto=$this->get_reply_to_address ($sender);
 
-				$messageerror=$LANG["mailing"][47];
+				$messageerror=$LANG['mailing'][47];
 				// Send all mails
+
 				foreach ($users as $private=>$someusers) {
 					if (count($someusers)){
 
@@ -633,12 +644,13 @@ class Mailing
 							$mmail->AltBody=$altbodys[$lang];
 
 							$mmail->AddAddress($email, "");
-
+							$mmail->MessageID="GLPI-".$this->job->fields["ID"].".".time().".".rand()."@".$_SERVER['HTTP_HOST'];
+		
 							if(!$mmail->Send()){
 								$senderror=true;
 								addMessageAfterRedirect($messageerror."<br>".$mmail->ErrorInfo);
 							}else{
-								logInFile("mail",$LANG["tracking"][38]." ".$email.": ".$subjects[$lang]."\n");
+								logInFile("mail",$LANG['tracking'][38]." ".$email.": ".$subjects[$lang]."\n");
 							} 
 
 							$mmail->ClearAddresses(); 
@@ -651,7 +663,7 @@ class Mailing
 					return false;
 				}
 			} else {
-				addMessageAfterRedirect($LANG["mailing"][112]);
+				addMessageAfterRedirect($LANG['mailing'][112]);
 			}
 		}
 		return true;
@@ -675,13 +687,33 @@ class MailingResa{
 	 * @param $resa ReservationResa to mail
 	 * @return nothing 
 	 */
-	function MailingResa ($resa,$type="new")
+	function __construct ($resa,$type="new")
 	{
 		$this->resa=$resa;
 		$this->type=$type;
 
 	}
+	/**
+	 * Add new mail with lang to current email array
+	 * 
+	 * @param $emails : emails array
+	 * @param $mail : new email to add
+	 * @param $lang used with this email - default to config language
+	 *
+	 */
+	function addToEmailList(&$emails,$mail,$lang=''){
+		global $CFG_GLPI;
 
+		$new_mail=trim($mail);
+		$new_lang=trim($lang);
+
+		if (!empty($new_mail)){
+		
+			if (isValidEmail($new_mail)&&!isset($emails[$new_mail])){
+				$emails[$new_mail] = (empty($new_lang) ? $CFG_GLPI["language"] : $new_lang);
+			}
+		}
+	}
 	/**
 	 * Give mails to send the mail
 	 * 
@@ -704,8 +736,7 @@ class MailingResa{
 						switch ($data["FK_item"]){
 							// ADMIN SEND
 							case ADMIN_MAILING :
-								if (isValidEmail($CFG_GLPI["admin_email"])&&!isset($emails[$CFG_GLPI["admin_email"]]))
-									$emails[$CFG_GLPI["admin_email"]]=$CFG_GLPI["default_language"];
+								$this->addToEmailList($emails,$CFG_GLPI["admin_email"]);
 								break;
 							// ADMIN ENTITY SEND
 							case ADMIN_ENTITY_MAILING :
@@ -720,13 +751,13 @@ class MailingResa{
 								}
 								
 								if ($entity>=0){
-									$query2 = "SELECT admin_email AS EMAIL FROM glpi_entities_data WHERE (FK_entities = '".$entity."')";
+									$query2 = "SELECT admin_email AS EMAIL 
+										FROM glpi_entities_data 
+										WHERE FK_entities = '".$entity."'";
 									if ($result2 = $DB->query($query2)) {
 										if ($DB->numrows($result2)==1){
 											$row = $DB->fetch_array($result2);
-											if (isValidEmail($CFG_GLPI["admin_email"])&&!isset($emails[$CFG_GLPI["admin_email"]])){
-												$emails[$row['EMAIL']]=$CFG_GLPI["default_language"];
-											}
+											$this->addToEmailList($emails,$row['EMAIL']);
 										}
 									}
 								}
@@ -735,9 +766,7 @@ class MailingResa{
 							case AUTHOR_MAILING :
 								$user = new User;
 								if ($user->getFromDB($this->resa->fields["id_user"]))
-									if (isValidEmail($user->fields["email"])&&!isset($emails[$user->fields["email"]])){
-										$emails[$user->fields["email"]]=$user->fields['language'];
-									}
+									$this->addToEmailList($emails,$user->fields["email"],$user->fields['language']);
 								break;
 							// TECH SEND
 							case TECH_MAILING :
@@ -748,13 +777,11 @@ class MailingResa{
 
 									if ($tmp=$ci->getField('tech_num')){
 										$query2 = "SELECT glpi_users.email as EMAIL, glpi_users.language as LANG 
-										FROM glpi_users WHERE (glpi_users.ID = '".$tmp."')";
+										FROM glpi_users WHERE glpi_users.ID = '".$tmp."'";
 										if ($result2 = $DB->query($query2)) {
 											if ($DB->numrows($result2)==1){
 												$row = $DB->fetch_row($result2);
-												if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-													$emails[$row['EMAIL']]=$row['LANG'];
-												}
+												$this->addToEmailList($emails,$row['EMAIL'],$row['LANG']);
 											}
 										}
 									}
@@ -769,13 +796,11 @@ class MailingResa{
 
 									if ($tmp=$ci->getField('FK_users')){
 										$query2 = "SELECT glpi_users.email AS EMAIL, glpi_users.language as LANG 
-										FROM glpi_users WHERE (glpi_users.ID = '".$tmp."')";
+										FROM glpi_users WHERE glpi_users.ID = '".$tmp."'";
 										if ($result2 = $DB->query($query2)) {
 											if ($DB->numrows($result2)==1){
 												$row = $DB->fetch_row($result2);
-												if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-													$emails[$row['EMAIL']]=$row['LANG'];
-												}
+												$this->addToEmailList($emails,$row['EMAIL'],$row['LANG']);
 											}
 										}
 									}
@@ -799,9 +824,7 @@ class MailingResa{
 						if ($result2= $DB->query($query)){
 							if ($DB->numrows($result2))
 								while ($row=$DB->fetch_assoc($result2)){
-									if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-										$emails[$row['EMAIL']]=$row['LANG'];
-									}
+									$this->addToEmailList($emails,$row['EMAIL'],$row['LANG']);
 							}
 						}
 						break;
@@ -813,9 +836,7 @@ class MailingResa{
 						if ($result2= $DB->query($query)){
 							if ($DB->numrows($result2))
 								while ($row=$DB->fetch_assoc($result2)){
-									if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-										$emails[$row['EMAIL']]=$row['LANG'];
-									}
+									$this->addToEmailList($emails,$row['EMAIL'],$row['LANG']);
 								}
 						}
 						break;
@@ -844,7 +865,7 @@ class MailingResa{
 			}
 		}
 		if ($entity>=0){
-			$query = "SELECT admin_email AS EMAIL FROM glpi_entities_data WHERE (FK_entities = '$entity')";
+			$query = "SELECT admin_email AS EMAIL FROM glpi_entities_data WHERE FK_entities = '$entity'";
 			if ($result=$DB->query($query)){
 				if ($DB->numrows($result)){
 					$data=$DB->fetch_assoc($result);
@@ -875,13 +896,13 @@ class MailingResa{
 			$body.=$this->resa->textDescription("html");
 			$body.="<br>-- <br>".$CFG_GLPI["mailing_signature"];
 			$body.="</body></html>";
-			$body=ereg_replace("\n","<br>",$body);
+			$body=str_replace("\n","<br>",$body);
 		}else{ // text format
 
 			$body.=$this->resa->textDescription();
 			$body.="\n-- \n".$CFG_GLPI["mailing_signature"];
-			$body=ereg_replace("<br />","\n",$body);
-			$body=ereg_replace("<br>","\n",$body);
+			$body=str_replace("<br />","\n",$body);
+			$body=str_replace("<br>","\n",$body);
 		}
 		return $body;
 	}
@@ -895,9 +916,9 @@ class MailingResa{
 
 		// Create the message subject 
 		if ($this->type=="new")
-			$subject="[GLPI] ".$LANG["mailing"][19];
-		else if ($this->type=="update") $subject="[GLPI] ".$LANG["mailing"][23];
-		else if ($this->type=="delete") $subject="[GLPI] ".$LANG["mailing"][29];
+			$subject="[GLPI] ".$LANG['mailing'][19];
+		else if ($this->type=="update") $subject="[GLPI] ".$LANG['mailing'][23];
+		else if ($this->type=="delete") $subject="[GLPI] ".$LANG['mailing'][29];
 
 		return $subject;
 	}
@@ -970,10 +991,10 @@ class MailingResa{
 					$mmail->AddAddress($email, "");
 	
 					if(!$mmail->Send()){
-						echo "<div class='center'>".$LANG["mailing"][47]."</div>";
+						echo "<div class='center'>".$LANG['mailing'][47]."</div>";
 						return false;
 					}else{
-						logInFile("mail",$LANG["reservation"][40]." ".$email.": ".$subjects[$lang]."\n");
+						logInFile("mail",$LANG['reservation'][40]." ".$email.": ".$subjects[$lang]."\n");
 					}
 	
 					$mmail->ClearAddresses(); 
@@ -1007,7 +1028,7 @@ class MailingAlert
 	 * @param $entity Restrict to a defined entity
 	 * @return nothing 
 	 */
-	function MailingAlert ($type,$message,$entity=-1)
+	function __construct ($type,$message,$entity=-1)
 	{
 		$this->type=$type;
 		$this->message=$message;
@@ -1038,18 +1059,18 @@ class MailingAlert
 							// ADMIN SEND
 							case ADMIN_MAILING :
 								if (isValidEmail($CFG_GLPI["admin_email"])&&!isset($emails[$CFG_GLPI["admin_email"]]))
-									$emails[$CFG_GLPI["admin_email"]]=$CFG_GLPI["default_language"];
+									$emails[$CFG_GLPI["admin_email"]]=$CFG_GLPI["language"];
 								break;
 							// ADMIN ENTITY SEND
 							case ADMIN_ENTITY_MAILING :
 								$query2 = "SELECT admin_email AS EMAIL 
 									FROM glpi_entities_data 
-									WHERE (FK_entities = '".$this->entity."')";
+									WHERE FK_entities = '".$this->entity."'";
 								if ($result2 = $DB->query($query2)) {
 									if ($DB->numrows($result2)==1){
 										$row = $DB->fetch_array($result2);
 										if (isValidEmail($row['EMAIL'])&&!isset($emails[$row['EMAIL']])){
-											$emails[$row['EMAIL']]=$CFG_GLPI["default_language"];
+											$emails[$row['EMAIL']]=$CFG_GLPI["language"];
 										}
 									}
 								}
@@ -1112,13 +1133,13 @@ class MailingAlert
 			$body.=$this->message;
 			$body.="<br>-- <br>".$CFG_GLPI["mailing_signature"];
 			$body.="</body></html>";
-			$body=ereg_replace("\n","<br>",$body);
+			$body=str_replace("\n","<br>",$body);
 		}else{ // text format
 
 			$body.=$this->message;
 			$body.="\n-- \n".$CFG_GLPI["mailing_signature"];
-			$body=ereg_replace("<br />","\n",$body);
-			$body=ereg_replace("<br>","\n",$body);
+			$body=str_replace("<br />","\n",$body);
+			$body=str_replace("<br>","\n",$body);
 		}
 		return $body;
 	}
@@ -1136,19 +1157,19 @@ class MailingAlert
 
 		switch ($this->type){
 			case "alertcartridge" :
-				$subject.=" ".$LANG["mailing"][33]. " - ".getDropdownName("glpi_entities",$this->entity);
+				$subject.=" ".$LANG['mailing'][33]. " - ".getDropdownName("glpi_entities",$this->entity);
 			break;
 			case "alertconsumable":
-				$subject.=" ".$LANG["mailing"][36]. " - ".getDropdownName("glpi_entities",$this->entity);
+				$subject.=" ".$LANG['mailing'][36]. " - ".getDropdownName("glpi_entities",$this->entity);
 			break;
 			case "alertcontract":
-				$subject.=" ".$LANG["mailing"][39]. " - ".getDropdownName("glpi_entities",$this->entity);
+				$subject.=" ".$LANG['mailing'][39]. " - ".getDropdownName("glpi_entities",$this->entity);
 			break;
 			case "alertinfocom":
-				$subject.=" ".$LANG["mailing"][41]. " - ".getDropdownName("glpi_entities",$this->entity);
+				$subject.=" ".$LANG['mailing'][41]. " - ".getDropdownName("glpi_entities",$this->entity);
 			break;
 			case "alertlicense":
-				$subject.=" ".$LANG["mailing"][52]. " - ".getDropdownName("glpi_entities",$this->entity);
+				$subject.=" ".$LANG['mailing'][52]. " - ".getDropdownName("glpi_entities",$this->entity);
 			break;
 		}
 		return $subject;
@@ -1161,7 +1182,7 @@ class MailingAlert
 	function get_mail_sender(){
 		global $CFG_GLPI,$DB;
 
-		$query = "SELECT admin_email AS EMAIL FROM glpi_entities_data WHERE (FK_entities = '".$this->entity."')";
+		$query = "SELECT admin_email AS EMAIL FROM glpi_entities_data WHERE FK_entities = '".$this->entity."'";
 		if ($result=$DB->query($query)){
 			if ($DB->numrows($result)){
 				$data=$DB->fetch_assoc($result);
@@ -1228,10 +1249,10 @@ class MailingAlert
 					$mmail->AddAddress($email, "");
 
 					if(!$mmail->Send()){
-						addMessageAfterRedirect($LANG["mailing"][47]);
+						addMessageAfterRedirect($LANG['mailing'][47]);
 						return false;
 					}else{
-						logInFile("mail",$LANG["mailing"][111]." ".$email.": ".$subjects[$lang]."\n");
+						logInFile("mail",$LANG['mailing'][111]." ".$email.": ".$subjects[$lang]."\n");
 					}
 					$mmail->ClearAddresses(); 
 				}
