@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: profile.function.php 7875 2009-01-23 15:16:47Z moyo $
+ * @version $Id: profile.function.php 8247 2009-04-29 11:50:34Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -37,45 +37,6 @@ if (!defined('GLPI_ROOT')){
 	die("Sorry. You can't access directly to this file");
 	}
 
-function showProfileConfig($target,$ID,$prof){
-	global $LANG,$CFG_GLPI;
-	
-	$onfocus="";
-		if (!empty($ID)&&$ID){
-			$prof->getFromDB($ID);
-		} else {
-			$prof->getEmpty();
-			$onfocus="onfocus=\"this.value=''\"";
-		}
-	
-	if (empty($prof->fields["interface"])) $prof->fields["interface"]="helpdesk";
-	if (empty($prof->fields["name"])) $prof->fields["name"]=$LANG["common"][0];
-	
-	echo "<form name='form' method='post' action=\"$target\">";
-	echo "<div class='center'>";
-	echo "<table class='tab_cadre_fixe'><tr>";
-	echo "<th>".$LANG["common"][16]." :&nbsp;&nbsp;&nbsp;&nbsp;";
-	echo "<input type='text' name='name' value=\"".$prof->fields["name"]."\" $onfocus></th>";
-	echo "<th>".$LANG["profiles"][2]." :&nbsp;&nbsp;&nbsp;&nbsp;";
-	echo "<select name='interface' id='profile_interface'>";
-	echo "<option value='helpdesk' ".($prof->fields["interface"]=="helpdesk"?"selected":"").">".$LANG["Menu"][31]."</option>";
-	echo "<option value='central' ".($prof->fields["interface"]=="central"?"selected":"").">".$LANG["title"][0]."</option>";
-	echo "</select></th>";
-	echo "</tr></table>";
-
-	$params=array('interface'=>'__VALUE__','ID'=>$ID,);
-	
-	ajaxUpdateItemOnSelectEvent("profile_interface","profile_form",$CFG_GLPI["root_doc"]."/ajax/profiles.php",$params,false);
-	ajaxUpdateItem("profile_form",$CFG_GLPI["root_doc"]."/ajax/profiles.php",$params,false,'profile_interface');
-
-	echo "<div align='center' id='profile_form'>";
-	echo "</div>";
-	echo "</div>";
-	showLegend();
-	echo "</form>";
-}
-
-	
 function showProfileEntityUser($target,$ID,$prof){	
  	
  	global $DB,$LANG,$CFG_GLPI;
@@ -92,8 +53,8 @@ function showProfileEntityUser($target,$ID,$prof){
 	 	
  	echo "<div class='center'>";
 	echo "<table class='tab_cadre_fixe'><tr>";
-	echo "<th>".$LANG["profiles"][22]." :&nbsp;&nbsp;&nbsp;&nbsp;".$prof->fields["name"]."</th></tr>";
-	echo "<tr><th colspan='2'>".$LANG["Menu"][14]." (D=".$LANG["profiles"][29].", R=".$LANG["profiles"][28].")</th></tr>";
+	echo "<th>".$LANG['profiles'][22]." :&nbsp;&nbsp;&nbsp;&nbsp;".$prof->fields["name"]."</th></tr>";
+	echo "<tr><th colspan='2'>".$LANG['Menu'][14]." (D=".$LANG['profiles'][29].", R=".$LANG['profiles'][28].")</th></tr>";
  	echo "</table>";
 	echo "</div>";
   	
@@ -101,24 +62,27 @@ function showProfileEntityUser($target,$ID,$prof){
 		return false;
 	}
 
-  	$query="SELECT glpi_users.*, glpi_users_profiles.FK_entities AS entity, glpi_users_profiles.ID AS linkID, glpi_users_profiles.dynamic as dynamic,glpi_users_profiles.recursive as recursive   
+  	$query="SELECT glpi_users.*, glpi_users_profiles.FK_entities AS entity, glpi_users_profiles.ID AS linkID, 
+			glpi_users_profiles.dynamic as dynamic,glpi_users_profiles.recursive as recursive   
  		FROM glpi_users_profiles 
  		LEFT JOIN glpi_entities ON (glpi_entities.ID=glpi_users_profiles.FK_entities)
  		LEFT JOIN glpi_users ON (glpi_users.ID=glpi_users_profiles.FK_users)
- 		WHERE glpi_users_profiles.FK_profiles='".$ID."' AND glpi_users.deleted=0 ".getEntitiesRestrictRequest("AND","glpi_users_profiles")." 
+ 		WHERE glpi_users_profiles.FK_profiles='".$ID."' 
+			AND glpi_users.deleted=0 ".getEntitiesRestrictRequest("AND","glpi_users_profiles")." 
  		ORDER BY glpi_entities.completename";
 
  	echo "<div class='center'>";
 	echo "<table class='tab_cadre_fixe'>";
-
+ 	
 	$i=0;
 	$nb_per_line=3;
+	$rand=mt_rand(); // Just to avoid IDE warning
 
  	if ($result = $DB->query($query))
  	{ 
  		if ($DB->numrows($result)!=0)
 	 	{
-	 		
+
 	 		$temp=-1;
 	 		while ($data=$DB->fetch_array($result)) 
 			{	
@@ -137,17 +101,17 @@ function showProfileEntityUser($target,$ID,$prof){
 						echo "</table>";
 						if ($canedit){
 							echo "<div class='center'>";
-							echo "<table width='100%'>";
-							echo "<tr><td><img src=\"".$CFG_GLPI["root_doc"]."/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markAllRows('profileuser_form$temp') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=all'>".$LANG["buttons"][18]."</a></td>";
+							echo "<table width='100%' class='tab_glpi'>";
+							echo "<tr><td><img src=\"".$CFG_GLPI["root_doc"]."/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markCheckboxes('profileuser_form".$rand."_$temp') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=all'>".$LANG['buttons'][18]."</a></td>";
 							
-							echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkAllRows('profileuser_form$temp') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=none'>".$LANG["buttons"][19]."</a>";
+							echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkCheckboxes('profileuser_form".$rand."_$temp') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=none'>".$LANG['buttons'][19]."</a>";
 							echo "</td><td align='left' width='80%'>";
 							dropdownValue("glpi_entities","FK_entities",0,1,$_SESSION['glpiactiveentities']);
-							echo "&nbsp;<input type='submit' name='moveentity' value=\"".$LANG["buttons"][20]."\"
+							echo "&nbsp;<input type='submit' name='moveentity' value=\"".$LANG['buttons'][20]."\"
  class='submit'>";
-							echo "&nbsp;<input type='submit' name='deleteuser' value=\"".$LANG["buttons"][6]."\" class='submit'>";
+							echo "&nbsp;<input type='submit' name='deleteuser' value=\"".$LANG['buttons'][6]."\" class='submit'>";
 
-							echo "</td>";
+							echo "</td></tr>";
 							echo "</table>";
 							echo "</div>";
 						}
@@ -159,18 +123,18 @@ function showProfileEntityUser($target,$ID,$prof){
 		 			$i=0;
 		 			$temp=$data["entity"];		
 
-					
+					$rand=mt_rand();
 					echo "<tr class='tab_bg_2'>";
 					echo "<td align='left'>"; 
-					echo "<a href=\"javascript:showHideDiv('entity$temp','imgcat$temp', '".GLPI_ROOT."/pics/folder.png','".GLPI_ROOT."/pics/folder-open.png');\">";
+					echo "<a href=\"javascript:showHideDiv('entity$temp$rand','imgcat$temp', '".GLPI_ROOT."/pics/folder.png','".GLPI_ROOT."/pics/folder-open.png');\">";
 					echo "<img alt='' name='imgcat$temp' src=\"".GLPI_ROOT."/pics/folder.png\">&nbsp; <strong>".getDropdownName('glpi_entities',$data["entity"])."</strong>";
 					echo "</a>"; 
 					echo "</td>"; 
 					echo "</tr>"; 
 					echo "<tr><td>";
-
-					echo "<form name='profileuser_form$temp' id='profileuser_form$temp' method='post' action=\"$target\">";
-					echo "<div align='center' id='entity$temp' style=\"display:none;\">\n"; 
+	 				
+					echo "<form name='profileuser_form".$rand."_$temp' id='profileuser_form".$rand."_$temp' method='post' action=\"$target\">";
+					echo "<div align='center' id='entity$temp$rand' style=\"display:none;\">\n"; 
 					echo "<table class='tab_cadre_fixe'>\n";
 				}
 
@@ -221,14 +185,14 @@ function showProfileEntityUser($target,$ID,$prof){
 				echo "</table>";
 				if ($canedit){
 					echo "<div class='center'>";
-					echo "<table width='100%'>";
-					echo "<tr><td><img src=\"".$CFG_GLPI["root_doc"]."/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markAllRows('profileuser_form$temp') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=all'>".$LANG["buttons"][18]."</a></td>";
+					echo "<table width='100%' class='tab_glpi'>";
+					echo "<tr><td><img src=\"".$CFG_GLPI["root_doc"]."/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markCheckboxes('profileuser_form".$rand."_$temp') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=all'>".$LANG['buttons'][18]."</a></td>";
 					
-					echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkAllRows('profileuser_form$temp') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=none'>".$LANG["buttons"][19]."</a>";
+					echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkCheckboxes('profileuser_form".$rand."_$temp') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=none'>".$LANG['buttons'][19]."</a>";
 					echo "</td><td align='left' width='80%'>";
 					dropdownValue("glpi_entities","FK_entities",0,1,$_SESSION['glpiactiveentities']);
-					echo "&nbsp;<input type='submit' name='moveentity' value=\"".$LANG["buttons"][20]."\" class='submit'>";
-					echo "&nbsp;<input type='submit' name='deleteuser' value=\"".$LANG["buttons"][6]."\" class='submit'>";
+					echo "&nbsp;<input type='submit' name='moveentity' value=\"".$LANG['buttons'][20]."\" class='submit'>";
+					echo "&nbsp;<input type='submit' name='deleteuser' value=\"".$LANG['buttons'][6]."\" class='submit'>";
 					echo "</td>";
 					echo "</table>";
 					echo "</div>";
@@ -238,7 +202,7 @@ function showProfileEntityUser($target,$ID,$prof){
 
 		}
  		else
- 			echo "<tr><td class='tab_bg_1' align=center>".$LANG["profiles"][33]."</td></tr>";
+ 			echo "<tr><td class='tab_bg_1' align=center>".$LANG['profiles'][33]."</td></tr>";
  		}
  
  	echo "</table>";
@@ -246,13 +210,4 @@ function showProfileEntityUser($target,$ID,$prof){
 
   }
 
-function showLegend(){
-	global $LANG;
-	
-	echo "<table class='tab_cadre_fixe'>";
-	echo "<tr class='tab_bg_2'><td width='70' style='text-decoration:underline'><strong>".$LANG["profiles"][34]." : </strong></td><td class='tab_bg_4' width='15' style='border:1px solid black'></td><td><strong>".$LANG["profiles"][0]."</strong></td></tr>";
-	echo "<tr class='tab_bg_2'><td></td><td class='tab_bg_2' width='15' style='border:1px solid black'></td><td><strong>".$LANG["profiles"][1]."</strong></td></tr>";
-	echo "</table>";
-}
-
 ?>
