@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: registry.class.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: registry.class.php 7762 2009-01-06 18:30:32Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -42,7 +42,7 @@ class Registry extends CommonDBTM{
 	/**
 	 * Constructor
 	**/
-   function Registry () {
+	function __construct () {
 		$this->table="glpi_registry";		
 		$this->type=REGISTRY_TYPE;
 	}
