@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: registry.function.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: registry.function.php 8026 2009-02-28 16:50:46Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -50,25 +50,26 @@ function showRegistry($ID){
 	"HKEY_DYN_DATA");
 
 
-	$query = "SELECT ID FROM glpi_registry WHERE computer_id='".$ID."'";
+	$query = "SELECT ID 
+		FROM glpi_registry 
+		WHERE computer_id='".$ID."'";
 	
-	echo "<br>";
 	if ($result = $DB->query($query)) {
 		if ($DB->numrows($result)!=0) { 
 			
-			echo "<br><br><div class='center'><table class='tab_cadre_fixe'>";
+			echo "<div class='center'><table class='tab_cadre_fixe'>";
 			echo "<tr>";
 			echo "<th colspan='4'>";
 			echo $DB->numrows($result)." ";
-			echo $LANG["registry"][4];
+			echo $LANG['registry'][4];
 			
 			echo ":</th>";
 
 			echo "</tr>";        
 			echo "<tr>";			
-			echo "<th>".$LANG["registry"][6]."</th>";
-			echo "<th>".$LANG["registry"][1]."</th><th>".$LANG["registry"][2]."</th>";
-			echo "<th>".$LANG["registry"][3]."</th></tr>\n";	
+			echo "<th>".$LANG['registry'][6]."</th>";
+			echo "<th>".$LANG['registry'][1]."</th><th>".$LANG['registry'][2]."</th>";
+			echo "<th>".$LANG['registry'][3]."</th></tr>\n";	
 			while ($regid=$DB->fetch_row($result)) {
 				$reg = new Registry;
 				$reg->getFromDB(current($regid));	
@@ -84,7 +85,7 @@ function showRegistry($ID){
 			echo "</div>\n\n";
 	
 		}
-		else echo "<div class='center'><strong>".$LANG["registry"][5]."</strong></div>";
+		else echo "<div class='center'><strong>".$LANG['registry'][5]."</strong></div>";
 	}
 	
 }
