@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: relation.constant.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: relation.constant.php 8557 2009-07-28 20:17:55Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -39,16 +39,19 @@ $RELATION=array(
 
 	"glpi_auth_ldap" => array("glpi_config"=>"extra_ldap_server",
 				"glpi_auth_ldap_replicate"=>"server_id"),
+	"glpi_bookmark" => array("glpi_display_default"=>"FK_bookmark"),
 
 	"glpi_cartridges_type" => array("glpi_cartridges"=>"FK_glpi_cartridges_type",
 				"glpi_cartridges_assoc"=>"FK_glpi_cartridges_type"),
 
 	"glpi_computers" => array("glpi_computer_device"=>"FK_computers",
+						"glpi_computerdisks"=>"FK_computers",
 						"glpi_connect_wire"=>"end2",
 						"glpi_inst_software"=>"cID",
-						"glpi_licenses"=>"oem_computer",
+						"glpi_softwarelicenses"=>"FK_computers",
 						"glpi_ocs_link"=>"glpi_id",
-						"glpi_registry"=>"computer_id"),
+						"glpi_registry"=>"computer_id",
+						),
 
 	"glpi_consumables_type" => array("glpi_consumables"=>"FK_glpi_consumables_type"),
 
@@ -78,17 +81,22 @@ $RELATION=array(
 						"glpi_networking"=>"domain"),
 	
 	"glpi_dropdown_enttype" =>array("glpi_enterprises"=>"type"),
+
+	"glpi_dropdown_filesystems" =>array("glpi_computerdisks"=>"FK_filesystems"),
 	
 	"glpi_dropdown_firmware" =>array("glpi_networking"=>"firmware"),
 	
 	"glpi_dropdown_iface" =>array("glpi_networking_ports"=>"iface"),
 	
 	"glpi_dropdown_interface" =>array("glpi_device_hdd"=>"interface",
-						"glpi_device_drive"=>"interface",
-						"glpi_device_control"=>"interface"),
+					"glpi_device_drive"=>"interface",
+					"glpi_device_gfxcard"=>"FK_interface",
+					"glpi_device_control"=>"interface"),
 	
 	"glpi_dropdown_kbcategories" =>array("glpi_dropdown_kbcategories"=>"parentID",
 					"glpi_kbitems" =>"categoryID"),
+
+	"glpi_dropdown_licensetypes" =>array("glpi_softwarelicenses"=>"type"),
 	
 	"glpi_dropdown_locations" =>array(
 					"glpi_cartridges_type"=>"location",
@@ -126,13 +134,6 @@ $RELATION=array(
 						"glpi_phones"=>"FK_glpi_enterprise",
 						"glpi_printers"=>"FK_glpi_enterprise",
 						"glpi_software"=>"FK_glpi_enterprise",
-						"glpi_rule_cache_model_computer"=>"manufacturer",
-						"glpi_rule_cache_model_monitor"=>"manufacturer",
-						"glpi_rule_cache_model_networking"=>"manufacturer",
-						"glpi_rule_cache_model_peripheral"=>"manufacturer",
-						"glpi_rule_cache_model_phone"=>"manufacturer",
-						"glpi_rule_cache_model_printer"=>"manufacturer",
-						"glpi_rule_cache_software"=>array("manufacturer","new_manufacturer"),
 	),
 	
 	"glpi_dropdown_model" =>array("glpi_computers"=>"model"),
@@ -151,11 +152,11 @@ $RELATION=array(
 	"glpi_dropdown_netpoint" =>array("glpi_networking_ports"=>"netpoint"),
 	
 	"glpi_dropdown_network" =>array("glpi_computers"=>"network",
-								"glpi_printers"=>"network",
-								"glpi_networking"=>"network",),
+					"glpi_printers"=>"network",
+					"glpi_networking"=>"network",),
 	
 	"glpi_dropdown_os" =>array("glpi_computers"=>"os",
-												"glpi_software"=>"platform"),
+				"glpi_software"=>"platform"),
 	
 	"glpi_dropdown_os_sp" =>array("glpi_computers"=>"os_sp"),
 	
@@ -177,10 +178,15 @@ $RELATION=array(
 					"glpi_peripherals"=>"state",
 					"glpi_phones"=>"state",
 					"glpi_printers"=>"state",
-					"glpi_software"=>"state",
+					"glpi_software"=>"oldstate", /// TODO DEL
+					"glpi_softwareversions"=>"state",
 				),
 	
 	"glpi_dropdown_tracking_category" =>array("glpi_tracking"=>"category"),
+
+	"glpi_dropdown_user_titles" =>array("glpi_users"=>"title"),
+	
+	"glpi_dropdown_user_types" =>array("glpi_users"=>"type"),
 	
 	"glpi_dropdown_vlan" =>array("glpi_networking_vlan"=>"FK_vlan"),
 	
@@ -203,6 +209,7 @@ $RELATION=array(
 				"_glpi_entities_data"=>"FK_entities",
 				"glpi_groups"=>"FK_entities",
 				"glpi_kbitems"=>"FK_entities",
+				"glpi_links"=>"FK_entities",
 				"glpi_mailgate"=>"FK_entities",
 				"glpi_monitors"=>"FK_entities",
 				"glpi_networking"=>"FK_entities",
@@ -212,6 +219,7 @@ $RELATION=array(
 				"glpi_reminder"=>"FK_entities",
 				"glpi_rules_descriptions"=>"FK_entities",
 				"glpi_software"=>"FK_entities",
+				"glpi_softwarelicenses"=>"FK_entities",
 				"glpi_tracking"=>"FK_entities",
 				"glpi_users"=>"FK_entities",
 				"glpi_users_profiles"=>"FK_entities"),
@@ -228,7 +236,6 @@ $RELATION=array(
 						"glpi_users_groups"=>"FK_groups",
 	),
 	
-	"glpi_licenses" =>array("glpi_inst_software"=>"license"),
 
 	"glpi_links" =>array("glpi_links_device"=>"FK_links"),
 	
@@ -265,8 +272,12 @@ $RELATION=array(
 						"glpi_rule_cache_os"=>"rule_id",
 						"glpi_rule_cache_os_sp"=>"rule_id",
 						"glpi_rule_cache_os_version"=>"rule_id"),
-						"glpi_software" =>array("glpi_licenses"=>"sID",
-						"glpi_software"=>"update_software"),
+	"glpi_software" =>array("glpi_softwarelicenses"=>"sID",
+				"glpi_softwareversions"=>"sID",
+				"glpi_software"=>"update_software"),
+
+	"glpi_softwareversions" =>array("glpi_inst_software"=>"vID",
+					"glpi_softwarelicenses"=>array("buy_version","use_version")),
 
 	"glpi_tracking" => array("_glpi_docs"=>"FK_tracking",
 				"glpi_followups"=>"tracking"),
@@ -275,7 +286,7 @@ $RELATION=array(
 	
 	"glpi_type_monitors"=>array("glpi_monitors"=>"type"),
 	
-	"glpi_type_docs"=>array("glpi_monitors"=>"type"),
+//	"glpi_type_docs"=>array("glpi_documents"=>"type"),
 	
 	"glpi_type_networking"=>array("glpi_networking"=>"type"),
 	
@@ -291,6 +302,7 @@ $RELATION=array(
 				"glpi_consumables"=>"id_user",
 				"glpi_consumables_type"=>"tech_num",
 				"glpi_display"=>"FK_users",
+				"glpi_display_default"=>"FK_users",
 				"glpi_docs"=>"FK_users",
 				"glpi_followups"=>"author",
 				"glpi_groups"=>"FK_users",
@@ -309,5 +321,13 @@ $RELATION=array(
 				"glpi_users_profiles"=>"FK_users",
 
 	),
+
+	// link from devices tables (computers, software, ...)
+	"_virtual_device" => array (
+		"glpi_contract_device" 	=> array("FK_device","device_type"),
+		"glpi_doc_device"		=> array("FK_device","device_type"),
+		"glpi_infocoms"			=> array("FK_device","device_type"),
+		),
 	
-);
\ No newline at end of file
+);
+?>
