@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.dictionnary.dropdown.class.php 8340 2009-05-29 17:06:39Z remi $
+ * @version $Id: rule.dictionnary.dropdown.class.php 8044 2009-03-04 16:12:43Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -39,9 +39,8 @@ class RuleDictionnaryDropdown extends RuleCached{
 	 * Constructor
 	 * @param $type dropdown type
 	**/
-	function RuleDictionnaryDropdown($type){
-		parent::RuleCached();
-		$this->rule_type=$type;
+	function __construct($type){
+		parent::__construct($type);
 		$this->can_sort=true;
 		$this->right="rule_dictionnary_dropdown";
 	}
@@ -52,60 +51,60 @@ class RuleDictionnaryDropdown extends RuleCached{
 
 	function getTitle() {
 		global $LANG;
-		switch ($this->rule_type){
+		switch ($this->sub_type){
 			case RULE_DICTIONNARY_MANUFACTURER :
-				return $LANG["rulesengine"][36];
+				return $LANG['rulesengine'][36];
 			break;
 			case RULE_DICTIONNARY_MODEL_COMPUTER :
-				return $LANG["rulesengine"][50];
+				return $LANG['rulesengine'][50];
 			break;
 			case RULE_DICTIONNARY_TYPE_COMPUTER :
-				return $LANG["rulesengine"][60];
+				return $LANG['rulesengine'][60];
 			break;
 			case RULE_DICTIONNARY_MODEL_MONITOR :
-				return $LANG["rulesengine"][51];
+				return $LANG['rulesengine'][51];
 			break;
 			case RULE_DICTIONNARY_TYPE_MONITOR :
-				return $LANG["rulesengine"][61];
+				return $LANG['rulesengine'][61];
 			break;
 			case RULE_DICTIONNARY_MODEL_PRINTER :
-				return $LANG["rulesengine"][54];
+				return $LANG['rulesengine'][54];
 			break;
 			case RULE_DICTIONNARY_TYPE_PRINTER :
-				return $LANG["rulesengine"][64];
+				return $LANG['rulesengine'][64];
 			break;
 			case RULE_DICTIONNARY_MODEL_PHONE :
-				return $LANG["rulesengine"][52];
+				return $LANG['rulesengine'][52];
 			break;
 			case RULE_DICTIONNARY_TYPE_PHONE :
-				return $LANG["rulesengine"][62];
+				return $LANG['rulesengine'][62];
 			break;
 			case RULE_DICTIONNARY_MODEL_PERIPHERAL :
-				return $LANG["rulesengine"][53];
+				return $LANG['rulesengine'][53];
 			break;
 			case RULE_DICTIONNARY_TYPE_PERIPHERAL :
-				return $LANG["rulesengine"][63];
+				return $LANG['rulesengine'][63];
 			break;
 			case RULE_DICTIONNARY_MODEL_NETWORKING :
-				return $LANG["rulesengine"][55];
+				return $LANG['rulesengine'][55];
 			break;
 			case RULE_DICTIONNARY_TYPE_NETWORKING :
-				return $LANG["rulesengine"][65];
+				return $LANG['rulesengine'][65];
 			break;
 			case RULE_DICTIONNARY_OS :
-				return $LANG["rulesengine"][67];
+				return $LANG['rulesengine'][67];
 			break;
 			case RULE_DICTIONNARY_OS_SP :
-				return $LANG["rulesengine"][68];
+				return $LANG['rulesengine'][68];
 			break;
 			case RULE_DICTIONNARY_OS_VERSION :
-				return $LANG["rulesengine"][69];
+				return $LANG['rulesengine'][69];
 			break;
 		}
 	}
 
 	function showCacheRuleHeader(){
-		if (in_array($this->rule_type,array(RULE_DICTIONNARY_MODEL_COMPUTER,
+		if (in_array($this->sub_type,array(RULE_DICTIONNARY_MODEL_COMPUTER,
 						RULE_DICTIONNARY_MODEL_MONITOR,
 						RULE_DICTIONNARY_MODEL_PRINTER,
 						RULE_DICTIONNARY_MODEL_PHONE,
@@ -113,11 +112,11 @@ class RuleDictionnaryDropdown extends RuleCached{
 						RULE_DICTIONNARY_MODEL_NETWORKING,
 							))){
 			global $LANG;
-			echo "<th colspan='3'>".$LANG["rulesengine"][100]." : ".$this->fields["name"]."</th></tr>";
+			echo "<th colspan='3'>".$LANG['rulesengine'][100]." : ".$this->fields["name"]."</th></tr>";
 			echo "<tr>";
-			echo "<td class='tab_bg_1'>".$LANG["rulesengine"][104]."</td>";
-			echo "<td class='tab_bg_1'>".$LANG["common"][5]."</td>";
-			echo "<td class='tab_bg_1'>".$LANG["rulesengine"][105]."</td>";
+			echo "<td class='tab_bg_1'>".$LANG['rulesengine'][104]."</td>";
+			echo "<td class='tab_bg_1'>".$LANG['common'][5]."</td>";
+			echo "<td class='tab_bg_1'>".$LANG['rulesengine'][105]."</td>";
 			echo "</tr>";
 		} else {
 			parent::showCacheRuleHeader();
@@ -125,7 +124,7 @@ class RuleDictionnaryDropdown extends RuleCached{
 	}
 
 	function showCacheRuleDetail($fields){
-		if (in_array($this->rule_type,array(RULE_DICTIONNARY_MODEL_COMPUTER,
+		if (in_array($this->sub_type,array(RULE_DICTIONNARY_MODEL_COMPUTER,
 						RULE_DICTIONNARY_MODEL_MONITOR,
 						RULE_DICTIONNARY_MODEL_PRINTER,
 						RULE_DICTIONNARY_MODEL_PHONE,
@@ -135,7 +134,7 @@ class RuleDictionnaryDropdown extends RuleCached{
 			global $LANG;
 			echo "<td class='tab_bg_2'>".$fields["old_value"]."</td>";
 			echo "<td class='tab_bg_2'>".($fields["manufacturer"]!=''?$fields["manufacturer"]:'')."</td>";		
-			echo "<td class='tab_bg_2'>".($fields["new_value"]!=''?$fields["new_value"]:$LANG["rulesengine"][106])."</td>";
+			echo "<td class='tab_bg_2'>".($fields["new_value"]!=''?$fields["new_value"]:$LANG['rulesengine'][106])."</td>";
 		} else {
 			parent::showCacheRuleDetail($fields);
 		}
@@ -155,12 +154,12 @@ class DictionnaryDropdownCollection extends RuleCachedCollection{
 	 * Constructor
 	 * @param $type dropdown type
 	**/
-	function DictionnaryDropdownCollection($type){
-		$this->rule_type = $type;
+	function __construct($type){
+		$this->sub_type = $type;
 		$this->rule_class_name = 'RuleDictionnaryDropdown';
 		$this->right="rule_dictionnary_dropdown";
 
-		switch ($this->rule_type){
+		switch ($this->sub_type){
 			case RULE_DICTIONNARY_MANUFACTURER :
 				$this->item_table="glpi_dropdown_manufacturer";
 				//Init cache system values
@@ -238,60 +237,60 @@ class DictionnaryDropdownCollection extends RuleCachedCollection{
 
 	function getTitle() {
 		global $LANG;
-		switch ($this->rule_type){
+		switch ($this->sub_type){
 			case RULE_DICTIONNARY_MANUFACTURER :
-				return $LANG["rulesengine"][36];
+				return $LANG['rulesengine'][36];
 			break;
 			case RULE_DICTIONNARY_MODEL_COMPUTER :
-				return $LANG["rulesengine"][50];
+				return $LANG['rulesengine'][50];
 			break;
 			case RULE_DICTIONNARY_TYPE_COMPUTER :
-				return $LANG["rulesengine"][60];
+				return $LANG['rulesengine'][60];
 			break;
 			case RULE_DICTIONNARY_MODEL_MONITOR :
-				return $LANG["rulesengine"][51];
+				return $LANG['rulesengine'][51];
 			break;
 			case RULE_DICTIONNARY_TYPE_MONITOR :
-				return $LANG["rulesengine"][61];
+				return $LANG['rulesengine'][61];
 			break;
 			case RULE_DICTIONNARY_MODEL_PRINTER :
-				return $LANG["rulesengine"][54];
+				return $LANG['rulesengine'][54];
 			break;
 			case RULE_DICTIONNARY_TYPE_PRINTER :
-				return $LANG["rulesengine"][64];
+				return $LANG['rulesengine'][64];
 			break;
 			case RULE_DICTIONNARY_MODEL_PHONE :
-				return $LANG["rulesengine"][52];
+				return $LANG['rulesengine'][52];
 			break;
 			case RULE_DICTIONNARY_TYPE_PHONE :
-				return $LANG["rulesengine"][62];
+				return $LANG['rulesengine'][62];
 			break;
 			case RULE_DICTIONNARY_MODEL_PERIPHERAL :
-				return $LANG["rulesengine"][53];
+				return $LANG['rulesengine'][53];
 			break;
 			case RULE_DICTIONNARY_TYPE_PERIPHERAL :
-				return $LANG["rulesengine"][63];
+				return $LANG['rulesengine'][63];
 			break;
 			case RULE_DICTIONNARY_MODEL_NETWORKING :
-				return $LANG["rulesengine"][55];
+				return $LANG['rulesengine'][55];
 			break;
 			case RULE_DICTIONNARY_TYPE_NETWORKING :
-				return $LANG["rulesengine"][65];
+				return $LANG['rulesengine'][65];
 			break;
 			case RULE_DICTIONNARY_OS :
-				return $LANG["rulesengine"][67];
+				return $LANG['rulesengine'][67];
 			break;
 			case RULE_DICTIONNARY_OS_SP :
-				return $LANG["rulesengine"][68];
+				return $LANG['rulesengine'][68];
 			break;
 			case RULE_DICTIONNARY_OS_VERSION :
-				return $LANG["rulesengine"][69];
+				return $LANG['rulesengine'][69];
 			break;
 		}
 	}
 
 	function getRuleClass(){
-		return new $this->rule_class_name($this->rule_type);
+		return new $this->rule_class_name($this->sub_type);
 	}
 
 
@@ -301,13 +300,13 @@ class DictionnaryDropdownCollection extends RuleCachedCollection{
 	 * @param $maxtime maximum time of process (reload at the end)
 	 * @return -1 on completion else current offset
 	**/
-	function replayRulesOnExistingDB($offset=0, $maxtime=0, $items=array(), $params=array()) {
+	function replayRulesOnExistingDB($offset=0,$maxtime=0, $items=array(),$params=array()){
 		global $DB,$LANG;
 
 
 
 		// Model check : need to check using manufacturer extra data so specific function
-		if (in_array($this->rule_type,array(RULE_DICTIONNARY_MODEL_COMPUTER,
+		if (in_array($this->sub_type,array(RULE_DICTIONNARY_MODEL_COMPUTER,
 						RULE_DICTIONNARY_MODEL_MONITOR,
 						RULE_DICTIONNARY_MODEL_PRINTER,
 						RULE_DICTIONNARY_MODEL_PHONE,
@@ -322,9 +321,9 @@ class DictionnaryDropdownCollection extends RuleCachedCollection{
 			echo "replayRulesOnExistingDB started : " . date("r") . "\n";
 
 		// Get All items
-		$Sql="SELECT * FROM " . $this->item_table;
+		$Sql="SELECT * FROM `".$this->item_table."`";
 		if ($offset) {
-			$Sql .= " LIMIT $offset,999999999";
+			$Sql .= " LIMIT ".intval($offset).",999999999";
 		} 
 		
 		$result = $DB->query($Sql);
@@ -406,13 +405,14 @@ class DictionnaryDropdownCollection extends RuleCachedCollection{
 
 
 		// Need to give manufacturer from item table
-		$Sql="SELECT DISTINCT glpi_dropdown_manufacturer.ID AS idmanu, glpi_dropdown_manufacturer.name AS manufacturer, ".
-			$this->item_table.".ID AS ID, ".$this->item_table.".name AS name, ".$this->item_table.".comments AS comments ".
-			"FROM ".$this->item_table.", $model_table LEFT JOIN glpi_dropdown_manufacturer ON ($model_table.FK_glpi_enterprise=glpi_dropdown_manufacturer.ID) ".
-			"WHERE $model_table.model=".$this->item_table.".ID ";
+		$Sql="SELECT DISTINCT glpi_dropdown_manufacturer.ID AS idmanu, glpi_dropdown_manufacturer.name AS manufacturer, 
+			".$this->item_table.".ID AS ID, `".$this->item_table."`.name AS name, `".$this->item_table."`.comments AS comments 
+			FROM `".$this->item_table."`, $model_table 
+			LEFT JOIN glpi_dropdown_manufacturer ON ($model_table.FK_glpi_enterprise=glpi_dropdown_manufacturer.ID) 
+			WHERE $model_table.model=`".$this->item_table."`.ID ";
 		if ($offset) {
-			$Sql .= " LIMIT $offset,999999999";
-		}
+			$Sql .= " LIMIT ".intval($offset).",999999999";
+		} 
 		$result = $DB->query($Sql);
 
 		$nb = $DB->numrows($result)+$offset;
@@ -441,14 +441,13 @@ class DictionnaryDropdownCollection extends RuleCachedCollection{
 
 				if ($data['ID'] != $ID) {
 					$tocheck[$data["ID"]][]=$ID;
-
-					$sql = "UPDATE $model_table SET model='".$ID."' WHERE model='".$data['ID']."'";
+					$sql = "UPDATE $model_table SET model=".$ID." WHERE model=".$data['ID'];
 					if (empty($data['idmanu'])){
 						$sql .= " AND (FK_glpi_enterprise IS NULL OR FK_glpi_enterprise = 0)";
 					} else {
 						$sql .= " AND FK_glpi_enterprise='".$data['idmanu']."'";
 					}
-
+					
 					$DB->query($sql);
 				}		
 
@@ -467,12 +466,12 @@ class DictionnaryDropdownCollection extends RuleCachedCollection{
 				$deletecartmodel=false;
 				// No item left : delete old item
 				if ($result && $DB->result($result,0,0)==0) {
-					$Sql = "DELETE FROM ".$this->item_table." WHERE ID='".$ID."'";
+					$Sql = "DELETE FROM `".$this->item_table."` WHERE ID='$ID'";
 					$resdel = $DB->query($Sql);
 					$deletecartmodel=true;
 				} 
 				// Manage cartridge assoc Update items
-				if ($this->rule_type==RULE_DICTIONNARY_MODEL_PRINTER){
+				if ($this->sub_type==RULE_DICTIONNARY_MODEL_PRINTER){
 					$sql="SELECT * FROM glpi_cartridges_assoc WHERE FK_glpi_dropdown_model_printers = '$ID'";
 					if ($result=$DB->query($sql)){
 						if ($DB->numrows($result)){	
@@ -483,7 +482,8 @@ class DictionnaryDropdownCollection extends RuleCachedCollection{
 							}
 							// Delete cartrodges_assoc
 							if ($deletecartmodel){
-								$sql="DELETE FROM glpi_cartridges_assoc WHERE FK_glpi_dropdown_model_printers = 'ID'";
+								$sql="DELETE FROM glpi_cartridges_assoc 
+									WHERE FK_glpi_dropdown_model_printers = 'ID'";
 								$DB->query($sql);
 							}
 							// Add new assoc
