@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.ocs.class.php 7875 2009-01-23 15:16:47Z moyo $
+ * @version $Id: rule.ocs.class.php 8968 2009-09-13 15:59:50Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -46,8 +46,8 @@ class OcsRuleCollection extends RuleCollection {
 	 * Constructor
 	 * @param $ocs_server_id ID of the OCS server
 	**/
-	function OcsRuleCollection($ocs_server_id=-1) {
-		$this->rule_type = RULE_OCS_AFFECT_COMPUTER;
+	function __construct($ocs_server_id=-1) {
+		$this->sub_type = RULE_OCS_AFFECT_COMPUTER;
 		$this->rule_class_name = 'OcsAffectEntityRule';
 		$this->ocs_server_id = $ocs_server_id;
 		$this->stop_on_first_match=true;
@@ -56,14 +56,14 @@ class OcsRuleCollection extends RuleCollection {
 
 	function getTitle() {
 		global $LANG;
-		return $LANG["rulesengine"][18];
+		return $LANG['rulesengine'][18];
 	}
 
 	function prepareInputDataForProcess($input,$computer_id){
 		global $DBocs;
 		$tables = $this->getTablesForQuery();
 		$fields = $this->getFieldsForQuery();
-		$linked_fields = $this->getFKFieldsForQuery();
+		//$linked_fields = $this->getFKFieldsForQuery();
 
 		$rule_parameters = array ();
 
@@ -90,19 +90,21 @@ class OcsRuleCollection extends RuleCollection {
 
 		//Build the FROM part of the request
 		//Remove all the non duplicated table names
-		$tables = array_unique($tables);
-		foreach ($tables as $table) {
-			$from_sql .= ($from_sql != "" ? " , " : "") . $table;
+		$from_sql = " hardware ";
+		foreach ($tables as $table => $linkfield) {
+			if ($table!='hardware' && !empty($linkfield)){
+				$from_sql .= " LEFT JOIN `$table` ON (`$table`.`$linkfield` = hardware.ID)";
+			}
 		}
 
 		//Build the WHERE part of the request
-		foreach ($linked_fields as $linked_field) {
-			$where_sql .= ($where_sql != "" ? " AND " : "") . $linked_field . "=hardware.ID ";
-		}
+//		foreach ($linked_fields as $linked_field) {
+//			$where_sql .= ($where_sql != "" ? " AND " : "") . $linked_field . "=hardware.ID ";
+//		}
 
-		if ($select_sql != "" && $from_sql != "" && $where_sql != "") {
+		if ($select_sql != "" && $from_sql != "" /*&& $where_sql != ""*/) {
 			//Build the all request
-			$sql = $begin_sql . $select_sql . " FROM " . $from_sql . " WHERE " . $where_sql . " AND hardware.ID='" . $computer_id."'";
+			$sql = $begin_sql . $select_sql . " FROM " . $from_sql . " WHERE  hardware.ID='".$computer_id."'";
 		
 			checkOCSconnection($this->ocs_server_id);
 			$result = $DBocs->query($sql);
@@ -143,9 +145,9 @@ class OcsRuleCollection extends RuleCollection {
 		global $RULES_CRITERIAS;
 
 		$tables = array();
-		foreach ($RULES_CRITERIAS[$this->rule_type] as $criteria){
-			if ((!isset($criteria['virtual']) || !$criteria['virtual']) && $criteria['table'] != '' && !array_key_exists($criteria["table"],$tables)) {
-				$tables[]=$criteria['table'];
+		foreach ($RULES_CRITERIAS[$this->sub_type] as $criteria){
+			if ((!isset($criteria['virtual']) || !$criteria['virtual']) && $criteria['table'] != '' && !isset($tables[$criteria["table"]])) {
+				$tables[$criteria['table']]=$criteria['linkfield'];
 			}
 		}
 		return $tables;		  
@@ -160,7 +162,7 @@ class OcsRuleCollection extends RuleCollection {
 		global $RULES_CRITERIAS;
 
 		$fields = array();
-		foreach ($RULES_CRITERIAS[$this->rule_type] as $key => $criteria){
+		foreach ($RULES_CRITERIAS[$this->sub_type] as $key => $criteria){
 
 			if ($withouttable)
 			{
@@ -201,7 +203,7 @@ class OcsRuleCollection extends RuleCollection {
 		global $RULES_CRITERIAS;
 
 		$fields = array();
-		foreach ($RULES_CRITERIAS[$this->rule_type] as $criteria){
+		foreach ($RULES_CRITERIAS[$this->sub_type] as $criteria){
 			//If the field name is not null AND a table name is provided
 			if ( (!isset($criteria['virtual']) || !$criteria['virtual']) && $criteria['linkfield'] != ''){
 				$fields[]=$criteria['table'].".".$criteria['linkfield'];
@@ -221,17 +223,15 @@ class OcsAffectEntityRule extends Rule {
 	 * Constructor
          * @param $ocs_server_id ID of the OCS server
 	**/
-	function OcsAffectEntityRule($ocs_server_id=-1) {
-		$this->table = "glpi_rules_descriptions";
-		$this->type = -1;
-		$this->rule_type = RULE_OCS_AFFECT_COMPUTER;
+	function __construct($ocs_server_id=-1) {
+		parent::__construct(RULE_OCS_AFFECT_COMPUTER);
 		$this->right="rule_ocs";
 		$this->can_sort=true;
 	}
 
 	function getTitle() {
 		global $LANG;
-		return $LANG["rulesengine"][18];
+		return $LANG['rulesengine'][18];
 	}
 
 	function maxActionsCount(){
@@ -252,36 +252,39 @@ class OcsAffectEntityRule extends Rule {
 
 		if ($canedit) {
 
-			echo "<div class='center'>";
-			echo "<table  class='tab_cadre_fixe'>";
-			echo "<tr class='tab_bg_1'><th colspan='4'>" .  $LANG["rulesengine"][18] . "</tr><tr><td class='tab_bg_2' align='center'>";
-			echo $LANG["common"][16] . ":";
-			echo "</td><td align='center' class='tab_bg_2'>";
-			autocompletionTextField("name", "glpi_rules_descriptions", "name", "", 30);
-			echo $LANG["joblist"][6] . ":";
-			autocompletionTextField("description", "glpi_rules_descriptions", "description", "", 30);
-			echo "</td><td align='center' class='tab_bg_2'>";
-			echo $LANG["rulesengine"][9] . ":";
-			$this->dropdownRulesMatch("match", "AND");
-			echo "</td><td align='center' class='tab_bg_2'>";
-			echo "<input type=hidden name='rule_type' value=\"" . $this->rule_type . "\">";
+         echo "<div class='center'>";
+         echo "<table  class='tab_cadre_fixe'>";
+         echo "<tr><th colspan='2'>" .  $LANG['rulesengine'][18] . "</th></tr>";
+         echo "<tr class='tab_bg_2'>";
+         echo "<td>".$LANG['common'][16] . "&nbsp;:&nbsp;";
+         autocompletionTextField("name", "glpi_rules_descriptions", "name", "", 33);
+         echo "&nbsp;&nbsp;&nbsp;".$LANG['joblist'][6] . "&nbsp;:&nbsp;";
+         autocompletionTextField("description", "glpi_rules_descriptions", "description", "", 33);
+         echo "&nbsp;&nbsp;&nbsp;".$LANG['rulesengine'][9] . "&nbsp;:&nbsp;";
+         $this->dropdownRulesMatch("match", "AND");
+         echo "</td><td class='tab_bg_2 center'>";
+			echo "<input type=hidden name='sub_type' value=\"" . $this->sub_type . "\">";
 			echo "<input type=hidden name='FK_entities' value=\"-1\">";
 			echo "<input type=hidden name='affectentity' value=\"" . $ID . "\">";
-			echo "<input type='submit' name='add_rule' value=\"" . $LANG["buttons"][8] . "\" class='submit'>";
+			echo "<input type='submit' name='add_rule' value=\"" . $LANG['buttons'][8] . "\" class='submit'>";
 			echo "</td></tr>";
 
 			echo "</table></div><br>";
 
 		}
 
-		echo "<div class='center'><table class='tab_cadrehov'><tr><th colspan='3'>" . $LANG["entity"][5] . "</th></tr>";
+		echo "<div class='center'><table class='tab_cadrehov'><tr><th colspan='3'>" . $LANG['entity'][5] . "</th></tr>";
 
 		//Get all rules and actions
 		$rules = $this->getRulesByID( $ID, 0, 1);
 
 		if (!empty ($rules)) {
 
+			initNavigateListItems(RULE_TYPE,$LANG['entity'][0]."=".getDropdownName("glpi_entities",$ID),$this->sub_type);
+			
 			foreach ($rules as $rule) {
+				addToNavigateListItems(RULE_TYPE,$rule->fields["ID"],$this->sub_type);
+				
 				echo "<tr class='tab_bg_1'>";
 
 				if ($canedit) {
@@ -306,12 +309,12 @@ class OcsAffectEntityRule extends Rule {
 
 		if ($canedit) {
 			echo "<div class='center'>";
-			echo "<table width='80%'>";
-			echo "<tr><td><img src=\"" . $CFG_GLPI["root_doc"] . "/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markAllRows('entityaffectation_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?ID=$ID&amp;select=all'>" . $LANG["buttons"][18] . "</a></td>";
+			echo "<table class='tab_glpi' width='80%'>";
+			echo "<tr><td><img src=\"" . $CFG_GLPI["root_doc"] . "/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markCheckboxes('entityaffectation_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?ID=$ID&amp;select=all'>" . $LANG['buttons'][18] . "</a></td>";
 
-			echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkAllRows('entityaffectation_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?ID=$ID&amp;select=none'>" . $LANG["buttons"][19] . "</a>";
+			echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkCheckboxes('entityaffectation_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?ID=$ID&amp;select=none'>" . $LANG['buttons'][19] . "</a>";
 			echo "</td><td align='left' width='80%'>";
-			echo "<input type='submit' name='delete_computer_rule' value=\"" . $LANG["buttons"][6] . "\" class='submit'>";
+			echo "<input type='submit' name='delete_computer_rule' value=\"" . $LANG['buttons'][6] . "\" class='submit'>";
 			echo "</td>";
 			echo "</table>";
 
@@ -333,9 +336,12 @@ function getRulesByID($ID, $withcriterias, $withactions) {
 	$ocs_affect_computer_rules = array ();
 
 
-	//Get all the rules whose rule_type is $rule_type and entity is $ID
-	$sql="SELECT * FROM `glpi_rules_actions` as gra, glpi_rules_descriptions as grd  WHERE gra.FK_rules=grd.ID AND gra.field='FK_entities'  and grd.rule_type='".$this->rule_type."' and gra.value='".$ID."'";
-
+	//Get all the rules whose sub_type is $sub_type and entity is $ID
+	$sql="SELECT * 
+		FROM `glpi_rules_actions` as gra, glpi_rules_descriptions as grd  
+		WHERE gra.FK_rules=grd.ID AND gra.field='FK_entities'  
+		AND grd.sub_type='".$this->sub_type."' AND gra.value='".$ID."'";
+	
 	$result = $DB->query($sql);
 	while ($rule = $DB->fetch_array($result)) {
 		$affect_rule = new Rule;
@@ -346,6 +352,42 @@ function getRulesByID($ID, $withcriterias, $withactions) {
 	return $ocs_affect_computer_rules;
 }
 
+	function preProcessPreviewResults($output)
+	{
+		return $output;
+	}
+
+	function executeActions($output,$params,$regex_results)
+	{
+		if (count($this->actions)){
+
+			foreach ($this->actions as $action){
+				switch ($action->fields["action_type"]){
+					case "assign" :
+						$output[$action->fields["field"]] = $action->fields["value"];
+					break;
+					case "regex_result":
+						//Assign entity using the regex's result
+						if ($action->fields["field"] == "_affect_entity_by_tag")
+						{
+							//Get the TAG from the regex's results
+							$res = getRegexResultById($action->fields["value"],$regex_results);
+							if ($res != null)
+							{
+								//Get the entity associated with the TAG
+								$target_entity = getEntityIDByTag($res);
+
+								if ($target_entity != '')
+									$output["FK_entities"]=$target_entity;
+							} 
+						}
+					break;								
+				}
+			}
+		}
+		return $output;
+	}
+
 }
 
 
