@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.right.class.php 8340 2009-05-29 17:06:39Z remi $
+ * @version $Id: rule.right.class.php 9132 2009-10-21 20:18:26Z walid $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -42,12 +42,10 @@ class RightAffectRule extends Rule {
 	/**
 	 * Constructor
 	**/
-	function RightAffectRule() {
+	function __construct() {
 		global $RULES_CRITERIAS;	
 	
-		$this->table = "glpi_rules_descriptions";
-		$this->type = -1;
-		$this->rule_type = RULE_AFFECT_RIGHTS;
+		parent::__construct(RULE_AFFECT_RIGHTS);
 		
 		//Dynamically add all the ldap criterias to the current list of rule's criterias
 		$this->addLdapCriteriasToArray();
@@ -55,6 +53,11 @@ class RightAffectRule extends Rule {
 		$this->orderby="name";
 	}
 
+	function preProcessPreviewResults($output)
+	{
+      return $output;
+	}
+	
 	function maxActionsCount(){
 		// Unlimited
 		return 4;
@@ -75,44 +78,44 @@ class RightAffectRule extends Rule {
 
 			echo "<div class='center'>";
 			echo "<table  class='tab_cadre_fixe'>";
-			echo "<tr class='tab_bg_1'><th colspan='4'>" .$LANG["rulesengine"][19] . "</tr><tr><td class='tab_bg_2' align='center'>";
-			echo $LANG["common"][16] . ":";
-			echo "</td><td align='center' class='tab_bg_2'>";
-			autocompletionTextField("name", "glpi_rules_descriptions", "name", "", 30);
-			echo $LANG["joblist"][6] . ":";
-			autocompletionTextField("description", "glpi_rules_descriptions", "description", "", 30);
-			echo "</td><td align='center' class='tab_bg_2'>";
-			echo $LANG["rulesengine"][9] . ":";
-			$this->dropdownRulesMatch("match", "AND");
-			echo "</td><td align='center' class='tab_bg_2'>";
-			echo "</td></tr>";
+         echo "<tr><th colspan='2'>" .$LANG['rulesengine'][19] . "</th></tr>";
+         echo "<tr class='tab_bg_2'>";
+         echo "<td>".$LANG['common'][16] . "&nbsp;:&nbsp;";
+         autocompletionTextField("name", "glpi_rules_descriptions", "name", "", 33);
+         echo "&nbsp;&nbsp;&nbsp;".$LANG['joblist'][6] . "&nbsp;:&nbsp;";
+         autocompletionTextField("description", "glpi_rules_descriptions", "description", "", 33);
+         echo "&nbsp;&nbsp;&nbsp;".$LANG['rulesengine'][9] . "&nbsp;:&nbsp;";
+         $this->dropdownRulesMatch("match", "AND");
+         echo "</td><td rowspan='2' class='tab_bg_2 center middle'>";
+         echo "<input type=hidden name='sub_type' value=\"" . $this->sub_type . "\">";
+         echo "<input type=hidden name='FK_entities' value=\"-1\">";
+         echo "<input type=hidden name='affectentity' value=\"" . $ID . "\">";
+         echo "<input type='submit' name='add_user_rule' value=\"" . $LANG['buttons'][8] . "\" class='submit'>";
+         echo "</td></tr>";
 
-			echo "<tr><td align='center' class='tab_bg_2'>";
-			echo "</td><td align='center' class='tab_bg_2'>";
-			echo $LANG["profiles"][22].":";
-			dropdownValue("glpi_profiles","FK_profiles");
-			echo "</td><td align='center' class='tab_bg_2'>";
-			echo $LANG["profiles"][28].":";
-			dropdownYesNo("recursive",0);
-			echo "</td><td align='center' class='tab_bg_2'>";
-			echo "<input type=hidden name='rule_type' value=\"" . $this->rule_type . "\">";
-			echo "<input type=hidden name='FK_entities' value=\"-1\">";
-			echo "<input type=hidden name='affectentity' value=\"" . $ID . "\">";
-			echo "<input type='submit' name='add_user_rule' value=\"" . $LANG["buttons"][8] . "\" class='submit'>";
+         echo "<tr class='tab_bg_2'>";
+         echo "<td class='center'>".$LANG['profiles'][22] . "&nbsp;:&nbsp;";
+         dropdownValue("glpi_profiles","FK_profiles");
+         echo "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;".$LANG['profiles'][28] . "&nbsp;:&nbsp;";
+         dropdownYesNo("recursive",0);
 			echo "</td></tr>";
 			
 			echo "</table></div><br>";
 
 		}
 
-		echo "<div class='center'><table class='tab_cadrehov'><tr><th colspan='3'>" . $LANG["entity"][6] . "</th></tr>";
+		echo "<div class='center'><table class='tab_cadrehov'><tr><th colspan='3'>" . $LANG['entity'][6] . "</th></tr>";
 
 		//Get all rules and actions
 		$rules = $this->getRulesByID( $ID, 0, 1);
 
 		if (!empty ($rules)) {
 
+			initNavigateListItems(RULE_TYPE,$LANG['entity'][0]."=".getDropdownName("glpi_entities",$ID),$this->sub_type);
+
 			foreach ($rules as $rule) {
+				addToNavigateListItems(RULE_TYPE,$rule->fields["ID"],$this->sub_type);
+
 				echo "<tr class='tab_bg_1'>";
 
 				if ($canedit) {
@@ -136,18 +139,15 @@ class RightAffectRule extends Rule {
 		echo "</table></div>";
 
 		if ($canedit) {
-			echo "<div class='center'>";
-			echo "<table width='80%'>";
-			echo "<tr><td><img src=\"" . $CFG_GLPI["root_doc"] . "/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markAllRows('ldapaffectation_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?ID=$ID&amp;select=all'>" . $LANG["buttons"][18] . "</a></td>";
+			echo "<table class='tab_glpi' width='80%'>";
+			echo "<tr><td><img src=\"" . $CFG_GLPI["root_doc"] . "/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markCheckboxes('ldapaffectation_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?ID=$ID&amp;select=all'>" . $LANG['buttons'][18] . "</a></td>";
 
-			echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkAllRows('ldapaffectation_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?ID=$ID&amp;select=none'>" . $LANG["buttons"][19] . "</a>";
+			echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkCheckboxes('ldapaffectation_form') ) return false;\" href='" . $_SERVER['PHP_SELF'] . "?ID=$ID&amp;select=none'>" . $LANG['buttons'][19] . "</a>";
 			echo "</td><td align='left' width='80%'>";
-			echo "<input type='submit' name='delete_user_rule' value=\"" . $LANG["buttons"][6] . "\" class='submit'>";
+			echo "<input type='submit' name='delete_user_rule' value=\"" . $LANG['buttons'][6] . "\" class='submit'>";
 			echo "</td>";
 			echo "</table>";
 
-			echo "</div>";
-
 		}
 		echo "</form>";
 	}
@@ -159,22 +159,53 @@ class RightAffectRule extends Rule {
 	{
 		global $DB,$RULES_CRITERIAS;
 
-			$sql = "SELECT name,value,rule_type FROM glpi_rules_ldap_parameters WHERE rule_type='".$this->rule_type."'";
+			$sql = "SELECT name,value,sub_type FROM glpi_rules_ldap_parameters WHERE sub_type='".$this->sub_type."'";
 			$result = $DB->query($sql);
 			while ($datas = $DB->fetch_array($result))
 			{
-					$RULES_CRITERIAS[$this->rule_type][$datas["value"]]['name']=$datas["name"];
-					$RULES_CRITERIAS[$this->rule_type][$datas["value"]]['field']=$datas["value"];
-					$RULES_CRITERIAS[$this->rule_type][$datas["value"]]['linkfield']='';
-					$RULES_CRITERIAS[$this->rule_type][$datas["value"]]['table']='';
+					$RULES_CRITERIAS[$this->sub_type][$datas["value"]]['name']=$datas["name"];
+					$RULES_CRITERIAS[$this->sub_type][$datas["value"]]['field']=$datas["value"];
+					$RULES_CRITERIAS[$this->sub_type][$datas["value"]]['linkfield']='';
+					$RULES_CRITERIAS[$this->sub_type][$datas["value"]]['table']='';
 				}
 	}
 
+	/**
+	 * Filter actions if needed
+	*  @param $actions the actions array
+	*  @param $new_action indicates if the function is called when adding a new action
+	*  or when displaying an already added action
+	 * @return the filtered actions array
+	 */
+	function filterActions($actions){
+			$RuleAction = new RuleAction;
+			$this->actions = $RuleAction->getRuleActions($this->fields["ID"]);
+			foreach($this->actions as $action)
+			{
+				switch ($action->fields["field"])
+				{
+					case "_affect_entity_by_dn":
+						unset($actions["_affect_entity_by_tag"]);
+						unset($actions["FK_entities"]);
+						break;
+					case "_affect_entity_by_tag":
+						unset($actions["_affect_entity_by_dn"]);
+						unset($actions["FK_entities"]);
+						break;
+					case "FK_entities":
+						unset($actions["_affect_entity_by_tag"]);
+						unset($actions["_affect_entity_by_dn"]);
+						break;
+				}
+			}
+
+		return $actions;
+	}
+
 	/**
 	* Execute the actions as defined in the rule
 	* @param $output the result of the actions
 	* @param $params the parameters
-	* @param $regex_results (not used)
 	* @return the fields modified
 	*/
 	function executeActions($output,$params,$regex_results)
@@ -182,30 +213,92 @@ class RightAffectRule extends Rule {
 		$entity='';
 		$right='';
 		$recursive = 0;
+		$continue = true;
+		$output_src = $output;
 		
 		if (count($this->actions)){
 			foreach ($this->actions as $action){
+					
 				switch ($action->fields["action_type"]){
 					case "assign" :
-						if ($action->fields["field"] == "FK_entities") $entity = $action->fields["value"]; 
-						elseif ($action->fields["field"] == "FK_profiles") $right = $action->fields["value"];
-						elseif ($action->fields["field"] == "recursive") $recursive = $action->fields["value"];
-						elseif ($action->fields["field"] == "active") $output["active"] = $action->fields["value"];
-					break;
-				}
-			}
-		}
+						switch ($action->fields["field"])
+						{
+							case "FK_entities":
+								$entity = $action->fields["value"];
+							break;
+							case "FK_profiles":
+								$right = $action->fields["value"];
+							break;
+							case "recursive":
+								$recursive = $action->fields["value"];
+							break;
+							case "active":
+								$output["active"] = $action->fields["value"];
+							break;
+						} // switch (field)
+						break;
+					case "regex_result" :
+						switch ($action->fields["field"])
+						{
+							case "_affect_entity_by_dn":
+                     case "_affect_entity_by_tag":
+                        $match_entity = false;
+                        $entity = array();
+                        foreach ($regex_results as $regex_result) {
+                           $res = getRegexResultById($action->fields["value"],array($regex_result));
+                           if ($res != null) {
+                              
+                              if ($action->fields["field"] == "_affect_entity_by_dn" ) {
+                                 $entity_found = getEntityIDByDN($res);
+                              }
+                              else {
+                                $entity_found = getEntityIDByTag($res);	
+                              }
+                              
+                              //If an entity was found
+                              if ($entity > -1) {
+                                 array_push($entity, array($entity_found,$recursive));	
+                                 $match_entity=true;
+                              }
+                           }
+                        }
 
-		//Nothing to be returned by the function :
-		//Store in session the entity and/or right
-		if ($entity != '' && $right != '')
-			$output["_ldap_rules"]["rules_entities_rights"][]=array($entity,$right,$recursive);
-		elseif ($entity != '') 
-			$output["_ldap_rules"]["rules_entities"][]=array($entity,$recursive);
-		elseif ($right != '') 
-			$output["_ldap_rules"]["rules_rights"][]=$right;
+								if (!$match_entity) {
+									//Not entity assigned : action processing must be stopped for this rule
+									$continue=false;										
+								}
+							break;
+						} // switch (field)
+					break;
+				} // switch (action_type)
+			} // foreach (action)
+		} // count (actions)
+
+		if ($continue)
+		{
+			//Nothing to be returned by the function :
+			//Store in session the entity and/or right
+			if ($entity != '' && $right != '') {
+				$output["_ldap_rules"]["rules_entities_rights"][]=array($entity,$right,$recursive);
+			}
+			elseif ($entity != '') {
+            if (!is_array($entity)) {
+              $entities_array=array($entity,$recursive);
+              $output["_ldap_rules"]["rules_entities"][]=array($entities_array);	
+				}
+            //If it comes from a regex with multiple results
+            else {
+               $output["_ldap_rules"]["rules_entities"][] = $entity;
+            }
+			} 
+			elseif ($right != '') 
+				$output["_ldap_rules"]["rules_rights"][]=$right;
+
+			return $output;
+		}
+		else
+			return $output_src;
 			
-		return $output;
 	}
 
 
@@ -222,9 +315,12 @@ function getRulesByID($ID, $withcriterias, $withactions) {
 	// MOYO : ca correspond pas deja à un cas particulier de ca : getRuleWithCriteriasAndActions ?
 
 
-	//Get all the rules whose rule_type is $rule_type and entity is $ID
-	$sql="SELECT * FROM `glpi_rules_actions` as gra, glpi_rules_descriptions as grd  WHERE gra.FK_rules=grd.ID AND gra.field='FK_entities'  and grd.rule_type=".$this->rule_type." and gra.value='".$ID."'";
-
+	//Get all the rules whose sub_type is $sub_type and entity is $ID
+	$sql="SELECT * 
+		FROM `glpi_rules_actions` as gra, glpi_rules_descriptions as grd  
+		WHERE gra.FK_rules=grd.ID AND gra.field='FK_entities' 
+			AND grd.sub_type='".$this->sub_type."' AND gra.value='".$ID."'";
+	
 	$result = $DB->query($sql);
 	while ($rule = $DB->fetch_array($result)) {
 		$affect_rule = new Rule;
@@ -241,7 +337,7 @@ function getRulesByID($ID, $withcriterias, $withactions) {
 		echo "<table class='tab_cadrehov'>";
 		echo "<tr  class='tab_bg_2'>";
 		echo "<td width='100%'>";
-		echo "<a href=\"".$CFG_GLPI["root_doc"]."/front/ldap.parameters.php\">".$LANG["setup"][142]." ".$LANG["ruleldap"][1]."</a>";
+		echo "<a href=\"".$CFG_GLPI["root_doc"]."/front/ldap.parameters.php\">".$LANG['Menu'][26]." ".$LANG['ruleldap'][1]."</a>";
 		echo "</td></tr>";
 		echo "</table></div><br>";
 
@@ -253,7 +349,7 @@ function getRulesByID($ID, $withcriterias, $withactions) {
 	function getTitle()
 	{
 		global $LANG;
-		return $LANG["entity"][6];
+		return $LANG['entity'][6];
 	}
 }
 
@@ -270,9 +366,9 @@ class RightRuleCollection extends RuleCollection {
 	/**
 	 * Constructor
 	**/
-	function RightRuleCollection() {
+	function __construct() {
 		global $DB;
-		$this->rule_type = RULE_AFFECT_RIGHTS;
+		$this->sub_type = RULE_AFFECT_RIGHTS;
 		$this->rule_class_name = 'RightAffectRule';
 		$this->stop_on_first_match=false;
 		$this->right="rule_ldap";
@@ -281,7 +377,7 @@ class RightRuleCollection extends RuleCollection {
 
 	function getTitle() {
 		global $LANG;
-		return $LANG["rulesengine"][19];
+		return $LANG['rulesengine'][19];
 	}
 
 
@@ -294,40 +390,42 @@ class RightRuleCollection extends RuleCollection {
 
 	function showTestResults($rule,$output,$global_result){
 		global $LANG,$RULES_ACTIONS;
-
-		echo "<tr><th colspan='4'>" . $LANG["rulesengine"][81] . "</th></tr>";
+      
+      logInFile("debug","output=".exportArrayToDB($output)."\n");
+		echo "<tr><th colspan='4'>" . $LANG['rulesengine'][81] . "</th></tr>";
 		echo "<tr  class='tab_bg_2'>";
-		echo "<td class='tab_bg_2' colspan='4' align='center'>".$LANG["rulesengine"][41]." : <strong> ".getYesNo($global_result)."</strong></td>";
+		echo "<td class='tab_bg_2' colspan='4' align='center'>".$LANG['rulesengine'][41]." : <strong> ".getYesNo($global_result)."</strong></td>";
 
-		
 		if (isset($output["_ldap_rules"]["rules_entities"]))
 		{
 			echo "<tr  class='tab_bg_2'>";
-			echo "<td class='tab_bg_2' colspan='4' align='center'>".$LANG["rulesengine"][111]."</td>";
+			echo "<td class='tab_bg_2' colspan='4' align='center'>".$LANG['rulesengine'][111]."</td>";
 
-			foreach ($output["_ldap_rules"]["rules_entities"] as $val)
+			foreach ($output["_ldap_rules"]["rules_entities"] as $entities)
 			{
-				$this->displayActionByName("entity",$val[0]);
-				if (isset($val[1]))
-					$this->displayActionByName("recursive",$val[1]);
+            foreach ($entities as $entity) {
+               $this->displayActionByName("entity",$entity[0]);
+               if (isset($entity[1]))
+                  $this->displayActionByName("recursive",$entity[1]);
+            }
 			}
 		}
 
 		if (isset($output["_ldap_rules"]["rules_rights"]))
 		{
 			echo "<tr  class='tab_bg_2'>";
-			echo "<td class='tab_bg_2' colspan='4' align='center'>".$LANG["rulesengine"][110]."</td>";
+			echo "<td class='tab_bg_2' colspan='4' align='center'>".$LANG['rulesengine'][110]."</td>";
 
 			foreach ($output["_ldap_rules"]["rules_rights"] as $val)
 				$this->displayActionByName("profile",$val[0]);
 		}
 
+
 		if (isset($output["_ldap_rules"]["rules_entities_rights"]))
 		{
 			echo "<tr  class='tab_bg_2'>";
-			echo "<td class='tab_bg_2' colspan='4' align='center'>".$LANG["rulesengine"][112]."</td>";
-
-			foreach ($output["_ldap_rules"]["rules_entities_rights"] as $val)
+			echo "<td class='tab_bg_2' colspan='4' align='center'>".$LANG['rulesengine'][112]."</td>";
+ 			foreach ($output["_ldap_rules"]["rules_entities_rights"] as $val)
 			{
 				$this->displayActionByName("entity",$val[0]);
 				if (isset($val[1]))
@@ -335,6 +433,7 @@ class RightRuleCollection extends RuleCollection {
 				if (isset($val[2]))
 					$this->displayActionByName("recursive",$val[2]);
 			}
+
 		}
 		
 		if (isset($output["_ldap_rules"]))
@@ -344,7 +443,7 @@ class RightRuleCollection extends RuleCollection {
 		{
 			echo "<tr  class='tab_bg_2'>";
 			echo "<td class='tab_bg_2' align='center'>";
-			echo $RULES_ACTIONS[$this->rule_type][$criteria]["name"];
+			echo $RULES_ACTIONS[$this->sub_type][$criteria]["name"];
 			echo "</td>";
 			echo "<td class='tab_bg_2' align='center'>";
 			echo $rule->getActionValue($criteria,$value);
@@ -364,21 +463,21 @@ class RightRuleCollection extends RuleCollection {
 		echo "<tr>"; 
 		switch ($name){
 			case "entity":
-			 	echo  "<td class='tab_bg_2' align='center'>".$LANG["entity"][0]." </td>\n"; 
+			 	echo  "<td class='tab_bg_2' align='center'>".$LANG['entity'][0]." </td>\n"; 
 			 	echo  "<td class='tab_bg_2' align='center'>";                                                                         
 			 	echo  getDropdownName("glpi_entities",$value);  
 			 	echo  "</td>"; 
 			break;
 			case "profile":
-			 	echo  "<td class='tab_bg_2' align='center'>".$LANG["Menu"][35]." </td>\n"; 
+			 	echo  "<td class='tab_bg_2' align='center'>".$LANG['Menu'][35]." </td>\n"; 
 			 	echo  "<td class='tab_bg_2' align='center'>";                                                                         
 			 	echo  getDropdownName("glpi_profiles",$value);  
 			 	echo  "</td>"; 
 			break;			
 			case "recursive":
-			 	echo "<td class='tab_bg_2' align='center'>".$LANG["profiles"][28]." </td>\n";
+			 	echo "<td class='tab_bg_2' align='center'>".$LANG['profiles'][28]." </td>\n";
 			 	echo  "<td class='tab_bg_2' align='center'>";                                                                         
-			 	echo ((!$value)?$LANG["choice"][0]:$LANG["choice"][1]); 
+			 	echo ((!$value)?$LANG['choice'][0]:$LANG['choice'][1]); 
 			 	echo  "</td>"; 
 			break;			
 		}
@@ -391,10 +490,12 @@ class RightRuleCollection extends RuleCollection {
 	{
 		global $DB;
 		$params = array();
-		$sql = "SELECT DISTINCT value " .
-				"FROM glpi_rules_descriptions, glpi_rules_criterias, glpi_rules_ldap_parameters " .
-				"WHERE glpi_rules_descriptions.rule_type='".$this->rule_type."' AND glpi_rules_criterias.FK_rules=glpi_rules_descriptions.ID AND glpi_rules_criterias.criteria=glpi_rules_ldap_parameters.value";
-
+		$sql = "SELECT DISTINCT value 
+			FROM glpi_rules_descriptions, glpi_rules_criterias, glpi_rules_ldap_parameters 
+			WHERE glpi_rules_descriptions.sub_type='".$this->sub_type."' 
+				AND glpi_rules_criterias.FK_rules=glpi_rules_descriptions.ID 
+				AND glpi_rules_criterias.criteria=glpi_rules_ldap_parameters.value";
+		
 		$result = $DB->query($sql);
 		while ($param = $DB->fetch_array($result))
 		{
@@ -486,8 +587,8 @@ class RightRuleCollection extends RuleCollection {
 		global $RULES_CRITERIAS;
 
 		$fields = array();
-		foreach ($RULES_CRITERIAS[$this->rule_type] as $criteria){
-				if (isset($criteria['virtual']) && $criteria['virtual'] == "true")
+		foreach ($RULES_CRITERIAS[$this->sub_type] as $criteria){
+				if (isset($criteria['virtual']) && $criteria['virtual'])
 					$fields[]=$criteria['id'];
 				else	
 				$fields[]=$criteria['field'];	
