@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.softwarecategories.class.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: rule.softwarecategories.class.php 8026 2009-02-28 16:50:46Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -42,8 +42,8 @@ class SoftwareCategoriesRuleCollection extends RuleCollection {
 	/**
 	 * Constructor
 	**/
-	function SoftwareCategoriesRuleCollection(){
-		$this->rule_type = RULE_SOFTWARE_CATEGORY;
+	function __construct(){
+		$this->sub_type = RULE_SOFTWARE_CATEGORY;
 		$this->rule_class_name = 'SoftwareCategoriesRule';
 		$this->stop_on_first_match=true;
 		$this->right="rule_softwarecategories";
@@ -51,7 +51,7 @@ class SoftwareCategoriesRuleCollection extends RuleCollection {
 
 	function getTitle(){
 		global $LANG;
-		return $LANG["rulesengine"][37];
+		return $LANG['rulesengine'][37];
 	}
 
 	/**
@@ -62,6 +62,10 @@ class SoftwareCategoriesRuleCollection extends RuleCollection {
 	 */
 	function prepareInputDataForProcess($input,$software){
 		$params["name"]=$software["name"];
+		
+		if (isset($software["comments"]))
+			$params["comments"]=$software["comments"];
+			
 		if (isset($software["FK_glpi_enterprise"]))
 			$params["manufacturer"]=getDropdownName("glpi_dropdown_manufacturer",$software["FK_glpi_enterprise"]);
 		return $params;
@@ -81,17 +85,16 @@ class SoftwareCategoriesRule extends Rule {
 	/**
 	 * Constructor
 	**/
-	function SoftwareCategoriesRule() {
-		$this->table = "glpi_rules_descriptions";
-		$this->type = -1;
-		$this->rule_type = RULE_SOFTWARE_CATEGORY;
+	function __construct() {
+		parent::__construct(RULE_SOFTWARE_CATEGORY);
+
 		$this->right="rule_softwarecategories";
 		$this->can_sort=true;
 	}
 
 	function getTitle() {
 		global $LANG;
-		return $LANG["rulesengine"][37];
+		return $LANG['rulesengine'][37];
 	}
 
 	function maxActionsCount(){
