@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: setup.class.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: setup.class.php 8026 2009-02-28 16:50:46Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -42,14 +42,16 @@ class SetupSearchDisplay extends CommonDBTM{
 	/**
 	 * Constructor
 	**/
-	function SetupSearchDisplay () {
+	function __construct () {
 		$this->table="glpi_display";
 		$this->type=-1;
 	}
 
 	function prepareInputForAdd($input) {
 		global $DB;
-		$query="SELECT MAX(rank) FROM glpi_display WHERE type='".$input["type"]."' AND FK_users='".$input["FK_users"]."'";
+		$query="SELECT MAX(rank) 
+			FROM glpi_display 
+			WHERE type='".$input["type"]."' AND FK_users='".$input["FK_users"]."'";
 		$result=$DB->query($query);
 		$input["rank"]=$DB->result($result,0,0)+1;
 
@@ -67,7 +69,9 @@ class SetupSearchDisplay extends CommonDBTM{
 
 		if (!haveRight("search_config","w")) return false;
 
-		$query="SELECT * FROM glpi_display WHERE type='".$input["type"]."' AND FK_users='0'";
+		$query="SELECT * 
+			FROM glpi_display 
+			WHERE type='".$input["type"]."' AND FK_users='0'";
 		$result=$DB->query($query);
 		if ($DB->numrows($result)){
 			while ($data=$DB->fetch_assoc($result)){
@@ -108,18 +112,27 @@ class SetupSearchDisplay extends CommonDBTM{
 	function up($input){
 		global $DB;
 		// Get current item
-		$query="SELECT rank FROM glpi_display WHERE ID='".$input['ID']."';";
+		$query="SELECT rank 
+			FROM glpi_display 
+			WHERE ID='".$input['ID']."';";
 		$result=$DB->query($query);
 		$rank1=$DB->result($result,0,0);
 		// Get previous item
-		$query="SELECT ID,rank FROM glpi_display WHERE type='".$input['type']."' AND FK_users='".$input["FK_users"]."' AND rank<'$rank1' ORDER BY rank DESC;";
+		$query="SELECT ID, rank 
+			FROM glpi_display 
+			WHERE type='".$input['type']."' AND FK_users='".$input["FK_users"]."' AND rank<'$rank1'
+			ORDER BY rank DESC;";
 		$result=$DB->query($query);
 		$rank2=$DB->result($result,0,"rank");
 		$ID2=$DB->result($result,0,"ID");
 		// Update items
-		$query="UPDATE glpi_display SET rank='$rank2' WHERE ID ='".$input['ID']."'";
+		$query="UPDATE glpi_display 
+			SET rank='$rank2' 
+			WHERE ID ='".$input['ID']."'";
 		$DB->query($query);
-		$query="UPDATE glpi_display SET rank='$rank1' WHERE ID ='$ID2'";
+		$query="UPDATE glpi_display 
+			SET rank='$rank1' 
+			WHERE ID ='$ID2'";
 		$DB->query($query);
 	}
 
@@ -133,18 +146,27 @@ class SetupSearchDisplay extends CommonDBTM{
 		global $DB;
 
 		// Get current item
-		$query="SELECT rank FROM glpi_display WHERE ID='".$input['ID']."';";
+		$query="SELECT rank 
+			FROM glpi_display 
+			WHERE ID='".$input['ID']."';";
 		$result=$DB->query($query);
 		$rank1=$DB->result($result,0,0);
 		// Get next item
-		$query="SELECT ID,rank FROM glpi_display WHERE type='".$input['type']."' AND FK_users='".$input["FK_users"]."' AND rank>'$rank1' ORDER BY rank ASC;";
+		$query="SELECT ID, rank 
+			FROM glpi_display 
+			WHERE type='".$input['type']."' AND FK_users='".$input["FK_users"]."' AND rank>'$rank1' 
+			ORDER BY rank ASC;";
 		$result=$DB->query($query);
 		$rank2=$DB->result($result,0,"rank");
 		$ID2=$DB->result($result,0,"ID");
 		// Update items
-		$query="UPDATE glpi_display SET rank='$rank2' WHERE ID ='".$input['ID']."'";
+		$query="UPDATE glpi_display 
+			SET rank='$rank2' 
+			WHERE ID ='".$input['ID']."'";
 		$DB->query($query);
-		$query="UPDATE glpi_display SET rank='$rank1' WHERE ID ='$ID2'";
+		$query="UPDATE glpi_display 
+			SET rank='$rank1' 
+			WHERE ID ='$ID2'";
 		$DB->query($query);
 	}
 
@@ -156,70 +178,61 @@ class SetupSearchDisplay extends CommonDBTM{
 	 *
 	 *@return nothing
 	 **/
-	function showForm($target,$type){
+	function showFormPerso($target,$type){
 		global $SEARCH_OPTION,$CFG_GLPI,$LANG,$DB;
 
 		if (!isset($SEARCH_OPTION[$type])) {
 			return false;
 		}
-		$is_global=($_SESSION['glpi_searchconfig']==1);
-		if ($is_global) $IDuser=0;
-		else $IDuser=$_SESSION["glpiID"];
 
-		$global_write=haveRight("search_config_global","w");
+		$IDuser=$_SESSION["glpiID"];
 
-		echo "<div id='barre_onglets'><ul id='onglet'>";
-		echo "<li "; if ($_SESSION['glpi_searchconfig']==1){ echo "class='actif'";} echo  "><a href='$target?onglet=1&amp;type=$type'>".$LANG["central"][13]."</a></li>";
-		if (haveRight("search_config","w")){
-			echo "<li "; if ($_SESSION['glpi_searchconfig']==2){ echo "class='actif'";} echo  "><a href='$target?onglet=2&amp;type=$type'>".$LANG["central"][12]."</a></li>";
-		}
-		echo "</ul></div>";
-
-		echo "<div class='center'>";
+		echo "<div class='center' id='tabsbody' >";
 		// Defined items
-		$query="SELECT * from glpi_display WHERE type='$type' AND FK_users='$IDuser' order by rank";
+		$query="SELECT * 
+			FROM glpi_display 
+			WHERE type='$type' AND FK_users='$IDuser' 
+			ORDER BY rank";
 
 		$result=$DB->query($query);
 		$numrows=0;
 		$numrows=$DB->numrows($result);
-		if ($numrows==0&&!$is_global){
+		if ($numrows==0){
 			checkRight("search_config","w");
 			echo "<table class='tab_cadre_fixe' cellpadding='2' ><tr><th colspan='4'>";
 			echo "<form method='post' action=\"$target\">";
 			echo "<input type='hidden' name='type' value='$type'>";
 			echo "<input type='hidden' name='FK_users' value='$IDuser'>";
 
-			echo $LANG["setup"][241];
-			echo "&nbsp;&nbsp;&nbsp;<input type='submit' name='activate' value=\"".$LANG["buttons"][2]."\" class='submit' >";
+			echo $LANG['setup'][241];
+			echo "&nbsp;&nbsp;&nbsp;<input type='submit' name='activate' value=\"".$LANG['buttons'][2]."\" class='submit' >";
 			echo "</form></th></tr></table>";
 
 		} else {
 
 			echo "<table class='tab_cadre_fixe' cellpadding='2' ><tr><th colspan='4'>";
-			echo $LANG["setup"][252].": </th></tr>";
-			if (!$is_global||$global_write){
-				echo "<tr class='tab_bg_1'><td colspan='4' align='center'>";
-				echo "<form method='post' action=\"$target\">";
-				echo "<input type='hidden' name='type' value='$type'>";
-				echo "<input type='hidden' name='FK_users' value='$IDuser'>";
-				echo "<select name='num'>";
-				$first_group=true;
-				$searchopt=cleanSearchOption($type);
-				foreach ($searchopt as $key => $val)
-					if (!is_array($val)){
-						if (!$first_group) echo "</optgroup>";
-						else $first_group=false;
-						echo "<optgroup label=\"".$val."\">";
-					} else 	if ($key!=1){
-						echo "<option value='$key'>".$val["name"]."</option>";
-					}
-				if (!$first_group) echo "</optgroup>";
+			echo $LANG['setup'][252].": </th></tr>";
+			echo "<tr class='tab_bg_1'><td colspan='4' align='center'>";
+			echo "<form method='post' action=\"$target\">";
+			echo "<input type='hidden' name='type' value='$type'>";
+			echo "<input type='hidden' name='FK_users' value='$IDuser'>";
+			echo "<select name='num'>";
+			$first_group=true;
+			$searchopt=cleanSearchOption($type);
+			foreach ($searchopt as $key => $val)
+				if (!is_array($val)){
+					if (!$first_group) echo "</optgroup>";
+					else $first_group=false;
+					echo "<optgroup label=\"".$val."\">";
+				} else 	if ($key!=1){
+					echo "<option value='$key'>".$val["name"]."</option>";
+				}
+			if (!$first_group) echo "</optgroup>";
 
-				echo "</select>";
-				echo "&nbsp;&nbsp;&nbsp;<input type='submit' name='add' value=\"".$LANG["buttons"][8]."\" class='submit' >";
-				echo "</form>";
-				echo "</td></tr>";
-			}
+			echo "</select>";
+			echo "&nbsp;&nbsp;&nbsp;<input type='submit' name='add' value=\"".$LANG['buttons'][8]."\" class='submit' >";
+			echo "</form>";
+			echo "</td></tr>";
 
 
 			// print first element 
@@ -227,7 +240,6 @@ class SetupSearchDisplay extends CommonDBTM{
 			echo $SEARCH_OPTION[$type][1]["name"];
 
 
-			if (!$is_global||$global_write)
 				echo "</td><td colspan='3'>&nbsp;</td>";
 			echo "</tr>";
 			$i=0;
@@ -237,40 +249,38 @@ class SetupSearchDisplay extends CommonDBTM{
 						echo "<tr class='tab_bg_2'><td align='center' width='50%' >";
 						echo $SEARCH_OPTION[$type][$data["num"]]["name"];
 						echo "</td>";
-						if (!$is_global||$global_write){
-							if ($i!=0){
-								echo "<td align='center' valign='middle'>";
-								echo "<form method='post' action=\"$target\">";
-								echo "<input type='hidden' name='ID' value='".$data["ID"]."'>";
-								echo "<input type='hidden' name='FK_users' value='$IDuser'>";
-
-								echo "<input type='hidden' name='type' value='$type'>";
-								echo "<input type='image' name='up'  value=\"".$LANG["buttons"][24]."\"  src=\"".$CFG_GLPI["root_doc"]."/pics/puce-up2.png\" alt=\"".$LANG["buttons"][24]."\"  title=\"".$LANG["buttons"][24]."\" >";	
-								echo "</form>";
-								echo "</td>";
-							} else echo "<td>&nbsp;</td>";
-							if ($i!=$numrows-1){
-								echo "<td align='center' valign='middle'>";
-								echo "<form method='post' action=\"$target\">";
-								echo "<input type='hidden' name='ID' value='".$data["ID"]."'>";
-								echo "<input type='hidden' name='FK_users' value='$IDuser'>";
-
-								echo "<input type='hidden' name='type' value='$type'>";
-								echo "<input type='image' name='down' value=\"".$LANG["buttons"][25]."\" src=\"".$CFG_GLPI["root_doc"]."/pics/puce-down2.png\" alt=\"".$LANG["buttons"][25]."\"  title=\"".$LANG["buttons"][25]."\" >";	
-								echo "</form>";
-								echo "</td>";
-							} else echo "<td>&nbsp;</td>";
-
+						if ($i!=0){
 							echo "<td align='center' valign='middle'>";
 							echo "<form method='post' action=\"$target\">";
 							echo "<input type='hidden' name='ID' value='".$data["ID"]."'>";
 							echo "<input type='hidden' name='FK_users' value='$IDuser'>";
 
 							echo "<input type='hidden' name='type' value='$type'>";
-							echo "<input type='image' name='delete' value=\"".$LANG["buttons"][6]."\"src=\"".$CFG_GLPI["root_doc"]."/pics/puce-delete2.png\" alt=\"".$LANG["buttons"][6]."\"  title=\"".$LANG["buttons"][6]."\" >";	
+							echo "<input type='image' name='up'  value=\"".$LANG['buttons'][24]."\"  src=\"".$CFG_GLPI["root_doc"]."/pics/puce-up2.png\" alt=\"".$LANG['buttons'][24]."\"  title=\"".$LANG['buttons'][24]."\" >";	
 							echo "</form>";
 							echo "</td>";
-						}
+						} else echo "<td>&nbsp;</td>";
+						if ($i!=$numrows-1){
+							echo "<td align='center' valign='middle'>";
+							echo "<form method='post' action=\"$target\">";
+							echo "<input type='hidden' name='ID' value='".$data["ID"]."'>";
+							echo "<input type='hidden' name='FK_users' value='$IDuser'>";
+
+							echo "<input type='hidden' name='type' value='$type'>";
+							echo "<input type='image' name='down' value=\"".$LANG['buttons'][25]."\" src=\"".$CFG_GLPI["root_doc"]."/pics/puce-down2.png\" alt=\"".$LANG['buttons'][25]."\"  title=\"".$LANG['buttons'][25]."\" >";	
+							echo "</form>";
+							echo "</td>";
+						} else echo "<td>&nbsp;</td>";
+
+						echo "<td align='center' valign='middle'>";
+						echo "<form method='post' action=\"$target\">";
+						echo "<input type='hidden' name='ID' value='".$data["ID"]."'>";
+						echo "<input type='hidden' name='FK_users' value='$IDuser'>";
+
+						echo "<input type='hidden' name='type' value='$type'>";
+						echo "<input type='image' name='delete' value=\"".$LANG['buttons'][6]."\"src=\"".$CFG_GLPI["root_doc"]."/pics/puce-delete2.png\" alt=\"".$LANG['buttons'][6]."\"  title=\"".$LANG['buttons'][6]."\" >";	
+						echo "</form>";
+						echo "</td>";
 						echo "</tr>";
 						$i++;
 					}
@@ -280,6 +290,121 @@ class SetupSearchDisplay extends CommonDBTM{
 		}			
 		echo "</div>";
 	}
+
+	/**
+	 * Print the search config form
+	 *
+	 *@param $target form target
+	 *@param $type item type
+	 *
+	 *@return nothing
+	 **/
+	function showFormGlobal($target,$type){
+		global $SEARCH_OPTION,$CFG_GLPI,$LANG,$DB;
+
+		if (!isset($SEARCH_OPTION[$type])) {
+			return false;
+		}
+		$IDuser=0;
+
+		$global_write=haveRight("search_config_global","w");
+
+		echo "<div class='center' id='tabsbody' >";
+		// Defined items
+		$query="SELECT * 
+			FROM glpi_display 
+			WHERE type='$type' AND FK_users='$IDuser' 
+			ORDER BY rank";
+
+		$result=$DB->query($query);
+		$numrows=0;
+		$numrows=$DB->numrows($result);
+
+		echo "<table class='tab_cadre_fixe' cellpadding='2' ><tr><th colspan='4'>";
+		echo $LANG['setup'][252].": </th></tr>";
+		if ($global_write){
+			echo "<tr class='tab_bg_1'><td colspan='4' align='center'>";
+			echo "<form method='post' action=\"$target\">";
+			echo "<input type='hidden' name='type' value='$type'>";
+			echo "<input type='hidden' name='FK_users' value='$IDuser'>";
+			echo "<select name='num'>";
+			$first_group=true;
+			$searchopt=cleanSearchOption($type);
+			foreach ($searchopt as $key => $val)
+				if (!is_array($val)){
+					if (!$first_group) echo "</optgroup>";
+					else $first_group=false;
+					echo "<optgroup label=\"".$val."\">";
+				} else 	if ($key!=1){
+					echo "<option value='$key'>".$val["name"]."</option>";
+				}
+			if (!$first_group) echo "</optgroup>";
+
+			echo "</select>";
+			echo "&nbsp;&nbsp;&nbsp;<input type='submit' name='add' value=\"".$LANG['buttons'][8]."\" class='submit' >";
+			echo "</form>";
+			echo "</td></tr>";
+		}
+
+		// print first element 
+		echo "<tr class='tab_bg_2'><td  align='center' width='50%'>";
+		echo $SEARCH_OPTION[$type][1]["name"];
+
+
+		if ($global_write){
+			echo "</td><td colspan='3'>&nbsp;</td>";
+		}
+		echo "</tr>";
+		$i=0;
+		if ($numrows){
+			while ($data=$DB->fetch_array($result)){
+				if ($data["num"]!=1){
+					echo "<tr class='tab_bg_2'><td align='center' width='50%' >";
+					echo $SEARCH_OPTION[$type][$data["num"]]["name"];
+					echo "</td>";
+					if ($global_write){
+						if ($i!=0){
+							echo "<td align='center' valign='middle'>";
+							echo "<form method='post' action=\"$target\">";
+							echo "<input type='hidden' name='ID' value='".$data["ID"]."'>";
+							echo "<input type='hidden' name='FK_users' value='$IDuser'>";
+
+							echo "<input type='hidden' name='type' value='$type'>";
+							echo "<input type='image' name='up'  value=\"".$LANG['buttons'][24]."\"  src=\"".$CFG_GLPI["root_doc"]."/pics/puce-up2.png\" alt=\"".$LANG['buttons'][24]."\"  title=\"".$LANG['buttons'][24]."\" >";	
+							echo "</form>";
+							echo "</td>";
+						} else echo "<td>&nbsp;</td>";
+						if ($i!=$numrows-1){
+							echo "<td align='center' valign='middle'>";
+							echo "<form method='post' action=\"$target\">";
+							echo "<input type='hidden' name='ID' value='".$data["ID"]."'>";
+							echo "<input type='hidden' name='FK_users' value='$IDuser'>";
+
+							echo "<input type='hidden' name='type' value='$type'>";
+							echo "<input type='image' name='down' value=\"".$LANG['buttons'][25]."\" src=\"".$CFG_GLPI["root_doc"]."/pics/puce-down2.png\" alt=\"".$LANG['buttons'][25]."\"  title=\"".$LANG['buttons'][25]."\" >";	
+							echo "</form>";
+							echo "</td>";
+						} else echo "<td>&nbsp;</td>";
+
+						echo "<td align='center' valign='middle'>";
+						echo "<form method='post' action=\"$target\">";
+						echo "<input type='hidden' name='ID' value='".$data["ID"]."'>";
+						echo "<input type='hidden' name='FK_users' value='$IDuser'>";
+
+						echo "<input type='hidden' name='type' value='$type'>";
+						echo "<input type='image' name='delete' value=\"".$LANG['buttons'][6]."\"src=\"".$CFG_GLPI["root_doc"]."/pics/puce-delete2.png\" alt=\"".$LANG['buttons'][6]."\"  title=\"".$LANG['buttons'][6]."\" >";	
+						echo "</form>";
+						echo "</td>";
+					}
+					echo "</tr>";
+					$i++;
+				}
+			}
+		}
+	echo "</table>";
+	echo "</div>";
+	}
+
 }
 
 ?>
