@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: tracking.class.php 8321 2009-05-22 12:24:53Z remi $
+ * @version $Id: tracking.class.php 8504 2009-07-26 12:40:12Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -48,11 +48,35 @@ class Job extends CommonDBTM{
 	/**
 	 * Constructor
 	**/
-	function Job(){
+	function __construct(){
 		$this->table="glpi_tracking";
 		$this->type=TRACKING_TYPE;
-	}
+		$this->entity_assign=true;
 
+	}
+	
+	function defineTabs($ID,$withtemplate){ 
+		global $LANG,$CFG_GLPI; 
+		
+		$job=new Job();
+		$job->getFromDB($ID);
+		
+		$ong[1]=$LANG['job'][38]." ".$ID;
+		if ($_SESSION["glpiactiveprofile"]["interface"]=="central"){
+			if ($job->canAddFollowups()){
+				$ong[2]=$LANG['job'][29];
+			}
+		}elseif (haveRight("comment_ticket","1")){
+			$ong[1]=$LANG['job'][38]." ".$ID;
+			if (!strstr($job->fields["status"],"old_")&&$job->fields["author"]==$_SESSION["glpiID"]){
+				$ong[2]=$LANG['job'][29];
+			}
+		}
+
+		$ong['no_all_tab']=true;
+
+		return $ong; 
+	}
 	/**
 	 * Retrieve an item from the database with datas associated (hardwares)
 	 *
@@ -109,13 +133,31 @@ class Job extends CommonDBTM{
 
 	function prepareInputForUpdate($input) {
 		global $LANG,$CFG_GLPI;
+
+		if (isset($input["date"])&&empty($input["date"])){
+			unset($input["date"]);
+		}
+		if (isset($input["closedate"])&&empty($input["closedate"])){
+			unset($input["closedate"]);
+		}
+
 		// Security checks
 		if (!haveRight("assign_ticket","1")){
 			if (isset($input["assign"])){
-				// Can not steal or can steal and not assign to me
-				if (!haveRight("steal_ticket","1")||$input["assign"]!=$_SESSION["glpiID"]){
-					unset($input["assign"]);
-				} 
+				$this->getFromDB($input['ID']);
+				// must own_ticket to grab a non assign ticket
+				if ($this->fields['assign']==0){
+					if ((!haveRight("steal_ticket","1") && !haveRight("own_ticket","1"))
+						|| ($input["assign"]!=$_SESSION["glpiID"])){
+						unset($input["assign"]);
+					}
+				} else {
+					// Can not steal or can steal and not assign to me
+					if (!haveRight("steal_ticket","1")||$input["assign"]!=$_SESSION["glpiID"]){
+						unset($input["assign"]);
+					} 
+
+				}
 			}
 			if (isset($input["assign_ent"])){
 				unset($input["assign_ent"]);
@@ -183,7 +225,7 @@ class Job extends CommonDBTM{
 			// add Document if exists
 			if (isset($_FILES['filename'])&&count($_FILES['filename'])>0&&$_FILES['filename']["size"]>0){
 				$input2=array();
-				$input2["name"]=addslashes(resume_text($LANG["tracking"][24]." ".$input["ID"],200));
+				$input2["name"]=addslashes(resume_text($LANG['tracking'][24]." ".$input["ID"],200)); 
 				$input2["FK_tracking"]=$input["ID"];
 				$input2["rubrique"]=$CFG_GLPI["default_rubdoc_tracking"];
 				$this->getFromDB($input["ID"]);
@@ -195,11 +237,11 @@ class Job extends CommonDBTM{
 					// force update date_mod
 					$input["date_mod"]=$_SESSION["glpi_currenttime"];
 					if ($CFG_GLPI["followup_on_update_ticket"]){
-						$input['_doc_added']=stripslashes($doc->fields["name"]);
+						$input['_doc_added']=stripslashes($doc->fields["name"]); 
 					}
 				}
 			} else if (!empty($_FILES['filename']['name'])&&isset($_FILES['filename']['error'])&&$_FILES['filename']['error']){
-				addMessageAfterRedirect($LANG["document"][46]);
+				addMessageAfterRedirect($LANG['document'][46],false,ERROR);
 			}
 		}
 
@@ -235,29 +277,12 @@ class Job extends CommonDBTM{
 			$input["_old_date"]=$this->fields["date"];
 			$input["_old_closedate"]=$this->fields["closedate"];
 		}
-
 		return $input;
 	}
 
-	function pre_updateInDB($input,$updates) {
+	function pre_updateInDB($input,$updates,$oldvalues=array()) {
 		global $LANG;
 
-		// Status close : check dates
-		if (ereg("old_",$this->fields["status"])&&(in_array("date",$updates)||in_array("closedate",$updates))){
-			// Invalid dates : no change
-			if ($this->fields["closedate"]<$this->fields["date"]){
-				addMessageAfterRedirect($LANG["tracking"][3]);
-				if (($key=array_search('date',$updates))!==false){
-					unset($updates[$key]);
-				}
-				if (($key=array_search('closedate',$updates))!==false){
-					unset($updates[$key]);
-				}
-			}
-		}
-
-
-
 		if (((in_array("assign",$updates)&&$input["assign"]>0)||(in_array("assign_ent",$updates)&&$input["assign_ent"]>0)||(in_array("assign_group",$updates)&&$input["assign_group"]>0))&&$this->fields["status"]=="new"){
 			$updates[]="status";
 			$this->fields["status"]="assign";
@@ -269,8 +294,9 @@ class Job extends CommonDBTM{
 				$this->fields["status"]="new";
 			}
 
-			if (in_array("status",$updates)&&ereg("old_",$input["status"])){
+			if (in_array("status",$updates)&&strstr($input["status"],"old_")){
 				$updates[]="closedate";
+				$oldvalues['closedate']=$this->fields["closedate"];
 				$this->fields["closedate"]=$_SESSION["glpi_currenttime"];
 				// If invalid date : set open date
 				if ($this->fields["closedate"]<$this->fields["date"]){
@@ -279,6 +305,31 @@ class Job extends CommonDBTM{
 			}
 		}
 
+
+		// Status close : check dates
+		if (strstr($this->fields["status"],"old_")&&(in_array("date",$updates)||in_array("closedate",$updates))){
+			// Invalid dates : no change
+			if ($this->fields["closedate"]<$this->fields["date"]){
+				addMessageAfterRedirect($LANG['tracking'][3],false,ERROR);
+				if (($key=array_search('date',$updates))!==false){
+					unset($updates[$key]);
+				}
+				if (($key=array_search('closedate',$updates))!==false){
+					unset($updates[$key]);
+				}
+			}
+		}
+
+		// Check dates change interval due to the fact that second are not displayed in form
+		
+		if (($key=array_search('date',$updates))!==false && (substr($this->fields["date"],0,16) == substr($oldvalues['date'],0,16))){
+			unset($updates[$key]);
+		}
+		if (($key=array_search('closedate',$updates))!==false && (substr($this->fields["closedate"],0,16) == substr($oldvalues['closedate'],0,16))){
+			unset($updates[$key]);
+		}
+
+
 		if (in_array("author",$updates)){
 			$user=new User;
 			$user->getFromDB($input["author"]);
@@ -287,6 +338,11 @@ class Job extends CommonDBTM{
 				$this->fields["uemail"]=$user->fields["email"];
 			}
 		}
+		
+		// Do not take into account date_mod if no update is done
+		if (count($updates)==1 && ($key=array_search('date_mod',$updates))!==false){
+			unset($updates[$key]);
+		}
 
 		return array($input,$updates);
 	}
@@ -298,7 +354,7 @@ class Job extends CommonDBTM{
 			// New values for add followup in change
 			$change_followup_content="";
 			if (isset($input['_doc_added'])){
-				$change_followup_content=$LANG["mailing"][26]." ".$input['_doc_added'];
+				$change_followup_content=$LANG['mailing'][26]." ".$input['_doc_added'];
 			}
 			$global_mail_change_count=0;
 	
@@ -319,31 +375,31 @@ class Job extends CommonDBTM{
 				foreach ($updates as $key)
 				switch ($key) {
 					case "name":
-						$change_followup_content.=$LANG["mailing"][45]."\n";
+						$change_followup_content.=$LANG['mailing'][45]."\n";
 						$global_mail_change_count++;
 						break;
 					case "contents":
-						$change_followup_content.=$LANG["mailing"][46]."\n";
+						$change_followup_content.=$LANG['mailing'][46]."\n";
 						$global_mail_change_count++;
 					break;
 					case "date":
-						$change_followup_content.=$LANG["mailing"][48].": ".$input["_old_date"]." -> ".$this->fields["date"]."\n";
+						$change_followup_content.=$LANG['mailing'][48].": ".$input["_old_date"]." -> ".$this->fields["date"]."\n";
 		
 						$global_mail_change_count++;
 					break;
 					case "closedate":
 						// if update status from an not closed status : no mail for change closedate
-						if (!in_array("status",$updates)||!ereg("old_",$input["status"])){
-							$change_followup_content.=$LANG["mailing"][49].": ".$input["_old_closedate"]." -> ".$this->fields["closedate"]."\n";
+						if (!in_array("status",$updates)||!strstr($input["status"],"old_")){
+							$change_followup_content.=$LANG['mailing'][49].": ".$input["_old_closedate"]." -> ".$this->fields["closedate"]."\n";
 			
 							$global_mail_change_count++;
 						}
 					break;
 					case "status":
 						$new_status=$this->fields["status"];
-						$change_followup_content.=$LANG["mailing"][27].": ".getStatusName($input["_old_status"])." -> ".getStatusName($new_status)."\n";
+						$change_followup_content.=$LANG['mailing'][27].": ".getStatusName($input["_old_status"])." -> ".getStatusName($new_status)."\n";
 		
-						if (ereg("old_",$new_status))
+						if (strstr($new_status,"old_"))
 							$newinput["add_close"]="add_close";
 
 						if (in_array("closedate",$updates))	
@@ -357,7 +413,7 @@ class Job extends CommonDBTM{
 						$old_author_name=$author->getName();
 						$author->getFromDB($this->fields["author"]);
 						$new_author_name=$author->getName();
-						$change_followup_content.=$LANG["mailing"][18].": $old_author_name -> ".$new_author_name."\n";
+						$change_followup_content.=$LANG['mailing'][18].": $old_author_name -> ".$new_author_name."\n";
 		
 						$global_mail_change_count++;
 					break;
@@ -367,34 +423,34 @@ class Job extends CommonDBTM{
 						$old_recipient_name=$recipient->getName();
 						$recipient->getFromDB($this->fields["recipient"]);
 						$new_recipient_name=$recipient->getName();
-						$change_followup_content.=$LANG["mailing"][50].": $old_recipient_name -> ".$new_recipient_name."\n";
+						$change_followup_content.=$LANG['mailing'][50].": $old_recipient_name -> ".$new_recipient_name."\n";
 		
 						$global_mail_change_count++;
 					break;
 					case "FK_group" :
 						$new_group=$this->fields["FK_group"];
-						$old_group_name=ereg_replace("&nbsp;",$LANG["mailing"][109],getDropdownName("glpi_groups",$input["_old_group"]));
-						$new_group_name=ereg_replace("&nbsp;",$LANG["mailing"][109],getDropdownName("glpi_groups",$new_group));
-						$change_followup_content.=$LANG["mailing"][20].": ".$old_group_name." -> ".$new_group_name."\n";
+						$old_group_name=str_replace("&nbsp;",$LANG['mailing'][109],getDropdownName("glpi_groups",$input["_old_group"]));
+						$new_group_name=str_replace("&nbsp;",$LANG['mailing'][109],getDropdownName("glpi_groups",$new_group));
+						$change_followup_content.=$LANG['mailing'][20].": ".$old_group_name." -> ".$new_group_name."\n";
 						$global_mail_change_count++;
 					break;
 					case "priority" :
 						$new_priority=$this->fields["priority"];
-						$change_followup_content.=$LANG["mailing"][15].": ".getPriorityName($input["_old_priority"])." -> ".getPriorityName($new_priority)."\n";
+						$change_followup_content.=$LANG['mailing'][15].": ".getPriorityName($input["_old_priority"])." -> ".getPriorityName($new_priority)."\n";
 						$global_mail_change_count++;		
 					break;
 					case "category":
 						$new_category=$this->fields["category"];
-						$old_category_name=ereg_replace("&nbsp;",$LANG["mailing"][100],getDropdownName("glpi_dropdown_tracking_category",$input["_old_category"]));
-						$new_category_name=ereg_replace("&nbsp;",$LANG["mailing"][100],getDropdownName("glpi_dropdown_tracking_category",$new_category));
-						$change_followup_content.=$LANG["mailing"][14].": ".$old_category_name." -> ".$new_category_name."\n";
+						$old_category_name=str_replace("&nbsp;",$LANG['mailing'][100],getDropdownName("glpi_dropdown_tracking_category",$input["_old_category"]));
+						$new_category_name=str_replace("&nbsp;",$LANG['mailing'][100],getDropdownName("glpi_dropdown_tracking_category",$new_category));
+						$change_followup_content.=$LANG['mailing'][14].": ".$old_category_name." -> ".$new_category_name."\n";
 						$global_mail_change_count++;
 					break;
 					case "request_type":
 						$new_request_type=$this->fields["request_type"];
 						$old_request_type_name=getRequestTypeName($input["_old_request_type"]);
 						$new_request_type_name=getRequestTypeName($new_request_type);
-						$change_followup_content.=$LANG["mailing"][21].": ".$old_request_type_name." -> ".$new_request_type_name."\n";
+						$change_followup_content.=$LANG['mailing'][21].": ".$old_request_type_name." -> ".$new_request_type_name."\n";
 						$global_mail_change_count++;
 					break;
 					case "computer" :
@@ -404,55 +460,56 @@ class Job extends CommonDBTM{
 						} else {
 							$already_done_computer_device_type_update=true;
 						}
+
 						$ci=new CommonItem;
 						$ci->getFromDB($input["_old_item_type"],$input["_old_item"]);
 						$old_item_name=$ci->getName();
 						if ($old_item_name=="N/A"||empty($old_item_name))
-							$old_item_name=$LANG["mailing"][107];
+							$old_item_name=$LANG['mailing'][107];
 						$ci->getFromDB($this->fields["device_type"],$this->fields["computer"]);
 						$new_item_name=$ci->getName();
 						if ($new_item_name=="N/A"||empty($new_item_name))
-							$new_item_name=$LANG["mailing"][107];
+							$new_item_name=$LANG['mailing'][107];
 		
-						$change_followup_content.=$LANG["mailing"][17].": $old_item_name -> ".$new_item_name."\n";
+						$change_followup_content.=$LANG['mailing'][17].": $old_item_name -> ".$new_item_name."\n";
 						if (in_array("computer",$updates)) $global_mail_change_count++;
 						if (in_array("device_type",$updates)) $global_mail_change_count++;
 					break;
 					case "assign" :
 						$new_assign_name=getAssignName($this->fields["assign"],USER_TYPE);
 						if ($input["_old_assign"]==0){
-							$input["_old_assign_name"]=$LANG["mailing"][105];
+							$input["_old_assign_name"]=$LANG['mailing'][105];
 						}
-						$change_followup_content.=$LANG["mailing"][12].": ".$input["_old_assign_name"]." -> ".$new_assign_name."\n";
+						$change_followup_content.=$LANG['mailing'][12].": ".$input["_old_assign_name"]." -> ".$new_assign_name."\n";
 						$global_mail_change_count++;
 					break;
 					case "assign_ent" :
 						$new_assign_ent_name=getAssignName($this->fields["assign_ent"],ENTERPRISE_TYPE);
-						$change_followup_content.=$LANG["mailing"][12].": ".$input["_old_assign_ent_name"]." -> ".$new_assign_ent_name."\n";
+						$change_followup_content.=$LANG['mailing'][12].": ".$input["_old_assign_ent_name"]." -> ".$new_assign_ent_name."\n";
 						$global_mail_change_count++;
 					break;
 					case "assign_group" :
 						$new_assign_group_name=getAssignName($this->fields["assign_group"],GROUP_TYPE);
-						$change_followup_content.=$LANG["mailing"][12].": ".$input["_old_assign_group_name"]." -> ".$new_assign_group_name."\n";
+						$change_followup_content.=$LANG['mailing'][12].": ".$input["_old_assign_group_name"]." -> ".$new_assign_group_name."\n";
 						$global_mail_change_count++;
 					break;
 					case "cost_time":
-						$change_followup_content.=$LANG["mailing"][42].": ".formatNumber($input["_old_cost_time"])." -> ".formatNumber($this->fields["cost_time"])."\n";
+						$change_followup_content.=$LANG['mailing'][42].": ".formatNumber($input["_old_cost_time"])." -> ".formatNumber($this->fields["cost_time"])."\n";
 						$global_mail_change_count++;
 					break;
 					case "cost_fixed" :
-						$change_followup_content.=$LANG["mailing"][43].": ".formatNumber($input["_old_cost_fixed"])." -> ".formatNumber($this->fields["cost_fixed"])."\n";
+						$change_followup_content.=$LANG['mailing'][43].": ".formatNumber($input["_old_cost_fixed"])." -> ".formatNumber($this->fields["cost_fixed"])."\n";
 						$global_mail_change_count++;
 					break;
 					case "cost_material" :
-						$change_followup_content.=$LANG["mailing"][44].": ".formatNumber($input["_old_cost_material"])." -> ".formatNumber($this->fields["cost_material"])."\n";
+						$change_followup_content.=$LANG['mailing'][44].": ".formatNumber($input["_old_cost_material"])." -> ".formatNumber($this->fields["cost_material"])."\n";
 						$global_mail_change_count++;
 					break;
 					case "emailupdates":
 						if ($this->fields["emailupdates"]){
-							$change_followup_content.=$LANG["mailing"][101]."\n";
+							$change_followup_content.=$LANG['mailing'][101]."\n";
 						} else {
-							$change_followup_content.=$LANG["mailing"][102]."\n";
+							$change_followup_content.=$LANG['mailing'][102]."\n";
 						}
 						$global_mail_change_count++;
 					break;
@@ -476,7 +533,7 @@ class Job extends CommonDBTM{
 				if (isset($input["_old_assign"])){
 					$newinput["_old_assign"]=$input["_old_assign"];
 				} 
-				if (isset($input["status"])&&in_array("status",$updates)&&ereg("old_",$input["status"])){
+				if (isset($input["status"])&&in_array("status",$updates)&&strstr($input["status"],"old_")){
 					$newinput["type"]="finish";
 				}
 				$fup=new Followup();
@@ -492,7 +549,7 @@ class Job extends CommonDBTM{
 				$user=new User;
 				$user->getFromDB($_SESSION["glpiID"]);
 				$mailtype="update";
-				if ($input["status"]&&in_array("status",$updates)&&ereg("old_",$input["status"])){
+				if (isset($input["status"])&&$input["status"]&&in_array("status",$updates)&&strstr($input["status"],"old_")){
 					$mailtype="finish";
 				} 
 				if (isset($input["_old_assign"])){
@@ -507,9 +564,7 @@ class Job extends CommonDBTM{
 
 	function prepareInputForAdd($input) {
 		global $CFG_GLPI,$LANG;
-
-//		print_r($input);
-//		exit();
+		
 		// Check mandatory
 		$mandatory_ok=true;
 
@@ -519,19 +574,19 @@ class Job extends CommonDBTM{
 			$_SESSION["helpdeskSaved"]=$input;
 	
 			if ($CFG_GLPI["ticket_content_mandatory"]&&(!isset($input['contents'])||empty($input['contents']))){
-				addMessageAfterRedirect($LANG["tracking"][8]);
+				addMessageAfterRedirect($LANG['tracking'][8],false,ERROR);
 				$mandatory_ok=false;
 			}
 			if ($CFG_GLPI["ticket_title_mandatory"]&&(!isset($input['name'])||empty($input['name']))){
-				addMessageAfterRedirect($LANG["help"][40]);
+				addMessageAfterRedirect($LANG['help'][40],false,ERROR);
 				$mandatory_ok=false;
 			}
 			if ($CFG_GLPI["ticket_category_mandatory"]&&(!isset($input['category'])||empty($input['category']))){
-				addMessageAfterRedirect($LANG["help"][41]);
+				addMessageAfterRedirect($LANG['help'][41],false,ERROR);
 				$mandatory_ok=false;
 			}
 			if (isset($input['emailupdates'])&&$input['emailupdates']&&(!isset($input['uemail'])||empty($input['uemail']))){
-				addMessageAfterRedirect($LANG["help"][16]);
+				addMessageAfterRedirect($LANG['help'][16],false,ERROR);
 				$mandatory_ok=false;
 			}
 	
@@ -541,6 +596,7 @@ class Job extends CommonDBTM{
 		}
 		unset($_SESSION["helpdeskSaved"]);
 
+
 		// Manage helpdesk.html submission type
 		unset($input["type"]);
 
@@ -563,12 +619,7 @@ class Job extends CommonDBTM{
 		if (!isset($input["status"])) $input["status"]="new";
 		if (!isset($input["assign"])) $input["assign"]=0;
 		
-		$user=new User();
-		if ($user->getFromDB($input["author"])){
-			$input['author_location']=$user->fields['location'];
-		}
-
-		if (!isset($input["date"])||$input["date"]=='0000-00-00 00:00'){
+		if (!isset($input["date"])||empty($input["date"])){
 			$input["date"] = $_SESSION["glpi_currenttime"];
 		}
 
@@ -603,6 +654,20 @@ class Job extends CommonDBTM{
 		// Process Business Rules
 		$rules=new TrackingBusinessRuleCollection();
 
+		// Set unset variables with are needed
+		$user=new User();
+		if ($user->getFromDB($input["author"])){
+			$input['author_location']=$user->fields['location'];
+		}
+
+		// Set default dropdown
+		$dropdown_fields=array('FK_entities','device_type','request_type','assign_group','assign','FK_group','author','category');
+		foreach ($dropdown_fields as $field ){
+			if (!isset($input[$field])){
+				$input[$field]=0;
+			}
+		} 
+
 		$input=$rules->processAllRules($input,$input);
 
 		if (isset($input["emailupdates"])&&$input["emailupdates"]&&empty($input["uemail"])){
@@ -633,12 +698,13 @@ class Job extends CommonDBTM{
 				$input["closedate"]=$_SESSION["glpi_currenttime"];
 			}
 		} 
-
-		if (empty($input["name"])) {
-			$input["name"]=preg_replace('/\r\n/',' ',$input['contents']);
-			$input["name"]=preg_replace('/\n/',' ',$input['name']);
-			$input["name"]=substr($input['name'],0,70);
-		}
+		
+		// No name set name
+                if (empty($input["name"])) {
+                        $input["name"]=preg_replace('/\r\n/',' ',$input['contents']);
+                        $input["name"]=preg_replace('/\n/',' ',$input['name']);
+                        $input["name"]=substr($input['name'],0,70);
+                }
 
 		return $input;
 	}
@@ -656,9 +722,9 @@ class Job extends CommonDBTM{
 		foreach ($TMPFILE as $_FILES) {
 			if (isset($_FILES['filename'])&&count($_FILES['filename'])>0&&$_FILES['filename']["size"]>0){
 				$input2=array();
-				$input2["name"]=$LANG["tracking"][24]." $newID";
+				$input2["name"]=$LANG['tracking'][24]." $newID";
 				$input2["FK_tracking"]=$newID;
-				$input2["FK_entities"]=$input["FK_entities"];
+				$input2["FK_entities"]=$this->fields["FK_entities"];
 				$input2["rubrique"]=$CFG_GLPI["default_rubdoc_tracking"];
 				$input2["_only_if_upload_succeed"]=1;
 				$doc=new Document();
@@ -668,7 +734,7 @@ class Job extends CommonDBTM{
 		}
 
 		// Log this event
-		logEvent($newID,"tracking",4,"tracking",getUserName($input["author"])." ".$LANG["log"][20]);
+		logEvent($newID,"tracking",4,"tracking",getUserName($input["author"])." ".$LANG['log'][20]);
 
 		$already_mail=false;
 		if (((isset($input["_followup"])&&is_array($input["_followup"])&&strlen($input["_followup"]['contents']))||isset($input["plan"]))
@@ -676,7 +742,7 @@ class Job extends CommonDBTM{
 
 			$fup=new Followup();
 			$type="new";
-			if (isset($this->fields["status"])&&ereg("old_",$this->fields["status"])) $type="finish";
+			if (isset($this->fields["status"])&&strstr($this->fields["status"],"old_")) $type="finish";
 			$toadd=array("type"=>$type,"tracking"=>$newID);
 			if (isset($input["_hour"])) $toadd["hour"]=$input["_hour"];
 			if (isset($input["_minute"])) $toadd["minute"]=$input["_minute"];
@@ -692,13 +758,11 @@ class Job extends CommonDBTM{
 		{
 			$user=new User();
 			$user->getFromDB($input["author"]);
-
-			//$this->fields=stripslashes_deep($this->fields);
 			// Clean reload of the ticket
 			$this->getFromDB($newID);
 
 			$type="new";
-			if (isset($this->fields["status"])&&ereg("old_",$this->fields["status"])) $type="finish";
+			if (isset($this->fields["status"])&&strstr($this->fields["status"],"old_")) $type="finish";
 			$mail = new Mailing($type,$this,$user);
 			$mail->send();
 		}
@@ -771,55 +835,55 @@ class Job extends CommonDBTM{
 			$result=$DB->query($query);
 			$nbfollow=$DB->numrows($result);
 			if($format=="html"){
-				$message = "<div class='description'><strong>".$LANG["mailing"][4]." : $nbfollow<br></strong></div>\n";
+				$message = "<div class='description'><strong>".$LANG['mailing'][4]." : $nbfollow<br></strong></div>\n";
 
 				if ($nbfollow>0){
 					$fup=new Followup();
 					while ($data=$DB->fetch_array($result)){
 						$fup->getFromDB($data['ID']);
-						$message .= "<strong>[ ".convDateTime($fup->fields["date"])." ] ".($fup->fields["private"]?"<i>".$LANG["common"][77]."</i>":"")."</strong>\n";
-						$message .= "<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG["job"][4].":</span> ".$fup->getAuthorName()."<br>";
-						$message .= "<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG["mailing"][3]."</span>:<br>".ereg_replace("\n","<br>",$fup->fields["contents"])."\n";
+						$message .= "<strong>[ ".convDateTime($fup->fields["date"])." ] ".($fup->fields["private"]?"<i>".$LANG['common'][77]."</i>":"")."</strong>\n";
+						$message .= "<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG['job'][4].":</span> ".$fup->getAuthorName()."\n";
+						$message .= "<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG['mailing'][3]."</span>:<br>".str_replace("\n","<br>",$fup->fields["contents"])."\n";
 						if ($fup->fields["realtime"]>0)
-							$message .= "<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG["mailing"][104].":</span> ".getRealtime($fup->fields["realtime"])."\n";
+							$message .= "<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG['mailing'][104].":</span> ".getRealtime($fup->fields["realtime"])."\n";
 
-						$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG["mailing"][25]."</span> ";
-						$query2="SELECT * from glpi_tracking_planning WHERE id_followup='".$data['ID']."'";
+						$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG['mailing'][25]."</span> ";
+						$query2="SELECT * FROM glpi_tracking_planning WHERE id_followup='".$data['ID']."'";
 						$result2=$DB->query($query2);
 						if ($DB->numrows($result2)==0)
-							$message.=$LANG["job"][32]."\n";
+							$message.=$LANG['job'][32]."\n";
 						else {
 							$data2=$DB->fetch_array($result2);
 							$message.=convDateTime($data2["begin"])." -> ".convDateTime($data2["end"])."\n";
 						}
 
-						$message.=$LANG["mailing"][0]."\n";	
+						$message.=$LANG['mailing'][0]."\n";	
 					}	
 				}
 			}else{ // text format
-				$message = $LANG["mailing"][1]."\n".$LANG["mailing"][4]." : $nbfollow\n".$LANG["mailing"][1]."\n";
+				$message = $LANG['mailing'][1]."\n".$LANG['mailing'][4]." : $nbfollow\n".$LANG['mailing'][1]."\n";
 
 				if ($nbfollow>0){
 					$fup=new Followup();
 					while ($data=$DB->fetch_array($result)){
 						$fup->getFromDB($data['ID']);
-						$message .= "[ ".convDateTime($fup->fields["date"])." ]".($fup->fields["private"]?"\t".$LANG["common"][77]:"")."\n";
-						$message .= $LANG["job"][4].": ".$fup->getAuthorName()."\n";
-						$message .= $LANG["mailing"][3].":\n".$fup->fields["contents"]."\n";
+						$message .= "[ ".convDateTime($fup->fields["date"])." ]".($fup->fields["private"]?"\t".$LANG['common'][77]:"")."\n";
+						$message .= $LANG['job'][4].": ".$fup->getAuthorName()."\n";
+						$message .= $LANG['mailing'][3].":\n".$fup->fields["contents"]."\n";
 						if ($fup->fields["realtime"]>0)
-							$message .= $LANG["mailing"][104].": ".getRealtime($fup->fields["realtime"])."\n";
+							$message .= $LANG['mailing'][104].": ".getRealtime($fup->fields["realtime"])."\n";
 
-						$message.=$LANG["mailing"][25]." ";
-						$query2="SELECT * from glpi_tracking_planning WHERE id_followup='".$data['ID']."'";
+						$message.=$LANG['mailing'][25]." ";
+						$query2="SELECT * FROM glpi_tracking_planning WHERE id_followup='".$data['ID']."'";
 						$result2=$DB->query($query2);
 						if ($DB->numrows($result2)==0)
-							$message.=$LANG["job"][32]."\n";
+							$message.=$LANG['job'][32]."\n";
 						else {
 							$data2=$DB->fetch_array($result2);
 							$message.=convDateTime($data2["begin"])." -> ".convDateTime($data2["end"])."\n";
 						}
 
-						$message.=$LANG["mailing"][0]."\n";	
+						$message.=$LANG['mailing'][0]."\n";	
 					}	
 				}
 
@@ -838,7 +902,7 @@ class Job extends CommonDBTM{
 		global $DB,$LANG;
 
 
-		$name=$LANG["help"][30];
+		$name=$LANG['help'][30];
 		$contact='';
 		$tech='';
 		$name=$this->hardwaredatas->getType()." ".$this->hardwaredatas->getName();
@@ -887,17 +951,17 @@ class Job extends CommonDBTM{
 			$message.=".description{ color: inherit; background: #ebebeb; border-style: solid; border-color: #8d8d8d; border-width: 0px 1px 1px 0px; }";
 			$message.=" </style></head><body>";
 
-			$message.="<div class='description'><strong>".$LANG["mailing"][5]."</strong></div>\n";
-			$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG["common"][57].":</span> ".$this->fields["name"]."\n";
+			$message.="<div class='description'><strong>".$LANG['mailing'][5]."</strong></div>\n";
+			$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG['common'][57].":</span> ".$this->fields["name"]."\n";
 			$author=$this->getAuthorName();
-			if (empty($author)) $author=$LANG["mailing"][108];
-			$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG["job"][4].":</span> ".$author."\n";
-			$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>". $LANG["search"][8].":</span> ".convDateTime($this->fields["date"])."\n";
-			$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>". $LANG["job"][44].":</span> ".getRequestTypeName($this->fields["request_type"])."\n";
-			$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>". $LANG["mailing"][7].":</span> ".$name."\n";
+			if (empty($author)) $author=$LANG['mailing'][108];
+			$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG['job'][4].":</span> ".$author."\n";
+			$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>". $LANG['search'][8].":</span> ".convDateTime($this->fields["date"])."\n";
+			$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>". $LANG['job'][44].":</span> ".getRequestTypeName($this->fields["request_type"])."\n";
+			$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>". $LANG['mailing'][7].":</span> ".$name."\n";
 			if (!empty($tech))
-				$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>". $LANG["common"][10].":</span> ".$tech."\n";
-			$message.= "<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG["joblist"][0].":</span> ".getStatusName($this->fields["status"])."\n";
+				$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>". $LANG['common'][10].":</span> ".$tech."\n";
+			$message.= "<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG['joblist'][0].":</span> ".getStatusName($this->fields["status"])."\n";
 			$assign=getAssignName($this->fields["assign"],USER_TYPE);
 			$assign_group="";
 			if (isset($this->fields["assign_group"])){
@@ -907,43 +971,43 @@ class Job extends CommonDBTM{
 				if (!empty($assign_group)){
 					$assign=$assign_group;
 				} else {
-					$assign=$LANG["mailing"][105];
+					$assign=$LANG['mailing'][105];
 				}
 			} else {
 				if (!empty($assign_group)){
 					$assign.=" / ".$assign_group;
 				}
 			}
-			$message.= "<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG["mailing"][8].":</span> ".$assign."\n";
-			$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG["joblist"][2].":</span> ".getPriorityName($this->fields["priority"])."\n";
+			$message.= "<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG['mailing'][8].":</span> ".$assign."\n";
+			$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG['joblist'][2].":</span> ".getPriorityName($this->fields["priority"])."\n";
 			if ($this->fields["device_type"]!=SOFTWARE_TYPE&&!empty($contact))
-				$message.= "<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG["common"][18].":</span> ".$contact."\n";
+				$message.= "<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG['common'][18].":</span> ".$contact."\n";
 			if (isset($this->fields["emailupdates"]) && $this->fields["emailupdates"]){
-				$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG["mailing"][103].":</span> ".$LANG["choice"][1]."\n";
+				$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG['mailing'][103].":</span> ".$LANG['choice'][1]."\n";
 			} else {
-				$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG["mailing"][103].":</span> ".$LANG["choice"][0]."\n";
+				$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG['mailing'][103].":</span> ".$LANG['choice'][0]."\n";
 			}
 
-			$message.= "<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG["common"][36].":</span> ";
+			$message.= "<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>".$LANG['common'][36].":</span> ";
 			if (isset($this->fields["category"])&&$this->fields["category"]){
 				$message.= getDropdownName("glpi_dropdown_tracking_category",$this->fields["category"]);
-			} else $message.=$LANG["mailing"][100];
+			} else $message.=$LANG['mailing'][100];
 			$message.= "\n";
-			$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>". $LANG["mailing"][3].":</span><br>".ereg_replace("\n","<br>",$this->fields["contents"])."<br>\n";	
+			$message.="<span style='color:#8B8C8F; font-weight:bold;  text-decoration:underline; '>". $LANG['mailing'][3].":</span><br>".str_replace("\n","<br>",$this->fields["contents"])."<br>\n";	
 
 		}else{ //text format
-			$message = $LANG["mailing"][1]."\n*".$LANG["mailing"][5]."*\n".$LANG["mailing"][1]."\n";
+			$message = $LANG['mailing'][1]."\n*".$LANG['mailing'][5]."*\n".$LANG['mailing'][1]."\n";
 			
-			$message.=mailRow($LANG["common"][57],$this->fields["name"]);
+			$message.=mailRow($LANG['common'][57],$this->fields["name"]);
 			$author=$this->getAuthorName();
-			if (empty($author)) $author=$LANG["mailing"][108];
-			$message.=mailRow($LANG["job"][4],$author);
-			$message.=mailRow($LANG["search"][8],convDateTime($this->fields["date"]));
-			$message.=mailRow($LANG["job"][44],getRequestTypeName($this->fields["request_type"]));
-			$message.=mailRow($LANG["mailing"][7],$name);
+			if (empty($author)) $author=$LANG['mailing'][108];
+			$message.=mailRow($LANG['job'][4],$author);
+			$message.=mailRow($LANG['search'][8],convDateTime($this->fields["date"]));
+			$message.=mailRow($LANG['job'][44],getRequestTypeName($this->fields["request_type"]));
+			$message.=mailRow($LANG['mailing'][7],$name);
 			if (!empty($tech))
-				$message.= mailRow($LANG["common"][10],$tech);
-			$message.= mailRow($LANG["joblist"][0],getStatusName($this->fields["status"]));
+				$message.= mailRow($LANG['common'][10],$tech);
+			$message.= mailRow($LANG['joblist'][0],getStatusName($this->fields["status"]));
 			$assign=getAssignName($this->fields["assign"],USER_TYPE);
 			$assign_group="";
 			if (isset($this->fields["assign_group"])){
@@ -953,7 +1017,7 @@ class Job extends CommonDBTM{
                                 if (!empty($assign_group)){
                                         $assign=$assign_group;
                                 } else {
-                                        $assign=$LANG["mailing"][105];
+                                        $assign=$LANG['mailing'][105];
                                 }
                         } else {
 				if (!empty($assign_group)){
@@ -961,22 +1025,22 @@ class Job extends CommonDBTM{
 				}
                         }
 
-			$message.= mailRow($LANG["mailing"][8],$assign);
-			$message.= mailRow($LANG["joblist"][2],getPriorityName($this->fields["priority"]));
+			$message.= mailRow($LANG['mailing'][8],$assign);
+			$message.= mailRow($LANG['joblist'][2],getPriorityName($this->fields["priority"]));
 			if ($this->fields["device_type"]!=SOFTWARE_TYPE&&!empty($contact))
-				$message.= mailRow($LANG["common"][18],$contact);
+				$message.= mailRow($LANG['common'][18],$contact);
 			if (isset($this->fields["emailupdates"]) && $this->fields["emailupdates"]){
-				$message.=mailRow($LANG["mailing"][103],$LANG["choice"][1]);
+				$message.=mailRow($LANG['mailing'][103],$LANG['choice'][1]);
 			} else {
-				$message.=mailRow($LANG["mailing"][103],$LANG["choice"][0]);
+				$message.=mailRow($LANG['mailing'][103],$LANG['choice'][0]);
 			}
 
 			
 			if (isset($this->fields["category"])&&$this->fields["category"]){
-				$message.= mailRow($LANG["common"][36],getDropdownName("glpi_dropdown_tracking_category",$this->fields["category"]));
-			} else $message.=mailRow($LANG["common"][36],$LANG["mailing"][100]);
+				$message.= mailRow($LANG['common'][36],getDropdownName("glpi_dropdown_tracking_category",$this->fields["category"]));
+			} else $message.=mailRow($LANG['common'][36],$LANG['mailing'][100]);
 			$message.= "--\n";
-			$message.= $LANG["mailing"][3]." : \n".$this->fields["contents"]."\n";	
+			$message.= $LANG['mailing'][3]." : \n".$this->fields["contents"]."\n";	
 			$message.="\n\n";
 
 		}
@@ -1012,7 +1076,7 @@ class Job extends CommonDBTM{
 	 * 
 	 * @return boolean
 	 */
-	function canShowTicket(){
+	function canView(){
 		return (
 			haveRight("show_all_ticket","1")
 			|| (isset($_SESSION["glpiID"])&&$this->fields["author"]==$_SESSION["glpiID"])
@@ -1033,9 +1097,9 @@ class Followup  extends CommonDBTM {
 	/**
 	 * Constructor
 	**/
-	function Followup () {
+	function __construct () {
 		$this->table="glpi_followups";
-		$this->type=-1;
+		$this->type=FOLLOWUP_TYPE;
 	}
 
 	function cleanDBonPurge($ID) {
@@ -1070,6 +1134,7 @@ class Followup  extends CommonDBTM {
 
 		$job=new Job;
 		$mailsend=false;
+
 		if ($job->getFromDB($input["tracking"])){
 			$job->updateDateMod($input["tracking"]);
 			
@@ -1158,6 +1223,9 @@ class Followup  extends CommonDBTM {
 			if (isset($input["add_close"])) $input['_close']=1;
 			unset($input["add_close"]);
 
+			if (isset($input["add_reopen"])) $input['_reopen']=1;
+			unset($input["add_reopen"]);
+
 			if (!isset($input["hour"])){
 				$input["hour"]=0;
 			}
@@ -1179,13 +1247,10 @@ class Followup  extends CommonDBTM {
 	function post_addItem($newID,$input) {
 		global $CFG_GLPI;
 
-		$job=new Job();
-		$job->getFromDB($input["tracking"]);
-
-		$job->updateDateMod($input["tracking"]);
+		$input["_job"]->updateDateMod($input["tracking"]);
 
 		if (isset($input["realtime"])&&$input["realtime"]>0) {
-			$job->updateRealTime($input["tracking"]);
+			$input["_job"]->updateRealTime($input["tracking"]);
 		}
 
 
@@ -1210,13 +1275,25 @@ class Followup  extends CommonDBTM {
 				$input["_job"]->fields["closedate"] = $_SESSION["glpi_currenttime"];
 				$input["_job"]->updateInDB($updates);
 			}
-
 		}
 
+      // No check on admin because my be used by mailgate
+		if (isset($input["_reopen"]) && $input["_reopen"] && strstr($input["_job"]->fields["status"],"old_")){
+			$updates[]="status";
+			if ($input["_job"]->fields["assign"]>0 || $input["_job"]->fields["assign_group"]>0
+				|| $input["_job"]->fields["assign_ent"]>0){
+				$input["_job"]->fields["status"]="assign";
+			} else {
+				$input["_job"]->fields["status"]="new";
+			}
+			$input["_job"]->updateInDB($updates);
+		}
+
+
 		if ($CFG_GLPI["mailing"]){
 			if ($input["_close"]) $input["_type"]="finish";
 			$user=new User;
-			if (!isset($input['_auto_import'])&&isset($_SESSION["glpiID"])){
+			if (!isset($input['_auto_import'])&&isset($_SESSION["glpiID"])){ 
 				$user->getFromDB($_SESSION["glpiID"]);
 			}
 			$mail = new Mailing($input["_type"],$input["_job"],$user,
