@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: user.function.php 7876 2009-01-23 15:50:37Z moyo $
+ * @version $Id: user.function.php 8479 2009-07-23 08:42:40Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -51,17 +51,17 @@ function showAddExtAuthUserForm($target){
 	echo "<form method='get' action=\"$target\">\n";
 
 	echo "<table class='tab_cadre'>\n";
-	echo "<tr><th colspan='4'>".$LANG["setup"][126]."</th></tr>\n";
-	echo "<tr class='tab_bg_1'><td>".$LANG["login"][6]."</td>\n";
+	echo "<tr><th colspan='4'>".$LANG['setup'][126]."</th></tr>\n";
+	echo "<tr class='tab_bg_1'><td>".$LANG['login'][6]."</td>\n";
 	echo "<td>";
 	echo "<input type='text' name='login'>";
 	echo "</td>";
 	echo "<td align='center' class='tab_bg_2'>\n";
 	echo "<input type='hidden' name='ext_auth' value='1'>\n";
-	echo "<input type='submit' name='add_ext_auth_ldap' value=\"".$LANG["buttons"][8]." ".$LANG["login"][2]."\" class='submit'>\n";
+	echo "<input type='submit' name='add_ext_auth_ldap' value=\"".$LANG['buttons'][8]." ".$LANG['login'][2]."\" class='submit'>\n";
 	echo "</td>";
 	echo "<td align='center' class='tab_bg_2'>\n";
-	echo "<input type='submit' name='add_ext_auth_simple' value=\"".$LANG["buttons"][8]." ".$LANG["common"][62]."\" class='submit'>\n";
+	echo "<input type='submit' name='add_ext_auth_simple' value=\"".$LANG['buttons'][8]." ".$LANG['common'][62]."\" class='submit'>\n";
 	echo "</td>";
 
 	echo "</tr>\n";
@@ -80,7 +80,10 @@ function showDeviceUser($ID){
 
 	$group_where="";
 	$groups=array();
-	$query="SELECT glpi_users_groups.FK_groups, glpi_groups.name FROM glpi_users_groups LEFT JOIN glpi_groups ON (glpi_groups.ID = glpi_users_groups.FK_groups) WHERE glpi_users_groups.FK_users='$ID';";
+	$query="SELECT glpi_users_groups.FK_groups, glpi_groups.name 
+		FROM glpi_users_groups 
+		LEFT JOIN glpi_groups ON (glpi_groups.ID = glpi_users_groups.FK_groups) 
+		WHERE glpi_users_groups.FK_users='$ID';";
 	$result=$DB->query($query);
 	if ($DB->numrows($result)>0){
 		$first=true;
@@ -97,7 +100,12 @@ function showDeviceUser($ID){
 
 
 	$ci=new CommonItem();
-	echo "<div class='center'><table class='tab_cadre_fixe'><tr><th>".$LANG["common"][17]."</th><th>".$LANG["common"][16]."</th><th>".$LANG["common"][19]."</th><th>".$LANG["common"][20]."</th><th>&nbsp;</th></tr>";
+	echo "<div class='center'><table class='tab_cadre_fixe'><tr><th>".$LANG['common'][17]
+		."</th><th>".$LANG['entity'][0]
+		."</th><th>".$LANG['common'][16]
+		."</th><th>".$LANG['common'][19]
+		."</th><th>".$LANG['common'][20]
+		."</th><th>&nbsp;</th></tr>";
 
 	foreach ($CFG_GLPI["linkuser_types"] as $type){
 		if (haveTypeRight($type,'r')){
@@ -112,17 +120,22 @@ function showDeviceUser($ID){
 
 			$result=$DB->query($query);
 			if ($DB->numrows($result)>0){
-				$ci->setType($type);
+				$ci->setType($type,true);
 				$type_name=$ci->getType();
-				$cansee=haveTypeRight($type,"r");
 				while ($data=$DB->fetch_array($result)){
+					$cansee=$ci->obj->can($data["ID"],"r");
 					$link=$data["name"];
-					if ($cansee) $link="<a href='".$CFG_GLPI["root_doc"]."/".$INFOFORM_PAGES[$type]."?ID=".$data["ID"]."'>".$link.(($CFG_GLPI["view_ID"]||empty($link))?" (".$data["ID"].")":"")."</a>";
+					if ($cansee) {
+						$link="<a href='".$CFG_GLPI["root_doc"]."/".$INFOFORM_PAGES[$type]."?ID=".$data["ID"]."'>".
+							$link.(($_SESSION["glpiview_ID"]||empty($link))?" (".$data["ID"].")":"")."</a>";	
+					}
 					$linktype="";
 					if ($data["FK_users"]==$ID){
-						$linktype=$LANG["common"][34];
+						$linktype=$LANG['common'][34];
 					}
-					echo "<tr class='tab_bg_1'><td class='center'>$type_name</td><td class='center'>$link</td>";
+					echo "<tr class='tab_bg_1'><td class='center'>$type_name</td>" 
+						."<td class='center'>".getDropdownName("glpi_entities",$data["FK_entities"])."</td>"
+						."<td class='center'>$link</td>";
 					echo "<td class='center'>";
 					if (isset($data["serial"])&&!empty($data["serial"])){
 						echo $data["serial"];
@@ -140,9 +153,14 @@ function showDeviceUser($ID){
 	echo "</table></div><br>";
 
 	if (!empty($group_where)){
-		echo "<div class='center'><table class='tab_cadre_fixe'><tr><th>".$LANG["common"][17]."</th><th>".$LANG["common"][16]."</th><th>".$LANG["common"][19]."</th><th>".$LANG["common"][20]."</th><th>&nbsp;</th></tr>";
-
-		foreach ($CFG_GLPI["linkuser_types"] as $type){
+		echo "<div class='center'><table class='tab_cadre_fixe'><tr><th>"
+			.$LANG['common'][17]."</th><th>"
+			.$LANG['entity'][0]."</th><th>"
+			.$LANG['common'][16]."</th><th>"
+			.$LANG['common'][19]."</th><th>"
+			.$LANG['common'][20]."</th><th>&nbsp;</th></tr>";
+	
+		foreach ($CFG_GLPI["linkgroup_types"] as $type){
 			$query="SELECT * FROM ".$LINK_ID_TABLE[$type]." WHERE $group_where";
 
 			if (in_array($LINK_ID_TABLE[$type],$CFG_GLPI["template_tables"])){
@@ -154,17 +172,20 @@ function showDeviceUser($ID){
 
 			$result=$DB->query($query);
 			if ($DB->numrows($result)>0){
-				$ci->setType($type);
+				$ci->setType($type,true);
 				$type_name=$ci->getType();
-				$cansee=haveTypeRight($type,"r");
 				while ($data=$DB->fetch_array($result)){
+					$cansee=$ci->obj->can($data["ID"],"r");
 					$link=$data["name"];
-					if ($cansee) $link="<a href='".$CFG_GLPI["root_doc"]."/".$INFOFORM_PAGES[$type]."?ID=".$data["ID"]."'>".$link.(($CFG_GLPI["view_ID"]||empty($link))?" (".$data["ID"].")":"")."</a>";
+					if ($cansee) $link="<a href='".$CFG_GLPI["root_doc"]."/".$INFOFORM_PAGES[$type]."?ID=".$data["ID"]."'>".$link.(($_SESSION["glpiview_ID"]||empty($link))?" (".$data["ID"].")":"")."</a>";
 					$linktype="";
 					if (isset($groups[$data["FK_groups"]])){
-						$linktype=$LANG["common"][35]." ".$groups[$data["FK_groups"]];
+						$linktype=$LANG['common'][35]." ".$groups[$data["FK_groups"]];
 					}
-					echo "<tr class='tab_bg_1'><td class='center'>$type_name</td><td class='center'>$link</td>";
+					echo "<tr class='tab_bg_1'><td class='center'>$type_name</td>"
+						."<td class='center'>".getDropdownName("glpi_entities",$data["FK_entities"])."</td>"
+						."<td class='center'>$link</td>";
+						
 					echo "<td class='center'>";
 					if (isset($data["serial"])&&!empty($data["serial"])){
 						echo $data["serial"];
@@ -192,51 +213,34 @@ function showGroupAssociated($target,$ID){
 	if (!haveRight("user","r")||!haveRight("group","r"))	return false;
 
 	$canedit=haveRight("user","w");
-	$strict_entities=getUserEntities($ID,false);
+	$strict_entities=getUserEntities($ID,true);
 	if (!haveAccessToOneOfEntities($strict_entities)&&!isViewAllEntities()){
 		$canedit=false;
 	}
 
+	$rand=mt_rand();
 	$nb_per_line=3;
-	if ($canedit) $headerspan=$nb_per_line*2;
-	else $headerspan=$nb_per_line;
-
-	echo "<form name='groupuser_form' id='groupuser_form' method='post' action=\"$target\">";
-
-	if ($canedit){
-		echo "<div class='center'>";
-		echo "<table  class='tab_cadre_fixe'>";
-
-		echo "<tr class='tab_bg_1'><th colspan='2'>".$LANG["setup"][604]."</tr><tr><td class='tab_bg_2' align='center'>";
-		echo "<input type='hidden' name='FK_users' value='$ID'>";
-		$query="SELECT glpi_groups.ID, glpi_groups.name, glpi_entities.completename FROM glpi_groups LEFT JOIN glpi_entities ON (glpi_groups.FK_entities=glpi_entities.ID) WHERE glpi_groups.FK_entities IN (SELECT FK_entities FROM glpi_users_profiles WHERE FK_users = '$ID')";
-		$result=$DB->query($query);
-		if ($DB->numrows($result)>0){
-			$groups=array();
-			while ($data=$DB->fetch_array($result)){
-				$groups[$data['ID']]=$data['name'];
-				if (!empty($data['completename'])){
-					$groups[$data['ID']].= ' - '.$data['completename'];
-				}
-			}
-			dropdownArrayValues("FK_groups",$groups);
-
-		}
-		echo "</td><td align='center' class='tab_bg_2'>";
-		echo "<input type='submit' name='addgroup' value=\"".$LANG["buttons"][8]."\" class='submit'>";
-		echo "</td></tr>";
-
-		echo "</table></div><br>";
+	if ($canedit) {
+		$headerspan=$nb_per_line*2;	
+		echo "<form name='groupuser_form$rand' id='groupuser_form$rand' method='post' action=\"$target\">";
+	} else {
+		$headerspan=$nb_per_line;
 	}
 
-	echo "<div class='center'><table class='tab_cadrehov'><tr><th colspan='$headerspan'>".$LANG["Menu"][36]."</th></tr>";
-	$query="SELECT glpi_groups.*, glpi_users_groups.ID AS IDD,glpi_users_groups.ID as linkID from glpi_users_groups LEFT JOIN glpi_groups ON (glpi_groups.ID = glpi_users_groups.FK_groups) WHERE glpi_users_groups.FK_users='$ID' ORDER BY glpi_groups.name";
+	echo "<div class='center'><table class='tab_cadrehov'><tr><th colspan='$headerspan'>".$LANG['Menu'][36]."</th></tr>";
+	$query="SELECT glpi_groups.*, glpi_users_groups.ID AS IDD, glpi_users_groups.ID as linkID 
+		FROM glpi_users_groups 
+		LEFT JOIN glpi_groups ON (glpi_groups.ID = glpi_users_groups.FK_groups) 
+		WHERE glpi_users_groups.FK_users='$ID' 
+		ORDER BY glpi_groups.name";
 
 	$result=$DB->query($query);
+	$used=array();
 	if ($DB->numrows($result)>0){
 		$i=0;
 
 		while ($data=$DB->fetch_array($result)){
+			$used[]=$data["ID"];
 			if ($i%$nb_per_line==0) {
 				if ($i!=0) echo "</tr>";
 				echo "<tr class='tab_bg_1'>";
@@ -250,38 +254,58 @@ function showGroupAssociated($target,$ID){
 				echo "</td>";
 			}
 
-			echo "<td><a href='".$CFG_GLPI["root_doc"]."/front/group.form.php?ID=".$data["ID"]."'>".$data["name"].($CFG_GLPI["view_ID"]?" (".$data["ID"].")":"")."</a>";
+			echo "<td><a href='".$CFG_GLPI["root_doc"]."/front/group.form.php?ID=".$data["ID"]."'>".$data["name"].($_SESSION["glpiview_ID"]?" (".$data["ID"].")":"")."</a>";
 			echo "&nbsp;";
 
 			echo "</td>";
 			$i++;
 		}
 		while ($i%$nb_per_line!=0){
+			if ($canedit){
+				echo "<td>&nbsp;</td>";
+			}
 			echo "<td>&nbsp;</td>";
 			$i++;
 		}
 		echo "</tr>";
+	} else {
+		echo "<tr class='tab_bg_1'><td colspan='$headerspan' class='center'>".$LANG['common'][49]."</td></tr>";
 	}
 
 	echo "</table></div>";
 
 	if ($canedit){
 		echo "<div class='center'>";
-		echo "<table width='80%'>";
-		echo "<tr><td><img src=\"".$CFG_GLPI["root_doc"]."/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markAllRows('groupuser_form') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=all'>".$LANG["buttons"][18]."</a></td>";
+		
+		if (count($used)) {	
+			echo "<table width='80%' class='tab_glpi'>";
+			echo "<tr><td><img src=\"".$CFG_GLPI["root_doc"]."/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markCheckboxes('groupuser_form$rand') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=all'>".$LANG['buttons'][18]."</a></td>";
+	
+			echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkCheckboxes('groupuser_form$rand') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=none'>".$LANG['buttons'][19]."</a>";
+			echo "</td><td align='left' width='80%'>";
+			echo "<input type='submit' name='deletegroup' value=\"".$LANG['buttons'][6]."\" class='submit'>";
+			echo "</td></tr>";
+			echo "</table>";
+		} else {
+			echo "<br>";
+		}
 
-		echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkAllRows('groupuser_form') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=none'>".$LANG["buttons"][19]."</a>";
-		echo "</td><td align='left' width='80%'>";
-		echo "<input type='submit' name='deletegroup' value=\"".$LANG["buttons"][6]."\" class='submit'>";
+		echo "<table  class='tab_cadre_fixe'>";
+		echo "<tr class='tab_bg_1'><th colspan='2'>".$LANG['setup'][604]."</tr><tr><td class='tab_bg_2' align='center'>";
+		echo "<input type='hidden' name='FK_users' value='$ID'>";
+		if (countElementsInTableForEntity("glpi_groups",$strict_entities) > count($used)) {
+			
+			dropdownValue("glpi_groups", "FK_groups", "", 1, $strict_entities, "", $used);	
+			echo "</td><td align='center' class='tab_bg_2'>";
+			echo "<input type='submit' name='addgroup' value=\"".$LANG['buttons'][8]."\" class='submit'>";
+	
+		} else {
+			echo $LANG['common'][49];
+		}
 		echo "</td></tr>";
-		echo "</table>";
-
-		echo "</div>";
-
+		echo "</table></div></form>";
 	}
 
-	echo "</form>";
-
 }
 
 /**  Show rights of a user
@@ -302,31 +326,32 @@ function showUserRights($target,$ID){
 
 	$canshowentity=haveRight("entity","r");
 
-	echo "<form name='entityuser_form' id='entityuser_form' method='post' action=\"$target\">";
+	$rand=mt_rand();
+	echo "<form name='entityuser_form$rand' id='entityuser_form$rand' method='post' action=\"$target\">";
 
 	if ($canedit){
 		echo "<div class='center'>";
 		echo "<table  class='tab_cadre_fixe'>";
 
-		echo "<tr class='tab_bg_1'><th colspan='4'>".$LANG["entity"][3]."</tr><tr class='tab_bg_2'><td class='center'>";
+		echo "<tr class='tab_bg_1'><th colspan='4'>".$LANG['entity'][3]."</tr><tr class='tab_bg_2'><td class='center'>";
 		echo "<input type='hidden' name='FK_users' value='$ID'>";
 
 		dropdownValue("glpi_entities","FK_entities",0,1,$_SESSION['glpiactiveentities']);
 		echo "</td><td class='center'>";
 
-		echo $LANG["profiles"][22].":";
+		echo $LANG['profiles'][22].":";
 		dropdownUnderProfiles("FK_profiles");
 		echo "</td><td class='center'>";
-		echo $LANG["profiles"][28].":";
+		echo $LANG['profiles'][28].":";
 		dropdownYesNo("recursive",0);
 		echo "</td><td class='center'>";
-		echo "<input type='submit' name='addright' value=\"".$LANG["buttons"][8]."\" class='submit'>";
+		echo "<input type='submit' name='addright' value=\"".$LANG['buttons'][8]."\" class='submit'>";
 		echo "</td></tr>";
 
 		echo "</table></div><br>";
 	}
 
-	echo "<div class='center'><table class='tab_cadrehov'><tr><th colspan='2'>".$LANG["Menu"][37]."</th><th>".$LANG["profiles"][22]." (D=".$LANG["profiles"][29].", R=".$LANG["profiles"][28].")</th></tr>";
+	echo "<div class='center'><table class='tab_cadrehov'><tr><th colspan='2'>".$LANG['Menu'][37]."</th><th>".$LANG['profiles'][22]." (D=".$LANG['profiles'][29].", R=".$LANG['profiles'][28].")</th></tr>";
 
 	$query="SELECT DISTINCT glpi_users_profiles.ID as linkID, glpi_profiles.ID, glpi_profiles.name, glpi_users_profiles.recursive,
 			glpi_users_profiles.dynamic, glpi_entities.completename, glpi_users_profiles.FK_entities
@@ -354,13 +379,13 @@ function showUserRights($target,$ID){
 			echo "</td>";
 
 			if ($data["FK_entities"]==0) {
-				$data["completename"]=$LANG["entity"][2];
+				$data["completename"]=$LANG['entity'][2];
 			}
 			echo "<td>";
 			if ($canshowentity){
 				echo "<a href='".$CFG_GLPI["root_doc"]."/front/entity.form.php?ID=".$data["FK_entities"]."'>";
 			}
-			echo $data["completename"].($CFG_GLPI["view_ID"]?" (".$data["FK_entities"].")":"");
+			echo $data["completename"].($_SESSION["glpiview_ID"]?" (".$data["FK_entities"].")":"");
 			if ($canshowentity){
 				echo "</a>";
 			}
@@ -384,12 +409,12 @@ function showUserRights($target,$ID){
 
 	if ($canedit){
 		echo "<div class='center'>";
-		echo "<table width='80%'>";
-		echo "<tr><td><img src=\"".$CFG_GLPI["root_doc"]."/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markAllRows('entityuser_form') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=all'>".$LANG["buttons"][18]."</a></td>";
+		echo "<table width='80%' class='tab_glpi'>";
+		echo "<tr><td><img src=\"".$CFG_GLPI["root_doc"]."/pics/arrow-left.png\" alt=''></td><td class='center'><a onclick= \"if ( markCheckboxes('entityuser_form$rand') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=all'>".$LANG['buttons'][18]."</a></td>";
 
-		echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkAllRows('entityuser_form') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=none'>".$LANG["buttons"][19]."</a>";
+		echo "<td>/</td><td class='center'><a onclick= \"if ( unMarkCheckboxes('entityuser_form$rand') ) return false;\" href='".$_SERVER['PHP_SELF']."?ID=$ID&amp;select=none'>".$LANG['buttons'][19]."</a>";
 		echo "</td><td align='left' width='80%'>";
-		echo "<input type='submit' name='deleteright' value=\"".$LANG["buttons"][6]."\" class='submit'>";
+		echo "<input type='submit' name='deleteright' value=\"".$LANG['buttons'][6]."\" class='submit'>";
 		echo "</td></tr>";
 		echo "</table>";
 
@@ -465,13 +490,13 @@ function getUserEntities($ID,$recursive=true){
 				$entities[]=$data['FK_entities'];
 			}
 		}
-		return $entities;
+		return array_unique($entities);
 	} 
 
 	return array();
 }
 
-/** Get all the authentication methods parameters for a specific auth_method and id_auth and return it as an array
+/** Get all the authentication methods parameters for a specific auth_method and id_auth and return it as an array 
 * @param $auth_method Authentication method
 * @param $id_auth Authentication method ID
 */
@@ -487,16 +512,16 @@ function getAuthMethodsByID($auth_method, $id_auth) {
 		case AUTH_CAS :
 			if ($id_auth>0){
 				//Get all the ldap directories
-				$sql = "SELECT * FROM glpi_auth_ldap WHERE ID='" . $id_auth."'";
+				$sql = "SELECT * FROM glpi_auth_ldap WHERE ID='".$id_auth."'";
 			}
 			break;
 		case AUTH_LDAP :
 			//Get all the ldap directories
-			$sql = "SELECT * FROM glpi_auth_ldap WHERE ID='" . $id_auth."'";
+			$sql = "SELECT * FROM glpi_auth_ldap WHERE ID='".$id_auth."'";
 			break;
 		case AUTH_MAIL :
 			//Get all the pop/imap servers
-			$sql = "SELECT * FROM glpi_auth_mail WHERE ID='" . $id_auth."'";
+			$sql = "SELECT * FROM glpi_auth_mail WHERE ID='".$id_auth."'";
 			break;
 	}
 
@@ -522,41 +547,52 @@ function getAuthMethodName($auth_method, $id_auth, $link=0,$name=''){
 		case AUTH_LDAP :
 			if (empty($name)){
 				$method = getAuthMethodsByID($auth_method,$id_auth);
-				$name=$method["name"];
+				if (isset($method["name"])){
+					$name=$method["name"];
+				} else {
+					$name="???";
+					$link=false;
+				}
 			}
-			$out= $LANG["login"][2];
+			$out= $LANG['login'][2];
 			if ($link && haveRight("config", "w")){
-				return  $out."&nbsp " . $LANG["common"][52] . " <a href=\"" . $CFG_GLPI["root_doc"] . "/front/setup.auth.php?next=extauth_ldap&amp;ID=" . $id_auth . "\">" . $name . "</a>";
+				return  $out."&nbsp " . $LANG['common'][52] . " <a href=\"" . $CFG_GLPI["root_doc"] . "/front/auth.ldap.php?next=extauth_ldap&amp;ID=" . $id_auth . "\">" . $name . "</a>";
 			} else {
-				return  $out."&nbsp " . $LANG["common"][52] . " " . $name;
+				return  $out."&nbsp " . $LANG['common'][52] . " " . $name;
 			}
 		break;
 		case AUTH_MAIL :
 			if (empty($name)){
 				$method = getAuthMethodsByID($auth_method,$id_auth);
-				$name=$method["name"];
+
+				if (isset($method["name"])){
+					$name=$method["name"];
+				} else {
+					$name="???";
+					$link=false;
+				}
 			}
-			$out= $LANG["login"][3];
+			$out= $LANG['login'][3];
 			if ($link && haveRight("config", "w")){
-				return  $out. "&nbsp " . $LANG["common"][52] . " <a href=\"" . $CFG_GLPI["root_doc"] . "/front/setup.auth.php?next=extauth_mail&amp;ID=" . $id_auth . "\">" . $name . "</a>";
+				return  $out. "&nbsp " . $LANG['common'][52] . " <a href=\"" . $CFG_GLPI["root_doc"] . "/front/auth.imap.php?next=extauth_mail&amp;ID=" . $id_auth . "\">" . $name . "</a>";
 			} else {
-				return  $out. "&nbsp " . $LANG["common"][52] . " " . $name;
+				return  $out. "&nbsp " . $LANG['common'][52] . " " . $name;
 			}
 		break;
 		case AUTH_CAS :
-			return  $LANG["login"][4];
+			return  $LANG['login'][4];
 			break;
 		case AUTH_X509 :
-			return  $LANG["setup"][190];
+			return  $LANG['setup'][190];
 			break;
 		case AUTH_EXTERNAL :
-			return  $LANG["common"][62];
+			return  $LANG['common'][62];
 			break;
 		case AUTH_DB_GLPI :
-			return $LANG["login"][18];
+			return $LANG['login'][18];
 		break;
 		case NOT_YET_AUTHENTIFIED :
-			return $LANG["login"][9];
+			return $LANG['login'][9];
 			break;
 	}
 }
@@ -576,6 +612,9 @@ function getLDAPSyncFields($auth_method_array){
  			'ldap_field_phone2'=>'phone2', 
  			'ldap_field_mobile'=>'mobile', 
  			'ldap_field_comments'=>'comments', 
+ 			'ldap_field_title'=>'title',
+ 			'ldap_field_type'=>'type',
+ 			'ldap_field_language'=>'language'		
  		); 
  	foreach ($fields as $key => $val){ 
  		if (isset($auth_method_array[$key])){ 
@@ -585,20 +624,30 @@ function getLDAPSyncFields($auth_method_array){
  	return $ret; 
 } 
 
-/** Show onglets for user preferences
-* @param $target where to go on action
-* @param $actif active onglet
-*/
-function showUserPreferencesOnglets($target,$actif) {
-	global $LANG,$PLUGIN_HOOKS;
-	if (isset($PLUGIN_HOOKS['user_preferences'])&&count($PLUGIN_HOOKS['user_preferences'])){
-		echo "<div id='barre_onglets'><ul id='onglet'>";
-		echo "<li ".($actif=="my"?"class='actif'":"")."><a href='$target?onglet=my'>".$LANG["title"][26]."</a></li>";
-		echo "<li ".($actif=="plugins"?"class='actif'":"")."><a href='$target?onglet=plugins'>".$LANG["common"][29]."</a></li>";
-//		echo "<li class='invisible'>&nbsp;</li>";
-//		echo "<li ".($actif=="all"?"class='actif'":"")."><a href='$target?onglet=all'>".$LANG["common"][66]."</a></li>";
+/**
+ * Get language in GLPI associated with the value coming from LDAP
+ * Value can be, for example : English, en_EN or en
+ * @param value : the value coming from LDAP
+ * @return the locale's php page in GLPI or '' is no language associated with the value
+ */
+function getUserLanguage($lang)
+{
+	global $CFG_GLPI;
+	foreach ($CFG_GLPI["languages"] as $ID => $language)
+		if ($lang==$ID || $lang == $language[0] || $lang == $language[2] || $lang == $language[3])
+			return $ID;
 
-		echo "</ul></div>";
+	return ""; 
+}
+
+function changeUserAuthMethod($IDs=array(),$auth_method=1,$server=-1)
+{
+	global $DB;
+	if (!empty($IDs) && in_array($auth_method,array(AUTH_DB_GLPI,AUTH_LDAP,AUTH_MAIL,AUTH_EXTERNAL)))
+	{
+		$where = implode(',',$IDs);
+		$query="UPDATE glpi_users SET auth_method=".$auth_method.", id_auth=".$server." WHERE ID IN (".$where.")";
+		$DB->query($query);
 	}
 }
 ?>
