@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: index.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: index.php 8235 2009-04-24 16:00:10Z jmd $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -33,8 +33,7 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-// Test si config_db n'existe pas on lance l'installation
-
+// If config_db doesn't exist ->  start installation
 define('GLPI_ROOT', '.');
 
 include (GLPI_ROOT . "/config/based_config.php");
@@ -62,7 +61,7 @@ else
 
 	echo "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">";
 	echo "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"fr\" lang=\"fr\">";
-	echo "<head><title>GLPI Login</title>\n";
+	echo "<head><title>GLPI - ".$LANG['login'][10]."</title>\n";
 	echo "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8 \" />\n";
 	echo "<meta http-equiv=\"Content-Script-Type\" content=\"text/javascript\" />\n";
 	echo '<link rel="shortcut icon" type="images/x-icon" href="'.$CFG_GLPI["root_doc"].'/pics/favicon.ico" />';
@@ -77,23 +76,14 @@ else
 
 	echo "</head>";
 
-	// Body with configured stuff
 	echo "<body>";
-	// contenu
-
 	echo "<div id='contenulogin'>";
-	
 	echo "<div id='logo-login'>";
-
 	echo nl2br(unclean_cross_side_scripting_deep($CFG_GLPI['text_login']));
-
-	
 	echo "</div>";
 
 	echo "<div id='boxlogin'>";
-
 	echo "<form action='login.php' method='post'>";
-
 	// Other CAS 
 	if (isset($_GET["noAUTO"])) {
 		echo "<input type='hidden' name='noAUTO' value='1' />";
@@ -104,82 +94,54 @@ else
 		manageRedirect($_GET["redirect"]);
 		echo '<input type="hidden" name="redirect" value="'.$_GET['redirect'].'">';
 	}
-
 	echo "<fieldset>";
-	echo '<legend>'.$LANG["login"][10].'</legend>';
-
-
-	echo '<div class="row"><span class="label"><label>'.$LANG["login"][6].' :  </label></span><span class="formw"> <input type="text" name="login_name" id="login_name" size="15" /></span></div>';
-
-
-	echo '<div class="row"><span class="label"><label>'.$LANG["login"][7].' : </label></span><span class="formw"><input type="password" name="login_password" id="login_password" size="15" /> </span></div>';
-
-
-
+	echo '<legend>'.$LANG['login'][10].'</legend>';
+	echo '<div class="row"><span class="label"><label>'.$LANG['login'][6].' :  </label></span><span class="formw"> <input type="text" name="login_name" id="login_name" size="15" /></span></div>';
 
+	echo '<div class="row"><span class="label"><label>'.$LANG['login'][7].' : </label></span><span class="formw"><input type="password" name="login_password" id="login_password" size="15" /> </span></div>';
 
 	echo "</fieldset>";
-	echo '<p ><span> <input type="submit" name="submit" value="'.$LANG["buttons"][2].'" class="submit" /></span></p>';
+	echo '<p ><span> <input type="submit" name="submit" value="'.$LANG['buttons'][2].'" class="submit" /></span></p>';
 	echo "</form>";
 
 	echo "<script type='text/javascript' >\n";
 	echo "document.getElementById('login_name').focus();";
 	echo "</script>";
 
-
-	echo "</div>";  // fin box login
+	echo "</div>";  // end login box
 
 
 
 	echo "<div class='error'>";
 	echo "<noscript><p>";
-	echo $LANG["login"][26];
+	echo $LANG['login'][26];
 	echo "</p></noscript>";
 	if (isset($_GET['error'])){
 		switch ($_GET['error']){
 			case 1 : // cookie error
-				echo $LANG["login"][27];
+				echo $LANG['login'][27];
 				break;
 			case 2 : // GLPI_SESSION_DIR not writable
-				echo $LANG["install"][50].": ".GLPI_SESSION_DIR;
+				echo $LANG['install'][50].": ".GLPI_SESSION_DIR;
 				break;
 		}
 	}
 	echo "</div>";
 
 
-	// Affichage autorisee FAQ
+	// Display FAQ is enable
 	if ($CFG_GLPI["public_faq"]){
-		echo '<div id="box-faq"><a href="front/helpdesk.faq.php">[ '.$LANG["knowbase"][24].' ]</a></div>';
+		echo '<div id="box-faq"><a href="front/helpdesk.faq.php">[ '.$LANG['knowbase'][24].' ]</a></div>';
 	}
 	
+	echo "</div>"; // end contenu login
 
-	echo "</div>"; // fin contenu login
-
-	if ($CFG_GLPI["debug"]==DEMO_MODE){
-		echo "<div align='center'";
-
-		$query="SELECT count(*) 
-			FROM `glpi_event_log` 
-			WHERE message LIKE '%logged in%'";
-
-		$query2="SELECT date 
-			FROM `glpi_event_log` 
-			ORDER BY date ASC 
-			LIMIT 1";
-
-		$DB=new DB;
-		$result=$DB->query($query);
-		$result2=$DB->query($query2);
-		$nb_login=$DB->result($result,0,0);
-		$date=$DB->result($result2,0,0);
-
-		echo '<b>'.$nb_login.'</b> logins since '.$date ;
-
+	if (GLPI_DEMO_MODE){
+		echo "<div class='center'>";
+		getCountLogin();
 		echo "</div>";
 	}
 
-
 	echo "<div id='footer-login'>";
 	echo "<a href=\"http://glpi-project.org/\" title=\"Powered By Indepnet\"  >";
 	echo 'GLPI version '.(isset($CFG_GLPI["version"])?$CFG_GLPI["version"]:"").' Copyright (C) 2003-'.date("Y").' INDEPNET Development Team.';
@@ -187,15 +149,14 @@ else
 	echo "</div>";
 
 }
-// Appel de cron
-if ($CFG_GLPI["debug"]!=DEMO_MODE){
-	callCron();
+// call cron
+if (! GLPI_DEMO_MODE){
+	callCronForce();
 }
 
-
 echo "</body></html>";
 
-// End
+
 
 
 ?>
