@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: update_to_031.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: update_to_031.php 8025 2009-02-28 16:30:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -39,11 +39,11 @@ function updateDbTo031(){
 
 	//amSize ramSize
 	$query = "Alter table users drop can_assign_job";
-	$DB->query($query) or die($LANG["update"][90].$DB->error());
+	$DB->query($query) or die($LANG['update'][90].$DB->error());
 	$query = "Alter table users add can_assign_job enum('yes','no') NOT NULL default 'no'";
-	$DB->query($query) or die($LANG["update"][90].$DB->error());
+	$DB->query($query) or die($LANG['update'][90].$DB->error());
 	$query = "Update users set can_assign_job = 'yes' where type = 'admin'";
-	$DB->query($query) or die($LANG["update"][90].$DB->error());
+	$DB->query($query) or die($LANG['update'][90].$DB->error());
 
 	echo "<p class='center'>Version 0.2 & < </p>";
 
@@ -52,7 +52,7 @@ function updateDbTo031(){
 
 	if(!FieldExists("printers", "ramSize")) {
 		$query = "alter table printers add ramSize varchar(6) NOT NULL default ''";
-		$DB->query($query) or die($LANG["update"][90].$DB->error());
+		$DB->query($query) or die($LANG['update'][90].$DB->error());
 	}
 
 	echo "<p class='center'>Version 0.21  </p>";
@@ -61,25 +61,25 @@ function updateDbTo031(){
 	//Ajout de NOT NULL et des valeurs par defaut.
 
 	$query = "ALTER TABLE computers MODIFY achat_date date NOT NULL default '0000-00-00'";
-	$DB->query($query) or die($LANG["update"][90].$DB->error());
+	$DB->query($query) or die($LANG['update'][90].$DB->error());
 	$query = "ALTER TABLE computers MODIFY date_fin_garantie date NOT NULL default '0000-00-00'";
 
 
 	$query = "ALTER TABLE monitors MODIFY achat_date date NOT NULL default '0000-00-00'";
-	$DB->query($query) or die($LANG["update"][90].$DB->error());
+	$DB->query($query) or die($LANG['update'][90].$DB->error());
 	$query = "ALTER TABLE monitors MODIFY date_fin_garantie date NOT NULL default '0000-00-00'";
 
 	$query = "ALTER TABLE networking MODIFY achat_date date NOT NULL default '0000-00-00'";
-	$DB->query($query) or die($LANG["update"][90].$DB->error());
+	$DB->query($query) or die($LANG['update'][90].$DB->error());
 	$query = "ALTER TABLE networking MODIFY date_fin_garantie date NOT NULL default '0000-00-00'";
 
 
 	$query = "ALTER TABLE printers MODIFY achat_date date NOT NULL default '0000-00-00'";
-	$DB->query($query) or die($LANG["update"][90].$DB->error());
+	$DB->query($query) or die($LANG['update'][90].$DB->error());
 	$query = "ALTER TABLE printers MODIFY date_fin_garantie date NOT NULL default '0000-00-00'";
 
 	$query = "ALTER TABLE templates MODIFY achat_date date NOT NULL default '0000-00-00'";
-	$DB->query($query) or die($LANG["update"][90].$DB->error());
+	$DB->query($query) or die($LANG['update'][90].$DB->error());
 	$query = "ALTER TABLE templates MODIFY date_fin_garantie date NOT NULL default '0000-00-00'";
 
 	echo "<p class='center'>Version 0.3  </p>";
