@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: login.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: login.php 9110 2009-10-13 19:06:50Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -34,7 +34,6 @@
 // Original Author of file:
 // Purpose of file:
 // ----------------------------------------------------------------------
-
 define('GLPI_ROOT', '.');
 $NEEDED_ITEMS = array (
 	"user",
@@ -54,6 +53,7 @@ if (!isset($_SESSION["glpitest"])||$_SESSION["glpitest"]!='testcookie'){
 	} else {
 		glpi_header($CFG_GLPI['root_doc'] . "/index.php?error=1");
 	}
+	
 }
 
 $_POST = array_map('stripslashes', $_POST);
@@ -77,6 +77,9 @@ if (!isset ($_POST["noAUTO"]) && $auth_method=checkAlternateAuthSystems()) {
 
 	if ($identificat->getAlternateAuthSystemsUserLogin($auth_method)&&!empty($identificat->user->fields['name'])){
 		$user=$identificat->user->fields['name'];
+      // Used for log when login process failed
+      $_POST['login_name']=$user;
+
 		$identificat->auth_succeded = true;
 		$identificat->extauth = 1;
 		$identificat->user_present = $identificat->user->getFromDBbyName(addslashes($user));
@@ -101,7 +104,7 @@ if (!isset ($_POST["noAUTO"]) && $auth_method=checkAlternateAuthSystems()) {
 		$identificat->user->fields['name']=$user;
 		$identificat->user->fields["last_login"] = $_SESSION["glpi_currenttime"];
 	} else {
-		$identificat->addToError($LANG["login"][8]);
+		$identificat->addToError($LANG['login'][8]);
 	}
 }
 
@@ -112,7 +115,7 @@ if (!isset ($_POST["noAUTO"]) && $auth_method=checkAlternateAuthSystems()) {
 	// If not already auth
 	if (!$identificat->auth_succeded){ 
 		if (empty ($_POST['login_name']) || empty ($_POST['login_password'])) {
-			$identificat->addToError($LANG["login"][8]);
+			$identificat->addToError($LANG['login'][8]);
 		} else {
 	
 			// exists=0 -> no exist
@@ -195,7 +198,7 @@ if (!isset ($_POST["noAUTO"]) && $auth_method=checkAlternateAuthSystems()) {
 			unset ($identificat->user->fields);
 			$identificat->user->add($input);
 		} else	if (!$identificat->user_present) { // Auto add not enable so auth failed
-			$identificat->addToError($LANG["login"][11]);
+			$identificat->addToError($LANG['login'][11]);
 			$identificat->auth_succeded = false;
 		} else	if ($identificat->user_present) {
 			// update user and Blank PWD to clean old database for the external auth
@@ -209,41 +212,46 @@ if (!isset ($_POST["noAUTO"]) && $auth_method=checkAlternateAuthSystems()) {
 	// GET THE IP OF THE CLIENT
 	$ip = (getenv("HTTP_X_FORWARDED_FOR") ? getenv("HTTP_X_FORWARDED_FOR") : getenv("REMOTE_ADDR"));
 
+
+	$identificat->initSession();
+
+   // Redirect management
+   $REDIRECT = "";
+   if (isset ($_POST['redirect'])&&strlen($_POST['redirect'])>0){
+      $REDIRECT = "?redirect=" .$_POST['redirect'];
+   } else if (isset ($_GET['redirect'])&&strlen($_GET['redirect'])>0){
+      $REDIRECT = "?redirect=" .$_GET['redirect'];
+   }
+
+
 	// now we can continue with the process...
 	if ($identificat->auth_succeded) {
-		$identificat->initSession();
-	} else { // we have done at least a good login? No, we exit. 
+		// Log Event
+		if (GLPI_DEMO_MODE){
+			logEvent("-1", "system", 3, "login", $_POST['login_name'] . " logged in." . $LANG['log'][40] . " : " . $ip);
+		} else {
+			logEvent("-1", "system", 3, "login", $_POST['login_name'] . " " . $LANG['log'][40] . " : " . $ip);
+		}
+		
+		// Redirect to Command Central if not post-only
+		if ($_SESSION["glpiactiveprofile"]["interface"] == "helpdesk") {
+			glpi_header($CFG_GLPI['root_doc'] . "/front/helpdesk.public.php$REDIRECT");
+		} else {
+			glpi_header($CFG_GLPI['root_doc'] . "/front/central.php$REDIRECT");
+		}
+
+	} else {
+		// we have done at least a good login? No, we exit. 
 		nullHeader("Login", $_SERVER['PHP_SELF']);
 		echo '<div align="center"><b>' . $identificat->getErr() . '</b><br><br>';
-		echo '<b><a href="' . $CFG_GLPI["root_doc"] . '/logout.php">' . $LANG["login"][1] . '</a></b></div>';
-		if ($CFG_GLPI["debug"] == DEMO_MODE){
+      // Logout whit noAUto to manage auto_login with errors
+		echo '<b><a href="' . $CFG_GLPI["root_doc"] . '/logout.php?noAUTO=1'.str_replace("?","&",$REDIRECT).'">' . $LANG['login'][1] . '</a></b></div>';
+		if (GLPI_DEMO_MODE){
 			logEvent(-1, "system", 1, "login", "failed login: " . $_POST['login_name'] . "  ($ip)");
 		} else {
-			logEvent(-1, "system", 1, "login", $LANG["log"][41] . ": " . $_POST['login_name'] . " ($ip)");
+			logEvent(-1, "system", 1, "login", $LANG['log'][41] . ": " . $_POST['login_name'] . " ($ip)");
 		}
 		nullFooter();
 		exit();
-	}
-
-	// Log Event
-	if ($CFG_GLPI["debug"] == DEMO_MODE){
-		logEvent("-1", "system", 3, "login", $_POST['login_name'] . " logged in." . $LANG["log"][40] . " : " . $ip);
-	} else {
-		logEvent("-1", "system", 3, "login", $_POST['login_name'] . " " . $LANG["log"][40] . " : " . $ip);
-	}
-
-	// Redirect management
-	$REDIRECT = "";
-	if (isset ($_POST['redirect'])&&strlen($_POST['redirect'])>0){
-		$REDIRECT = "?redirect=" .$_POST['redirect'];
-	} else 	if (isset ($_GET['redirect'])&&strlen($_GET['redirect'])>0){
-		$REDIRECT = "?redirect=" .$_GET['redirect'];
-	}
-
-	// Redirect to Command Central if not post-only
-	if ($_SESSION["glpiactiveprofile"]["interface"] == "helpdesk") {
-		glpi_header($CFG_GLPI['root_doc'] . "/front/helpdesk.public.php$REDIRECT");
-	} else {
-		glpi_header($CFG_GLPI['root_doc'] . "/front/central.php$REDIRECT");
-	}
+	} 
 ?>
