@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: logout.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: logout.php 9110 2009-10-13 19:06:50Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -46,15 +46,29 @@ if (!isset($_SESSION["noAUTO"])&&isset($_SESSION["glpiauth_method"])&&$_SESSION[
 	$cas->logout($CFG_GLPI["cas_logout"]);
 }
 
-$noAUTO="";
-if (isset($_SESSION["noAUTO"]) || isset($_GET['noAUTO'])) {
-	$noAUTO="?noAUTO=1";
+$toADD="";
+
+// Redirect management
+if (isset ($_POST['redirect'])&&strlen($_POST['redirect'])>0){
+   $toADD = "?redirect=" .$_POST['redirect'];
+} else if (isset ($_GET['redirect'])&&strlen($_GET['redirect'])>0){
+   $toADD = "?redirect=" .$_GET['redirect'];
 }
 
+if (isset($_SESSION["noAUTO"]) || isset($_GET['noAUTO'])) {
+   if (empty($toADD)){
+      $toADD.="?";
+   } else {
+      $toADD.="&";
+   }
+	$toADD.="noAUTO=1";
+}
+
+
 $id = new Identification();
 $id->destroySession();
 
 // Redirect to the login-page
 
-glpi_header($CFG_GLPI["root_doc"]."/index.php".$noAUTO);
+glpi_header($CFG_GLPI["root_doc"]."/index.php".$toADD);
 ?>
