@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: ldap_mass_sync.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: ldap_mass_sync.php 8105 2009-03-23 11:43:55Z walid $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -31,7 +31,7 @@
  */
 
 // ----------------------------------------------------------------------
-// Original Author of file: Walid Nouh (walid.nouh@atosorigin.com)
+// Original Author of file: Walid Nouh
 // Purpose of file:
 // ----------------------------------------------------------------------
 
@@ -41,8 +41,8 @@ if ($argv) {
 		//To be able to use = in search filters, enter \= instead in command line
 		//Replace the \= by ° not to match the split function
 		$arg=str_replace('\=','°',$argv[$i]);
-		$it = split("=",$arg);
-		$it[0] = eregi_replace('^--','',$it[0]);
+		$it = explode("=",$arg);
+		$it[0] = preg_replace('/^--/','',$it[0]);
 		
 		//Replace the ° by = the find the good filter 
 		$it=str_replace('°','=',$it);
@@ -56,13 +56,18 @@ $NEEDED_ITEMS = array (
 	"group",
 	"entity",
 	"rulesengine",
-	"rule.right"
+	"rule.right",
+	"setup"
 );
 
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-// Default action : synchro (1=synchro 0=import)
+// Default action : synchro 
+// - possible option :
+//   - 0 : import new users
+//	 - 1 : synchronize users
+//	 - 2 : force synchronization of all the users (even if ldap timestamp wasn't modified)
 if (!isset($_GET["action"])) $_GET["action"]=1;
 
 //If no ldap_server ID is given, then use all the available servers
