@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ocsng_mass_sync.php 7763 2009-01-06 18:44:50Z moyo $
+ * @version $Id: ocsng_mass_sync.php 7762 2009-01-06 18:30:32Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2009 by the INDEPNET Development Team.
@@ -39,8 +39,8 @@ if ($argv) {
 		//To be able to use = in search filters, enter \= instead in command line
 		//Replace the \= by ° not to match the split function
 		$arg=str_replace('\=','°',$argv[$i]);
-		$it = split("=",$arg);
-		$it[0] = eregi_replace('^--','',$it[0]);
+		$it = explode("=",$arg);
+		$it[0] = preg_replace('/^--/','',$it[0]);
 		
 		//Replace the ° by = the find the good filter 
 		$it=str_replace('°','=',$it);
